RB-SFA
======

High Harmonic Generation in the Strong Field Approximation via Mathematica

© Emilio Pisanty, 2014-2017

RB-SFA is a compact and flexible Mathematica package for calculating High Harmonic Generation emission within the Strong Field Approximation. It combines Mathematica's analytical integration capabilities with its numerical calculation capacities to offer a fast and user-friendly plug-and-play solver for calculating HHG spectra and other properties. In addition, it can calculate first-order nondipole corrections to the SFA results to evaluate the effect of the driving laser's magnetic field on harmonic spectra. There is also an experimental section for calculating spectra using quantum-orbit methods.

The name RB-SFA comes from its first application (as Rotating Bicircular High Harmonic Generation in the Strong field Approximation) but the code is general so RB-SFA just stands for itself now. The publications by the author that use this code are:


 - The imaginary part of the high-harmonic cutoff. E. Pisanty, M.F. Ciappina and M. Lewenstein. [*J. Phys: Photon.* **2** 034013 (2020)](https://dx.doi.org/10.1088/2515-7647/ab8f1e), [arXiv:2003.00277](https://arxiv.org/abs/2003.00277).
 - High harmonic interferometry of the Lorentz force in strong mid-infrared laser fields. E. Pisanty et al. [*New J. Phys.* **20** 053036 (2018)](https://dx.doi.org/10.1088/1367-2630/aabb4d), [arXiv:1606.01931](https://arxiv.org/abs/1606.01931).
 - Strong-field approximation in a rotating frame: high-order harmonic emission from p states in bicircular fields. E. Pisanty and Á. Jiménez-Galán. [*Phys. Rev. A* **96**, 063401 (2017)](https://doi.org/10.1103/PhysRevA.96.063401), [arXiv:1709.00397](https://arxiv.org/abs/1709.00397).
 - Electron dynamics in complex time and complex space. E. Pisanty Alatorre. [PhD Thesis, Imperial College London, 2016](http://hdl.handle.net/10044/1/43538).
 - Spin conservation in high-order-harmonic generation using bicircular fields. E. Pisanty, S. Sukiasyan and M. Ivanov. [*Phys. Rev. A* **90**, 043829 (2014)](http://dx.doi.org/10.1103/PhysRevA.90.043829), [arXiv:1404.6242](http://arxiv.org/abs/1404.6242).


This code is dual-licensed under the GPL and CC-BY-SA licenses; you are free to use, modify, and redistribute it, but you must abide by the terms in either of those licenses.

In addition to that legal obligation, if you use this code in calculations for an academic publication, you have an academic obligation to cite it correctly. For that purpose, please cite the PhD thesis above, or use a direct citation to the code such as

>    E. Pisanty. RB-SFA: High Harmonic Generation in the Strong Field Approximation via Mathematica. https://github.com/episanty/RB-SFA (2016).

If you wish to include a DOI in your citation, please use one of the [numbered-version releases](https://github.com/episanty/RB-SFA/releases).

This software consists of the Mathematica notebook `RB-SFA.nb`, which contains the code and its documentation, a corresponding auto-generated package file `RB-SFA.m`, which provides the package functions to other notebooks, a `Usage and Examples.nb` notebook which explains how to install and use the code, and documents the calculations used in the original publication, and a (draft) `Quantum Orbits Usage.nb` notebook documenting the use of the quantum-orbit functionality. PDF printouts of all notebooks are also provided. 





