Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["RB-SFA: High Harmonic Generation in the Strong Field Approximation \
via ",
  FontSize->24],
 StyleBox["Mathematica",
  FontSize->24,
  FontSlant->"Italic"]
}], "Title",ExpressionUUID->"4f97aa06-5237-417d-a3de-abc5fa8e4b58"],

Cell["\[Copyright] Emilio Pisanty 2014-2020. Licensed under GPL and \
CC-BY-SA.", "Text",ExpressionUUID->"e4423e52-691d-4b3a-910a-227a5f4c9d8a"],

Cell[CellGroupData[{

Cell["Introduction", "Subchapter",
 CellTags->
  "Introduction",ExpressionUUID->"c6192770-807e-4c6d-bd69-7a28378f3924"],

Cell[CellGroupData[{

Cell["Readme", \
"Subsection",ExpressionUUID->"f6463701-603f-47b6-b7bc-2cff5fb56a45"],

Cell[CellGroupData[{

Cell[TextData[{
 "RB-SFA is a compact and flexible Mathematica package for calculating High \
Harmonic Generation emission within the Strong Field Approximation. It \
combines Mathematica\[CloseCurlyQuote]s analytical integration capabilities \
with its numerical calculation capacities to offer a fast and user-friendly \
plug-and-play solver for calculating HHG spectra and other properties. In \
addition, it can calculate first-order nondipole corrections to the SFA \
results to evaluate the effect of the driving laser\[CloseCurlyQuote]s \
magnetic field on harmonic spectra. There is also an experimental section for \
calculating spectra using quantum-orbit methods.\n\nThe name RB-SFA comes \
from its first application (as Rotating Bicircular High Harmonic Generation \
in the Strong field Approximation) but the code is general so RB-SFA just \
stands for itself now. The publications by the author that use this code are:\
\n\n \[Bullet] The imaginary part of the high-harmonic cutoff. E. Pisanty, \
M.F. Ciappina and M. Lewenstein. ",
 StyleBox[ButtonBox["J. Phys: Photon.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/2515-7647/ab8f1e"], None},
  ButtonNote->"https://doi.org/10.1088/2515-7647/ab8f1e"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/2515-7647/ab8f1e"], None},
  ButtonNote->"https://doi.org/10.1088/2515-7647/ab8f1e"],
 StyleBox[ButtonBox["2",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/2515-7647/ab8f1e"], None},
  ButtonNote->"https://doi.org/10.1088/2515-7647/ab8f1e"],
  FontWeight->"Bold"],
 ButtonBox[" 034013 (2020)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/2515-7647/ab8f1e"], None},
  ButtonNote->"https://doi.org/10.1088/2515-7647/ab8f1e"],
 ", ",
 ButtonBox["arXiv:2003.00277",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/2003.00277"], None},
  ButtonNote->"https://arxiv.org/abs/2003.00277"],
 ".\n \[Bullet] High harmonic interferometry of the Lorentz force in strong \
mid-infrared laser fields. E. Pisanty et al. ",
 StyleBox[ButtonBox["New J. Phys.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/1367-2630/aabb4d"], None},
  ButtonNote->"https://doi.org/10.1088/1367-2630/aabb4d"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/1367-2630/aabb4d"], None},
  ButtonNote->"https://doi.org/10.1088/1367-2630/aabb4d"],
 StyleBox[ButtonBox["20",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/1367-2630/aabb4d"], None},
  ButtonNote->"https://doi.org/10.1088/1367-2630/aabb4d"],
  FontWeight->"Bold"],
 ButtonBox[" 053036 (2018)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/1367-2630/aabb4d"], None},
  ButtonNote->"https://doi.org/10.1088/1367-2630/aabb4d"],
 ", ",
 ButtonBox["arXiv:1606.01931",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1606.01931"], None},
  ButtonNote->"https://arxiv.org/abs/1606.01931"],
 ".\n \[Bullet] Strong-field approximation in a rotating frame: high-order \
harmonic emission from p states in bicircular fields. E. Pisanty and \
\[CapitalAAcute]. Jim\[EAcute]nez-Gal\[AAcute]n. ",
 StyleBox[ButtonBox["Phys. Rev. A",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1103/PhysRevA.96.063401\n\n"], None},
  ButtonNote->"https://doi.org/10.1103/PhysRevA.96.063401\n\n"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1103/PhysRevA.96.063401\n\n"], None},
  ButtonNote->"https://doi.org/10.1103/PhysRevA.96.063401\n\n"],
 StyleBox[ButtonBox["96",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1103/PhysRevA.96.063401\n\n"], None},
  ButtonNote->"https://doi.org/10.1103/PhysRevA.96.063401\n\n"],
  FontWeight->"Bold"],
 ButtonBox[" 063401 (2017)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1103/PhysRevA.96.063401\n\n"], None},
  ButtonNote->"https://doi.org/10.1103/PhysRevA.96.063401\n\n"],
 ", ",
 ButtonBox["arXiv:1709.00397",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://arxiv.org/abs/1709.00397"], None},
  ButtonNote->"https://arxiv.org/abs/1709.00397"],
 ".\n \[Bullet] Electron dynamics in complex time and complex space. E. \
Pisanty Alatorre. ",
 ButtonBox["PhD Thesis, Imperial College London, 2016",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://hdl.handle.net/10044/1/43538"], None},
  ButtonNote->"http://hdl.handle.net/10044/1/43538"],
 ".\n \[Bullet] Spin conservation in high-order-harmonic generation using \
bicircular fields. E. Pisanty, S. Sukiasyan and M. Ivanov. ",
 StyleBox[ButtonBox["Phys. Rev. A",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
 StyleBox[ButtonBox["90",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
  FontWeight->"Bold"],
 ButtonBox[", 043829 (2014)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
 ", ",
 ButtonBox["arXiv:1404.6242",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://arxiv.org/abs/1404.6242"], None},
  ButtonNote->"http://arxiv.org/abs/1404.6242"],
 ".\n \nThis code is dual-licensed under the GPL and CC-BY-SA licenses; you \
are free to use, modify, and redistribute it, but you must abide by the terms \
in either of those licenses.\n\nIn addition to that ",
 StyleBox["legal",
  FontSlant->"Italic"],
 " obligation, if you use this code in calculations for an academic \
publication, you have an ",
 StyleBox["academic",
  FontSlant->"Italic"],
 " obligation to cite it correctly. For that purpose, please cite the PhD \
thesis above, or use a direct citation to the code such as\n\n    E. Pisanty. \
RB-SFA: High Harmonic Generation in the Strong Field Approximation via ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". ",
 ButtonBox["https://github.com/episanty/RB-SFA",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://github.com/episanty/RB-SFA"], None},
  ButtonNote->"https://github.com/episanty/RB-SFA"],
 " (2020).\n    \nIf you wish to include a DOI in your citation, please use \
one of the ",
 ButtonBox["numbered-version releases",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://github.com/episanty/RB-SFA/releases"], None},
  ButtonNote->"https://github.com/episanty/RB-SFA/releases"],
 ".\n\nThis software consists of the Mathematica notebook `RB-SFA.nb`, which \
contains the code and its documentation, a corresponding auto-generated \
package file `RB-SFA.m`, which provides the package functions to other \
notebooks, a `Usage and Examples.nb` notebook which explains how to install \
and use the code, and documents the calculations used in the original \
publication, and a (draft) `Quantum Orbits Usage.nb` notebook documenting the \
use of the quantum-orbit functionality. PDF printouts of all notebooks are \
also provided."
}], "Text",
 CellGroupingRules->{
  GroupTogetherGrouping, 
   10000.},ExpressionUUID->"6ac175a7-f178-4dfe-9bdc-458722381b12"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"This", " ", "is", " ", "the", " ", "RB"}], "-", 
    RowBox[{
    "SFA", " ", "package", " ", "for", " ", "calculating", " ", "high"}], "-", 
    RowBox[{
    "order", " ", "harmonic", " ", "generation", " ", "within", " ", "the", 
     " ", "Strong", " ", "Field", " ", 
     RowBox[{"Approximation", ".", " ", "For"}], " ", "the", " ", "notebook", 
     " ", "that", " ", "generated", " ", "this", " ", "package", " ", "file", 
     " ", "and", " ", "additional", " ", "documentaion"}]}], ",", " ", 
   RowBox[{
    RowBox[{"see", " ", 
     RowBox[{"https", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"github", ".", "com"}], "/", "episanty"}], "/", "RB"}], "-", 
     RowBox[{"SFA", "."}]}]}]}], "\[IndentingNewLine]", "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->
  True,ExpressionUUID->"82d38177-9df9-4b82-9d60-a29240b5c273"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", \
"Subchapter",ExpressionUUID->"92eba27c-32a2-4778-b937-12004504f118"],

Cell[CellGroupData[{

Cell["Supporting functions", \
"Section",ExpressionUUID->"63ce1fac-976b-4ffb-9096-45068b912d68"],

Cell[CellGroupData[{

Cell["Initialization", \
"Subsection",ExpressionUUID->"5aeda15b-76fe-4aed-a4a6-75764c3d3231"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BeginPackage", "[", "\"\<RBSFA`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"d8194a12-20ba-4527-9da4-5c21f77858c8"],

Cell[CellGroupData[{

Cell["Version number", "Subsubsection",
 CellTags->
  "version-section",ExpressionUUID->"4a58faea-5e89-4a18-8638-f58dbf15ff2e"],

Cell["\<\
The command RBSFAversion prints the version of the RB-SFA package currently \
loaded and its timestamp\
\>", "Text",ExpressionUUID->"3cc4e9c7-4560-4484-b6a1-3feb4291ed7c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"$RBSFAversion", "::", "usage"}], "=", 
   "\"\<$RBSFAversion prints the current version of the RB-SFA package in use \
and its timestamp.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"$RBSFAtimestamp", "::", "usage"}], "=", 
   "\"\<$RBSFAtimestamp prints the timestamp of the current version of the \
RB-SFA package.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$RBSFAversion", ":=", 
   RowBox[{"\"\<RB-SFA v2.2.2, \>\"", "<>", "$RBSFAtimestamp"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"aa97ee0f-f35a-441d-9482-ce45b1a816f6"],

Cell[TextData[{
 "Old syntax (in functional form ",
 StyleBox["RBSFAversion[]", "Code"],
 "), deprecated"
}], "Text",ExpressionUUID->"3487794f-0ec6-4e71-9c07-3446d161e0a5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"RBSFAversion", "::", "usage"}], "=", 
   "\"\<RBSFAversion[] has been deprecated in favour of $RBSFAversion.\>\""}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RBSFAversion", "::", "dprc"}], "=", 
   "\"\<RBSFAversion[] has been deprecated in favour of $RBSFAversion.\>\""}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RBSFAversion", "[", "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Message", "[", 
      RowBox[{"RBSFAversion", "::", "dprc"}], "]"}], ";", "$RBSFAversion"}], 
    ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"32505096-dec4-4a2e-820c-3889286e3339"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], \
"Input",ExpressionUUID->"2f40f4dd-5630-46c8-a89d-7ff471ed3995"],

Cell["\<\
The timestamp is updated every time the notebook is saved via an appropriate \
notebook option, which is set by the code below.\
\>", "Text",ExpressionUUID->"887427dc-d969-4eef-9ca3-6df9cab14874"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EvaluationNotebook", "[", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"NotebookEventActions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<MenuCommand\>\"", ",", "\"\<Save\>\""}], "}"}], 
        "\[RuleDelayed]", 
        RowBox[{"(", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"NotebookWrite", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Cells", "[", 
              RowBox[{"CellTags", "\[Rule]", "\"\<version-timestamp\>\""}], 
              "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"Cell", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"BoxData", "[", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<Begin[\\\"`Private`\\\"];\\n$RBSFAtimestamp=\\\"\>\"", "<>", 
                  RowBox[{"DateString", "[", "]"}], "<>", 
                  "\"\<\\\";\\nEnd[];\>\""}], "}"}], "]"}], "]"}], 
              "\[IndentingNewLine]", ",", "\"\<Input\>\"", ",", 
              RowBox[{"InitializationCell", "\[Rule]", "True"}], ",", 
              RowBox[{"CellTags", "\[Rule]", "\"\<version-timestamp\>\""}]}], 
             "\[IndentingNewLine]", "]"}], ",", "None", ",", 
            RowBox[{"AutoScroll", "\[Rule]", "False"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"NotebookSave", "[", "]"}]}], "\[IndentingNewLine]", 
         ")"}]}], ",", 
       RowBox[{"PassEventsDown", "\[Rule]", "True"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input",ExpressionUUID->"9fc2d5fa-1617-4717-8d93-fc3b81379664"],

Cell["To reset this behaviour to normal, evaluate the cell below", \
"Text",ExpressionUUID->"bc795509-3913-49b6-84f3-de50f36f2b1a"],

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{
   RowBox[{"EvaluationNotebook", "[", "]"}], ",", 
   RowBox[{"NotebookEventActions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<MenuCommand\>\"", ",", "\"\<Save\>\""}], "}"}], 
       "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{"NotebookSave", "[", "]"}], ")"}]}], ",", 
      RowBox[{"PassEventsDown", "\[Rule]", "True"}]}], "}"}]}]}], 
  "]"}]], "Input",ExpressionUUID->"45760a97-ec43-42f5-a401-6d3b7f33f832"]
}, Closed]],

Cell[CellGroupData[{

Cell["Timestamp", \
"Subsubsection",ExpressionUUID->"2ac2d3ad-8207-436c-afb8-bc0ae16d4c35"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"$RBSFAtimestamp", "=", "\"\<Mon 21 Sep 2020 18:05:26\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellTags->
  "version-timestamp",ExpressionUUID->"c84fb08a-9548-44ca-93bc-bc3e14ce0924"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Directory", \
"Subsubsection",ExpressionUUID->"d265a8f6-abd3-4556-b1e7-2a394098c33f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$RBSFAdirectory", "::", "usage"}], "=", 
   "\"\<$RBSFAdirectory is the directory where the current RB-SFA package \
instance is located.\>\""}], ";"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"c87f6883-8e5e-4a34-a1b9-2f3cdfa24230"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"softLinkTestString", "=", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"StringJoin", "[", 
         RowBox[{"ReadList", "[", 
          RowBox[{
           RowBox[{"\"\<! ls -la \>\"", "<>", 
            RowBox[{"StringReplace", "[", 
             RowBox[{"$InputFileName", ",", 
              RowBox[{"{", 
               RowBox[{"\"\< \>\"", "\[Rule]", "\"\<\\\\ \>\""}], "}"}]}], 
             "]"}]}], ",", "String"}], "]"}], "]"}], ",", "\"\< -> \>\""}], 
       "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Length", "[", "softLinkTestString", "]"}], ">", "1"}], ",", 
      RowBox[{"(*", 
       RowBox[{
       "Testing", " ", "in", " ", "case", " ", "$InputFileName", " ", "is", 
        " ", "a", " ", "soft", " ", "link", " ", "to", " ", "the", " ", 
        "actual", " ", 
        RowBox[{"directory", "."}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"$RBSFAdirectory", "=", 
       RowBox[{"StringReplace", "[", 
        RowBox[{
         RowBox[{"DirectoryName", "[", 
          RowBox[{
          "softLinkTestString", "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\< \>\"", "\[Rule]", "\"\<\\\\ \>\""}], "}"}]}], "]"}]}],
       ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"$RBSFAdirectory", "=", 
        RowBox[{"StringReplace", "[", 
         RowBox[{
          RowBox[{"DirectoryName", "[", "$InputFileName", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\"\< \>\"", "\[Rule]", "\"\<\\\\ \>\""}], "}"}]}], 
         "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"f4003c50-c4bf-43a7-96de-6f1292ddff7e"]
}, Closed]],

Cell[CellGroupData[{

Cell["Git commit hash and message", \
"Subsubsection",ExpressionUUID->"b01571eb-22a0-4ae9-bcdf-68217bd8bd00"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"$RBSFAcommit", "::", "usage"}], "=", 
   "\"\<$RBSFAcommit returns the git commit log at the location of the RB-SFA \
package if there is one.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"$RBSFAcommit", "::", "OS"}], "=", 
   "\"\<$RBSFAcommit has only been tested on Linux.\>\""}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"fce25619-8923-4995-9cae-ebb712b0cd01"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$RBSFAcommit", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"$OperatingSystem", "\[NotEqual]", "\"\<Unix\>\""}], ",", 
       RowBox[{"Message", "[", 
        RowBox[{"$RBSFAcommit", "::", "OS"}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"StringJoin", "[", 
      RowBox[{"Riffle", "[", 
       RowBox[{
        RowBox[{"ReadList", "[", 
         RowBox[{
          RowBox[{
          "\"\<!cd \>\"", "<>", "$RBSFAdirectory", "<>", 
           "\"\< && git log -1\>\""}], ",", "String"}], "]"}], ",", 
        RowBox[{"{", "\"\<\\n\>\"", "}"}]}], "]"}], "]"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"56b69d2c-3f13-4848-bcc7-6db05f85bf58"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Standard function (re)definitions", \
"Subsection",ExpressionUUID->"ce066b21-33f3-4900-bb2d-ab254654ae24"],

Cell[CellGroupData[{

Cell["ConstantArray", \
"Subsubsection",ExpressionUUID->"0fbe8538-f395-4838-aff7-9b2435bf6e5e"],

Cell[TextData[{
 "This redefines ConstantArray to take the corner case of an empty dimensions \
list, which returns an error code (and an unevaluated ",
 StyleBox["ConstantArray", "Code"],
 ") for Mathematica versions under 10.1.0 (cf. mma.se/q/133078)."
}], "Text",ExpressionUUID->"d68e6855-0b8b-46e3-808e-d6b3f085b500"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Quiet", "[", 
   RowBox[{"Check", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", "}"}]}], "]"}], ";"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "ConstantArray", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ConstantArray", "[", 
        RowBox[{"Private`x_", ",", 
         RowBox[{"{", "}"}]}], "]"}], ":=", "Private`x"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Protect", "[", "ConstantArray", "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}], "]"}], ";"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"b17f45d8-f79e-44fb-962a-3150163e90ce"],

Cell["\<\

Similarly, this needs to be put inside an initialization code for any \
parallelized subkernels that may get launched later (cf. mm.se/q/131856).\
\>", "Text",ExpressionUUID->"7bc1c475-9ad0-40cc-beff-3e7d23aa1664"],

Cell[BoxData[{
 RowBox[{"Parallelize", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Parallel`Developer`$InitCode", "=", 
   RowBox[{"Hold", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Quiet", "[", 
      RowBox[{"Check", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"ConstantArray", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "}"}]}], "]"}], ";"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Unprotect", "[", "ConstantArray", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"ConstantArray", "[", 
           RowBox[{"Private`x_", ",", 
            RowBox[{"{", "}"}]}], "]"}], ":=", "Private`x"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Protect", "[", "ConstantArray", "]"}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"e564a731-456d-4803-96b2-4131cc9c0e13"]
}, Closed]],

Cell[CellGroupData[{

Cell["ReIm", \
"Subsubsection",ExpressionUUID->"1a5531fe-3d9a-459d-816d-ea974534c8ef"],

Cell["\<\
This adds the definition of ReIm for those versions (<10.1) that don\
\[CloseCurlyQuote]t have it.\
\>", "Text",ExpressionUUID->"04242243-db68-411f-b1c0-cdd55e025b4d"],

Cell[BoxData[
 RowBox[{"If", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "ReIm", "]"}], "=!=", "\"\<System`\>\""}], "&&", 
    RowBox[{
     RowBox[{"Attributes", "[", "ReIm", "]"}], "\[Equal]", 
     RowBox[{"{", "}"}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ReIm", "::", "usage"}], "=", 
     "\"\<\\!\\(\\*RowBox[{\\\"ReIm\\\", \\\"[\\\", StyleBox[\\\"z\\\", \
\\\"TI\\\"], \\\"]\\\"}]\\) gives the list \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"Re\\\", \\\"[\\\", StyleBox[\\\"z\\\", \\\"TI\\\"], \\\"]\
\\\"}], \\\",\\\", RowBox[{\\\"Im\\\", \\\"[\\\", StyleBox[\\\"z\\\", \
\\\"TI\\\"], \\\"]\\\"}]}], \\\"}\\\"}]\\) of the number \\!\\(\\*StyleBox[\\\
\"z\\\", \\\"TI\\\"]\\).\>\""}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ReIm", "[", "Private`z_", "]"}], ":=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Re", "[", "Private`z", "]"}], ",", 
       RowBox[{"Im", "[", "Private`z", "]"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"SetAttributes", "[", 
     RowBox[{"ReIm", ",", "Listable"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Protect", "[", "ReIm", "]"}], ";"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"210258ce-70de-4ba9-87ee-9923aa5119df"]
}, Closed]],

Cell[CellGroupData[{

Cell["AssociationTranspose", \
"Subsubsection",ExpressionUUID->"208a7ce2-9e90-4e8e-9c06-77b1c2566673"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "AssociationTranspose", 
  "]"}]], "Input",ExpressionUUID->"9e2f0aa2-fc3a-4e77-ad03-e2aa60b219f6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"AssociationTranspose", "::", "usage"}], "=", 
   "\"\<AssociationTranspose[association] transposes the given two-level \
association of associations.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AssociationTranspose", "::", "wrngshp"}], "=", 
   "\"\<Input `1` is the wrong shape; it must be an association all of whose \
Values are valid associations.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AssociationTranspose", "[", 
    RowBox[{"association_", "?", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"And", "@@", 
        RowBox[{"(", 
         RowBox[{"AssociationQ", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", "#", "}"}], ",", 
            RowBox[{"Values", "[", "#", "]"}]}], "]"}]}], ")"}]}], "&"}], 
      "\[IndentingNewLine]", ")"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"GroupBy", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Join", "@@", 
       RowBox[{"Thread", "/@", 
        RowBox[{"Normal", "//@", "association"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"First", "@*", "Last"}], ",", "First"}], "}"}]}], 
     "\[IndentingNewLine]", "]"}], "\[LeftDoubleBracket]", 
    RowBox[{"All", ",", "All", ",", "1", ",", "2", ",", "2"}], 
    "\[RightDoubleBracket]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AssociationTranspose", "[", "association__", "]"}], ":=", 
  RowBox[{"\"\<Doesn't display; cf. mm.se/q/29321 for details\>\"", "/;", 
   RowBox[{"Message", "[", 
    RowBox[{
     RowBox[{"AssociationTranspose", "::", "wrngshp"}], ",", "association"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"6490e2f6-e54f-43dc-8bb2-c5241010d578"],

Cell[TextData[{
 "The above function is taken from \
http://mathematica.stackexchange.com/a/86526 by \
http://mathematica.stackexchange.com/users/121/mr-wizard. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 10.1 and higher, it can be replaced by a ",
 StyleBox["Query[Transpose]", "Code"],
 " construct as below, but ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 10.0, despite having most of the ",
 StyleBox["Association", "Code"],
 " code, is unable to transpose ragged associations using that construct."
}], "Text",ExpressionUUID->"d6113208-53f6-48c6-928b-0621c5338097"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"AssociationTranspose", "[", "association_", "]"}], ":=", 
   RowBox[{"DeleteMissing", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Query", "[", "Transpose", "]"}], "[", "\[IndentingNewLine]", 
      "association", "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",",
      "2"}], "]"}]}], "\[IndentingNewLine]", 
  "*)"}]], "Input",ExpressionUUID->"70d1b7ab-2296-449a-8ada-60400a7b1fc0"]
}, Closed]],

Cell[CellGroupData[{

Cell["KeyValueMap", \
"Subsubsection",ExpressionUUID->"ab7eca39-9550-49ae-9232-9423e5ae9945"],

Cell[TextData[{
 "This exists in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 10.1 and later, but it\[CloseCurlyQuote]s nice to have it on version 10.0 \
so this is a back-port for versions that do not have it."
}], "Text",ExpressionUUID->"29f477f2-e73c-4ff1-8b59-eedde10a6d78"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$VersionNumber", "<", "10.1"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"KeyValueMap", "::", "usage"}], "=", 
      "\"\<\\!\\(\\*RowBox[{\\\"KeyValueMap\\\", \\\"[\\\", RowBox[{StyleBox[\
\\\"f\\\",\\\"TI\\\"], \\\",\\\", \
RowBox[{\\\"\[LeftAssociation]\\\",RowBox[{RowBox[{SubscriptBox[StyleBox[\\\"\
key\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\"\[Rule]\\\", \
SubscriptBox[StyleBox[\\\"val\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]]}], \\\",\\\", RowBox[{SubscriptBox[StyleBox[\\\"key\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\"\[Rule]\\\", \
SubscriptBox[StyleBox[\\\"val\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]]}], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"\
\[RightAssociation]\\\"}]}], \\\"]\\\"}]\\) gives the list \
\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{StyleBox[\\\"f\\\", \\\"TI\\\"], \
\\\"[\\\", RowBox[{SubscriptBox[StyleBox[\\\"key\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"val\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]]}], \\\"]\\\"}], \\\",\\\", RowBox[{StyleBox[\\\"f\\\", \
\\\"TI\\\"], \\\"[\\\", RowBox[{SubscriptBox[StyleBox[\\\"key\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"val\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]]}], \\\"]\\\"}], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \
\\\"TR\\\"]}], \\\"}\\\"}]\\). (Note: function backported from v10.1+.)\n\n\
\\!\\(\\*RowBox[{\\\"KeyValueMap\\\", \\\"[\\\", StyleBox[\\\"f\\\", \\\"TI\\\
\"], \\\"]\\\"}]\\) represents an operator form of KeyValueMap that can be \
applied to an expression.\>\""}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"KeyValueMap", "::", "invak"}], "=", 
      "\"\<The argument `1` is not a valid association\>\""}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"$VersionNumber", "<", "10.1"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"KeyValueMap", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"assoc_", "?", "AssociationQ"}]}], "]"}], ":=", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{"Apply", "[", "f", "]"}], ",", 
       RowBox[{"Normal", "[", "assoc", "]"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"KeyValueMap", "[", "f_", "]"}], "[", 
      RowBox[{"assoc_", "?", "AssociationQ"}], "]"}], ":=", 
     RowBox[{"KeyValueMap", "[", 
      RowBox[{"f", ",", "assoc"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"KeyValueMap", "[", 
      RowBox[{"f_", ",", "assoc__"}], "]"}], ":=", 
     RowBox[{"\"\<Doesn't display; cf. mm.se/q/29321 for details\>\"", "/;", 
      RowBox[{"Message", "[", 
       RowBox[{
        RowBox[{"KeyValueMap", "::", "invak"}], ",", "assoc"}], "]"}]}]}], 
    ";"}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"0f95b62d-806b-4d6d-aa99-eaf16d190717"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dipole transition matrix elements", \
"Subsection",ExpressionUUID->"cf55b015-5325-4f17-b7a4-e9def4bc2b0f"],

Cell[CellGroupData[{

Cell["Default DTME, for a hydrogenic 1s state", \
"Subsubsection",ExpressionUUID->"02e56c3a-1a35-447c-bee9-65d2fbc491d8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenicDTME", "::", "usage"}], "=", 
   "\"\<hydrogenicDTME[p,\[Kappa]] returns the dipole transition matrix \
element for a 1s hydrogenic state of ionization potential \!\(\*SubscriptBox[\
\(I\), \(p\)]\)=\!\(\*FractionBox[\(1\), \(2\)]\)\!\(\*SuperscriptBox[\(\
\[Kappa]\), \(2\)]\).\n\nhydrogenicDTME[p,\[Kappa],{n,l,m}] returns the \
dipole transition matrix element for an n,l,m hydrogenic state of \
ground-state ionization potential \!\(\*SubscriptBox[\(I\), \
\(p\)]\)=\!\(\*FractionBox[\(1\), \(2\)]\)\!\(\*SuperscriptBox[\(\[Kappa]\), \
\(2\)]\).\n\nhydrogenicDTME[p,\[Kappa],n,l,m] returns the dipole transition \
matrix element for an n,l,m hydrogenic state of ground-state ionization \
potential \!\(\*SubscriptBox[\(I\), \(p\)]\)=\!\(\*FractionBox[\(1\), \
\(2\)]\)\!\(\*SuperscriptBox[\(\[Kappa]\), \(2\)]\).\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenicDTMERegularized", "::", "usage"}], "=", 
   "\"\<hydrogenicDTMERegularized[p,\[Kappa]] returns the dipole transition \
matrix element for a 1s hydrogenic state of ionization potential \
\!\(\*SubscriptBox[\(I\), \(p\)]\)=\!\(\*FractionBox[\(1\), \
\(2\)]\)\!\(\*SuperscriptBox[\(\[Kappa]\), \(2\)]\), regularized to remove \
the denominator of 1/(\!\(\*SuperscriptBox[\(p\), \
\(2\)]\)+\!\(\*SuperscriptBox[\(\[Kappa]\), \
\(2\)]\)\!\(\*SuperscriptBox[\()\), \(3\)]\), where the saddle-point \
solutions are singular.\n\nhydrogenicDTMERegularized[p,\[Kappa],{n,l,m}] \
returns the dipole transition matrix element for an n,l,m hydrogenic state of \
ground-state ionization potential \!\(\*SubscriptBox[\(I\), \
\(p\)]\)=\!\(\*FractionBox[\(1\), \(2\)]\)\!\(\*SuperscriptBox[\(\[Kappa]\), \
\(2\)]\), regularized to remove factors of (\!\(\*SuperscriptBox[\(p\), \
\(2\)]\)+\!\(\*SuperscriptBox[\(\[Kappa]\), \(2\)]\)) from the denominator.\n\
\nhydrogenicDTMERegularized[p,\[Kappa],n,l,m] returns the dipole transition \
matrix element for an n,l,m hydrogenic state of ground-state ionization \
potential \!\(\*SubscriptBox[\(I\), \(p\)]\)=\!\(\*FractionBox[\(1\), \
\(2\)]\)\!\(\*SuperscriptBox[\(\[Kappa]\), \(2\)]\), regularized to remove \
factors of (\!\(\*SuperscriptBox[\(p\), \(2\)]\)+\!\(\*SuperscriptBox[\(\
\[Kappa]\), \(2\)]\)) from the denominator.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hydrogenicDTME", "[", 
   RowBox[{"p_List", ",", "\[Kappa]_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"8", "\[ImaginaryI]"}], "\[Pi]"], 
   FractionBox[
    RowBox[{
     SqrtBox[
      RowBox[{"2", 
       SuperscriptBox["\[Kappa]", "5"]}]], "p"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Total", "[", 
        SuperscriptBox["p", "2"], "]"}], "+", 
       SuperscriptBox["\[Kappa]", "2"]}], ")"}], 
     "3"]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hydrogenicDTME", "[", 
   RowBox[{
    RowBox[{"p_", "?", "NumberQ"}], ",", "\[Kappa]_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"8", "\[ImaginaryI]"}], "\[Pi]"], 
   FractionBox[
    RowBox[{
     SqrtBox[
      RowBox[{"2", 
       SuperscriptBox["\[Kappa]", "5"]}]], "p"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p", "2"], "+", 
       SuperscriptBox["\[Kappa]", "2"]}], ")"}], 
     "3"]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hydrogenicDTMERegularized", "[", 
   RowBox[{"p_List", ",", "\[Kappa]_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"8", "\[ImaginaryI]"}], "\[Pi]"], 
   FractionBox[
    RowBox[{
     SqrtBox[
      RowBox[{"2", 
       SuperscriptBox["\[Kappa]", "5"]}]], "p"}], 
    "1"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hydrogenicDTMERegularized", "[", 
   RowBox[{
    RowBox[{"p_", "?", "NumberQ"}], ",", "\[Kappa]_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"8", "\[ImaginaryI]"}], "\[Pi]"], 
   FractionBox[
    RowBox[{
     SqrtBox[
      RowBox[{"2", 
       SuperscriptBox["\[Kappa]", "5"]}]], "p"}], 
    "1"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"1c6ff3c7-04d2-4a4c-80e7-6f6bf03987af"]
}, Closed]],

Cell[CellGroupData[{

Cell["For a gaussian orbital", \
"Subsubsection",ExpressionUUID->"32c383cd-d2a1-45ec-b07f-65b4a05e01a8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gaussianDTME", "::", "usage"}], "=", 
   "\"\<gaussianDTME[p,\[Kappa]] returns the dipole transition matrix element \
for a gaussian state of characteristic size 1/\[Kappa].\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gaussianDTME", "[", 
   RowBox[{"p_List", ",", "\[Kappa]_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"4", "\[Pi]"}], ")"}], 
    RowBox[{"3", "/", "4"}]], 
   SuperscriptBox["\[Kappa]", 
    RowBox[{
     RowBox[{"-", "7"}], "/", "2"}]], "p", " ", 
   RowBox[{"Exp", "[", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Total", "[", 
       SuperscriptBox["p", "2"], "]"}], 
      RowBox[{"2", 
       SuperscriptBox["\[Kappa]", "2"]}]]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gaussianDTME", "[", 
   RowBox[{
    RowBox[{"p_", "?", "NumberQ"}], ",", "\[Kappa]_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"4", "\[Pi]"}], ")"}], 
    RowBox[{"3", "/", "4"}]], 
   SuperscriptBox["\[Kappa]", 
    RowBox[{
     RowBox[{"-", "7"}], "/", "2"}]], "p", " ", 
   RowBox[{"Exp", "[", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["p", "2"], 
      RowBox[{"2", 
       SuperscriptBox["\[Kappa]", "2"]}]]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"4fa8291a-2597-4d66-9ed8-83e16fd1d61f"]
}, Closed]],

Cell[CellGroupData[{

Cell["SolidHarmonicS", \
"Subsubsection",ExpressionUUID->"11cf6846-b923-4326-9a63-3e6114b9522d"],

Cell[TextData[{
 "This function implements the solid harmonic ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["S", 
      RowBox[{"l", ",", "m"}]], "(", 
     StyleBox["r",
      FontWeight->"Bold"], ")"}], "=", 
    RowBox[{
     SuperscriptBox["r", "l"], 
     RowBox[{
      SubscriptBox["Y", 
       RowBox[{"l", ",", "m"}]], "(", 
      RowBox[{"\[Theta]", ",", "\[Phi]"}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"d724b05e-afb4-4bfb-a94c-79b15bd4b303"],
 ", which is a homogeneous polynomial of degree ",
 Cell[BoxData[
  FormBox["l", TraditionalForm]],ExpressionUUID->
  "d688b867-df12-4d40-9be3-38f82741320c"],
 ", and lends itself much better to symbolic differentiation than explicit \
spherical harmonics.\n\nCode provided by J.M. at \
http://mathematica.stackexchange.com/a/124336/1000 under the WTFPL."
}], "Text",ExpressionUUID->"e0eac970-28af-43dd-861f-525fbdd9f248"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SolidHarmonicS", "::", "usage"}], "=", 
   "\"\<SolidHarmonicS[l,m,x,y,z] calculates the solid harmonic \
\!\(\*SubscriptBox[\(S\), \(lm\)]\)(x,y,z)=\!\(\*SuperscriptBox[\(r\), \(l\)]\
\)\!\(\*SubscriptBox[\(Y\), \(lm\)]\)(x,y,z).\n\nSolidHarmonicS[l,m,{x,y,z}] \
does the same.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SolidHarmonicS", "[", 
    RowBox[{
    "\[Lambda]_Integer", ",", "\[Mu]_Integer", ",", "x_", ",", "y_", ",", 
     "z_"}], "]"}], "/;", 
   RowBox[{"\[Lambda]", "\[GreaterEqual]", 
    RowBox[{"Abs", "[", "\[Mu]", "]"}]}]}], ":=", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", "\[Lambda]"}], "+", "1"}], 
     RowBox[{"4", " ", "\[Pi]"}]], "]"}], " ", 
   RowBox[{"Sqrt", "[", 
    FractionBox[
     RowBox[{"Gamma", "[", 
      RowBox[{"\[Lambda]", "-", 
       RowBox[{"Abs", "[", "\[Mu]", "]"}], "+", "1"}], "]"}], 
     RowBox[{"Gamma", "[", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"Abs", "[", "\[Mu]", "]"}], "+", "1"}], "]"}]], "]"}], " ", 
   SuperscriptBox["2", 
    RowBox[{"-", "\[Lambda]"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Mu]", "-", 
       RowBox[{"Abs", "[", "\[Mu]", "]"}]}], ")"}], "/", "2"}]], "\[Times]", 
   "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Rationalize", "[", "\[Mu]", "]"}], "\[Equal]", "0"}], ",", "1",
      ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{
         RowBox[{"Sign", "[", "\[Mu]", "]"}], "\[ImaginaryI]", " ", "y"}]}], 
       ")"}], 
      RowBox[{"Abs", "[", "\[Mu]", "]"}]]}], "]"}], "\[Times]", 
   "\[IndentingNewLine]", 
   RowBox[{"Sum", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"\[Mu]", "+", "k"}]], " ", 
      RowBox[{"Binomial", "[", 
       RowBox[{"\[Lambda]", ",", "k"}], "]"}], " ", 
      RowBox[{"Binomial", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", "\[Lambda]"}], "-", 
         RowBox[{"2", " ", "k"}]}], ",", "\[Lambda]"}], "]"}], " ", 
      RowBox[{"Pochhammer", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", "-", 
         RowBox[{"Abs", "[", "\[Mu]", "]"}], "-", 
         RowBox[{"2", " ", "k"}], "+", "1"}], ",", 
        RowBox[{"Abs", "[", "\[Mu]", "]"}]}], "]"}], " ", "\[Times]", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"TrueQ", "[", 
         RowBox[{
          RowBox[{"Pochhammer", "[", 
           RowBox[{
            RowBox[{"\[Lambda]", "-", 
             RowBox[{"Abs", "[", "\[Mu]", "]"}], "-", 
             RowBox[{"2", " ", "k"}], "+", "1"}], ",", 
            RowBox[{"Abs", "[", "\[Mu]", "]"}]}], "]"}], "\[Equal]", "0"}], 
         "]"}], ",", "1", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Rationalize", "[", "k", "]"}], "\[Equal]", "0"}], ",", 
           "1", ",", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"], "+", 
              SuperscriptBox["z", "2"]}], ")"}], "k"]}], "]"}], 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Rationalize", "[", 
             RowBox[{"\[Lambda]", "-", 
              RowBox[{"Abs", "[", "\[Mu]", "]"}], "-", 
              RowBox[{"2", " ", "k"}]}], "]"}], "\[Equal]", "0"}], ",", "1", 
           ",", 
           SuperscriptBox["z", 
            RowBox[{"\[Lambda]", "-", 
             RowBox[{"Abs", "[", "\[Mu]", "]"}], "-", 
             RowBox[{"2", " ", "k"}]}]]}], "]"}]}]}], "\[IndentingNewLine]", 
       "]"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"Quotient", "[", 
        RowBox[{"\[Lambda]", ",", "2"}], "]"}]}], "}"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SolidHarmonicS", "[", 
    RowBox[{"\[Lambda]_Integer", ",", "\[Mu]_Integer", ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}]}], "]"}], "/;", 
   RowBox[{"\[Lambda]", "\[GreaterEqual]", 
    RowBox[{"Abs", "[", "\[Mu]", "]"}]}]}], ":=", 
  RowBox[{"SolidHarmonicS", "[", 
   RowBox[{"\[Lambda]", ",", "\[Mu]", ",", "x", ",", "y", ",", "z"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"e3180fac-994e-48ec-aa3f-c3a05bc1f046"]
}, Closed]],

Cell[CellGroupData[{

Cell["hydrogenic\[CapitalPsi] and hydrogenic\[CapitalUpsilon] (momentum-space \
wavefunctions)", \
"Subsubsection",ExpressionUUID->"27cc6df5-a9a8-4c7d-a0ee-4d7878c69599"],

Cell[TextData[{
 "This implements the dipole transition matrix element from an arbitrary \
hydrogenic orbital ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", ",", "l", ",", "m"}], TraditionalForm]],ExpressionUUID->
  "e74ac89e-08f0-4184-b3f5-1941e069806c"],
 ", where the ground-state ionization potential is given by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["I", "p"], "=", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["\[Kappa]", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "aa384db4-fbac-4c69-9b5c-77793ae04fbe"],
 ", as described in Luke Chipperfield\[CloseCurlyQuote]s PhD thesis (Imperial \
College London, 2008, p. 52). This code uses partial memoization as in \
mm.se/q/21782."
}], "Text",ExpressionUUID->"8af70c61-d91f-4dcc-9824-c92a14a60da9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenic\[CapitalPsi]", "::", "usage"}], "=", 
   "\"\<hydrogenic\[CapitalPsi][n,l,m,\[Kappa],px,py,pz] calculates the \
momentum-space wavefunction \[CapitalPsi](p)=\[LeftAngleBracket]p|nlm\
\[RightAngleBracket] for a hydrogenic atom with ionization potential \
\!\(\*SuperscriptBox[\(\[Kappa]\), \(2\)]\)/2.\n\n\
hydrogenic\[CapitalPsi][n,l,m,\[Kappa],{px,py,pz}] calculates the \
momentum-space wavefunction \[CapitalPsi](p)=\[LeftAngleBracket]p|nlm\
\[RightAngleBracket] for a hydrogenic atom with ionization potential \
\!\(\*SuperscriptBox[\(\[Kappa]\), \(2\)]\)/2.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenic\[CapitalPsi]", "[", 
    RowBox[{
    "n_", ",", "l_", ",", "m_", ",", "\[Kappa]\[Kappa]_", ",", "ppx_", ",", 
     "ppy_", ",", "ppz_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Kappa]", ",", "px", ",", "py", ",", "pz"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"hydrogenic\[CapitalPsi]", "[", 
        RowBox[{
        "n", ",", "l", ",", "m", ",", "\[Kappa]_", ",", "px_", ",", "py_", 
         ",", "pz_"}], "]"}], "=", 
       RowBox[{"Simplify", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"SolidHarmonicS", "[", 
           RowBox[{"l", ",", "m", ",", "px", ",", "py", ",", "pz"}], "]"}]}], 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "\[ImaginaryI]"}], ")"}], "l"], "\[Pi]", " ", 
           SuperscriptBox["2", 
            RowBox[{
             RowBox[{"2", "l"}], "+", "4"}]], 
           RowBox[{"l", "!"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]", " ", "\[Kappa]"}], ")"}], 
           RowBox[{"3", "/", "2"}]]], 
         SqrtBox[
          FractionBox[
           RowBox[{"n", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "-", "l", "-", "1"}], ")"}], "!"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"n", "+", "l"}], ")"}], "!"}]]], 
         FractionBox[
          SuperscriptBox["\[Kappa]", 
           RowBox[{"l", "+", "4"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["px", "2"], "+", 
             SuperscriptBox["py", "2"], "+", 
             SuperscriptBox["pz", "2"], "+", 
             SuperscriptBox["\[Kappa]", "2"]}], ")"}], 
           RowBox[{"l", "+", "2"}]]], 
         RowBox[{"GegenbauerC", "[", 
          RowBox[{
           RowBox[{"n", "-", "l", "-", "1"}], ",", 
           RowBox[{"l", "+", "1"}], ",", 
           FractionBox[
            RowBox[{
             SuperscriptBox["px", "2"], "+", 
             SuperscriptBox["py", "2"], "+", 
             SuperscriptBox["pz", "2"], "-", 
             SuperscriptBox["\[Kappa]", "2"]}], 
            RowBox[{
             SuperscriptBox["px", "2"], "+", 
             SuperscriptBox["py", "2"], "+", 
             SuperscriptBox["pz", "2"], "+", 
             SuperscriptBox["\[Kappa]", "2"]}]]}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"hydrogenic\[CapitalPsi]", "[", 
       RowBox[{
       "n", ",", "l", ",", "m", ",", "\[Kappa]\[Kappa]", ",", "ppx", ",", 
        "ppy", ",", "ppz"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenic\[CapitalPsi]", "[", 
    RowBox[{"n_", ",", "l_", ",", "m_", ",", "\[Kappa]_", ",", 
     RowBox[{"{", 
      RowBox[{"px_", ",", "py_", ",", "pz_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"hydrogenic\[CapitalPsi]", "[", 
    RowBox[{
    "n", ",", "l", ",", "m", ",", "\[Kappa]", ",", "px", ",", "py", ",", 
     "pz"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"36777044-5955-4a90-b29e-ffd80956d5eb"],

Cell[TextData[{
 "Regularized version, removing the powers of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["p", "2"], "+", 
    SuperscriptBox["\[Kappa]", "2"]}], TraditionalForm]],ExpressionUUID->
  "ee375a62-e0b5-4e8d-84be-aafeb33402f8"],
 " in the denominator, to eliminate poles at the saddle-point momentum ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "=", 
    RowBox[{"\[ImaginaryI]", " ", "\[Kappa]"}]}], TraditionalForm]],
  ExpressionUUID->"b542a96b-32d6-4527-a51e-973029b86187"],
 "."
}], "Text",ExpressionUUID->"5a1d46e7-92ad-4260-bdf4-d98b8ebc6d13"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenic\[CapitalPsi]Regularized", "::", "usage"}], "=", 
   "\"\<hydrogenic\[CapitalUpsilon]Regularized[n,l,m,\[Kappa],px,py,pz] \
calculates the momentum-space wavefunction \[CapitalPsi](p)=\
\[LeftAngleBracket]p|nlm\[RightAngleBracket] for a hydrogenic atom with \
ionization potential \!\(\*SuperscriptBox[\(\[Kappa]\), \(2\)]\)/2, \
multiplied by (\!\(\*SuperscriptBox[\(p\), \(2\)]\)+\!\(\*SuperscriptBox[\(\
\[Kappa]\), \(2\)]\)\!\(\*SuperscriptBox[\()\), \(n + 1\)]\) to remove any \
factors of \!\(\*SuperscriptBox[\(p\), \(2\)]\)+\!\(\*SuperscriptBox[\(\
\[Kappa]\), \(2\)]\) in the denominator.\n\n\
hydrogenic\[CapitalUpsilon]Regularized[n,l,m,\[Kappa],{px,py,pz}] calculates \
the momentum-space wavefunction \[CapitalPsi](p)=\[LeftAngleBracket]p|nlm\
\[RightAngleBracket] for a hydrogenic atom with ionization potential \
\!\(\*SuperscriptBox[\(\[Kappa]\), \(2\)]\)/2, multiplied by \
(\!\(\*SuperscriptBox[\(p\), \(2\)]\)+\!\(\*SuperscriptBox[\(\[Kappa]\), \
\(2\)]\)\!\(\*SuperscriptBox[\()\), \(n + 1\)]\) to remove any factors of \
\!\(\*SuperscriptBox[\(p\), \(2\)]\)+\!\(\*SuperscriptBox[\(\[Kappa]\), \
\(2\)]\) in the denominator.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenic\[CapitalPsi]Regularized", "[", 
    RowBox[{
    "n_", ",", "l_", ",", "m_", ",", "\[Kappa]\[Kappa]_", ",", "ppx_", ",", 
     "ppy_", ",", "ppz_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Kappa]", ",", "px", ",", "py", ",", "pz"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"hydrogenic\[CapitalPsi]Regularized", "[", 
        RowBox[{
        "n", ",", "l", ",", "m", ",", "\[Kappa]_", ",", "px_", ",", "py_", 
         ",", "pz_"}], "]"}], "=", 
       RowBox[{"Simplify", "[", 
        RowBox[{"Cancel", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"SolidHarmonicS", "[", 
            RowBox[{"l", ",", "m", ",", "px", ",", "py", ",", "pz"}], "]"}]}], 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "\[ImaginaryI]"}], ")"}], "l"], "\[Pi]", " ", 
            SuperscriptBox["2", 
             RowBox[{
              RowBox[{"2", "l"}], "+", "4"}]], 
            RowBox[{"l", "!"}]}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"2", "\[Pi]", " ", "\[Kappa]"}], ")"}], 
            RowBox[{"3", "/", "2"}]]], 
          SqrtBox[
           FractionBox[
            RowBox[{"n", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "-", "l", "-", "1"}], ")"}], "!"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "+", "l"}], ")"}], "!"}]]], 
          SuperscriptBox["\[Kappa]", 
           RowBox[{"l", "+", "4"}]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["px", "2"], "+", 
             SuperscriptBox["py", "2"], "+", 
             SuperscriptBox["pz", "2"], "+", 
             SuperscriptBox["\[Kappa]", "2"]}], ")"}], 
           RowBox[{"n", "-", "l", "-", "1"}]], 
          RowBox[{"GegenbauerC", "[", 
           RowBox[{
            RowBox[{"n", "-", "l", "-", "1"}], ",", 
            RowBox[{"l", "+", "1"}], ",", 
            FractionBox[
             RowBox[{
              SuperscriptBox["px", "2"], "+", 
              SuperscriptBox["py", "2"], "+", 
              SuperscriptBox["pz", "2"], "-", 
              SuperscriptBox["\[Kappa]", "2"]}], 
             RowBox[{
              SuperscriptBox["px", "2"], "+", 
              SuperscriptBox["py", "2"], "+", 
              SuperscriptBox["pz", "2"], "+", 
              SuperscriptBox["\[Kappa]", "2"]}]]}], "]"}]}], 
         "\[IndentingNewLine]", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"hydrogenic\[CapitalPsi]Regularized", "[", 
       RowBox[{
       "n", ",", "l", ",", "m", ",", "\[Kappa]\[Kappa]", ",", "ppx", ",", 
        "ppy", ",", "ppz"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenic\[CapitalPsi]Regularized", "[", 
    RowBox[{"n_", ",", "l_", ",", "m_", ",", "\[Kappa]_", ",", 
     RowBox[{"{", 
      RowBox[{"px_", ",", "py_", ",", "pz_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"hydrogenic\[CapitalPsi]Regularized", "[", 
    RowBox[{
    "n", ",", "l", ",", "m", ",", "\[Kappa]", ",", "px", ",", "py", ",", 
     "pz"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"c82ea7eb-ad85-42ac-b432-38bc2af975e3"],

Cell[TextData[{
 "\nUpsilon function, given by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[CapitalUpsilon]", "(", 
     StyleBox["p",
      FontWeight->"Bold"], ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox[
          StyleBox["p",
           FontWeight->"Bold"], "2"]}], "+", 
        SubscriptBox["I", "p"]}], ")"}], 
      RowBox[{"\[CapitalPsi]", "(", 
       StyleBox["p",
        FontWeight->"Bold"], ")"}]}], "=", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         StyleBox["p",
          FontWeight->"Bold"], "2"], "+", 
        SuperscriptBox["\[Kappa]", "2"]}], ")"}], 
      RowBox[{"\[LeftAngleBracket]", 
       RowBox[{
        RowBox[{
         StyleBox["p",
          FontWeight->"Bold"], "|", "n"}], " ", ",", "l", ",", "m"}], 
       "\[RightAngleBracket]"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "36213059-c9c3-4fc6-838d-b307c21896dc"],
 ", which can be used in the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalUpsilon]", "(", 
    RowBox[{
     StyleBox["p",
      FontWeight->"Bold"], "+", 
     RowBox[{
      StyleBox["A",
       FontWeight->"Bold"], "(", 
      RowBox[{"t", "'"}], ")"}]}], ")"}], TraditionalForm]],ExpressionUUID->
  "d34b830c-025d-48af-a5c4-c3add731e47b"],
 " as a replacement for the ionization dipole ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["d",
      FontWeight->"Bold"], "(", 
     RowBox[{
      StyleBox["p",
       FontWeight->"Bold"], "+", 
      RowBox[{
       StyleBox["A",
        FontWeight->"Bold"], "(", 
       RowBox[{"t", "'"}], ")"}]}], ")"}], "\[CenterDot]", 
    RowBox[{
     StyleBox["F",
      FontWeight->"Bold"], "(", 
     RowBox[{"t", "'"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "2e0dd889-e260-4775-ac31-534b5f0abdeb"],
 ", particularly for cases where the latter is singular but the former is \
not. (For details cf. arXiv:1304.2413, appendix A.)"
}], "Text",ExpressionUUID->"33d4bfc2-b32f-4688-ae9f-8a77fe9b900a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenic\[CapitalUpsilon]", "::", "usage"}], "=", 
   "\"\<hydrogenic\[CapitalUpsilon][n,l,m,\[Kappa],px,py,pz] calculates the \
Upsilon function \[CapitalUpsilon](p)=(\!\(\*FractionBox[\(1\), \
\(2\)]\)\!\(\*SuperscriptBox[\(p\), \(2\)]\)+\!\(\*SubscriptBox[\(I\), \(p\)]\
\))\[LeftAngleBracket]p|nlm\[RightAngleBracket] for a hydrogenic atom with \
ionization potential \!\(\*SuperscriptBox[\(\[Kappa]\), \(2\)]\)/2.\n\n\
hydrogenic\[CapitalUpsilon][n,l,m,\[Kappa],{px,py,pz}] calculates the Upsilon \
function \[CapitalUpsilon](p)=(\!\(\*FractionBox[\(1\), \
\(2\)]\)\!\(\*SuperscriptBox[\(p\), \(2\)]\)+\!\(\*SubscriptBox[\(I\), \(p\)]\
\))\[LeftAngleBracket]p|nlm\[RightAngleBracket] for a hydrogenic atom with \
ionization potential \!\(\*SuperscriptBox[\(\[Kappa]\), \(2\)]\)/2.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenic\[CapitalUpsilon]", "[", 
    RowBox[{
    "n_", ",", "l_", ",", "m_", ",", "\[Kappa]_", ",", "px_", ",", "py_", ",",
      "pz_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["px", "2"], "+", 
      SuperscriptBox["py", "2"], "+", 
      SuperscriptBox["pz", "2"], "+", 
      SuperscriptBox["\[Kappa]", "2"]}], ")"}], 
    RowBox[{"hydrogenic\[CapitalPsi]", "[", 
     RowBox[{
     "n", ",", "l", ",", "m", ",", "\[Kappa]", ",", "px", ",", "py", ",", 
      "pz"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenic\[CapitalUpsilon]", "[", 
    RowBox[{"n_", ",", "l_", ",", "m_", ",", "\[Kappa]_", ",", 
     RowBox[{"{", 
      RowBox[{"px_", ",", "py_", ",", "pz_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"hydrogenic\[CapitalUpsilon]", "[", 
    RowBox[{
    "n", ",", "l", ",", "m", ",", "\[Kappa]", ",", "px", ",", "py", ",", 
     "pz"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"866176ba-ca2f-4edd-995a-a377519480bf"]
}, Closed]],

Cell[CellGroupData[{

Cell["hydrogenicDTME for arbitrary states", \
"Subsubsection",ExpressionUUID->"fe7ebb74-4a15-4366-b006-603b4289f9c3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenicDTME", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ppx_", ",", "ppy_", ",", "ppz_"}], "}"}], ",", 
     "\[Kappa]\[Kappa]_", ",", "n_", ",", "l_", ",", "m_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Kappa]", ",", "px", ",", "py", ",", "pz"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"hydrogenicDTME", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"px_", ",", "py_", ",", "pz_"}], "}"}], ",", "\[Kappa]_", 
         ",", "n", ",", "l", ",", "m"}], "]"}], "=", 
       RowBox[{"Simplify", "[", 
        RowBox[{"Grad", "[", 
         RowBox[{
          RowBox[{"hydrogenic\[CapitalUpsilon]", "[", 
           RowBox[{
           "n", ",", "l", ",", "m", ",", "\[Kappa]", ",", "px", ",", "py", 
            ",", "pz"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"px", ",", "py", ",", "pz"}], "}"}]}], "]"}], "]"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"hydrogenicDTME", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ppx", ",", "ppy", ",", "ppz"}], "}"}], ",", 
        "\[Kappa]\[Kappa]", ",", "n", ",", "l", ",", "m"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenicDTME", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"px_", ",", "py_", ",", "pz_"}], "}"}], ",", "\[Kappa]_", ",", 
     RowBox[{"{", 
      RowBox[{"n_", ",", "l_", ",", "m_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"hydrogenicDTME", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"px", ",", "py", ",", "pz"}], "}"}], ",", "\[Kappa]", ",", "n", 
     ",", "l", ",", "m"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"fc96c402-844b-40a8-9afb-d21a0b0502ea"],

Cell[TextData[{
 "Regularized version, removing the powers of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["p", "2"], "+", 
    SuperscriptBox["\[Kappa]", "2"]}], TraditionalForm]],ExpressionUUID->
  "1f2526f3-bcf9-427a-97b7-4c8f4204639b"],
 " in the denominator, to eliminate poles at the saddle-point momentum ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "=", 
    RowBox[{"\[ImaginaryI]", " ", "\[Kappa]"}]}], TraditionalForm]],
  ExpressionUUID->"5eaf735b-9b98-4b57-91d7-58eadd4f1473"],
 "."
}], "Text",ExpressionUUID->"3d150d8a-2528-45fc-8210-50cb3e8b78e6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenicDTMERegularized", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"px_", ",", "py_", ",", "pz_"}], "}"}], ",", "\[Kappa]_", ",", 
     "n_", ",", "l_", ",", "m_"}], "]"}], ":=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["px", "2"], "+", 
       SuperscriptBox["py", "2"], "+", 
       SuperscriptBox["pz", "2"], "+", 
       SuperscriptBox["\[Kappa]", "2"]}], ")"}], 
     RowBox[{"n", "+", "1"}]], 
    RowBox[{"hydrogenicDTME", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"px", ",", "py", ",", "pz"}], "}"}], ",", "\[Kappa]", ",", "n",
       ",", "l", ",", "m"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hydrogenicDTMERegularized", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"px_", ",", "py_", ",", "pz_"}], "}"}], ",", "\[Kappa]_", ",", 
     RowBox[{"{", 
      RowBox[{"n_", ",", "l_", ",", "m_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"hydrogenicDTMERegularized", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"px", ",", "py", ",", "pz"}], "}"}], ",", "\[Kappa]", ",", "n", 
     ",", "l", ",", "m"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"6d33da39-df8e-45ec-a2cb-d6d8c4ad890d"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Various field envelopes", \
"Subsection",ExpressionUUID->"6173bea3-a855-4b94-90b3-7219b594f83d"],

Cell[CellGroupData[{

Cell["flatTopEnvelope", \
"Subsubsection",ExpressionUUID->"28b5ac5a-c776-4e63-aef2-4e8a1e13b55d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"flatTopEnvelope", "::", "usage"}], "=", 
   "\"\<flatTopEnvelope[\[Omega],num,nRamp] returns a Function object \
representing a flat-top envelope at carrier frequency \[Omega] lasting a \
total of num cycles and with linear ramps nRamp cycles long.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"flatTopEnvelope", "[", 
   RowBox[{"\[Omega]_", ",", "num_", ",", "nRamp_"}], "]"}], ":=", 
  RowBox[{"Function", "[", 
   RowBox[{"t", ",", 
    RowBox[{"Piecewise", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"t", "<", "0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           FractionBox[
            RowBox[{"\[Omega]", " ", "t"}], 
            RowBox[{"4", "nRamp"}]], "]"}], "2"], ",", 
         RowBox[{"0", "\[LessEqual]", "t", "<", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "\[Omega]"], " ", "nRamp"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "\[Omega]"], "nRamp"}], 
          "\[LessEqual]", "t", "<", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "\[Omega]"], 
           RowBox[{"(", 
            RowBox[{"num", "-", "nRamp"}], ")"}]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           FractionBox[
            RowBox[{"\[Omega]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox[
                 RowBox[{"2", " ", "\[Pi]"}], "\[Omega]"], "num"}], "-", 
               "t"}], ")"}]}], 
            RowBox[{"4", "nRamp"}]], "]"}], "2"], ",", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "\[Omega]"], 
           RowBox[{"(", 
            RowBox[{"num", "-", "nRamp"}], ")"}]}], "\[LessEqual]", "t", "<", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "\[Omega]"], "num"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "\[Pi]"}], "\[Omega]"], " ", "num"}], 
          "\[LessEqual]", "t"}]}], "}"}]}], "}"}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"f253dc81-804b-4926-986d-da1c9cbefa99"]
}, Closed]],

Cell[CellGroupData[{

Cell["cosPowerFlatTop", \
"Subsubsection",ExpressionUUID->"df129a09-1d0f-47a3-a01b-607b35a7adc8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"cosPowerFlatTop", "::", "usage"}], "=", 
   "\"\<cosPowerFlatTop[\[Omega],num,power] returns a Function object \
representing a smooth flat-top envelope of the form 1-Cos(\[Omega] t/2 \
num\!\(\*SuperscriptBox[\()\), \(power\)]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cosPowerFlatTop", "[", 
   RowBox[{"\[Omega]_", ",", "num_", ",", "power_"}], "]"}], ":=", 
  RowBox[{"Function", "[", 
   RowBox[{"t", ",", 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"\[Omega]", " ", "t"}], 
        RowBox[{"2", "num"}]], "]"}], "power"]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"4e57843e-9a39-4d35-9aba-6afe6dd6b470"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field duration standard options", \
"Subsection",ExpressionUUID->"5c6b76ac-93a3-4d7a-be3e-c828fff86bf2"],

Cell["\<\
The standard options for the duration of the pulse and the resolution are\
\>", "Text",
 CellChangeTimes->{},ExpressionUUID->"4ad00a13-2fd0-46cb-805a-7e21f43d4d5a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PointsPerCycle", "::", "usage"}], "=", 
   "\"\<PointsPerCycle is a sampling option which specifies the number of \
sampling points per cycle to be used in integrations.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TotalCycles", "::", "usage"}], "=", 
   "\"\<TotalCycles is a sampling option which specifies the total number of \
periods to be integrated over.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CarrierFrequency", "::", "usage"}], "=", 
   "\"\<CarrierFrequency is a sampling option which specifies the carrier \
frequency to be used.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CarrierFrequency", "::", "default"}], "=", 
   "\"\<Warning: no CarrierFrequency was specified, using \[Omega]=`1` a.u. \
as the default.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"$DefaultCarrierFrequency", "::", "usage"}], "=", 
    "\"\<Default CarrierFrequency to use when no explicit option is \
indicated.\>\""}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Protect", "[", 
   RowBox[{"PointsPerCycle", ",", "TotalCycles", ",", "CarrierFrequency"}], 
   "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"8e199f90-2893-4ee3-ad5b-4fe4459907ba"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"standardOptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PointsPerCycle", "\[Rule]", "90"}], ",", 
     RowBox[{"TotalCycles", "\[Rule]", "1"}], ",", 
     RowBox[{"CarrierFrequency", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"IntegrationPointsPerCycle", "\[Rule]", "Automatic"}]}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$DefaultCarrierFrequency", "=", "0.057"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"2ba142d6-ac2f-4076-b3cc-9d2e54c48e35"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"GetCarrierFrequency", "::", "usage"}], "=", 
     "\"\<GetCarrierFrequency[OptionValue[CarrierFrequency]] returns \
OptionValue[CarrierFrequency], unless it's set to Automatic, in which case it \
returns $DefaultCarrierFrequency and issues a warning.\n\n\
GetCarrierFrequency[\[Omega]] works for any input.\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GetCarrierFrequency", "[", "optionvalue_", "]"}], ":=", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"optionvalue", "===", "Automatic"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Message", "[", 
        RowBox[{
         RowBox[{"CarrierFrequency", "::", "default"}], ",", 
         "$DefaultCarrierFrequency"}], "]"}], ";", 
       "$DefaultCarrierFrequency"}], ",", "\[IndentingNewLine]", 
      "optionvalue"}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"End", "[", "]"}], ";"}]}]}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"ec4bd02f-f3d9-42e7-9ff9-c06e50730d97"],

Cell[TextData[{
 "PointsPerCycle dictates how many sampling points are used per laser cycle \
(at frequency CarrierFrequency, of the infrared laser), and it should be at \
least twice the highest harmonic of interest. The total duration is ",
 Cell[BoxData[
  FormBox["TotalCycles", TraditionalForm]],ExpressionUUID->
  "2f963352-4fbf-4237-a351-7eeca669b6ed"],
 " cycles. ",
 "CarrierFrequency",
 " is the frequency of the fundamental laser, in atomic units."
}], "Text",ExpressionUUID->"d768a1fd-67da-4d4c-8f78-2731a14a3b8c"]
}, Closed]],

Cell[CellGroupData[{

Cell["harmonicOrderAxis", \
"Subsection",ExpressionUUID->"39801302-03d6-4f12-9029-76cae94f200e"],

Cell[TextData[{
 "harmonicOrderAxis produces a list that can be used as a harmonic order axis \
for the given pulse parameters. \n\nThe length can be fine-tuned (to match \
exactly a spectrum, for instance, and get a matrix of the correct shape) \
using the ",
 Cell[BoxData[
  FormBox["correction", TraditionalForm]],ExpressionUUID->
  "45779e02-2228-424d-83b1-2309ed344501"],
 " option, or a TargetLength can be directly specified."
}], "Text",
 CellChangeTimes->{},ExpressionUUID->"52380089-76eb-4667-8c2b-310f63fe002f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"harmonicOrderAxis", "::", "usage"}], "=", 
   "\"\<harmonicOrderAxis[opt\[Rule]value] returns a list of frequencies \
which can be used as a frequency axis for Fourier transforms, scaled in units \
of harmonic order, for the provided field duration and sampling \
options.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TargetLength", "::", "usage"}], "=", 
   "\"\<TargetLength is an option for harmonicOrderAxis which specifies the \
total length required of the resulting list.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LengthCorrection", "::", "usage"}], "=", 
   "\"\<LengthCorrection is an option for harmonicOrderAxis which allows for \
manual correction of the length of the resulting list.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Protect", "[", 
   RowBox[{"LengthCorrection", ",", "TargetLength"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "harmonicOrderAxis", "]"}], "=", 
   RowBox[{"Join", "[", 
    RowBox[{"standardOptions", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"TargetLength", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"LengthCorrection", "\[Rule]", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"harmonicOrderAxis", "::", "target"}], "=", 
   "\"\<Invalid TargetLength option `1`. This must be a positive integer or \
Automatic.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"harmonicOrderAxis", "[", 
   RowBox[{"OptionsPattern", "[", "]"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"num", "=", 
       RowBox[{"OptionValue", "[", "TotalCycles", "]"}]}], ",", 
      RowBox[{"npp", "=", 
       RowBox[{"OptionValue", "[", "PointsPerCycle", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Piecewise", "[", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox["1", "num"], 
           RowBox[{"Range", "[", 
            RowBox[{"0.", ",", 
             RowBox[{
              RowBox[{"Round", "[", 
               FractionBox[
                RowBox[{
                 RowBox[{"npp", " ", "num"}], "+", "1"}], "2."], "]"}], "-", 
              "1", "+", 
              RowBox[{"OptionValue", "[", "LengthCorrection", "]"}]}]}], 
            "]"}]}], ",", 
          RowBox[{
           RowBox[{"OptionValue", "[", "TargetLength", "]"}], "===", 
           "Automatic"}]}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox[
            RowBox[{"Round", "[", 
             FractionBox[
              RowBox[{
               RowBox[{"npp", " ", "num"}], "+", "1"}], "2."], "]"}], "num"], 
           FractionBox[
            RowBox[{"Range", "[", 
             RowBox[{"0", ",", 
              RowBox[{
               RowBox[{"OptionValue", "[", "TargetLength", "]"}], "-", 
               "1"}]}], "]"}], 
            RowBox[{"OptionValue", "[", "TargetLength", "]"}]]}], ",", 
          RowBox[{
           RowBox[{"IntegerQ", "[", 
            RowBox[{"OptionValue", "[", "TargetLength", "]"}], "]"}], "&&", 
           RowBox[{
            RowBox[{"OptionValue", "[", "TargetLength", "]"}], 
            "\[GreaterEqual]", "0"}]}]}], "}"}]}], "\[IndentingNewLine]", 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Message", "[", 
        RowBox[{
         RowBox[{"harmonicOrderAxis", "::", "target"}], ",", 
         RowBox[{"OptionValue", "[", "\"\<TargetLength\>\"", "]"}]}], "]"}], 
       ";", 
       RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"834c56a9-6669-4e0e-a886-b2a0a575c973"]
}, Closed]],

Cell[CellGroupData[{

Cell["frequencyAxis", \
"Subsection",ExpressionUUID->"782a03ee-fe8c-4c60-b0be-5733bce52ae0"],

Cell["\<\
frequencyAxis produces a list that can be used as a harmonic order axis for \
the given pulse parameters. Identical to harmonicOrderAxis but produces a \
frequency axis (in atomic units) instead.\
\>", "Text",ExpressionUUID->"1efbacaa-95c6-45ce-91b4-5e7ef62ec2b4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"frequencyAxis", "::", "usage"}], "=", 
   "\"\<frequencyAxis[opt\[Rule]value] returns a list of frequencies which \
can be used as a frequency axis for Fourier transforms, in atomic units of \
frequency, for the provided field duration and sampling options.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "frequencyAxis", "]"}], "=", 
   RowBox[{"Options", "[", "harmonicOrderAxis", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"frequencyAxis", "[", 
   RowBox[{"options", ":", 
    RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"GetCarrierFrequency", "[", 
    RowBox[{"OptionValue", "[", "CarrierFrequency", "]"}], "]"}], 
   RowBox[{
   "harmonicOrderAxis", "[", "options", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"c793c8a3-78b5-4e74-b665-d3f90223e313"]
}, Closed]],

Cell[CellGroupData[{

Cell["timeAxis", \
"Subsection",ExpressionUUID->"f20a3c81-d1e1-43b7-a338-38599e2296bd"],

Cell["\<\
timeAxis produces a list that can be used as a time axis for the given pulse \
parameters.\
\>", "Text",
 CellChangeTimes->{},ExpressionUUID->"ee19ce4b-9acc-4032-801b-13e20b4fcf03"],

Cell[BoxData["Quit"], \
"Input",ExpressionUUID->"50ce7b69-384d-43fd-81c8-f56f86a22153"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"timeAxis", "::", "usage"}], "=", 
   "\"\<timeAxis[opt\[Rule]value] returns a list of times which can be used \
as a time axis \>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TimeScale", "::", "usage"}], "=", 
   "\"\<TimeScale is an option for timeAxis which specifies the units the \
list should use: AtomicUnits by default, or LaserPeriods if required.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AtomicUnits", "::", "usage"}], "=", 
   "\"\<AtomicUnits is a value for the option TimeScale of timeAxis which \
specifies that the times should be in atomic units of time.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LaserPeriods", "::", "usage"}], "=", 
   "\"\<LaserPeriods is a value for the option TimeScale of timeAxis which \
specifies that the times should be in multiples of the carrier laser \
period.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Protect", "[", 
   RowBox[{"TimeScale", ",", "AtomicUnits", ",", "LaserPeriods"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "timeAxis", "]"}], "=", 
   RowBox[{"standardOptions", "~", "Join", "~", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"TimeScale", "\[Rule]", "AtomicUnits"}], ",", 
      RowBox[{"PointNumberCorrection", "\[Rule]", "0"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"timeAxis", "::", "scale"}], "=", 
   "\"\<Invalid TimeScale option `1`. Available values are AtomicUnits and \
LaserPeriods\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timeAxis", "[", 
   RowBox[{"OptionsPattern", "[", "]"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"T", "=", 
       RowBox[{"2", 
        RowBox[{"\[Pi]", "/", "\[Omega]"}]}]}], ",", 
      RowBox[{"\[Omega]", "=", 
       RowBox[{"GetCarrierFrequency", "[", 
        RowBox[{"OptionValue", "[", "CarrierFrequency", "]"}], "]"}]}], ",", 
      RowBox[{"num", "=", 
       RowBox[{"OptionValue", "[", "TotalCycles", "]"}]}], ",", 
      RowBox[{"npp", "=", 
       RowBox[{"OptionValue", "[", "PointsPerCycle", "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"OptionValue", "[", "TimeScale", "]"}], "===", 
            "AtomicUnits"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           FractionBox["1", "T"], ",", 
           RowBox[{
            RowBox[{"OptionValue", "[", "TimeScale", "]"}], "===", 
            "LaserPeriods"}]}], "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"timeAxis", "::", "scale"}], ",", 
          RowBox[{"OptionValue", "[", "TimeScale", "]"}]}], "]"}], ";", 
        RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
     "\[Times]", 
     RowBox[{"Table", "[", 
      RowBox[{"t", "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", 
         RowBox[{"num", 
          FractionBox[
           RowBox[{"2", "\[Pi]"}], "\[Omega]"]}], ",", 
         RowBox[{
          FractionBox["num", 
           RowBox[{
            RowBox[{"num", "\[Times]", "npp"}], "+", 
            RowBox[{"OptionValue", "[", "PointNumberCorrection", "]"}]}]], 
          FractionBox[
           RowBox[{"2", "\[Pi]"}], "\[Omega]"]}]}], "}"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"aa179fb0-64c6-461d-9367-109750ef2374"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"tInit", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tFinal", "=", 
     RowBox[{
      FractionBox[
       RowBox[{"2", "\[Pi]"}], "\[Omega]"], " ", "num"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Delta]t", "=", 
     FractionBox[
      RowBox[{"tFinal", "-", "tInit"}], 
      RowBox[{
       RowBox[{"num", "\[Times]", "npp"}], "+", 
       RowBox[{"OptionValue", "[", "PointNumberCorrection", "]"}]}]]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"integration", " ", "and", " ", "looping", " ", "timestep"}], 
    "*)"}]}]}]], \
"Input",ExpressionUUID->"1094c001-30c5-4ddb-9a15-44ab2a76aff9"]
}, Closed]],

Cell[CellGroupData[{

Cell["VectorFourier", \
"Subsection",ExpressionUUID->"abbfd122-2a25-420e-8e41-3a8e5327e845"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"VectorFourier", "::", "usage"}], "=", 
    "\"\<VectorFourier[array,n] performs a Fourier transform on array only on \
level n of the array.\nVectorFourier[array,{n1,n2,\[Ellipsis],nk}] performs a \
Fourier transform on array only on the specified levels \
{n1,n2,\[Ellipsis],nk}.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "VectorFourier", "]"}], "=", 
   RowBox[{"Options", "[", "Fourier", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"VectorFourier", "::", "levelspec"}], "=", 
    "\"\<The level specification `1` is not correct.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VectorFourier", "[", 
   RowBox[{"array_", ",", 
    RowBox[{"level_", "?", "NumericQ"}], ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"VectorFourier", "[", 
   RowBox[{"array", ",", 
    RowBox[{"{", "level", "}"}], ",", "opts"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VectorFourier", "[", 
    RowBox[{"array_", ",", "levelsToTransform_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "totalLevels", ",", "untouchedLevels", ",", "permutation", ",", 
       "inversePermutation"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"totalLevels", "=", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"Depth", "[", "array", "]"}], "-", "1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"untouchedLevels", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{"totalLevels", ",", "levelsToTransform"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{"SubsetQ", "[", 
          RowBox[{"totalLevels", ",", "levelsToTransform"}], "]"}], "]"}], 
        ",", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"VectorFourier", "::", "levelspec"}], ",", 
           "levelsToTransform"}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"permutation", "=", 
       RowBox[{"Join", "[", 
        RowBox[{"untouchedLevels", ",", "levelsToTransform"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"inversePermutation", "=", 
       RowBox[{"InversePermutation", "[", "permutation", "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Map", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Function", "[", 
           RowBox[{"Fourier", "[", 
            RowBox[{"#", ",", "opts"}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
           RowBox[{
           "array", ",", "\[IndentingNewLine]", "inversePermutation"}], 
           "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Length", "[", "untouchedLevels", "]"}], "}"}]}], 
         "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        "permutation"}], "\[IndentingNewLine]", "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"6e8ca0bc-b9e8-4549-b34a-108db01b5227"],

Cell[TextData[{
 "In its usage within getSpectralAmplitude, this function is used in the \
format VectorFourier[array,{1}], to take the temporal Fourier transform of a \
vector-valued time series, i.e., to take an ",
 Cell[BoxData[
  FormBox[
   RowBox[{"N", "\[Times]", "d"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "491edba7-8188-4efa-8641-9ddfef139725"],
 " array and transform it over the first level, of length ",
 Cell[BoxData[
  FormBox["N", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "92589665-36d0-4e08-bfc9-6732f3ff39d4"],
 "."
}], "Text",ExpressionUUID->"7c497a2f-6bb4-4ebf-8dc5-8145a9496bae"]
}, Closed]],

Cell[CellGroupData[{

Cell["differentiateDipoleList", \
"Subsection",ExpressionUUID->"5944a03f-68be-4661-afda-4981da62fba5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"differentiateDipoleList", "::", "usage"}], "=", 
    "\"\<differentiateDipoleList[dipoleList,\[Delta]t,DifferentiationOrder\
\[Rule]n] differentiates dipoleList numerically with step \[Delta]t to order \
n=0,1,2.\>\""}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "differentiateDipoleList", "]"}], "=", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"DifferentiationOrder", "\[Rule]", "0"}], "}"}], ",", 
      "standardOptions"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"differentiateDipoleList", "::", "diffOrd"}], "=", 
    "\"\<Invalid differentiation order `1`.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"differentiateDipoleList", "[", 
    RowBox[{"dipoleList_", ",", "\[Delta]t_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Piecewise", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"dipoleList", ",", 
           RowBox[{
            RowBox[{"OptionValue", "[", "DifferentiationOrder", "]"}], 
            "\[Equal]", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["1", 
             RowBox[{"2", "\[Delta]t"}]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Most", "[", 
               RowBox[{"Most", "[", "dipoleList", "]"}], "]"}], "-", 
              RowBox[{"Rest", "[", 
               RowBox[{"Rest", "[", "dipoleList", "]"}], "]"}]}], ")"}]}], 
           ",", 
           RowBox[{
            RowBox[{"OptionValue", "[", "DifferentiationOrder", "]"}], 
            "\[Equal]", "1"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["1", 
             SuperscriptBox["\[Delta]t", "2"]], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Most", "[", 
               RowBox[{"Most", "[", "dipoleList", "]"}], "]"}], "-", 
              RowBox[{"2", 
               RowBox[{"Most", "[", 
                RowBox[{"Rest", "[", "dipoleList", "]"}], "]"}]}], "+", 
              RowBox[{"Rest", "[", 
               RowBox[{"Rest", "[", "dipoleList", "]"}], "]"}]}], ")"}]}], 
           ",", 
           RowBox[{
            RowBox[{"OptionValue", "[", "DifferentiationOrder", "]"}], 
            "\[Equal]", "2"}]}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"differentiateDipoleList", "::", "diffOrd"}], ",", 
          RowBox[{"OptionValue", "[", "DifferentiationOrder", "]"}]}], "]"}], 
        ";", 
        RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"aa2173cb-9b44-4712-8c00-5f7a303cd8dc"]
}, Closed]],

Cell[CellGroupData[{

Cell["getSpectralAmplitude", \
"Subsection",ExpressionUUID->"a4afb916-1191-4270-ac2a-1b70ee3bca91"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"getSpectralAmplitude", "::", "usage"}], "=", 
    "\"\<getSpectralAmplitude[DipoleList] returns the spectral amplitude of \
DipoleList.\>\""}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Polarization", "::", "usage"}], "=", 
   "\"\<Polarization is an option for getSpectrum and getSpectralAmplitude \
which specifies a polarization vector along which to polarize the dipole \
list. The default, Polarization\[Rule]False, specifies an unpolarized \
spectrum.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComplexPart", "::", "usage"}], "=", 
   "\"\<ComplexPart is an option for getSpectrum and getSpectralAmplitude \
which specifies a function (like Re, Im, or by default #&) which should be \
applied to the dipole list before the spectrum is taken.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]Power", "::", "usage"}], "=", 
   "\"\<\[Omega]Power is an option for getSpectrum and getSpectralAmplitude \
which specifies a power of frequency which should multiply the \
spectrum.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DifferentiationOrder", "::", "usage"}], "=", 
    "\"\<DifferentiationOrder is an option for getSpectrum and \
getSpectralAmplitude which specifies the order to which the dipole list \
should be differentiated before the spectrum is taken.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Protect", "[", 
    RowBox[{
    "Polarization", ",", "ComplexPart", ",", "\[Omega]Power", ",", 
     "DifferentiationOrder"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "getSpectralAmplitude", "]"}], "=", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Polarization", "\[Rule]", "False"}], ",", 
        RowBox[{"ComplexPart", "\[Rule]", "Re"}], ",", 
        RowBox[{"\[Omega]Power", "\[Rule]", "0"}], ",", 
        RowBox[{"DifferentiationOrder", "\[Rule]", "0"}]}], "}"}], ",", 
      "standardOptions"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"getSpectralAmplitude", "::", "\[Omega]Pow"}], "=", 
    "\"\<Invalid \[Omega] power `1`.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getSpectralAmplitude", "[", 
    RowBox[{"dipoleList_", ",", 
     RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
   RowBox[{"Block", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "polarizationVector", ",", "preprocessedList", ",", "depth", ",", 
       "dimensions", ",", "\[IndentingNewLine]", 
       RowBox[{"num", "=", 
        RowBox[{"OptionValue", "[", "TotalCycles", "]"}]}], ",", 
       RowBox[{"npp", "=", 
        RowBox[{"OptionValue", "[", "PointsPerCycle", "]"}]}], ",", 
       "\[Omega]", ",", 
       RowBox[{"\[Delta]t", "=", 
        FractionBox[
         RowBox[{"2", 
          RowBox[{"\[Pi]", "/", "\[Omega]"}]}], "npp"]}]}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"polarizationVector", "=", 
       FractionBox[
        RowBox[{"OptionValue", "[", "Polarization", "]"}], 
        RowBox[{"Norm", "[", 
         RowBox[{"OptionValue", "[", "Polarization", "]"}], "]"}]]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"preprocessedList", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", "ComplexPart", "]"}], "[", 
        "\[IndentingNewLine]", 
        RowBox[{"differentiateDipoleList", "[", 
         RowBox[{"dipoleList", ",", "\[Delta]t", ",", 
          RowBox[{"DifferentiationOrder", "\[Rule]", 
           RowBox[{"OptionValue", "[", "DifferentiationOrder", "]"}]}]}], 
         "]"}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"NumberQ", "[", 
         RowBox[{"OptionValue", "[", "\[Omega]Power", "]"}], "]"}], ",", 
        RowBox[{"Null", ";"}], ",", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"getSpectralAmplitude", "::", "\[Omega]Pow"}], ",", 
           RowBox[{"OptionValue", "[", "\[Omega]Power", "]"}]}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}]}], "  ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"OptionValue", "[", "\[Omega]Power", "]"}], "\[NotEqual]", 
         "0"}], ",", 
        RowBox[{"\[Omega]", "=", 
         RowBox[{"GetCarrierFrequency", "[", 
          RowBox[{"OptionValue", "[", "CarrierFrequency", "]"}], "]"}]}], ",", 
        RowBox[{"\[Omega]", "=", "1"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"If", " ", "\[Omega]Power"}], "\[Equal]", 
        RowBox[{
        "0", " ", "the", " ", "value", " ", "of", " ", "\[Omega]", " ", 
         RowBox[{"doesn", "'"}], "t", " ", "matter", " ", "and", " ", 
         RowBox[{"there", "'"}], "s", " ", "no", " ", "sense", " ", "in", " ",
          "risking", " ", "printing", " ", "error", " ", "messages", " ", 
         "that", " ", "would", " ", "result", " ", "from", " ", "a", " ", 
         "missing", " ", "CarrierFrequency", " ", 
         RowBox[{"option", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"Times", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SqrtBox["num"], " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FractionBox["\[Omega]", "num"], " ", "k"}], ")"}], 
            RowBox[{"OptionValue", "[", "\[Omega]Power", "]"}]], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", 
             RowBox[{"Round", "[", 
              FractionBox[
               RowBox[{"Length", "[", "preprocessedList", "]"}], "2"], 
              "]"}]}], "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Map", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"OptionValue", "[", "Polarization", "]"}], "===", 
              "False"}], ",", "\[IndentingNewLine]", 
             RowBox[{"#", "&"}], ",", 
             RowBox[{"(*", 
              RowBox[{"unpolarized", " ", "spectrum"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Dot", "[", 
               RowBox[{"#", ",", "polarizationVector"}], "]"}], "&"}]}], 
            "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"VectorFourier", "[", 
            RowBox[{"preprocessedList", ",", 
             RowBox[{"{", "1", "}"}]}], "]"}]}], "\[IndentingNewLine]", "]"}],
          "\[LeftDoubleBracket]", 
         RowBox[{"1", ";;", 
          RowBox[{"Round", "[", 
           FractionBox[
            RowBox[{"Length", "[", "preprocessedList", "]"}], "2"], "]"}]}], 
         "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", "]"}]}]}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"f3145e2d-d069-4c38-b5d2-829512d98a02"]
}, Closed]],

Cell[CellGroupData[{

Cell["getSpectrum", \
"Subsection",ExpressionUUID->"8b24d0dc-f123-4c71-ae02-3b3cad42c392"],

Cell[TextData[{
 "getSpectrum takes a time-dependent dipole list and returns its Fourier \
transform in absolute-value-squared. It takes as options\n  ",
 StyleBox["\[CenterDot]",
  FontWeight->"Bold"],
 " pulse parameters \[Omega], TotalCycles and PointsPerCycle,\n  ",
 StyleBox["\[CenterDot]",
  FontWeight->"Bold"],
 " a polarization parameter \[Epsilon], which gives an unpolarized spectrum \
when given False, or polarizes along an ellipticity vector \[Epsilon] (this \
is meant primarily to select right- and left-circularly polarized spectra \
using ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", "\[ImaginaryI]"}], "}"}]}], TraditionalForm]],
  ExpressionUUID->"f6bac9d9-281e-4132-b94b-b5e16d5e397f"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Epsilon]", "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], TraditionalForm]],
  ExpressionUUID->"d63e723b-ab45-480f-9ded-c86b73afc08e"],
 " respectively),\n  ",
 StyleBox["\[CenterDot]",
  FontWeight->"Bold"],
 " a DifferentiationOrder, which can return the dipole value (default,",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", "0"}], TraditionalForm]],ExpressionUUID->
  "c3cc2849-5242-4c68-9200-acd972490d08"],
 "), velocity (",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", "1"}], TraditionalForm]],ExpressionUUID->
  "edbf0c35-3f4e-42b2-a7d0-41c7bab7b9e1"],
 "), or acceleration (",
 Cell[BoxData[
  FormBox[
   RowBox[{"=", "2"}], TraditionalForm]],ExpressionUUID->
  "40ba1635-b0cd-4d10-8268-873d12a0b0dc"],
 "), \n  \[CenterDot] a power of \[Omega], \[Omega]Power, with which to \
multiply the spectrum before returning it (which should be equivalent to \
DifferentiationOrder except for pathological cases), and\n  \[CenterDot] a \
ComplexPart function to apply immediately after differentiation (default is \
the identity function, but Re, Im, or ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"Abs", "[", "#", "]"}], "2"], "&"}], TraditionalForm]],
  ExpressionUUID->"00f33e49-5498-477e-99f9-091883e96f7c"],
 " are reasonable choices).\nIf no option is passed to ",
 Cell[BoxData[
  FormBox["\[Omega]Power", TraditionalForm]],ExpressionUUID->
  "1025ebcf-e3c5-4d3b-844a-25713f3f6e71"],
 " and DifferentiationOrder, the pulse parameters do not really affect the \
output, except by a global factor of ",
 "TotalCycles",
 "."
}], "Text",ExpressionUUID->"343fd9eb-64ea-43c2-a868-c274330eb2a8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"getSpectrum", "::", "usage"}], "=", 
    "\"\<getSpectrum[DipoleList] returns the power spectrum of \
DipoleList.\>\""}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "getSpectrum", "]"}], "=", 
    RowBox[{"Options", "[", "getSpectralAmplitude", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getSpectrum", "[", 
    RowBox[{"dipoleList_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Map", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Norm", "[", "#", "]"}], "2"], "&"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"getSpectralAmplitude", "[", 
      RowBox[{"dipoleList", ",", "opts"}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"4a8f64f5-f8f1-4ca5-9bc1-e631fe136b35"]
}, Closed]],

Cell[CellGroupData[{

Cell["spectrumPlotter", \
"Subsection",ExpressionUUID->"c4715e00-2339-42d0-ae4f-47ecf3d2f30a"],

Cell["\<\
spectrumPlotter takes a spectrum and a list of options and returns a plot of \
the spectrum. The available options are
  \[CenterDot] a FrequencyAxis option, which will give the harmonic order as \
a horizontal axis by default, and an arbitrary scale with any other option,
  \[CenterDot] all the options of harmonicOrderAxis, which will be passed to \
the call that makes the horizontal axis, and
  \[CenterDot] all the options of ListLinePlot, which will be used to format \
the plot.\
\>", "Text",ExpressionUUID->"b00e511e-501d-49c6-8b32-e0c48cf8f114"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"spectrumPlotter", "::", "usage"}], "=", 
   "\"\<spectrumPlotter[spectrum] plots the given spectrum with an \
appropriate axis in a \!\(\*SubscriptBox[\(log\), \(10\)]\) scale.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FrequencyAxis", "::", "usage"}], "=", 
   "\"\<FrequencyAxis is an option for spectrumPlotter which specifies the \
axis to use.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Protect", "[", "FrequencyAxis", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "spectrumPlotter", "]"}], "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"FrequencyAxis", "\[Rule]", "\"\<HarmonicOrder\>\""}], "}"}], 
     ",", 
     RowBox[{"Options", "[", "harmonicOrderAxis", "]"}], ",", 
     RowBox[{"Options", "[", "ListLinePlot", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"spectrumPlotter", "[", 
   RowBox[{"spectrum_", ",", 
    RowBox[{"options", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"OptionValue", "[", "FrequencyAxis", "]"}], "===", 
          "\"\<HarmonicOrder\>\""}], ",", "\[IndentingNewLine]", 
         RowBox[{"harmonicOrderAxis", "[", 
          RowBox[{
           RowBox[{"\"\<TargetLength\>\"", "\[Rule]", 
            RowBox[{"Length", "[", "spectrum", "]"}]}], ",", 
           RowBox[{"Sequence", "@@", 
            RowBox[{"FilterRules", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", "options", "}"}], "~", "Join", "~", 
               RowBox[{"Options", "[", "spectrumPlotter", "]"}]}], ",", 
              RowBox[{"Options", "[", "harmonicOrderAxis", "]"}]}], "]"}]}]}],
           "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"OptionValue", "[", "FrequencyAxis", "]"}], "===", 
          "\"\<Frequency\>\""}], ",", "\[IndentingNewLine]", 
         RowBox[{"frequencyAxis", "[", 
          RowBox[{
           RowBox[{"\"\<TargetLength\>\"", "\[Rule]", 
            RowBox[{"Length", "[", "spectrum", "]"}]}], ",", 
           RowBox[{"Sequence", "@@", 
            RowBox[{"FilterRules", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", "options", "}"}], "~", "Join", "~", 
               RowBox[{"Options", "[", "spectrumPlotter", "]"}]}], ",", 
              RowBox[{"Options", "[", "harmonicOrderAxis", "]"}]}], "]"}]}]}],
           "]"}], ",", "\[IndentingNewLine]", "True", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"Length", "[", "spectrum", "]"}], "]"}]}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", "spectrum"}], "]"}]}], "\[IndentingNewLine]", 
      "}"}], "\[Transpose]"}], "\[IndentingNewLine]", ",", 
    RowBox[{"Sequence", "@@", 
     RowBox[{"FilterRules", "[", 
      RowBox[{
       RowBox[{"{", "options", "}"}], ",", 
       RowBox[{"Options", "[", "ListLinePlot", "]"}]}], "]"}]}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
    RowBox[{"PlotRange", "\[Rule]", "Full"}], "\[IndentingNewLine]", ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Thick"}], "\[IndentingNewLine]", ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], "\[IndentingNewLine]", ",", 
    RowBox[{"ImageSize", "\[Rule]", "800"}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"f7878917-41e7-4692-b91f-dd51c165fba9"]
}, Closed]],

Cell[CellGroupData[{

Cell["biColorSpectrum", \
"Subsection",ExpressionUUID->"714e92c5-c46b-4897-a88e-1b99f38175d2"],

Cell["\<\
biColorSpectrum takes a time-dependent dipole list and produces overlaid \
plots of the right- and left-circular components of the spectrum, in red and \
blue respectively. It takes all the options of getSpectrum and \
spectrumPlotter, which are passed directly to the corresponding calls, as \
well as the options of Show, which can be used to modify the plot appearance.\
\>", "Text",
 CellChangeTimes->{},ExpressionUUID->"1eef6c37-b4c4-4ab8-acb2-39382cb36625"],

Cell[BoxData["Quit"], \
"Input",ExpressionUUID->"6af5c619-37d3-404a-a1ee-9a42f7a6a4d7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"biColorSpectrum", "::", "usage"}], "=", 
   "\"\<biColorSpectrum[DipoleList] produces a two-colour spectrum of \
DipoleList, separating the two circular polarizations.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "biColorSpectrum", "]"}], "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], "}"}], ",", 
     RowBox[{"Options", "[", "Show", "]"}], ",", 
     RowBox[{"Options", "[", "spectrumPlotter", "]"}], ",", 
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Options", "[", "getSpectrum", "]"}], ",", 
       RowBox[{"Polarization", "\[Rule]", "False"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"biColorSpectrum", "[", 
   RowBox[{"dipoleList_", ",", 
    RowBox[{"options", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"spectrumPlotter", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"getSpectrum", "[", 
         RowBox[{"dipoleList", ",", 
          RowBox[{"Polarization", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{"+", "\[ImaginaryI]"}]}], "}"}]}], ",", 
          RowBox[{"Sequence", "@@", 
           RowBox[{"FilterRules", "[", 
            RowBox[{
             RowBox[{"{", "options", "}"}], ",", 
             RowBox[{"Options", "[", "getSpectrum", "]"}]}], "]"}]}]}], "]"}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
        RowBox[{"Sequence", "@@", 
         RowBox[{"FilterRules", "[", 
          RowBox[{
           RowBox[{"{", "options", "}"}], ",", 
           RowBox[{"Options", "[", "spectrumPlotter", "]"}]}], "]"}]}]}], 
       "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"spectrumPlotter", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"getSpectrum", "[", 
         RowBox[{"dipoleList", ",", 
          RowBox[{"Polarization", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], ",", 
          RowBox[{"Sequence", "@@", 
           RowBox[{"FilterRules", "[", 
            RowBox[{
             RowBox[{"{", "options", "}"}], ",", 
             RowBox[{"Options", "[", "getSpectrum", "]"}]}], "]"}]}]}], "]"}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
        RowBox[{"Sequence", "@@", 
         RowBox[{"FilterRules", "[", 
          RowBox[{
           RowBox[{"{", "options", "}"}], ",", 
           RowBox[{"Options", "[", "spectrumPlotter", "]"}]}], "]"}]}]}], 
       "]"}]}], "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"OptionValue", "[", "PlotRange", "]"}]}], "\[IndentingNewLine]", 
    ",", 
    RowBox[{"Sequence", "@@", 
     RowBox[{"FilterRules", "[", 
      RowBox[{
       RowBox[{"{", "options", "}"}], ",", 
       RowBox[{"Options", "[", "Show", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"9a3d4833-6f11-4bf6-ab8d-962a8d0c6db1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Various gate functions", \
"Subsection",ExpressionUUID->"520f7ca6-5e8f-4541-b00a-186bb6b3c119"],

Cell[TextData[{
 "Gate functions are used to suppress the contributions of extra-long \
trajectories with long excursion times, partly to reflect the effect of phase \
matching but mostly to keep integration times reasonable. They are provided \
to the main numerical integrator ",
 StyleBox["makeDipoleList", "Code"],
 " via its ",
 StyleBox["Gate", "Code"],
 " option."
}], "Text",ExpressionUUID->"88c2c2b5-b2eb-44ae-b02a-6a27c459f565"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SineSquaredGate", "::", "usage"}], "=", 
   "\"\<SineSquaredGate[nGateRamp] specifies an integration gate with a \
sine-squared ramp, such that SineSquaredGate[nGateRamp][\[Omega]t,nGate] has \
nGate flat periods and nGateRamp ramp periods.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LinearRampGate", "::", "usage"}], "=", 
   "\"\<LinearRampGate[nGateRamp] specifies an integration gate with a linear \
ramp, such that SineSquaredGate[nGateRamp][\[Omega]t,nGate] has nGate flat \
periods and nGateRamp ramp periods.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SineSquaredGate", "[", "nGateRamp_", "]"}], "[", 
   RowBox[{"\[Omega]\[Tau]_", ",", "nGate_"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"\[Omega]\[Tau]", "\[LessEqual]", 
        RowBox[{"2", "\[Pi]", " ", 
         RowBox[{"(", 
          RowBox[{"nGate", "-", "nGateRamp"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"2", "\[Pi]", " ", "nGate"}], "-", "\[Omega]\[Tau]"}], 
          RowBox[{"4", "nGateRamp"}]], "]"}], "2"], ",", 
       RowBox[{
        RowBox[{"2", "\[Pi]", " ", 
         RowBox[{"(", 
          RowBox[{"nGate", "-", "nGateRamp"}], ")"}]}], "<", "\[Omega]\[Tau]",
         "\[LessEqual]", 
        RowBox[{"2", "\[Pi]", " ", "nGate"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"nGate", "<", "\[Omega]\[Tau]"}]}], "}"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LinearRampGate", "[", "nGateRamp_", "]"}], "[", 
   RowBox[{"\[Omega]\[Tau]_", ",", "nGate_"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"\[Omega]\[Tau]", "\[LessEqual]", 
        RowBox[{"2", "\[Pi]", " ", 
         RowBox[{"(", 
          RowBox[{"nGate", "-", "nGateRamp"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Omega]\[Tau]", "-", 
          RowBox[{"2", "\[Pi]", " ", 
           RowBox[{"(", 
            RowBox[{"nGate", "+", "nGateRamp"}], ")"}]}]}], 
         RowBox[{"2", "\[Pi]", " ", "nGateRamp"}]]}], ",", 
       RowBox[{
        RowBox[{"2", "\[Pi]", " ", 
         RowBox[{"(", 
          RowBox[{"nGate", "-", "nGateRamp"}], ")"}]}], "<", "\[Omega]\[Tau]",
         "\[LessEqual]", 
        RowBox[{"2", "\[Pi]", " ", "nGate"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"nGate", "<", "\[Omega]\[Tau]"}]}], "}"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"c12870bb-f797-492a-b1cc-bd912c1b3801"]
}, Closed]],

Cell[CellGroupData[{

Cell["getIonizationPotential", \
"Subsection",ExpressionUUID->"ef36ba33-fe06-4630-9e65-776972a13981"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"getIonizationPotential", "::", "usage"}], "=", 
   "\"\<getIonizationPotential[Target] returns the ionization potential of an \
atomic target, e.g. \\\"Hydrogen\\\", in atomic units.\[IndentingNewLine]\n\
getIonizationPotential[Target,q] returns the ionization potential of the q-th \
ion of the specified Target, in atomic units.\[IndentingNewLine]\n\
getIonizationPotential[{Target,q}] returns the ionization potential of the \
q-th ion of the specified Target, in atomic units.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getIonizationPotential", "[", 
   RowBox[{"Target_", ",", 
    RowBox[{"Charge_:", "0"}]}], "]"}], ":=", 
  RowBox[{"UnitConvert", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"ElementData", "[", 
      RowBox[{"Target", ",", "\"\<IonizationEnergies\>\""}], "]"}], 
     "\[LeftDoubleBracket]", 
     RowBox[{"Charge", "+", "1"}], "\[RightDoubleBracket]"}], 
    RowBox[{
     RowBox[{"Quantity", "[", 
      RowBox[{"1", ",", "\"\<AvogadroConstant\>\""}], "]"}], 
     RowBox[{"Quantity", "[", 
      RowBox[{"1", ",", "\"\<Hartrees\>\""}], "]"}]}]], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getIonizationPotential", "[", 
   RowBox[{"{", 
    RowBox[{"Target_", ",", 
     RowBox[{"Charge_:", "0"}]}], "}"}], "]"}], ":=", 
  RowBox[{"getIonizationPotential", "[", 
   RowBox[{"Target", ",", "Charge"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"99352a86-4d92-4475-8f97-b9096fd47592"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["makeDipoleList: main numerical integrator", \
"Section",ExpressionUUID->"6f836ab3-6b56-40cf-be11-85e8405d18b9"],

Cell[TextData[{
 "The main integration function is ",
 StyleBox["makeDipoleList", "Code"],
 ",  and its basic syntax is of the form ",
 StyleBox["makeDipoleList[VectorPotential\[Rule]A]", "Code"],
 ". Here the vector potential A must be a function object, such that for \
numeric ",
 StyleBox[" t ", "Code"],
 " the construct ",
 StyleBox["A[t]", "Code"],
 " returns a list of numbers after the appropriate field parameters have been \
introduced: thus the criterion is that, for a call of the form ",
 StyleBox["makeDipoleList[VectorPotential\[Rule]A, \
FieldParameters\[Rule]pars]", "Code"],
 ", a call of the form ",
 StyleBox["A[t]//.pars", "Code"],
 " returns a list of numbers for numeric ",
 StyleBox[" t ", "Code"],
 ". To see the available options use ",
 StyleBox["Options[makeDipoleList]", "Code"],
 ", and to get information on each option use the ",
 StyleBox["?VectorPotential", "Code"],
 " construct."
}], "Text",ExpressionUUID->"32069df7-8391-4698-8cc0-c50a1ae44962"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"makeDipoleList", "::", "usage"}], "=", 
    "\"\<makeDipoleList[VectorPotential\[Rule]A] calculates the dipole \
response to the vector potential A.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VectorPotential", "::", "usage"}], "=", 
   "\"\<VectorPotential is an option for makeDipole list which specifies the \
field's vector potential. Usage should be VectorPotential\[Rule]A, where \
A[t]//.pars must yield a list of numbers for numeric t and parameters \
indicated by FieldParameters\[Rule]pars.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"VectorPotentialGradient", "::", "usage"}], "=", 
   "\"\<VectorPotentialGradient is an option for makeDipole list which \
specifies the gradient of the field's vector potential. Usage should be \
VectorPotentialGradient\[Rule]GA, where GA[t]//.pars must yield a square \
matrix of the same dimension as the vector potential for numeric t and \
parameters indicated by FieldParameters\[Rule]pars. The indices must be such \
that GA[t]\[LeftDoubleBracket]i,j\[RightDoubleBracket] returns \
\!\(\*SubscriptBox[\(\[PartialD]\), \(i\)]\)\!\(\*SubscriptBox[\(A\), \
\(j\)]\)[t].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ElectricField", "::", "usage"}], "=", 
   "\"\<ElectricField is an option for makeDipole list which specifies an \
electric field to use in the ionization matrix element, in case the time \
derivative of the vector potential is not desired. Usage should be \
ElectricField\[Rule]F, where F[t]//.pars must yield a list of numbers for \
numeric t and parameters indicated by FieldParameters\[Rule]pars.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FieldParameters", "::", "usage"}], "=", 
   "\"\<FieldParameters is an option for makeDipole list which provides the \
parameters, as a list of replacement rules, to use in evaluating the vector \
potential. If the vector potential is provided as VectorPotential\[Rule]A, \
and the parameters as FieldParameters\[Rule]pars, then A[t]//.pars must yield \
a list of numbers if given a numeric argument t.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Preintegrals", "::", "usage"}], "=", 
   "\"\<Preintegrals is an option for makeDipole list which specifies whether \
the preintegrals of the vector potential should be \\\"Analytic\\\" or \
\\\"Numeric\\\".\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ReportingFunction", "::", "usage"}], "=", 
   "\"\<ReportingFunction is an option for makeDipole list which specifies a \
function used to report the results, either internally (by the default, \
Identity) or to an external file.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Gate", "::", "usage"}], "=", 
   "\"\<Gate is an option for makeDipole list which specifies the integration \
gate to use. Usage as Gate\[Rule]g, nGate\[Rule]n will gate the integral at \
time \[Omega]t/\[Omega] by g[\[Omega]t,n]. The default is \
Gate\[Rule]SineSquaredGate[1/2].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nGate", "::", "usage"}], "=", 
   "\"\<nGate is an option for makeDipole list which specifies the total \
number of cycles in the integration gate.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"IonizationPotential", "::", "usage"}], "=", 
   "\"\<IonizationPotential is an option for makeDipoleList which specifies \
the ionization potential \!\(\*SubscriptBox[\(I\), \(p\)]\) of the \
target.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Target", "::", "usage"}], "=", 
   "\"\<Target is an option for makeDipoleList which specifies chemical \
species producing the HHG emission, pulling the ionization potential from the \
Wolfram ElementData curated data set.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DipoleTransitionMatrixElement", "::", "usage"}], "=", 
   "\"\<DipoleTransitionMatrixElement is an option for makeDipoleList which \
secifies a function f to use as the dipole transition matrix element, or a \
pair of functions {\!\(\*SubscriptBox[\(f\), \
\(ion\)]\),\!\(\*SubscriptBox[\(f\), \(rec\)]\)} to be used separately for \
the ionization and recombination dipoels, to be used in the form \
f[p,\[Kappa]]=f[p,\!\(\*SqrtBox[\(2 \*SubscriptBox[\(I\), \
\(p\)]\)]\)].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]Correction", "::", "usage"}], "=", 
   "\"\<\[Epsilon]Correction is an option for makeDipoleList which specifies \
the regularization correction \[Epsilon], i.e. as used in the factor \
\!\(\*FractionBox[\(1\), SuperscriptBox[\((t - tt + \
\[ImaginaryI]\[Epsilon])\), \(3/2\)]]\).\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PointNumberCorrection", "::", "usage"}], "=", 
   "\"\<PointNumberCorrection is an option for makeDipoleList and timeAxis \
which specifies an extra number of points to be integrated over, which is \
useful to prevent Indeterminate errors when a Piecewise envelope is being \
differentiated at the boundaries.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"IntegrationPointsPerCycle", "::", "usage"}], "=", 
   "\"\<IntegrationPointsPerCycle is an option for makeDipoleList which \
controls the number of points per cycle to use for the integration. Set to \
Automatic, to follow PointsPerCycle, or to an integer.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RunInParallel", "::", "usage"}], "=", 
   "\"\<RunInParallel is an option for makeDipoleList which controls whether \
each RB-SFA instance is parallelized. It accepts False as the (Automatic) \
option, True, to parallelize each instance, or a pair of functions \
{TableCommand, SumCommand} to use for the iteration and summing, which could \
be e.g. {Inactive[ParallelTable], Inactive[Sum]}.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Simplifier", "::", "usage"}], "=", 
   "\"\<Simplifier is an option for makeDipoleList which specifies a function \
to use to simplify the intermediate and final analytical results.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CheckNumericFields", "::", "usage"}], "=", 
   "\"\<CheckNumericFields is an option for makeDipoleList which specifies \
whether to check for numeric values of A[t] and GA[t] for numeric t.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"QuadraticActionTerms", "::", "usage"}], "=", 
    "\"\<QuadraticActionTerms is an option for makeDipoleList which specifies \
whether to use quadratic terms in \[Del]\!\(\*SuperscriptBox[\(A\), \(2\)]\) \
in the action.\>\""}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Protect", "[", 
    RowBox[{
    "VectorPotential", ",", "VectorPotentialGradient", ",", "ElectricField", 
     ",", "FieldParameters", ",", "Preintegrals", ",", "ReportingFunction", 
     ",", "Gate", ",", "nGate", ",", "IonizationPotential", ",", "Target", 
     ",", "\[Epsilon]Correction", ",", "PointNumberCorrection", ",", 
     "DipoleTransitionMatrixElement", ",", "IntegrationPointsPerCycle", ",", 
     "RunInParallel", ",", "Simplifier", ",", "CheckNumericFields", ",", 
     "QuadraticActionTerms"}], "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "makeDipoleList", "]"}], "=", 
   RowBox[{"standardOptions", "~", "Join", "~", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"VectorPotentialGradient", "\[Rule]", "None"}], ",", 
      RowBox[{"ElectricField", "\[Rule]", "Automatic"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Preintegrals", "\[Rule]", "\"\<Analytic\>\""}], ",", 
      RowBox[{"ReportingFunction", "\[Rule]", "Identity"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Gate", "\[Rule]", 
       RowBox[{"SineSquaredGate", "[", 
        RowBox[{"1", "/", "2"}], "]"}]}], ",", 
      RowBox[{"nGate", "\[Rule]", 
       RowBox[{"3", "/", "2"}]}], ",", 
      RowBox[{"\[Epsilon]Correction", "\[Rule]", "0.1"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"IonizationPotential", "\[Rule]", "0.5"}], ",", 
      RowBox[{"Target", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"DipoleTransitionMatrixElement", "\[Rule]", "hydrogenicDTME"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"PointNumberCorrection", "\[Rule]", "0"}], ",", 
      RowBox[{"Verbose", "\[Rule]", "0"}], ",", 
      RowBox[{"CheckNumericFields", "\[Rule]", "True"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"RunInParallel", "\[Rule]", "Automatic"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Simplifier", "\[Rule]", "Identity"}], ",", 
      RowBox[{"QuadraticActionTerms", "\[Rule]", "True"}]}], 
     "\[IndentingNewLine]", "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"makeDipoleList", "::", "gate"}], "=", 
   "\"\<The integration gate g provided as Gate\[Rule]`1` is incorrect. Its \
usage as g[`2`,`3`] returns `4` and should return a number.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"makeDipoleList", "::", "pot"}], "=", 
   "\"\<The vector potential A provided as VectorPotential\[Rule]`1` is \
incorrect or is missing FieldParameters. Its usage as A[`2`] returns `3` and \
should return a list of numbers.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"makeDipoleList", "::", "efield"}], "=", 
   "\"\<The electric field f provided as ElectricField\[Rule]`1` is incorrect \
or is missing FieldParameters. Its usage as F[`2`] returns `3` and should \
return a list of numbers. Alternatively, use ElectricField\[Rule]Automatic.\>\
\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"makeDipoleList", "::", "gradpot"}], "=", 
   "\"\<The vector potential GA provided as VectorPotentialGradient\[Rule]`1` \
is incorrect or is missing FieldParameters. Its usage as GA[`2`] returns `3` \
and should return a square matrix of numbers. Alternatively, use \
VectorPotentialGradient\[Rule]None.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"makeDipoleList", "::", "preint"}], "=", 
   "\"\<Wrong Preintegrals option `1`. Valid options are \\\"Analytic\\\" and \
\\\"Numeric\\\".\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"makeDipoleList", "::", "runpar"}], "=", 
   "\"\<Wrong RunInParallel option `1`.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"makeDipoleList", "::", "carrfreq"}], "=", 
    "\"\<Non-numeric option CarrierFrequency `1`.\>\""}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"makeDipoleList", "[", 
   RowBox[{"OptionsPattern", "[", "]"}], "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"num", "=", 
       RowBox[{"OptionValue", "[", "TotalCycles", "]"}]}], ",", 
      RowBox[{"npp", "=", 
       RowBox[{"OptionValue", "[", "PointsPerCycle", "]"}]}], ",", "\[Omega]",
       ",", "\[IndentingNewLine]", "dipoleRec", ",", "dipoleIon", ",", 
      "\[Kappa]", ",", "\[IndentingNewLine]", "A", ",", "F", ",", "GA", ",", 
      "pi", ",", "ps", ",", "S", ",", "\[IndentingNewLine]", "gate", ",", 
      "tGate", ",", "setPreintegral", ",", "\[IndentingNewLine]", "tInit", 
      ",", "tFinal", ",", "\[Delta]t", ",", "\[Delta]tint", ",", 
      RowBox[{"\[Epsilon]", "=", 
       RowBox[{"OptionValue", "[", "\[Epsilon]Correction", "]"}]}], ",", 
      "\[IndentingNewLine]", "AInt", ",", "A2Int", ",", "GAInt", ",", 
      "GAdotAInt", ",", "AdotGAInt", ",", "GAIntInt", ",", 
      "\[IndentingNewLine]", "PScorrectionInt", ",", "constCorrectionInt", 
      ",", "GAIntdotGAIntInt", ",", "QuadMatrix", ",", "q", ",", 
      "\[IndentingNewLine]", "simplifier", ",", "prefactor", ",", "integrand",
       ",", "dipoleList", ",", "\[IndentingNewLine]", "TableCommand", ",", 
      "SumCommand"}], "\[IndentingNewLine]", "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"A", "[", "t_", "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", "VectorPotential", "]"}], "[", "t", "]"}],
        "//.", 
       RowBox[{"OptionValue", "[", "FieldParameters", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", "ElectricField", "]"}], "===", 
        "Automatic"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"F", "[", "t_", "]"}], "=", 
         RowBox[{"-", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"A", "[", "t", "]"}], ",", "t"}], "]"}]}]}], ";"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"F", "[", "t_", "]"}], "=", 
         RowBox[{
          RowBox[{
           RowBox[{"OptionValue", "[", "ElectricField", "]"}], "[", "t", 
           "]"}], "//.", 
          RowBox[{"OptionValue", "[", "FieldParameters", "]"}]}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"GA", "[", "t_", "]"}], "=", 
      RowBox[{"If", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"TrueQ", "[", 
         RowBox[{
          RowBox[{"OptionValue", "[", "VectorPotentialGradient", "]"}], 
          "\[Equal]", "None"}], "]"}], ",", "        ", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"Length", "[", 
            RowBox[{"A", "[", "tInit", "]"}], "]"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Length", "[", 
            RowBox[{"A", "[", "tInit", "]"}], "]"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"OptionValue", "[", "VectorPotentialGradient", "]"}], "[", 
          "t", "]"}], "//.", 
         RowBox[{"OptionValue", "[", "FieldParameters", "]"}]}]}], 
       "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Omega]", "=", 
      RowBox[{"GetCarrierFrequency", "[", 
       RowBox[{"OptionValue", "[", "CarrierFrequency", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"!", 
         RowBox[{"NumberQ", "[", "\[Omega]", "]"}]}], "&&", 
        RowBox[{"TrueQ", "[", 
         RowBox[{"OptionValue", "[", "CheckNumericFields", "]"}], "]"}]}], 
       ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"makeDipoleList", "::", "carrfreq"}], ",", "\[Omega]"}], 
         "]"}], ";", 
        RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"tInit", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"tFinal", "=", 
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]"}], "\[Omega]"], " ", "num"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"looping", " ", "timestep"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"\[Delta]t", "=", 
      FractionBox[
       RowBox[{"tFinal", "-", "tInit"}], 
       RowBox[{
        RowBox[{"num", "\[Times]", "npp"}], "+", 
        RowBox[{"OptionValue", "[", "PointNumberCorrection", "]"}]}]]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"integration", " ", "timestep"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"\[Delta]tint", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"OptionValue", "[", "IntegrationPointsPerCycle", "]"}], "===",
          "Automatic"}], ",", "\[Delta]t", ",", 
        FractionBox[
         RowBox[{"tFinal", "-", "tInit"}], 
         RowBox[{
          RowBox[{"num", "\[Times]", 
           RowBox[{"OptionValue", "[", "IntegrationPointsPerCycle", "]"}]}], 
          "+", 
          RowBox[{"OptionValue", "[", "PointNumberCorrection", "]"}]}]]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tGate", "=", 
      RowBox[{
       RowBox[{"OptionValue", "[", "nGate", "]"}], 
       FractionBox[
        RowBox[{"2", "\[Pi]"}], "\[Omega]"]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
      "Check", " ", "potential", " ", "and", " ", "potential", " ", 
       "gradient", " ", "for", " ", 
       RowBox[{"correctness", "."}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
        RowBox[{"To", " ", 
         RowBox[{"do", ":", " ", 
          RowBox[{
          "change", " ", "logic", " ", "conditions", " ", "to", " ", 
           "constructions", " ", "on", " ", 
           RowBox[{"VectorQ", "[", 
            RowBox[{"#", ",", "NumberQ"}], "]"}]}]}]}], "&"}], " ", "and", 
       " ", 
       RowBox[{"MatrixQ", "."}]}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"TrueQ", "[", 
        RowBox[{"OptionValue", "[", "CheckNumericFields", "]"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\[Omega]tRandom", "=", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Omega]", " ", "tInit"}], ",", 
              RowBox[{"\[Omega]", " ", "tFinal"}]}], "}"}], "]"}]}], "}"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"And", "@@", 
              RowBox[{"(", 
               RowBox[{"NumberQ", "/@", 
                RowBox[{"A", "[", 
                 RowBox[{"\[Omega]tRandom", "/", "\[Omega]"}], "]"}]}], 
               ")"}]}]}], ",", 
            RowBox[{
             RowBox[{"Message", "[", 
              RowBox[{
               RowBox[{"makeDipoleList", "::", "pot"}], ",", 
               RowBox[{"OptionValue", "[", "VectorPotential", "]"}], ",", 
               "\[Omega]tRandom", ",", 
               RowBox[{"A", "[", "\[Omega]tRandom", "]"}]}], "]"}], ";", 
             RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"And", "@@", 
              RowBox[{"(", 
               RowBox[{"NumberQ", "/@", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"GA", "[", 
                  RowBox[{"\[Omega]tRandom", "/", "\[Omega]"}], "]"}], 
                 "]"}]}], ")"}]}]}], ",", 
            RowBox[{
             RowBox[{"Message", "[", 
              RowBox[{
               RowBox[{"makeDipoleList", "::", "gradpot"}], ",", 
               RowBox[{"OptionValue", "[", "VectorPotentialGradient", "]"}], 
               ",", "\[Omega]tRandom", ",", 
               RowBox[{"GA", "[", "\[Omega]tRandom", "]"}]}], "]"}], ";", 
             RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"And", "@@", 
              RowBox[{"(", 
               RowBox[{"NumberQ", "/@", 
                RowBox[{"F", "[", 
                 RowBox[{"\[Omega]tRandom", "/", "\[Omega]"}], "]"}]}], 
               ")"}]}]}], ",", 
            RowBox[{
             RowBox[{"Message", "[", 
              RowBox[{
               RowBox[{"makeDipoleList", "::", "efield"}], ",", 
               RowBox[{"OptionValue", "[", "ElectricField", "]"}], ",", 
               "\[Omega]tRandom", ",", 
               RowBox[{"F", "[", "\[Omega]tRandom", "]"}]}], "]"}], ";", 
             RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gate", "[", "\[Omega]\[Tau]_", "]"}], ":=", 
      RowBox[{
       RowBox[{"OptionValue", "[", "Gate", "]"}], "[", 
       RowBox[{"\[Omega]\[Tau]", ",", 
        RowBox[{"OptionValue", "[", "nGate", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Omega]tRandom", "=", 
         RowBox[{"RandomReal", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Omega]", " ", "tInit"}], ",", 
            RowBox[{"\[Omega]", " ", "tFinal"}]}], "}"}], "]"}]}], "}"}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"TrueQ", "[", 
           RowBox[{"NumberQ", "[", 
            RowBox[{"gate", "[", "\[Omega]tRandom", "]"}], "]"}], "]"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{
            RowBox[{"makeDipoleList", "::", "gate"}], ",", 
            RowBox[{"OptionValue", "[", "Gate", "]"}], ",", "\[Omega]tRandom",
             ",", 
            RowBox[{"OptionValue", "[", "nGate", "]"}], ",", 
            RowBox[{"gate", "[", "\[Omega]tRandom", "]"}]}], "]"}], ";", 
          RowBox[{"Abort", "[", "]"}]}]}], "]"}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Target", " ", "setup"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"Which", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", "Target", "]"}], "===", "Automatic"}], 
       ",", 
       RowBox[{"\[Kappa]", "=", 
        SqrtBox[
         RowBox[{"2", 
          RowBox[{"OptionValue", "[", "IonizationPotential", "]"}]}]]}], ",", 
       "\[IndentingNewLine]", "True", ",", 
       RowBox[{"\[Kappa]", "=", 
        SqrtBox[
         RowBox[{"2", 
          RowBox[{"getIonizationPotential", "[", 
           RowBox[{"OptionValue", "[", "Target", "]"}], "]"}]}]]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"dim", "=", 
         RowBox[{"Length", "[", 
          RowBox[{"A", "[", 
           RowBox[{"RandomReal", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Omega]", " ", "tInit"}], ",", 
              RowBox[{"\[Omega]", " ", "tFinal"}]}], "}"}], "]"}], "]"}], 
          "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "Explicit", " ", "conjugation", " ", "of", " ", "the", " ", 
         "recombination", " ", "matrix", " ", "element", " ", "to", " ", 
         "keep", " ", "the", " ", "integrand", " ", 
         RowBox[{"analytic", "."}]}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Which", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", 
            RowBox[{
            "OptionValue", "[", "DipoleTransitionMatrixElement", "]"}], "]"}],
            "===", "List"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"dipoleIon", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"p1_", ",", "p2_", ",", "p3_"}], "}"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ";;", "dim"}], "\[RightDoubleBracket]"}], ",", 
              "\[Kappa]\[Kappa]_"}], "]"}], "=", 
            RowBox[{
             RowBox[{"First", "[", 
              RowBox[{
              "OptionValue", "[", "DipoleTransitionMatrixElement", "]"}], 
              "]"}], "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ";;", "dim"}], "\[RightDoubleBracket]"}], ",", 
              "\[Kappa]\[Kappa]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"dipoleRec", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"p1_", ",", "p2_", ",", "p3_"}], "}"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ";;", "dim"}], "\[RightDoubleBracket]"}], ",", 
              "\[Kappa]\[Kappa]_"}], "]"}], "=", 
            RowBox[{"Assuming", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                 "p1", ",", "p2", ",", "p3", ",", "\[Kappa]\[Kappa]"}], "}"}],
                 "\[Element]", "Reals"}], "}"}], ",", 
              RowBox[{"Simplify", "[", "\[IndentingNewLine]", 
               RowBox[{"Conjugate", "[", 
                RowBox[{
                 RowBox[{"Last", "[", 
                  RowBox[{
                  "OptionValue", "[", "DipoleTransitionMatrixElement", "]"}], 
                  "]"}], "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], 
                   "\[LeftDoubleBracket]", 
                   RowBox[{"1", ";;", "dim"}], "\[RightDoubleBracket]"}], ",",
                   "\[Kappa]\[Kappa]"}], "]"}], "]"}], "\[IndentingNewLine]", 
               "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", ",", "True", 
          ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"dipoleIon", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"p1_", ",", "p2_", ",", "p3_"}], "}"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ";;", "dim"}], "\[RightDoubleBracket]"}], ",", 
              "\[Kappa]\[Kappa]_"}], "]"}], "=", 
            RowBox[{
             RowBox[{
             "OptionValue", "[", "DipoleTransitionMatrixElement", "]"}], "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ";;", "dim"}], "\[RightDoubleBracket]"}], ",", 
              "\[Kappa]\[Kappa]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"dipoleRec", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"p1_", ",", "p2_", ",", "p3_"}], "}"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ";;", "dim"}], "\[RightDoubleBracket]"}], ",", 
              "\[Kappa]\[Kappa]_"}], "]"}], "=", 
            RowBox[{"Assuming", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                 "p1", ",", "p2", ",", "p3", ",", "\[Kappa]\[Kappa]"}], "}"}],
                 "\[Element]", "Reals"}], "}"}], ",", 
              RowBox[{"Simplify", "[", "\[IndentingNewLine]", 
               RowBox[{"Conjugate", "[", 
                RowBox[{
                 RowBox[{
                 "OptionValue", "[", "DipoleTransitionMatrixElement", "]"}], 
                 "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], 
                   "\[LeftDoubleBracket]", 
                   RowBox[{"1", ";;", "dim"}], "\[RightDoubleBracket]"}], ",",
                   "\[Kappa]\[Kappa]"}], "]"}], "]"}], "\[IndentingNewLine]", 
               "]"}]}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"simplifier", "=", 
      RowBox[{"OptionValue", "[", "Simplifier", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"q", "=", 
      RowBox[{"Boole", "[", 
       RowBox[{"TrueQ", "[", 
        RowBox[{"OptionValue", "[", "QuadraticActionTerms", "]"}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"setPreintegral", "[", 
       RowBox[{
       "integralVariable_", ",", "preintegrand_", ",", "dimensions_", ",", 
        "integrateWithoutGradient_", ",", "parametric_"}], "]"}], ":=", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"OptionValue", "[", "VectorPotentialGradient", "]"}], "=!=",
           "None"}], "||", 
         RowBox[{"TrueQ", "[", "integrateWithoutGradient", "]"}]}], ",", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "Vector", " ", "potential", " ", "gradient", " ", "specified"}], 
          ",", " ", 
          RowBox[{
          "or", " ", "integral", " ", "variable", " ", "does", " ", "not", 
           " ", "depend", " ", "on", " ", "it"}], ",", " ", 
          RowBox[{"so", " ", "integrate"}]}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Which", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"OptionValue", "[", "Preintegrals", "]"}], "\[Equal]", 
            "\"\<Analytic\>\""}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"integralVariable", "[", 
              RowBox[{"t_", ",", "tt_"}], "]"}], "=", 
             RowBox[{"simplifier", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"#", "/.", 
                    RowBox[{"{", 
                    RowBox[{"\[Tau]", "\[Rule]", "t"}], "}"}]}], ")"}], "-", 
                  RowBox[{"(", 
                   RowBox[{"#", "/.", 
                    RowBox[{"{", 
                    RowBox[{"\[Tau]", "\[Rule]", "tt"}], "}"}]}], ")"}]}], 
                 ")"}], "&"}], "[", 
               RowBox[{"Integrate", "[", 
                RowBox[{
                 RowBox[{"preintegrand", "[", 
                  RowBox[{"\[Tau]", ",", "tt"}], "]"}], ",", "\[Tau]"}], 
                "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
           "\[IndentingNewLine]", ",", 
           RowBox[{
            RowBox[{"OptionValue", "[", "Preintegrals", "]"}], "\[Equal]", 
            "\"\<Numeric\>\""}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Which", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"TrueQ", "[", 
               RowBox[{"Not", "[", "parametric", "]"}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Block", "[", 
                RowBox[{
                 RowBox[{"{", "innerVariable", "}"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"integralVariable", "[", 
                   RowBox[{"t_", ",", "tt_"}], "]"}], "=", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"innerVariable", "[", "t", "]"}], "-", 
                    RowBox[{"innerVariable", "[", "tt", "]"}]}], "/.", 
                    RowBox[{"First", "[", "\[IndentingNewLine]", 
                    RowBox[{"NDSolve", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"innerVariable", "'"}], "[", "\[Tau]", "]"}], 
                    "\[Equal]", 
                    RowBox[{"preintegrand", "[", "\[Tau]", "]"}]}], ",", 
                    RowBox[{
                    RowBox[{"innerVariable", "[", "tInit", "]"}], "\[Equal]", 
                    RowBox[{"ConstantArray", "[", 
                    RowBox[{"0", ",", "dimensions"}], "]"}]}]}], "}"}], ",", 
                    "innerVariable", ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Tau]", ",", "tInit", ",", "tFinal"}], "}"}], 
                    ",", 
                    RowBox[{"MaxStepSize", "\[Rule]", 
                    RowBox[{"0.25", "/", "\[Omega]"}]}]}], "]"}], 
                    "\[IndentingNewLine]", "]"}]}], ")"}]}]}], 
                "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
              ",", "True", ",", "\[IndentingNewLine]", 
              RowBox[{"Block", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                 "matrixpreintegrand", ",", "innerVariable", ",", 
                  "\[Tau]pre"}], "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"matrixpreintegrand", "[", 
                   RowBox[{"indices_", ",", 
                    RowBox[{"t_", "?", "NumericQ"}], ",", 
                    RowBox[{"tt_", "?", "NumericQ"}]}], "]"}], ":=", 
                  RowBox[{
                   RowBox[{"preintegrand", "[", 
                    RowBox[{"t", ",", "tt"}], "]"}], "\[LeftDoubleBracket]", 
                   RowBox[{
                    RowBox[{"##", "&"}], "@@", "indices"}], 
                   "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"integralVariable", "[", 
                   RowBox[{"t_", ",", "tt_"}], "]"}], "=", 
                  RowBox[{"Array", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"innerVariable", "[", "##", "]"}], "[", 
                    RowBox[{
                    RowBox[{"t", "-", "tt"}], ",", "tt"}], "]"}], "/.", 
                    RowBox[{"First", "@", 
                    RowBox[{"NDSolve", "[", 
                    RowBox[{
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"innerVariable", "[", "##", "]"}], "[", 
                    RowBox[{"\[Tau]pre", ",", "tt"}], "]"}], ",", 
                    "\[Tau]pre"}], "]"}], "\[Equal]", 
                    RowBox[{"Piecewise", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"matrixpreintegrand", "[", 
                    RowBox[{
                    RowBox[{"{", "##", "}"}], ",", 
                    RowBox[{"tt", "+", "\[Tau]pre"}], ",", "tt"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"tt", "+", "\[Tau]pre"}], "\[LessEqual]", 
                    "tFinal"}]}], "}"}], "}"}], ",", "0"}], "]"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"innerVariable", "[", "##", "]"}], "[", 
                    RowBox[{"0", ",", "tt"}], "]"}], "\[Equal]", "0"}]}], 
                    "\[IndentingNewLine]", "}"}], ",", 
                    RowBox[{"innerVariable", "[", "##", "]"}], 
                    "\[IndentingNewLine]", ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Tau]pre", ",", "0", ",", 
                    RowBox[{"tFinal", "-", "tInit"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"tt", ",", "tInit", ",", "tFinal"}], "}"}], 
                    "\[IndentingNewLine]", ",", 
                    RowBox[{"MaxStepSize", "\[Rule]", 
                    RowBox[{"0.25", "/", "\[Omega]"}]}]}], 
                    "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
                    ")"}], "&"}], ",", "dimensions"}], "]"}]}], ";"}]}], 
               "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
            ";"}]}], "\[IndentingNewLine]", "]"}], ";"}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{
         RowBox[{"OptionValue", "[", "VectorPotentialGradient", "]"}], "===", 
         "None"}], ",", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "Vector", " ", "potential", " ", "gradient", " ", "has", " ", "not",
            " ", "been", " ", "specified"}], ",", " ", 
          RowBox[{
          "and", " ", "integral", " ", "variable", " ", "depends", " ", "on", 
           " ", "it"}], ",", " ", 
          RowBox[{
          "so", " ", "return", " ", "appropriate", " ", "zero", " ", 
           "matrix"}]}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"integralVariable", "[", "t_", "]"}], "=", 
          RowBox[{"ConstantArray", "[", 
           RowBox[{"0", ",", "dimensions"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"integralVariable", "[", 
           RowBox[{"t_", ",", "tt_"}], "]"}], "=", 
          RowBox[{"ConstantArray", "[", 
           RowBox[{"0", ",", "dimensions"}], "]"}]}], ";"}]}], 
       "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"Apply", "[", 
      RowBox[{"setPreintegral", ",", 
       RowBox[{"(", GridBox[{
          {"AInt", 
           RowBox[{
            RowBox[{"A", "[", "#1", "]"}], "&"}], 
           RowBox[{"{", 
            RowBox[{"Length", "[", 
             RowBox[{"A", "[", "tInit", "]"}], "]"}], "}"}], "True", "False"},
          {"A2Int", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", "#1", "]"}], ".", 
             RowBox[{"A", "[", "#1", "]"}]}], "&"}], 
           RowBox[{"{", "}"}], "True", "False"},
          {"GAInt", 
           RowBox[{
            RowBox[{"GA", "[", "#1", "]"}], "&"}], 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"A", "[", "tInit", "]"}], "]"}], ",", 
             RowBox[{"Length", "[", 
              RowBox[{"A", "[", "tInit", "]"}], "]"}]}], "}"}], "False", 
           "False"},
          {"GAdotAInt", 
           RowBox[{
            RowBox[{
             RowBox[{"GA", "[", "#1", "]"}], ".", 
             RowBox[{"A", "[", "#1", "]"}]}], "&"}], 
           RowBox[{"{", 
            RowBox[{"Length", "[", 
             RowBox[{"A", "[", "tInit", "]"}], "]"}], "}"}], "False", "False"},
          {"AdotGAInt", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", "#1", "]"}], ".", 
             RowBox[{"GA", "[", "#1", "]"}]}], "&"}], 
           RowBox[{"{", 
            RowBox[{"Length", "[", 
             RowBox[{"A", "[", "tInit", "]"}], "]"}], "}"}], "False", "False"},
          {"GAIntInt", 
           RowBox[{
            RowBox[{"GAInt", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}], "&"}], 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"A", "[", "tInit", "]"}], "]"}], ",", 
             RowBox[{"Length", "[", 
              RowBox[{"A", "[", "tInit", "]"}], "]"}]}], "}"}], "False", 
           "True"},
          {"PScorrectionInt", 
           RowBox[{
            RowBox[{
             RowBox[{"GAdotAInt", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}], "+", 
             RowBox[{
              RowBox[{"A", "[", "#1", "]"}], ".", 
              RowBox[{"GAInt", "[", 
               RowBox[{"#1", ",", "#2"}], "]"}]}], "-", 
             RowBox[{"q", " ", 
              RowBox[{
               RowBox[{
                RowBox[{"GAInt", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}], "\[Transpose]"}], ".", 
               RowBox[{"GAdotAInt", "[", 
                RowBox[{"#1", ",", "#2"}], "]"}]}]}]}], "&"}], 
           RowBox[{"{", 
            RowBox[{"Length", "[", 
             RowBox[{"A", "[", "tInit", "]"}], "]"}], "}"}], "False", "True"},
          {"GAIntdotGAIntInt", 
           RowBox[{
            RowBox[{"q", " ", 
             RowBox[{
              RowBox[{
               RowBox[{"GAInt", "[", 
                RowBox[{"#1", ",", "#2"}], "]"}], "\[Transpose]"}], ".", 
              RowBox[{"GAInt", "[", 
               RowBox[{"#1", ",", "#2"}], "]"}]}]}], "&"}], 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"A", "[", "tInit", "]"}], "]"}], ",", 
             RowBox[{"Length", "[", 
              RowBox[{"A", "[", "tInit", "]"}], "]"}]}], "}"}], "False", 
           "True"},
          {"constCorrectionInt", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"A", "[", "#1", "]"}], "-", 
               RowBox[{
                FractionBox["q", "2"], 
                RowBox[{"GAdotAInt", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}]}], ")"}], ".", 
             RowBox[{"GAdotAInt", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}]}], "&"}], 
           RowBox[{"{", "}"}], "False", "True"}
         },
         GridBoxAlignment->{"Columns" -> {{Left}}}], ")"}], ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           SubscriptBox["t", "0"], "t"], 
          RowBox[{"A", 
           RowBox[{"(", "\[Tau]", ")"}], 
           RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}], ",", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           SubscriptBox["t", "0"], "t"], 
          RowBox[{"A", 
           SuperscriptBox[
            RowBox[{"(", "\[Tau]", ")"}], "2"], 
           RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}], ",", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           SubscriptBox["t", "0"], "t"], 
          RowBox[{
           RowBox[{"\[Del]", "A"}], 
           RowBox[{"(", "\[Tau]", ")"}], 
           RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}], ",", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           SubscriptBox["t", "0"], "t"], 
          RowBox[{
           RowBox[{"\[Del]", "A"}], 
           RowBox[{
            RowBox[{"(", "\[Tau]", ")"}], "\[CenterDot]", "A"}], 
           RowBox[{"(", "\[Tau]", ")"}], 
           RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}], ",", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           SubscriptBox["t", "0"], "t"], 
          RowBox[{"A", 
           RowBox[{
            RowBox[{"(", "\[Tau]", ")"}], "\[CenterDot]", 
            RowBox[{"\[Del]", "A"}]}], 
           RowBox[{"(", "\[Tau]", ")"}], 
           RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}], ",", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           RowBox[{"t", "'"}], "t"], 
          RowBox[{
           SubsuperscriptBox["\[Integral]", 
            RowBox[{"t", "'"}], "\[Tau]"], 
           RowBox[{
            RowBox[{"\[Del]", "A"}], 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "'"}], ")"}], 
            RowBox[{"\[DifferentialD]", 
             RowBox[{"\[Tau]", "'"}]}], 
            RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Integral]", 
            RowBox[{"t", "'"}], "t"], 
           RowBox[{
            SubsuperscriptBox["\[Integral]", 
             RowBox[{"t", "'"}], "\[Tau]"], 
            RowBox[{
             RowBox[{
              SubscriptBox["\[PartialD]", "j"], 
              SubscriptBox["A", "k"]}], 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "'"}], ")"}], 
             SubscriptBox["A", "k"], 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "'"}], ")"}], 
             RowBox[{"\[DifferentialD]", 
              RowBox[{"\[Tau]", "'"}]}]}]}]}], "+", 
          RowBox[{
           SubscriptBox["A", "k"], 
           RowBox[{"(", "\[Tau]", ")"}], 
           RowBox[{
            SubsuperscriptBox["\[Integral]", 
             RowBox[{"t", "'"}], "\[Tau]"], 
            RowBox[{
             RowBox[{
              SubscriptBox["\[PartialD]", "k"], 
              SubscriptBox["A", "j"]}], 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "'"}], ")"}], 
             RowBox[{"\[DifferentialD]", 
              RowBox[{"\[Tau]", "'"}]}]}]}]}], "-", 
          RowBox[{
           SubsuperscriptBox["\[Integral]", 
            RowBox[{"t", "'"}], "\[Tau]"], 
           RowBox[{
            RowBox[{
             SubscriptBox["\[PartialD]", "i"], 
             SubscriptBox["A", "j"]}], 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "'"}], ")"}], 
            RowBox[{"\[DifferentialD]", 
             RowBox[{"\[Tau]", "'"}]}], 
            RowBox[{
             SubsuperscriptBox["\[Integral]", 
              RowBox[{"t", "'"}], "\[Tau]"], 
             RowBox[{
              RowBox[{
               SubscriptBox["\[PartialD]", "i"], 
               SubscriptBox["A", "k"]}], 
              RowBox[{"(", 
               RowBox[{"\[Tau]", "'"}], ")"}], 
              SubscriptBox["A", "k"], 
              RowBox[{"(", 
               RowBox[{"\[Tau]", "'"}], ")"}], 
              RowBox[{"\[DifferentialD]", 
               RowBox[{"\[Tau]", "'"}]}], 
              RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}]}]}], ",", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           RowBox[{"t", "'"}], "t"], 
          RowBox[{
           SubsuperscriptBox["\[Integral]", 
            SubscriptBox["t", "0"], "t"], 
           RowBox[{
            RowBox[{
             SubscriptBox["\[PartialD]", "i"], 
             SubscriptBox["A", "j"]}], 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "'"}], ")"}], 
            SubscriptBox["A", "j"], 
            RowBox[{"(", 
             RowBox[{"\[Tau]", "'"}], ")"}], 
            RowBox[{"\[DifferentialD]", 
             RowBox[{"\[Tau]", "'"}]}], 
            RowBox[{
             SubsuperscriptBox["\[Integral]", 
              SubscriptBox["t", "0"], "t"], 
             RowBox[{
              RowBox[{
               SubscriptBox["\[PartialD]", "i"], 
               SubscriptBox["A", "k"]}], 
              RowBox[{"(", 
               RowBox[{"\[Tau]", "'"}], ")"}], 
              SubscriptBox["A", "k"], 
              RowBox[{"(", 
               RowBox[{"\[Tau]", "'"}], ")"}], 
              RowBox[{"\[DifferentialD]", 
               RowBox[{"\[Tau]", "'"}]}], 
              RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}]}]}], ",", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           RowBox[{"t", "'"}], "t"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["A", "k"], 
              RowBox[{"(", "\[Tau]", ")"}]}], "-", 
             RowBox[{
              FractionBox["1", "2"], 
              RowBox[{
               SubsuperscriptBox["\[Integral]", 
                RowBox[{"t", "'"}], "\[Tau]"], 
               RowBox[{
                RowBox[{
                 SubscriptBox["\[PartialD]", "k"], 
                 SubscriptBox["A", "i"]}], 
                RowBox[{"(", 
                 RowBox[{"\[Tau]", "'"}], ")"}], 
                SubscriptBox["A", "i"], 
                RowBox[{"(", 
                 RowBox[{"\[Tau]", "'"}], ")"}], 
                RowBox[{"\[DifferentialD]", 
                 RowBox[{"\[Tau]", "'"}]}]}]}]}]}], ")"}], "\[CenterDot]", 
           RowBox[{
            SubsuperscriptBox["\[Integral]", 
             RowBox[{"t", "'"}], "\[Tau]"], 
            RowBox[{
             RowBox[{
              SubscriptBox["\[PartialD]", "k"], 
              SubscriptBox["A", "j"]}], 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "'"}], ")"}], 
             SubscriptBox["A", "j"], 
             RowBox[{"(", 
              RowBox[{"\[Tau]", "'"}], ")"}], 
             RowBox[{"\[DifferentialD]", 
              RowBox[{"\[Tau]", "'"}]}], 
             RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}]}]}], "}"}], ";"}], 
      "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Displaced", " ", "momentum"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pi", "[", 
       RowBox[{"p_", ",", "t_", ",", "tt_"}], "]"}], ":=", 
      RowBox[{"p", "+", 
       RowBox[{"A", "[", "t", "]"}], "-", 
       RowBox[{
        RowBox[{"GAInt", "[", 
         RowBox[{"t", ",", "tt"}], "]"}], ".", "p"}], "-", 
       RowBox[{"GAdotAInt", "[", 
        RowBox[{"t", ",", "tt"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
      "Quadratic", " ", "coefficient", " ", "in", " ", "nondipole", " ", 
       "action"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"QuadMatrix", "[", 
       RowBox[{"t_", ",", "tt_"}], "]"}], ":=", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"GAIntInt", "[", 
          RowBox[{"t", ",", "tt"}], "]"}], "+", 
         RowBox[{
          RowBox[{"GAIntInt", "[", 
           RowBox[{"t", ",", "tt"}], "]"}], "\[Transpose]"}]}], "2"], "-", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"GAIntdotGAIntInt", "[", 
         RowBox[{"t", ",", "tt"}], "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Stationary", " ", "momentum", " ", "and", " ", "action"}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ps", "[", 
       RowBox[{"t_", ",", "tt_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"ps", "[", 
        RowBox[{"t", ",", "tt"}], "]"}], "=", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"t", "-", "tt", "-", 
           RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]]}], 
        RowBox[{
         RowBox[{"Inverse", "[", 
          RowBox[{
           RowBox[{"IdentityMatrix", "[", 
            RowBox[{"Length", "[", 
             RowBox[{"A", "[", "tInit", "]"}], "]"}], "]"}], "-", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"t", "-", "tt", "-", 
              RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]], "2", 
            RowBox[{"QuadMatrix", "[", 
             RowBox[{"t", ",", "tt"}], "]"}]}]}], "]"}], ".", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"AInt", "[", 
            RowBox[{"t", ",", "tt"}], "]"}], "-", 
           RowBox[{"PScorrectionInt", "[", 
            RowBox[{"t", ",", "tt"}], "]"}]}], ")"}]}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"S", "[", 
       RowBox[{"t_", ",", "tt_"}], "]"}], ":=", 
      RowBox[{"simplifier", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Total", "[", 
            SuperscriptBox[
             RowBox[{"ps", "[", 
              RowBox[{"t", ",", "tt"}], "]"}], "2"], "]"}], "+", 
           SuperscriptBox["\[Kappa]", "2"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"t", "-", "tt"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"ps", "[", 
          RowBox[{"t", ",", "tt"}], "]"}], ".", 
         RowBox[{"AInt", "[", 
          RowBox[{"t", ",", "tt"}], "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"A2Int", "[", 
          RowBox[{"t", ",", "tt"}], "]"}]}], "-", 
        RowBox[{"(", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"ps", "[", 
            RowBox[{"t", ",", "tt"}], "]"}], ".", 
           RowBox[{"QuadMatrix", "[", 
            RowBox[{"t", ",", "tt"}], "]"}], ".", 
           RowBox[{"ps", "[", 
            RowBox[{"t", ",", "tt"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"ps", "[", 
            RowBox[{"t", ",", "tt"}], "]"}], ".", 
           RowBox[{"PScorrectionInt", "[", 
            RowBox[{"t", ",", "tt"}], "]"}]}], "+", 
          RowBox[{"constCorrectionInt", "[", 
           RowBox[{"t", ",", "tt"}], "]"}]}], "\[IndentingNewLine]", ")"}]}], 
       "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"prefactor", "[", 
       RowBox[{"t_", ",", "\[Tau]_"}], "]"}], ":=", 
      RowBox[{"\[ImaginaryI]", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"2", "\[Pi]"}], 
          RowBox[{"\[Epsilon]", "+", 
           RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]], ")"}], 
        RowBox[{"3", "/", "2"}]], 
       RowBox[{"dipoleRec", "[", 
        RowBox[{
         RowBox[{"pi", "[", 
          RowBox[{
           RowBox[{"ps", "[", 
            RowBox[{"t", ",", 
             RowBox[{"t", "-", "\[Tau]"}]}], "]"}], ",", "t", ",", 
           RowBox[{"t", "-", "\[Tau]"}]}], "]"}], ",", "\[Kappa]"}], "]"}], 
       "\[Times]", 
       RowBox[{
        RowBox[{"dipoleIon", "[", 
         RowBox[{
          RowBox[{"pi", "[", 
           RowBox[{
            RowBox[{"ps", "[", 
             RowBox[{"t", ",", 
              RowBox[{"t", "-", "\[Tau]"}]}], "]"}], ",", 
            RowBox[{"t", "-", "\[Tau]"}], ",", 
            RowBox[{"t", "-", "\[Tau]"}]}], "]"}], ",", "\[Kappa]"}], "]"}], 
        ".", 
        RowBox[{"F", "[", 
         RowBox[{"t", "-", "\[Tau]"}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"integrand", "[", 
       RowBox[{"t_", ",", "\[Tau]_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"prefactor", "[", 
        RowBox[{"t", ",", "\[Tau]"}], "]"}], 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"S", "[", 
          RowBox[{"t", ",", 
           RowBox[{"t", "-", "\[Tau]"}]}], "]"}]}], "]"}], 
       RowBox[{"gate", "[", 
        RowBox[{"\[Omega]", " ", "\[Tau]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Debugging", " ", 
        RowBox[{"constructs", ".", " ", "Verbose"}]}], "\[Rule]", 
       RowBox[{
        RowBox[{
        "1", " ", "prints", " ", "information", " ", "about", " ", "the", " ",
          "internal", " ", 
         RowBox[{"functions", ".", " ", "Verbose"}]}], "\[Rule]", 
        RowBox[{
         RowBox[{
         "2", " ", "returns", " ", "all", " ", "the", " ", "relevant", " ", 
          "internal", " ", "functions", " ", "and", " ", 
          RowBox[{"stops", ".", " ", "Verbose"}]}], "\[Rule]", 
         RowBox[{
          RowBox[{"3", " ", "for", " ", "quantum"}], "-", 
          RowBox[{"orbit", " ", 
           RowBox[{"constructs", "."}]}]}]}]}]}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Which", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", "Verbose", "]"}], "\[Equal]", "1"}], ",", 
       RowBox[{"Information", "/@", 
        RowBox[{"{", 
         RowBox[{
         "A", ",", "GA", ",", "ps", ",", "pi", ",", "S", ",", "AInt", ",", 
          "A2Int", ",", "GAInt", ",", "GAdotAInt", ",", "AdotGAInt", ",", 
          "GAIntInt", ",", "PScorrectionInt", ",", "constCorrectionInt", ",", 
          "GAIntdotGAIntInt"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"OptionValue", "[", "Verbose", "]"}], "\[Equal]", "2"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"t", "=", 
             RowBox[{"Symbol", "[", "\"\<t\>\"", "]"}]}], ",", 
            RowBox[{"tt", "=", 
             RowBox[{"Symbol", "[", "\"\<tt\>\"", "]"}]}], ",", 
            RowBox[{"\[Tau]", "=", 
             RowBox[{"Symbol", "[", "\"\<\[Tau]\>\"", "]"}]}], ",", 
            RowBox[{"p", "=", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Symbol", "[", "\"\<p1\>\"", "]"}], ",", 
                RowBox[{"Symbol", "[", "\"\<p2\>\"", "]"}], ",", 
                RowBox[{"Symbol", "[", "\"\<p3\>\"", "]"}]}], "}"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"1", ";;", 
               RowBox[{"Length", "[", 
                RowBox[{"A", "[", 
                 RowBox[{"\[Omega]", " ", "tInit"}], "]"}], "]"}]}], 
              "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"A", "[", "t", "]"}], ",", 
            RowBox[{"GA", "[", "t", "]"}], ",", 
            RowBox[{"ps", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"pi", "[", 
             RowBox[{"p", ",", "t", ",", "tt"}], "]"}], ",", 
            RowBox[{"S", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"AInt", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"A2Int", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"GAInt", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"GAdotAInt", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"AdotGAInt", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"GAIntInt", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"PScorrectionInt", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"constCorrectionInt", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"GAIntdotGAIntInt", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"QuadMatrix", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", 
            RowBox[{"integrand", "[", 
             RowBox[{"t", ",", "\[Tau]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"OptionValue", "[", "Verbose", "]"}], "\[Equal]", "3"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Function", "[", 
           RowBox[{"Evaluate", "[", 
            RowBox[{"prefactor", "[", 
             RowBox[{"#1", ",", 
              RowBox[{"#1", "-", "#2"}]}], "]"}], "]"}], "]"}], ",", 
          RowBox[{"Function", "[", 
           RowBox[{"Evaluate", "[", 
            RowBox[{"S", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}], "]"}], "]"}]}], 
         "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Single", "-", 
       RowBox[{"run", " ", "parallelization"}]}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Which", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"OptionValue", "[", "RunInParallel", "]"}], "===", 
         "Automatic"}], "||", 
        RowBox[{
         RowBox[{"OptionValue", "[", "RunInParallel", "]"}], "===", 
         "False"}]}], ",", " ", 
       RowBox[{
        RowBox[{"TableCommand", "=", "Table"}], ";", 
        RowBox[{"SumCommand", "=", "Sum"}], ";"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"OptionValue", "[", "RunInParallel", "]"}], "===", "True"}], 
       ",", 
       RowBox[{
        RowBox[{"TableCommand", "=", "ParallelTable"}], ";", 
        RowBox[{"SumCommand", "=", "Sum"}], ";"}], ",", "\[IndentingNewLine]",
        "True", ",", 
       RowBox[{
        RowBox[{"TableCommand", "=", 
         RowBox[{
          RowBox[{"OptionValue", "[", "RunInParallel", "]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
        RowBox[{"SumCommand", "=", 
         RowBox[{
          RowBox[{"OptionValue", "[", "RunInParallel", "]"}], 
          "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Numerical", " ", "integration", " ", "loop"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"dipoleList", "=", 
      RowBox[{"Table", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"OptionValue", "[", "ReportingFunction", "]"}], "[", 
         "\[IndentingNewLine]", 
         RowBox[{"\[Delta]tint", " ", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{"(", "\[IndentingNewLine]", 
             RowBox[{"integrand", "[", 
              RowBox[{"t", ",", "\[Tau]"}], "]"}], "\[IndentingNewLine]", 
             ")"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Tau]", ",", "0", ",", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"OptionValue", "[", "Preintegrals", "]"}], 
                 "\[Equal]", "\"\<Analytic\>\""}], ",", "tGate", ",", 
                RowBox[{"Min", "[", 
                 RowBox[{
                  RowBox[{"t", "-", "tInit"}], ",", "tGate"}], "]"}]}], "]"}],
               ",", "\[Delta]tint"}], "}"}]}], "]"}]}], "\[IndentingNewLine]",
          "]"}], "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "tInit", ",", "tFinal", ",", "\[Delta]t"}], 
         "}"}]}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
     "dipoleList"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"d56fe599-2eb1-483c-910d-4ae22a3f3c3d"]
}, Closed]],

Cell[CellGroupData[{

Cell["Quantum orbit functions suite", \
"Section",ExpressionUUID->"d7c2a0eb-bd43-4c3c-b9c8-5933170b1ca1"],

Cell[CellGroupData[{

Cell["Complex root finder", \
"Subsection",ExpressionUUID->"e4256a5c-53fb-4c4b-86c6-98a7067ce466"],

Cell["\<\
This section implements a routine for solving contains subroutines for the \
numerical solution of multiple simultaneous complex-valued transcendental \
equations, essentially by using the Newton\[CloseCurlyQuote]s-method solver \
implemented in FindRoot, and seeding it multiple times with a random (or \
quasi-random) seed from a box. This code has been taken from the EPToolbox \
package, which is located and better documented at \
https://github.com/episanty/EPToolbox, and it is also documented in \
http://mathematica.stackexchange.com/a/57821/1000.\
\>", "Text",ExpressionUUID->"82d4cbe9-9560-415d-9ced-375d56802572"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"FindComplexRoots", "::", "usage"}], "=", 
   "\"\<FindComplexRoots[e1==e2, {z, zmin, zmax}] attempts to find complex \
roots of the equation e1==e2 in the complex rectangle with corners zmin and \
zmax.\n\nFindComplexRoots[{e1==e2, e3==e4, \[Ellipsis]}, {z1, z1min, z1max}, \
{z2, z2min, z2max}, \[Ellipsis]] attempts to find complex roots of the given \
system of equations in the multidimensional complex rectangle with corners \
z1min, z1max, z2min, z2max, \[Ellipsis].\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Seeds", "::", "usage"}], "=", 
   "\"\<Seeds is an option for FindComplexRoots which determines how many \
initial seeds are used to attempt to find roots of the given equation.\>\""}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SeedGenerator", "::", "usage"}], "=", 
    "\"\<SeedGenerator is an option for FindComplexRoots which determines the \
function   used to generate the seeds for the internal FindRoot call. Its \
value can be RandomComplex, RandomNiederreiterComplexes, \
RandomSobolComplexes, DeterministicComplexGrid, or any function f such that \
f[{zmin, zmax}, n] returns n complex numbers in the rectancle with corners \
zmin and zmax.\>\""}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "FindComplexRoots", "]"}], " ", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Options", "[", "FindRoot", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Seeds", " ", "->", " ", "50"}], ",", " ", 
       RowBox[{"SeedGenerator", " ", "->", " ", "RandomComplex"}], ",", " ", 
       RowBox[{"Tolerance", " ", "->", " ", "Automatic"}], ",", " ", 
       RowBox[{"Verbose", " ", "->", " ", "False"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"SyntaxInformation", "[", "FindComplexRoots", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<ArgumentsPattern\>\"", " ", "->", " ", 
      RowBox[{"{", 
       RowBox[{"_", ",", " ", 
        RowBox[{"{", 
         RowBox[{"_", ",", " ", "_", ",", " ", "_"}], "}"}], ",", " ", 
        RowBox[{"OptionsPattern", "[", "]"}]}], "}"}]}], ",", "    ", 
     RowBox[{"\"\<LocalVariables\>\"", " ", "->", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<Table\>\"", ",", " ", 
        RowBox[{"{", 
         RowBox[{"2", ",", " ", "\[Infinity]"}], "}"}]}], "}"}]}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FindComplexRoots", "::", "seeds"}], " ", "=", " ", 
   "\"\<Value of option Seeds -> `1` is not a positive integer.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FindComplexRoots", "::", "tol"}], " ", "=", " ", 
   "\"\<Value of option Tolerance -> `1` is not Automatic or a number in [0,\
\[Infinity]).\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"$MessageGroups", "=", 
    RowBox[{"Join", "[", 
     RowBox[{"$MessageGroups", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<FindComplexRoots\>\"", "\[RuleDelayed]", 
        RowBox[{"{", 
         RowBox[{"FindRoot", "::", "lstol"}], "}"}]}], "}"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Protect", "[", "Seeds", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "SeedGenerator", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"1f583d3e-c1a2-4e4b-bf45-3053e8ee6fa6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SetTolerances", "::", "usage"}], "=", 
   "\"\<SetTolerances[tolerance,length] produces a list of the given length \
with the specified tolerance, which may be a number or a list of numbers.\\n\n\
SetTolerances[tolerance,length,workingPrecision] allows a fallback to a \
specified workingPrecision in case the given tolerance fails to be numeric.\>\
\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetTolerances", "[", 
   RowBox[{"tolerance_", ",", "length_", ",", 
    RowBox[{"workingPrecision_:", "$MachinePrecision"}]}], "]"}], ":=", 
  RowBox[{"Which", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListQ", "[", "tolerance", "]"}], ",", "tolerance", ",", 
    "\[IndentingNewLine]", "True", ",", 
    RowBox[{"ConstantArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"NumberQ", "[", "tolerance", "]"}], ",", "tolerance", ",", 
        "\[IndentingNewLine]", "True", ",", 
        RowBox[{"10", "^", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"NumberQ", "[", "workingPrecision", "]"}], ",", " ", 
           RowBox[{"2", "-", "workingPrecision"}], ",", 
           RowBox[{"2", "-", "$MachinePrecision"}]}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", "length"}], 
     "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"f21b08cc-97f2-45a7-b509-6ba34911a4ce"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FindComplexRoots", "[", 
   RowBox[{"equations_List", ",", "domainSpecifiers__", ",", " ", 
    RowBox[{"ops", " ", ":", " ", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"seeds", ",", "tolerances"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"!", " ", 
         RowBox[{"IntegerQ", "[", 
          RowBox[{"Rationalize", "[", 
           RowBox[{"OptionValue", "[", "Seeds", "]"}], "]"}], "]"}]}], " ", "||",
         " ", 
        RowBox[{
         RowBox[{"OptionValue", "[", "Seeds", "]"}], "\[LessEqual]", "0"}]}], 
       ",", 
       RowBox[{"Message", "[", 
        RowBox[{
         RowBox[{"FindComplexRoots", "::", "seeds"}], ",", " ", 
         RowBox[{"OptionValue", "[", "Seeds", "]"}]}], "]"}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"OptionValue", "[", "Tolerance", "]"}], " ", "===", " ", 
           "Automatic"}], " ", "||", " ", 
          RowBox[{
           RowBox[{"OptionValue", "[", "Tolerance", "]"}], "\[GreaterEqual]", 
           "0"}]}], ")"}]}], ",", 
       RowBox[{"Message", "[", 
        RowBox[{
         RowBox[{"FindComplexRoots", "::", "tol"}], ",", " ", 
         RowBox[{"OptionValue", "[", "Seeds", "]"}]}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"seeds", "=", 
      RowBox[{
       RowBox[{"OptionValue", "[", "SeedGenerator", "]"}], "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", "domainSpecifiers", "}"}], "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"OptionValue", "[", "Seeds", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tolerances", "=", 
      RowBox[{"SetTolerances", "[", 
       RowBox[{
        RowBox[{"OptionValue", "[", "Tolerance", "]"}], ",", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "domainSpecifiers", "}"}], "]"}], ",", 
        RowBox[{"OptionValue", "[", "WorkingPrecision", "]"}]}], "]"}]}], ";",
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"OptionValue", "[", "Verbose", "]"}], ",", 
        RowBox[{"Hold", "[", "]"}], ",", " ", 
        RowBox[{"Hold", "[", 
         RowBox[{"FindRoot", "::", "lstol"}], "]"}]}], "]"}], " ", "/.", " ", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Hold", "[", "messageSequence___", "]"}], " ", ":>", " ", 
        RowBox[{"Quiet", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"DeleteDuplicates", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Select", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Check", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"FindRoot", "[", "\[IndentingNewLine]", 
                   RowBox[{"equations", "\[IndentingNewLine]", ",", 
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", "domainSpecifiers", "}"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "j", 
                    "\[RightDoubleBracket]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"Length", "[", 
                    RowBox[{"{", "domainSpecifiers", "}"}], "]"}]}], "}"}]}], 
                    "]"}]}], "]"}], "\[IndentingNewLine]", ",", 
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"Sequence", " ", "@@", " ", 
                    RowBox[{"FilterRules", "[", 
                    RowBox[{
                    RowBox[{"{", "ops", "}"}], ",", " ", 
                    RowBox[{"Options", "[", "FindRoot", "]"}]}], "]"}]}], 
                    "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"##", "&"}], "[", "]"}]}], "\[IndentingNewLine]", 
                 "]"}], "&"}], "/@", "seeds"}], ",", "\[IndentingNewLine]", 
              RowBox[{"Function", "[", "\[IndentingNewLine]", 
               RowBox[{"repList", ",", "\[IndentingNewLine]", 
                RowBox[{"ReplaceAll", "[", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Evaluate", "[", 
                   RowBox[{"And", "@@", 
                    RowBox[{"Table", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"And", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Re", "[", 
                    RowBox[{
                    RowBox[{"{", "domainSpecifiers", "}"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], "]"}],
                     "\[LessEqual]", 
                    RowBox[{"Re", "[", 
                    RowBox[{
                    RowBox[{"{", "domainSpecifiers", "}"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], "]"}],
                     "\[LessEqual]", 
                    RowBox[{"Re", "[", 
                    RowBox[{
                    RowBox[{"{", "domainSpecifiers", "}"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "3"}], "\[RightDoubleBracket]"}], 
                    "]"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Im", "[", 
                    RowBox[{
                    RowBox[{"{", "domainSpecifiers", "}"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], "]"}],
                     "\[LessEqual]", 
                    RowBox[{"Im", "[", 
                    RowBox[{
                    RowBox[{"{", "domainSpecifiers", "}"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], "]"}],
                     "\[LessEqual]", 
                    RowBox[{"Im", "[", 
                    RowBox[{
                    RowBox[{"{", "domainSpecifiers", "}"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "3"}], "\[RightDoubleBracket]"}], 
                    "]"}]}]}], "\[IndentingNewLine]", "]"}], 
                    "\[IndentingNewLine]", ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", 
                    RowBox[{"Length", "[", 
                    RowBox[{"{", "domainSpecifiers", "}"}], "]"}]}], "}"}]}], 
                    "]"}]}], "]"}], "\[IndentingNewLine]", ",", "repList"}], 
                 "]"}]}], "\[IndentingNewLine]", "]"}]}], 
             "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Function", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"repList1", ",", "repList2"}], "}"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"And", "@@", 
               RowBox[{"Table", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", "domainSpecifiers", "}"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], "/.", 
                    "repList1"}], ")"}], "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", "domainSpecifiers", "}"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], "/.", 
                    "repList2"}], ")"}]}], "]"}], "<", 
                  RowBox[{
                  "tolerances", "\[LeftDoubleBracket]", "j", 
                   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", 
                   RowBox[{"Length", "[", 
                    RowBox[{"{", "domainSpecifiers", "}"}], "]"}]}], "}"}]}], 
                "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
           "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", " ", 
          RowBox[{"{", "messageSequence", "}"}]}], "]"}]}], "}"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FindComplexRoots", "[", 
   RowBox[{
    RowBox[{"e1_", "==", "e2_"}], ",", 
    RowBox[{"{", 
     RowBox[{"z_", ",", "zmin_", ",", "zmax_"}], "}"}], ",", 
    RowBox[{"ops", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"FindComplexRoots", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"e1", "==", "e2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "zmin", ",", "zmax"}], "}"}], ",", "ops"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"d386312f-769a-4725-8ba1-624cabcfba5d"]
}, Closed]],

Cell[CellGroupData[{

Cell["Quasirandom number generators", \
"Subsection",ExpressionUUID->"64179afa-5a8c-4d22-964d-2c1a4015f1b1"],

Cell["\<\
This section implements quasirandom number generators for use with \
FindComplexRoots. As above, this code has been taken from the EPToolbox \
package, which is located and better documented at \
https://github.com/episanty/EPToolbox, and it is also documented in \
http://mathematica.stackexchange.com/a/57821/1000.\
\>", "Text",ExpressionUUID->"9acb209b-85e3-4fbe-bb09-1d3175083269"],

Cell[CellGroupData[{

Cell["RandomSobolComplexes", \
"Subsubsection",ExpressionUUID->"5f6c40d2-8df8-403d-9294-19f803b5aa7c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RandomSobolComplexes", "::", "usage"}], "=", 
   "\"\<RandomSobolComplexes[{zmin, zmax}, n] generates a low-discrepancy \
Sobol sequence of n quasirandom complex numbers in the rectangle with corners \
zmin and zmax.\n\nRandomSobolComplexes[{{z1min,z1max},{z2min,z2max},\
\[Ellipsis]},n] generates a low-discrepancy Sobol sequence of n quasirandom \
complex numbers in the multi-dimensional rectangle with corners \
{z1min,z1max},{z2min,z2max},\[Ellipsis].\>\""}], ";"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"9a612054-74db-4e4a-81ee-2c498c8d29b7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RandomSobolComplexes", "[", 
   RowBox[{"pairsList__", ",", " ", "number_"}], "]"}], " ", ":=", 
  RowBox[{"Map", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Function", "[", 
     RowBox[{"randomsList", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pairsList", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "+", 
       RowBox[{"Complex", "@@@", 
        RowBox[{"Times", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"ReIm", "[", 
           RowBox[{
            RowBox[{"pairsList", "\[LeftDoubleBracket]", 
             RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
            RowBox[{"pairsList", "\[LeftDoubleBracket]", 
             RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
          ",", "\[IndentingNewLine]", "randomsList"}], "\[IndentingNewLine]", 
         "]"}]}]}]}], "\[IndentingNewLine]", "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"BlockRandom", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"SeedRandom", "[", 
       RowBox[{"Method", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<MKL\>\"", ",", 
          RowBox[{"Method", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<Sobol\>\"", ",", " ", 
             RowBox[{"\"\<Dimension\>\"", " ", "\[Rule]", " ", 
              RowBox[{"2", 
               RowBox[{"Length", "[", "pairsList", "]"}]}]}]}], "}"}]}]}], 
         "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"SeedRandom", "[", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"number", ",", 
          RowBox[{"Length", "[", "pairsList", "]"}], ",", "2"}], "}"}]}], 
       "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RandomSobolComplexes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"zmin_", "?", "NumericQ"}], ",", 
      RowBox[{"zmax_", "?", "NumericQ"}]}], "}"}], ",", "number_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"RandomSobolComplexes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"zmin", ",", "zmax"}], "}"}], "}"}], ",", "number"}], "]"}], 
   "\[LeftDoubleBracket]", 
   RowBox[{"All", ",", "1"}], 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"d8fad433-89d3-4fcb-83d2-432364a5ad7d"]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomNiederreiterComplexes", \
"Subsubsection",ExpressionUUID->"46a503d0-6fef-41c5-94b6-f8c3c2abede3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RandomNiederreiterComplexes", "::", "usage"}], "=", 
   "\"\<RandomNiederreiterComplexes[{zmin, zmax}, n] generates a \
low-discrepancy Niederreiter sequence of n quasirandom complex numbers in the \
rectangle with corners zmin and zmax.\n\n\
RandomNiederreiterComplexes[{{z1min,z1max},{z2min,z2max},\[Ellipsis]},n] \
generates a low-discrepancy Niederreiter sequence of n quasirandom complex \
numbers in the multi-dimensional rectangle with corners \
{z1min,z1max},{z2min,z2max},\[Ellipsis].\>\""}], ";"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"d2cc815c-5c66-4c63-bc56-b1b78e9c84eb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RandomNiederreiterComplexes", "[", 
   RowBox[{"pairsList__", ",", " ", "number_"}], "]"}], " ", ":=", 
  RowBox[{"Map", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Function", "[", 
     RowBox[{"randomsList", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pairsList", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "+", 
       RowBox[{"Complex", "@@@", 
        RowBox[{"Times", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"ReIm", "[", 
           RowBox[{
            RowBox[{"pairsList", "\[LeftDoubleBracket]", 
             RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
            RowBox[{"pairsList", "\[LeftDoubleBracket]", 
             RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
          ",", "\[IndentingNewLine]", "randomsList"}], "\[IndentingNewLine]", 
         "]"}]}]}]}], "\[IndentingNewLine]", "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"BlockRandom", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"SeedRandom", "[", 
       RowBox[{"Method", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<MKL\>\"", ",", 
          RowBox[{"Method", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<Niederreiter\>\"", ",", " ", 
             RowBox[{"\"\<Dimension\>\"", " ", "\[Rule]", " ", 
              RowBox[{"2", 
               RowBox[{"Length", "[", "pairsList", "]"}]}]}]}], "}"}]}]}], 
         "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"SeedRandom", "[", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"RandomReal", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "1"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"number", ",", 
          RowBox[{"Length", "[", "pairsList", "]"}], ",", "2"}], "}"}]}], 
       "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RandomNiederreiterComplexes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"zmin_", "?", "NumericQ"}], ",", 
      RowBox[{"zmax_", "?", "NumericQ"}]}], "}"}], ",", "number_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"RandomNiederreiterComplexes", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"zmin", ",", "zmax"}], "}"}], "}"}], ",", "number"}], "]"}], 
   "\[LeftDoubleBracket]", 
   RowBox[{"All", ",", "1"}], 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"aa10198a-c140-4b61-a45d-0d509f3e8145"]
}, Closed]],

Cell[CellGroupData[{

Cell["DeterministicComplexGrid", \
"Subsubsection",ExpressionUUID->"b0347215-daa1-4555-bca3-ea104f259fe6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DeterministicComplexGrid", "::", "usage"}], "=", 
   "\"\<DeterministicComplexGrid[{zmin, zmax}, n] generates a grid of about n \
equally spaced complex numbers in the rectangle with corners zmin and zmax.\n\
\nDeterministicComplexGrid[{{z1min,z1max},{z2min,z2max},\[Ellipsis]},n] \
generates a regular grid of about n equally spaced complex numbers in the \
multi-dimensional rectangle with corners {z1min,z1max},{z2min,z2max},\
\[Ellipsis].\>\""}], ";"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"d9ac3e0e-a9ca-4e34-b31d-10403dc873a4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DeterministicComplexGrid", "[", 
   RowBox[{"pairsList_", ",", "number_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sep", ",", "separationsList", ",", "gridPointBasis", ",", "k"}],
      "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sep", "=", 
      RowBox[{"NestWhile", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"0.99", "#"}], "&"}], ",", 
        RowBox[{"Min", "[", 
         RowBox[{"Flatten", "[", 
          RowBox[{"ReIm", "[", 
           RowBox[{
            RowBox[{"pairsList", "\[LeftDoubleBracket]", 
             RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
            RowBox[{"pairsList", "\[LeftDoubleBracket]", 
             RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
          "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Times", "@@", 
           FractionBox[
            RowBox[{"Floor", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"ReIm", "[", 
                RowBox[{
                 RowBox[{"pairsList", "\[LeftDoubleBracket]", 
                  RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
                 RowBox[{"pairsList", "\[LeftDoubleBracket]", 
                  RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                "]"}], "]"}], ",", 
              RowBox[{"0.99", "#"}]}], "]"}], 
            RowBox[{"0.99", "#"}]]}], "\[LessEqual]", "number"}], "&"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"separationsList", "=", 
      RowBox[{"Round", "[", 
       FractionBox[
        RowBox[{"Floor", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"ReIm", "[", 
            RowBox[{
             RowBox[{"pairsList", "\[LeftDoubleBracket]", 
              RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
             RowBox[{"pairsList", "\[LeftDoubleBracket]", 
              RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
           "]"}], ",", "sep"}], "]"}], "sep"], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gridPointBasis", "=", 
      RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"l", ",", "n"}], "}"}], ",", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{
             RowBox[{
             "l", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
             RowBox[{
             "l", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
             FractionBox[
              RowBox[{
               RowBox[{
               "l", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
               "-", 
               RowBox[{
               "l", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
              RowBox[{"n", "+", "1"}]]}], "]"}], "\[LeftDoubleBracket]", 
           RowBox[{"2", ";;", 
            RowBox[{"-", "2"}]}], "\[RightDoubleBracket]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{"Transpose", "[", 
             RowBox[{
              RowBox[{"ReIm", "[", "pairsList", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}], ",", "1"}], 
           "]"}], ",", "separationsList"}], "}"}]}], "\[IndentingNewLine]", 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{
              RowBox[{"2", "j"}], "-", "1"}], "]"}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"k", "[", 
              RowBox[{"2", "j"}], "]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "pairsList", "]"}]}], "}"}]}], "]"}], ",",
          "\[IndentingNewLine]", 
         RowBox[{"Evaluate", "[", 
          RowBox[{"Sequence", "@@", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"k", "[", "j", "]"}], ",", 
               RowBox[{
               "gridPointBasis", "\[LeftDoubleBracket]", "j", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"2", 
                RowBox[{"Length", "[", "pairsList", "]"}]}]}], "}"}]}], 
            "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
       RowBox[{"Evaluate", "[", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", 
          RowBox[{"2", 
           RowBox[{"Length", "[", "pairsList", "]"}]}]}], "]"}], "]"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DeterministicComplexGrid", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"zmin_", "?", "NumericQ"}], ",", 
      RowBox[{"zmax_", "?", "NumericQ"}]}], "}"}], ",", "number_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"DeterministicComplexGrid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"zmin", ",", "zmax"}], "}"}], "}"}], ",", "number"}], "]"}], 
   "\[LeftDoubleBracket]", 
   RowBox[{"All", ",", "1"}], 
   "\[RightDoubleBracket]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"268a18c6-13a5-4b1c-b4f5-2c7433cca305"]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomComplex", \
"Subsubsection",ExpressionUUID->"8e229725-528e-4e80-b574-dfdb81733daf"],

Cell[TextData[{
 "Updating ",
 StyleBox["RandomComplex", "Code"],
 " to handle input of the form ",
 StyleBox["RandomComplex[{{0, 1+\[ImaginaryI]}, {2, 3+\[ImaginaryI]}}, n]", 
  "Code"],
 "."
}], "Text",ExpressionUUID->"6c461451-1d8c-49d3-8098-82cb34ce94ca"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Unprotect", "[", "RandomComplex", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RandomComplex", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"range1_List", ",", "moreRanges___"}], "}"}], ",", "number_"}], 
   "]"}], ":=", 
  RowBox[{"Transpose", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"RandomComplex", "[", 
      RowBox[{"#", ",", "number"}], "]"}], "&"}], "/@", 
    RowBox[{"{", 
     RowBox[{"range1", ",", "moreRanges"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Protect", "[", "RandomComplex", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"84577cda-a6c0-41f4-9388-cb7ef294142f"],

Cell["\<\

The following code places this redefinition as an initialization code for any \
parallelized subkernels that may get launched later (cf. mm.se/q/131856). \
This version, in addition, checks whether there is already any code in \
$InitCode and, if there is, it appends its own code there.\
\>", "Text",ExpressionUUID->"96250bac-fa0b-466a-a999-51d5287fdb31"],

Cell[BoxData[{
 RowBox[{"Parallelize", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", "Parallel`Developer`$InitCode", "]"}], "=!=", 
     "Hold"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Parallel`Developer`$InitCode", "=", 
     RowBox[{"Hold", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Parallel`Developer`$InitCode", "=", 
   RowBox[{"Join", "[", "\[IndentingNewLine]", 
    RowBox[{"Parallel`Developer`$InitCode", ",", "\[IndentingNewLine]", 
     RowBox[{"Hold", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Unprotect", "[", "RandomComplex", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"RandomComplex", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Private`range1_List", ",", "Private`moreRanges___"}], 
           "}"}], ",", "Private`number_"}], "]"}], ":=", 
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"RandomComplex", "[", 
            RowBox[{"#", ",", "Private`number"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{"Private`range1", ",", "Private`moreRanges"}], "}"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Protect", "[", "RandomComplex", "]"}], ";"}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"d091e95c-c543-45e3-aadc-296b1adc3429"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["ConstrainedDerivative", \
"Subsection",ExpressionUUID->"80d50d83-dc8a-41d9-a937-22e73de24dc4"],

Cell[TextData[{
 "In some situations, one can require solving the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "'"}], TraditionalForm]],ExpressionUUID->
  "e43dff62-2bf6-471d-8cc2-df55b58a332c"],
 " saddle-point equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox["\[PartialD]", 
      RowBox[{"\[PartialD]", 
       RowBox[{"t", "'"}]}]], 
     RowBox[{"S", "(", 
      RowBox[{"t", ",", 
       RowBox[{"t", "'"}]}], ")"}]}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"76a9005d-86dd-448f-a2fd-b91b86e6438e"],
 " first to find a saddle point ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"t", "'"}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["t", "s"], "'"}], 
     RowBox[{"(", "t", ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "719b551f-aabb-4e77-adf2-8838b05ba1d9"],
 " and an action ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"S", "(", "t", ")"}], "=", 
    RowBox[{"S", "(", 
     RowBox[{"t", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["t", "s"], "'"}], 
       RowBox[{"(", "t", ")"}]}]}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"156fc883-8ef1-44b4-afd2-b18129b8de66"],
 ", and then find the derivatives of this function with respect to ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "41ae88ba-c076-4593-9707-c512248b7a7d"],
 ". This can be done by differentiating the defining equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox["\[PartialD]", 
      RowBox[{"\[PartialD]", 
       RowBox[{"t", "'"}]}]], 
     RowBox[{"S", "(", 
      RowBox[{"t", ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["t", "s"], "'"}], 
        RowBox[{"(", "t", ")"}]}]}], ")"}]}], "\[Congruent]", "0"}], 
   TraditionalForm]],ExpressionUUID->"24730a5a-bf0d-43ff-8bee-188d794fafd4"],
 " with respect to ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "d0beedbe-6b78-4497-ba77-64a01cfe9db4"],
 " to find the relation obeyed by ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"d", " ", 
     RowBox[{
      SubscriptBox["t", "s"], "'"}]}], 
    RowBox[{"d", " ", "t"}]], TraditionalForm]],ExpressionUUID->
  "4067a337-51bd-40b1-b064-194dd45133e7"],
 ", in the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "S"}], 
        RowBox[{
         RowBox[{"\[PartialD]", 
          RowBox[{"t", "'"}]}], 
         RowBox[{"\[PartialD]", "t"}]}]], 
       RowBox[{"(", 
        RowBox[{"t", ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["t", "s"], "'"}], 
          RowBox[{"(", "t", ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"d", " ", 
         RowBox[{
          SubscriptBox["t", "s"], "'"}]}], 
        RowBox[{"d", " ", "t"}]], 
       RowBox[{"(", "t", ")"}], 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[PartialD]", "2"], "S"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[PartialD]", 
           RowBox[{"t", "'"}]}], ")"}], "2"]], 
       RowBox[{"(", 
        RowBox[{"t", ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["t", "s"], "'"}], 
          RowBox[{"(", "t", ")"}]}]}], ")"}]}]}], "\[Congruent]", "0"}], 
    ","}], TraditionalForm]],ExpressionUUID->
  "c85c0224-3222-4dd3-a122-bcce05dcdbe7"],
 " and using "
}], "Text",ExpressionUUID->"3be0369e-7395-492e-bed8-9c6aa21f3808"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ConstrainedDerivative", "::", "usage"}], "=", 
    "\"\<ConstrainedDerivative[n][f][t,tt] calculates the nth derivative of \
f[t,tt] with respect to t under the constraint that Derivative[0,1][f][t,tt]\
\[Congruent]0.\>\""}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ConstrainedDerivative", "[", "n_", "]"}], "[", "F_", "]"}], "[", 
   RowBox[{"te_", ",", "tte_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"f", ",", "tts", ",", "t", ",", "tt"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ConstrainedDerivative", "[", "n", "]"}], "[", "f_", "]"}], 
       "[", 
       RowBox[{"t_", ",", "tt_"}], "]"}], "=", 
      RowBox[{"Nest", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Function", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Simplify", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"#", "/.", 
               RowBox[{"{", 
                RowBox[{"tt", "\[Rule]", 
                 RowBox[{"tts", "[", "t", "]"}]}], "}"}]}], ",", "t"}], "]"}],
             "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Derivative", "[", 
                  RowBox[{"0", ",", "1"}], "]"}], "[", "f", "]"}], "[", 
                RowBox[{"t", ",", 
                 RowBox[{"tts", "[", "t", "]"}]}], "]"}], "\[Rule]", "0"}], 
              ",", 
              RowBox[{
               RowBox[{
                RowBox[{"tts", "'"}], "[", "t", "]"}], "\[Rule]", 
               RowBox[{"-", 
                FractionBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"Derivative", "[", 
                    RowBox[{"1", ",", "1"}], "]"}], "[", "f", "]"}], "[", 
                  RowBox[{"t", ",", 
                   RowBox[{"tts", "[", "t", "]"}]}], "]"}], 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Derivative", "[", 
                    RowBox[{"0", ",", "2"}], "]"}], "[", "f", "]"}], "[", 
                  RowBox[{"t", ",", 
                   RowBox[{"tts", "[", "t", "]"}]}], "]"}]]}]}]}], "}"}]}], 
           "\[IndentingNewLine]", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"tts", "[", "t", "]"}], "\[Rule]", "tt"}], "}"}]}], 
         "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "tt"}], "]"}], ",", "n"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"ConstrainedDerivative", "[", "n", "]"}], "[", "F", "]"}], "[", 
      RowBox[{"te", ",", "tte"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"e64e096d-4766-49fa-901d-c044eb9f2687"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetSaddlePoints", \
"Subsection",ExpressionUUID->"c149e8b0-70b6-45ea-8873-81618c14d6fd"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"GetSaddlePoints", "::", "usage"}], "=", 
   "\"\<GetSaddlePoints[\[CapitalOmega],S,{tmin,tmax},{\[Tau]min,\[Tau]max}] \
finds a list of solutions {t,\[Tau]} of the HHG temporal saddle-point \
equations at harmonic energy \[CapitalOmega] for action S, in the range \
{tmin, tmax} of recombination time and {\[Tau]min, \[Tau]max} of excursion \
time, where both ranges should be the lower-left and upper-right corners of \
rectangles in the complex plane.\n\n\
GetSaddlePoints[\[CapitalOmega]Range,S,{tmin,tmax},{\[Tau]min,\[Tau]max}] \
finds solutions of the HHG temporal saddle-point equations for a range of \
harmonic energies \[CapitalOmega]Range, and returns an Association with each \
harmonic energy \[CapitalOmega] indexing a list of saddle-point solution \
pairs {t,\[Tau]}.\n\n\
GetSaddlePoints[\[CapitalOmega]spec,S,{{{\!\(\*SubscriptBox[\(tmin\), \
\(1\)]\),\!\(\*SubscriptBox[\(tmax\), \
\(1\)]\)},{\!\(\*SubscriptBox[\(\[Tau]min\), \(1\)]\),\!\(\*SubscriptBox[\(\
\[Tau]max\), \(1\)]\)}},{{\!\(\*SubscriptBox[\(tmin\), \
\(2\)]\),\!\(\*SubscriptBox[\(tmax\), \
\(2\)]\)},{\!\(\*SubscriptBox[\(\[Tau]min\), \(2\)]\),\!\(\*SubscriptBox[\(\
\[Tau]max\), \(2\)]\)}},\[Ellipsis]}] uses multiple time domains and combines \
the solutions.\n\nGetSaddlePoints[\[CapitalOmega]spec,S,{{urange,vrange},\
\[Ellipsis]},IndependentVariables\[Rule]{u,v}] uses the explicit independent \
variables u and v to solve the equations and over the given ranges, where u \
and v can be any of \\\"RecombinationTime\\\", \\\"IonizationTime\\\" and \
\\\"ExcursionTime\\\", or their shorthands \\\"t\\\", \\\"tt\\\" and \\\"\
\[Tau]\\\" resp.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SortingFunction", "::", "usage"}], "=", 
   "\"\<SortingFunction is an option of GetSaddlePoints which sets a function \
f, to be used as f[t,\[Tau],S,\[CapitalOmega]], to be used to sort the \
solutions, or a list of such functions.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SelectionFunction", "::", "usage"}], "=", 
   "\"\<SelectionFunction is an option of GetSaddlePoints that sets a \
function f, to be used as f[t,\[Tau],S,\[CapitalOmega]], such that roots are \
only kept if f returns True.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"IndependentVariables", "::", "usage"}], "=", 
    "\"\<IndependentVariables is an option for GetSaddlePoints that specifies \
the two independent variables, out of \\\"RecombinationTime\\\", \
\\\"IonizationTime\\\" and \\\"ExcursionTime\\\" (or their shorthands \\\"t\\\
\", \\\"tt\\\" and \\\"\[Tau]\\\", respectively), to be used in solving the \
saddle-point equations, and which range over the given regions.\>\""}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FiniteDifference", "::", "usage"}], "=", 
    "\"\<FiniteDifference is a value for the option Jacobian of FindRoot, \
FindComplexRoots, GetSaddlePoints, and related functions, which specifies \
that the Jacobian at each step should be evaluated using numerical finite \
difference procedures.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GetSaddlePoints", "::", "error"}], "=", 
    "\"\<Errors encountered for harmonic energy \[CapitalOmega]=`1`.\>\""}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "GetSaddlePoints", "]"}], "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SortingFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"#2", "&"}], ")"}]}], ",", 
       RowBox[{"SelectionFunction", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"True", "&"}], ")"}]}], ",", 
       RowBox[{"IndependentVariables", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<RecombinationTime\>\"", ",", "\"\<ExcursionTime\>\""}], 
         "}"}]}]}], "}"}], ",", 
     RowBox[{"Options", "[", "FindComplexRoots", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Protect", "[", 
    RowBox[{
    "SortingFunction", ",", "SelectionFunction", ",", "IndependentVariables", 
     ",", "FiniteDifference"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetSaddlePoints", "[", 
    RowBox[{"\[CapitalOmega]spec_", ",", "S_", ",", 
     RowBox[{"{", 
      RowBox[{"tmin_", ",", "tmax_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Tau]min_", ",", "\[Tau]max_"}], "}"}], ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"GetSaddlePoints", "[", 
    RowBox[{"\[CapitalOmega]spec", ",", "S", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"tmin", ",", "tmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Tau]min", ",", "\[Tau]max"}], "}"}]}], "}"}], "}"}], ",", 
     "options"}], "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GetSaddlePoints", "[", 
   RowBox[{"\[CapitalOmega]_", ",", "S_", ",", "timeRanges_", ",", 
    RowBox[{"options", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"equations", ",", "roots", ",", 
      RowBox[{"t", "=", 
       RowBox[{"Symbol", "[", "\"\<t\>\"", "]"}]}], ",", 
      RowBox[{"tt", "=", 
       RowBox[{"Symbol", "[", "\"\<tt\>\"", "]"}]}], ",", 
      RowBox[{"\[Tau]", "=", 
       RowBox[{"Symbol", "[", "\"\<\[Tau]\>\"", "]"}]}], ",", "indVars", ",", 
      "depVar", ",", "depVarRule", ",", "tolerances"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tolerances", "=", 
      RowBox[{"SetTolerances", "[", 
       RowBox[{
        RowBox[{"OptionValue", "[", "Tolerance", "]"}], ",", "2", ",", 
        RowBox[{"OptionValue", "[", "WorkingPrecision", "]"}]}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"indVars", "=", 
      RowBox[{
       RowBox[{"OptionValue", "[", "IndependentVariables", "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<RecombinationTime\>\"", "\[Rule]", "\"\<t\>\""}], ",", 
         RowBox[{"\"\<ExcursionTime\>\"", "\[Rule]", "\"\<\[Tau]\>\""}], ",", 
         RowBox[{"\"\<IonizationTime\>\"", "\[Rule]", "\"\<tt\>\""}]}], 
        "}"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"depVar", "=", 
      RowBox[{"First", "[", 
       RowBox[{"DeleteCases", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<t\>\"", ",", "\"\<\[Tau]\>\"", ",", "\"\<tt\>\""}], 
          "}"}], ",", 
         RowBox[{"Alternatives", "@@", "indVars"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"depVarRule", "=", 
      RowBox[{"depVar", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<tt\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"tt", "\[Rule]", 
            RowBox[{"t", "-", "\[Tau]"}]}], "}"}]}], ",", 
         RowBox[{"\"\<t\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"t", "\[Rule]", 
            RowBox[{"tt", "+", "\[Tau]"}]}], "}"}]}], ",", 
         RowBox[{"\"\<\[Tau]\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\[Tau]", "\[Rule]", 
            RowBox[{"t", "-", "tt"}]}], "}"}]}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"equations", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", "t"}], "]"}], "\[Equal]", 
          "\[CapitalOmega]"}], ",", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", "tt"}], "]"}], "\[Equal]", 
          "0"}]}], "}"}], "/.", "depVarRule"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"SortBy", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"DeleteDuplicates", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Select", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Check", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"roots", "=", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], "/.", "depVarRule"}],
                     ")"}], "/.", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"FindComplexRoots", "[", "\[IndentingNewLine]", 
                    RowBox[{"equations", "\[IndentingNewLine]", ",", 
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"Sequence", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Symbol", "[", 
                    RowBox[{
                    "indVars", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Symbol", "[", 
                    RowBox[{
                    "indVars", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", ",", 
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"FilterRules", "[", 
                    RowBox[{
                    RowBox[{"{", "options", "}"}], ",", 
                    RowBox[{"Options", "[", "FindComplexRoots", "]"}]}], 
                    "]"}]}], "]"}], "\[IndentingNewLine]", ",", 
                    RowBox[{
                    "SeedGenerator", "\[Rule]", "RandomSobolComplexes"}], 
                    "\[IndentingNewLine]", ",", 
                    RowBox[{"Seeds", "\[Rule]", "50"}]}], 
                    "\[IndentingNewLine]", "]"}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "}"}], "\[Rule]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], "/.", "depVarRule"}],
                     ")"}], "\[Rule]", 
                    RowBox[{"{", "}"}]}], ")"}]}], "}"}]}], ")"}]}]}], 
                 RowBox[{"(*", 
                  RowBox[{
                  "to", " ", "deal", " ", "with", " ", "empty", " ", 
                   "results"}], "*)"}], "\[IndentingNewLine]", ",", 
                 RowBox[{
                  RowBox[{"Message", "[", 
                   RowBox[{
                    RowBox[{"GetSaddlePoints", "::", "error"}], ",", 
                    "\[CapitalOmega]"}], "]"}], ";", "roots"}]}], 
                "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
               RowBox[{"Function", "[", 
                RowBox[{"timesPair", ",", 
                 RowBox[{
                  RowBox[{"OptionValue", "[", "SelectionFunction", "]"}], "[", 
                  RowBox[{
                   RowBox[{
                   "timesPair", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{
                   "timesPair", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], ",", "S", ",", 
                   "\[CapitalOmega]"}], "]"}]}], "]"}]}], 
              "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"range", ",", "timeRanges"}], "}"}]}], "]"}], ",", 
           "1"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"timesPair1", ",", "timesPair2"}], "}"}], ",", "    ", 
           RowBox[{"And", "@@", 
            RowBox[{"Thread", "[", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"timesPair1", "-", "timesPair2"}], "]"}], "<", 
              "tolerances"}], "]"}]}]}], "     ", "]"}]}], 
        "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{"If", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ListQ", "[", 
          RowBox[{"OptionValue", "[", "SortingFunction", "]"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"timesPair", ",", 
             RowBox[{"f", "[", 
              RowBox[{
               RowBox[{
               "timesPair", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "timesPair", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], ",", "S", ",", "\[CapitalOmega]"}],
               "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"f", ",", 
             RowBox[{"OptionValue", "[", "SortingFunction", "]"}]}], "}"}]}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Function", "[", 
          RowBox[{"timesPair", ",", 
           RowBox[{
            RowBox[{"OptionValue", "[", "SortingFunction", "]"}], "[", 
            RowBox[{
             RowBox[{
             "timesPair", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{
             "timesPair", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], ",", "S", ",", "\[CapitalOmega]"}], 
            "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetSaddlePoints", "[", 
    RowBox[{"\[CapitalOmega]Range_List", ",", "S_", ",", "timeRanges_", ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Association", "[", 
    RowBox[{"ParallelTable", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[CapitalOmega]", "\[Rule]", 
       RowBox[{"GetSaddlePoints", "[", 
        RowBox[{
        "\[CapitalOmega]", ",", "S", ",", "timeRanges", ",", "options"}], 
        "]"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"\[CapitalOmega]", ",", 
        RowBox[{"Sort", "[", "\[CapitalOmega]Range", "]"}]}], "}"}]}], "]"}], 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"9e0c90e0-d258-437e-a135-aedd347a81ce"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetSaddlesFromSeeds", \
"Subsection",ExpressionUUID->"dbe896f6-c731-4938-9d1c-473bec1e184e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GetSaddlesFromSeeds", "::", "usage"}], "=", 
    "\"\<GetSaddlesFromSeeds[{{\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(1\)]\)},{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(2\)]\)},\[Ellipsis]},\[CapitalOmega],S] finds a list of solutions \
{t,\[Tau]} of the HHG temporal saddle-point equations at harmonic energy \
\[CapitalOmega] for action S, using the given {\!\(\*SubscriptBox[\(t\), \
\(i\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(i\)]\)} as seeds for the process.\n\
\nGetSaddlesFromSeeds[\[LeftAssociation]\!\(\*SubscriptBox[\(\[CapitalOmega]\)\
, \(1\)]\)\[RightArrow]{{\!\(\*SubscriptBox[\(t\), \
\(11\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(11\)]\)},{\!\(\*SubscriptBox[\(t\), \
\(12\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(12\)]\)},\[Ellipsis]},\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(2\)]\)\
\[RightArrow]{{\!\(\*SubscriptBox[\(t\), \
\(21\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(21\)]\)},{\!\(\*SubscriptBox[\(t\), \
\(22\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(22\)]\)},\[Ellipsis]},\[Ellipsis]\
\[RightAssociation],\[CapitalOmega],S] finds solutions of the HHG temporal \
saddle-point equations, using the seeds list from the \!\(\*SubscriptBox[\(\
\[CapitalOmega]\), \(i\)]\) that's closest to \[CapitalOmega], or as \
specified by the value of KeyChooserFunction.\n\n\
GetSaddlesFromSeeds[seeds,{\!\(\*SubscriptBox[\(\[CapitalOmega]\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(2\)]\),\[Ellipsis]},S] \
iterates over the given set of harmonic energies.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SeedsChooserFunction", "::", "usage"}], "=", 
   "\"\<SeedsChooserFunction is an option for GetSaddlesFromSeeds that \
specifies a function f (set by default to Nearest) that, when used as f[{\!\(\
\*SubscriptBox[\(\[CapitalOmega]\), \(1\)]\),\!\(\*SubscriptBox[\(\
\[CapitalOmega]\), \(2\)]\),\[Ellipsis]},\[CapitalOmega]], should return the \
indices {\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(i\)]\),\!\(\*SubscriptBox[\
\(\[CapitalOmega]\), \(j\)]\),\[Ellipsis]} corresponding to the seed sets {{{\
\!\(\*SubscriptBox[\(t\), \(i1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(i1\)]\)},\[Ellipsis]},{{\!\(\*SubscriptBox[\(t\), \
\(j1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(j1\)]\)},\[Ellipsis]}} to be used \
to solve the HHG saddle-point equations.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RecalculateRoots", "::", "usage"}], "=", 
    "\"\<RecalculateRoots is an option for GetSaddlesFromSeeds that specifies \
whether to re-solve the saddle-point equations if the given harmonic energy \
\[CapitalOmega] is among the set of keys of the given seeds association. The \
default is False, which is appropriate for S being the same action used to \
find the seeds, in which case setting RecalculateRoots\[RightArrow]True will \
produce multiple FindRoot errors. If using a different action than used to \
find the seeds, set to True.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetSaddlesFromSeeds", "::", "error"}], "=", 
   "\"\<Errors encountered for harmonic energy \[CapitalOmega]=`1`.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GetSaddlesFromSeeds", "::", "norecalc"}], "=", 
    "\"\<Skipping re-calculation of roots at harmonic energy `1` since it is \
already in the key set of the given seeds association. To run the calculation \
for this case set RecalculateRoots to True.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "GetSaddlesFromSeeds", "]"}], "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"RecalculateRoots", "\[Rule]", "False"}], ",", 
       RowBox[{"SeedsChooserFunction", "\[Rule]", "Nearest"}]}], "}"}], ",", 
     RowBox[{"Options", "[", "GetSaddlePoints", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Protect", "[", 
    RowBox[{"SeedsChooserFunction", ",", "RecalculateRoots"}], "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetSaddlesFromSeeds", "[", 
    RowBox[{"seedsSpec_", ",", "\[CapitalOmega]Range_List", ",", "S_", ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Association", "[", 
    RowBox[{"ParallelTable", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[CapitalOmega]", "\[Rule]", 
       RowBox[{"GetSaddlesFromSeeds", "[", 
        RowBox[{
        "seedsSpec", ",", "\[CapitalOmega]", ",", "S", ",", "options"}], 
        "]"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"\[CapitalOmega]", ",", 
        RowBox[{"Sort", "[", "\[CapitalOmega]Range", "]"}]}], "}"}]}], "]"}], 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetSaddlesFromSeeds", "[", 
    RowBox[{
    "seedsAssociation_Association", ",", "\[CapitalOmega]_", ",", "S_", ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"keys", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", "SeedsChooserFunction", "]"}], "[", 
        RowBox[{
         RowBox[{"Keys", "[", "seedsAssociation", "]"}], ",", 
         "\[CapitalOmega]"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"MemberQ", "[", 
          RowBox[{"keys", ",", "\[CapitalOmega]"}], "]"}], "&&", 
         RowBox[{"TrueQ", "[", 
          RowBox[{"!", 
           RowBox[{"OptionValue", "[", "RecalculateRoots", "]"}]}], "]"}]}], 
        ",", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"GetSaddlesFromSeeds", "::", "norecalc"}], ",", 
           "\[CapitalOmega]"}], "]"}], ";", 
         RowBox[{"Return", "[", 
          RowBox[{"seedsAssociation", "[", "\[CapitalOmega]", "]"}], 
          "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"GetSaddlesFromSeeds", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Values", "[", 
           RowBox[{"seedsAssociation", "\[LeftDoubleBracket]", 
            RowBox[{"Key", "/@", "keys"}], "\[RightDoubleBracket]"}], "]"}], 
          ",", "1"}], "]"}], ",", "\[CapitalOmega]", ",", "S", ",", 
        "options"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GetSaddlesFromSeeds", "[", 
   RowBox[{"seedsList_List", ",", 
    RowBox[{"\[CapitalOmega]_", "?", "NumberQ"}], ",", "S_", ",", 
    RowBox[{"options", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"equations", ",", "roots", ",", 
      RowBox[{"t", "=", 
       RowBox[{"Symbol", "[", "\"\<t\>\"", "]"}]}], ",", 
      RowBox[{"tt", "=", 
       RowBox[{"Symbol", "[", "\"\<tt\>\"", "]"}]}], ",", 
      RowBox[{"\[Tau]", "=", 
       RowBox[{"Symbol", "[", "\"\<\[Tau]\>\"", "]"}]}], ",", "indVars", ",", 
      "depVar", ",", "depVarRule", ",", "fullSeedVars", ",", "tolerances"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tolerances", "=", 
      RowBox[{"SetTolerances", "[", 
       RowBox[{
        RowBox[{"OptionValue", "[", "Tolerance", "]"}], ",", "2", ",", 
        RowBox[{"OptionValue", "[", "WorkingPrecision", "]"}]}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"indVars", "=", 
      RowBox[{
       RowBox[{"OptionValue", "[", "IndependentVariables", "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<RecombinationTime\>\"", "\[Rule]", "\"\<t\>\""}], ",", 
         RowBox[{"\"\<ExcursionTime\>\"", "\[Rule]", "\"\<\[Tau]\>\""}], ",", 
         RowBox[{"\"\<IonizationTime\>\"", "\[Rule]", "\"\<tt\>\""}]}], 
        "}"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"depVar", "=", 
      RowBox[{"First", "[", 
       RowBox[{"DeleteCases", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<t\>\"", ",", "\"\<\[Tau]\>\"", ",", "\"\<tt\>\""}], 
          "}"}], ",", 
         RowBox[{"Alternatives", "@@", "indVars"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"depVarRule", "=", 
      RowBox[{"depVar", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<tt\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"tt", "\[Rule]", 
            RowBox[{"t", "-", "\[Tau]"}]}], "}"}]}], ",", 
         RowBox[{"\"\<t\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"t", "\[Rule]", 
            RowBox[{"tt", "+", "\[Tau]"}]}], "}"}]}], ",", 
         RowBox[{"\"\<\[Tau]\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\[Tau]", "\[Rule]", 
            RowBox[{"t", "-", "tt"}]}], "}"}]}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fullSeedVars", "[", "seed_", "]"}], ":=", 
      RowBox[{"\[LeftAssociation]", 
       RowBox[{
        RowBox[{"\"\<t\>\"", "\[Rule]", 
         RowBox[{
         "seed", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
        ",", 
        RowBox[{"\"\<\[Tau]\>\"", "\[Rule]", 
         RowBox[{
         "seed", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
        ",", 
        RowBox[{"\"\<tt\>\"", "\[Rule]", 
         RowBox[{
          RowBox[{
          "seed", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "-", 
          RowBox[{
          "seed", "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}]}]}]}], "\[RightAssociation]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"equations", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", "t"}], "]"}], "\[Equal]", 
          "\[CapitalOmega]"}], ",", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", "tt"}], "]"}], "\[Equal]", 
          "0"}]}], "}"}], "/.", "depVarRule"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"SortBy", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"DeleteDuplicates", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Select", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Check", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"roots", "=", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], "/.", "depVarRule"}],
                   ")"}], "/.", 
                 RowBox[{"(", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"FindRoot", "[", "\[IndentingNewLine]", 
                    RowBox[{"equations", "\[IndentingNewLine]", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Symbol", "[", "#", "]"}], ",", 
                    RowBox[{
                    RowBox[{"fullSeedVars", "[", "seed", "]"}], 
                    "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}]}], 
                    "}"}], "&"}], "/@", "indVars"}], "\[IndentingNewLine]", 
                    ",", 
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"FilterRules", "[", 
                    RowBox[{
                    RowBox[{"{", "options", "}"}], ",", 
                    RowBox[{"Options", "[", "FindRoot", "]"}]}], "]"}]}], 
                    "]"}]}], "\[IndentingNewLine]", "]"}], 
                   "\[IndentingNewLine]", "/.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "}"}], "\[Rule]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], "/.", "depVarRule"}],
                     ")"}], "\[Rule]", 
                    RowBox[{"{", "}"}]}], ")"}]}], "}"}]}], ")"}]}]}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{
                RowBox[{"Message", "[", 
                 RowBox[{
                  RowBox[{"GetSaddlesFromSeeds", "::", "error"}], ",", 
                  "\[CapitalOmega]"}], "]"}], ";", "roots"}]}], 
              "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"seed", ",", "seedsList"}], "}"}]}], "]"}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"Function", "[", 
            RowBox[{"timesPair", ",", 
             RowBox[{
              RowBox[{"OptionValue", "[", "SelectionFunction", "]"}], "[", 
              RowBox[{
               RowBox[{
               "timesPair", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "timesPair", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], ",", "S", ",", "\[CapitalOmega]"}],
               "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"timesPair1", ",", "timesPair2"}], "}"}], ",", "    ", 
           RowBox[{"And", "@@", 
            RowBox[{"Thread", "[", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"timesPair1", "-", "timesPair2"}], "]"}], "<", 
              "tolerances"}], "]"}]}]}], "     ", "]"}]}], 
        "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{"If", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ListQ", "[", 
          RowBox[{"OptionValue", "[", "SortingFunction", "]"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"timesPair", ",", 
             RowBox[{"f", "[", 
              RowBox[{
               RowBox[{
               "timesPair", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "timesPair", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], ",", "S", ",", "\[CapitalOmega]"}],
               "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"f", ",", 
             RowBox[{"OptionValue", "[", "SortingFunction", "]"}]}], "}"}]}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Function", "[", 
          RowBox[{"timesPair", ",", 
           RowBox[{
            RowBox[{"OptionValue", "[", "SortingFunction", "]"}], "[", 
            RowBox[{
             RowBox[{
             "timesPair", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{
             "timesPair", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], ",", "S", ",", "\[CapitalOmega]"}], 
            "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"17c728c3-bdce-41fd-b746-d416a667aeb7"]
}, Closed]],

Cell[CellGroupData[{

Cell["Cutoff saddle finders", \
"Subsection",ExpressionUUID->"86151a87-32ca-49b6-96a5-9efdb111a3e2"],

Cell[CellGroupData[{

Cell["GetDoubleSaddlePoints", \
"Subsubsection",ExpressionUUID->"b0ba5f5c-1457-4690-9d0c-7f86cef1106a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GetDoubleSaddlePoints", "::", "usage"}], "=", 
    "\"\<GetDoubleSaddlePoints[S,{tmin,tmax},{\[Tau]min,\[Tau]max},{\
\[CapitalOmega]min,\[CapitalOmega]max}] finds a list of double solutions {t,\
\[Tau],\[CapitalOmega]} of the HHG temporal saddle-point equations, using a \
complex-valued \[CapitalOmega] in the range {\[CapitalOmega]min,\
\[CapitalOmega]max}, for action S, in the range {tmin, tmax} of recombination \
time and {\[Tau]min, \[Tau]max} of excursion time, where the ranges should \
indicate the lower-left and upper-right corners of rectangles in the complex \
plane.\n\nGetDoubleSaddlePoints[S,{{{\!\(\*SubscriptBox[\(tmin\), \(1\)]\),\!\
\(\*SubscriptBox[\(tmax\), \(1\)]\)},{\!\(\*SubscriptBox[\(\[Tau]min\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]max\), \(1\)]\)},{\!\(\*SubscriptBox[\(\
\[CapitalOmega]min\), \(1\)]\),\!\(\*SubscriptBox[\(\[CapitalOmega]max\), \(1\
\)]\)}},{{\!\(\*SubscriptBox[\(tmin\), \(2\)]\),\!\(\*SubscriptBox[\(tmax\), \
\(2\)]\)},{\!\(\*SubscriptBox[\(\[Tau]min\), \(2\)]\),\!\(\*SubscriptBox[\(\
\[Tau]max\), \(2\)]\)},{\!\(\*SubscriptBox[\(\[CapitalOmega]min\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[CapitalOmega]max\), \(2\)]\)}},\[Ellipsis]}] \
uses multiple variable ranges and combines the solutions.\n\n\
GetDoubleSaddlePoints[S,{{urange,vrange,\[CapitalOmega]range},\[Ellipsis]},\
IndependentVariables\[Rule]{u,v}] uses the explicit independent temporal \
variables u and v to solve the equations and over the given ranges, where u \
and v can be any of \\\"RecombinationTime\\\", \\\"IonizationTime\\\" and \
\\\"ExcursionTime\\\", or their shorthands \\\"t\\\", \\\"tt\\\" and \\\"\
\[Tau]\\\" resp.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GetDoubleSaddlePoints", "::", "error"}], "=", 
    "\"\<Errors encountered at tag `1`.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ErrorReportingTag", "::", "usage"}], "=", "\"\<\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Protect", "[", "ErrorReportingTag", "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "GetDoubleSaddlePoints", "]"}], "=", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SortingFunction", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#4", "&"}], ",", 
            RowBox[{"#2", "&"}], ",", 
            RowBox[{"#1", "&"}]}], "}"}], ")"}]}], ",", 
        RowBox[{"SelectionFunction", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"True", "&"}], ")"}]}], ",", 
        RowBox[{"ErrorReportingTag", "\[Rule]", "None"}], ",", 
        RowBox[{"IndependentVariables", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<RecombinationTime\>\"", ",", "\"\<ExcursionTime\>\""}],
           "}"}]}]}], "}"}], ",", 
      RowBox[{"Options", "[", "FindComplexRoots", "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetDoubleSaddlePoints", "[", 
    RowBox[{"S_", ",", 
     RowBox[{"{", 
      RowBox[{"tmin_", ",", "tmax_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Tau]min_", ",", "\[Tau]max_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[CapitalOmega]min_", ",", "\[CapitalOmega]max_"}], "}"}], ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"GetDoubleSaddlePoints", "[", 
    RowBox[{"S", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"tmin", ",", "tmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Tau]min", ",", "\[Tau]max"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[CapitalOmega]min", ",", "\[CapitalOmega]max"}], "}"}]}], 
       "}"}], "}"}], ",", "options"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GetDoubleSaddlePoints", "[", 
   RowBox[{"S_", ",", "variableRanges_", ",", 
    RowBox[{"options", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"equations", ",", "roots", ",", 
      RowBox[{"t", "=", 
       RowBox[{"Symbol", "[", "\"\<t\>\"", "]"}]}], ",", 
      RowBox[{"tt", "=", 
       RowBox[{"Symbol", "[", "\"\<tt\>\"", "]"}]}], ",", 
      RowBox[{"\[Tau]", "=", 
       RowBox[{"Symbol", "[", "\"\<\[Tau]\>\"", "]"}]}], ",", 
      "\[CapitalOmega]", ",", "indVars", ",", "depVar", ",", "depVarRule", 
      ",", "tolerances"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tolerances", "=", 
      RowBox[{"SetTolerances", "[", 
       RowBox[{
        RowBox[{"OptionValue", "[", "Tolerance", "]"}], ",", "3", ",", 
        RowBox[{"OptionValue", "[", "WorkingPrecision", "]"}]}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"indVars", "=", 
      RowBox[{
       RowBox[{"OptionValue", "[", "IndependentVariables", "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<RecombinationTime\>\"", "\[Rule]", "\"\<t\>\""}], ",", 
         RowBox[{"\"\<ExcursionTime\>\"", "\[Rule]", "\"\<\[Tau]\>\""}], ",", 
         RowBox[{"\"\<IonizationTime\>\"", "\[Rule]", "\"\<tt\>\""}]}], 
        "}"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"depVar", "=", 
      RowBox[{"First", "[", 
       RowBox[{"DeleteCases", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<t\>\"", ",", "\"\<\[Tau]\>\"", ",", "\"\<tt\>\""}], 
          "}"}], ",", 
         RowBox[{"Alternatives", "@@", "indVars"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"depVarRule", "=", 
      RowBox[{"depVar", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<tt\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"tt", "\[Rule]", 
            RowBox[{"t", "-", "\[Tau]"}]}], "}"}]}], ",", 
         RowBox[{"\"\<t\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"t", "\[Rule]", 
            RowBox[{"tt", "+", "\[Tau]"}]}], "}"}]}], ",", 
         RowBox[{"\"\<\[Tau]\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\[Tau]", "\[Rule]", 
            RowBox[{"t", "-", "tt"}]}], "}"}]}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"equations", "=", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", "t"}], "]"}], "\[Equal]", 
          "\[CapitalOmega]"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", "tt"}], "]"}], "\[Equal]", 
          "0"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"S", "[", 
               RowBox[{"t", ",", "tt"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", "2"}], "}"}]}], "]"}], " ", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"S", "[", 
               RowBox[{"t", ",", "tt"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"tt", ",", "2"}], "}"}]}], "]"}]}], "-", 
           SuperscriptBox[
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"S", "[", 
               RowBox[{"t", ",", "tt"}], "]"}], ",", "t", ",", "tt"}], "]"}], 
            "2"]}], "\[Equal]", "0"}]}], "\[IndentingNewLine]", "}"}], "/.", 
       "depVarRule"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"SortBy", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"DeleteDuplicates", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Select", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Check", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"roots", "=", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]", ",", "\[CapitalOmega]"}], 
                    "}"}], "/.", "depVarRule"}], ")"}], "/.", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"FindComplexRoots", "[", "\[IndentingNewLine]", 
                    RowBox[{"equations", "\[IndentingNewLine]", ",", 
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"Sequence", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Symbol", "[", 
                    RowBox[{
                    "indVars", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    "}"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Symbol", "[", 
                    RowBox[{
                    "indVars", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    "}"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"\[CapitalOmega]", ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"3", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    "}"}]}], "\[IndentingNewLine]", "]"}], "]"}], 
                    "\[IndentingNewLine]", ",", 
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"FilterRules", "[", 
                    RowBox[{
                    RowBox[{"{", "options", "}"}], ",", 
                    RowBox[{"Options", "[", "FindComplexRoots", "]"}]}], 
                    "]"}]}], "]"}], "\[IndentingNewLine]", ",", 
                    RowBox[{
                    "SeedGenerator", "\[Rule]", "RandomSobolComplexes"}], 
                    "\[IndentingNewLine]", ",", 
                    RowBox[{"Seeds", "\[Rule]", "50"}]}], 
                    "\[IndentingNewLine]", "]"}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "}"}], "\[Rule]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], "/.", "depVarRule"}],
                     ")"}], "\[Rule]", 
                    RowBox[{"{", "}"}]}], ")"}]}], "}"}]}], ")"}]}]}], 
                 RowBox[{"(*", 
                  RowBox[{
                  "to", " ", "deal", " ", "with", " ", "empty", " ", 
                   "results"}], "*)"}], "\[IndentingNewLine]", ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"OptionValue", "[", "ErrorReportingTag", "]"}], 
                    "\[NotEqual]", "None"}], ",", 
                    RowBox[{"Message", "[", 
                    RowBox[{
                    RowBox[{"GetDoubleSaddlePoints", "::", "error"}], ",", 
                    RowBox[{"OptionValue", "[", "ErrorReportingTag", "]"}]}], 
                    "]"}]}], "]"}], ";", "\[IndentingNewLine]", "roots"}]}], 
                "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
               RowBox[{"Function", "[", 
                RowBox[{"variableSet", ",", 
                 RowBox[{
                  RowBox[{"OptionValue", "[", "SelectionFunction", "]"}], "[", 
                  RowBox[{
                   RowBox[{
                   "variableSet", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{
                   "variableSet", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], ",", "S"}], "]"}]}], "]"}]}], 
              "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"range", ",", "variableRanges"}], "}"}]}], "]"}], ",", 
           "1"}], "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"variableSet1", ",", "variableSet2"}], "}"}], ",", "    ", 
           RowBox[{"And", "@@", 
            RowBox[{"Thread", "[", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"variableSet1", "-", "variableSet2"}], "]"}], "<", 
              "tolerances"}], "]"}]}]}], "     ", "]"}]}], 
        "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{"If", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ListQ", "[", 
          RowBox[{"OptionValue", "[", "SortingFunction", "]"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"variableSet", ",", 
             RowBox[{"f", "[", 
              RowBox[{
               RowBox[{
               "variableSet", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "variableSet", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], ",", "S", ",", 
               RowBox[{
               "variableSet", "\[LeftDoubleBracket]", "3", 
                "\[RightDoubleBracket]"}]}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"f", ",", 
             RowBox[{"OptionValue", "[", "SortingFunction", "]"}]}], "}"}]}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Function", "[", 
          RowBox[{"variableSet", ",", 
           RowBox[{
            RowBox[{"OptionValue", "[", "SortingFunction", "]"}], "[", 
            RowBox[{
             RowBox[{
             "variableSet", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{
             "variableSet", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], ",", "S", ",", 
             RowBox[{
             "variableSet", "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"fb3222ef-d737-477d-8d0c-075d517dbcec"]
}, Closed]],

Cell[CellGroupData[{

Cell["GetCutoffSaddlePoints", \
"Subsubsection",ExpressionUUID->"f2b55272-52dd-4b0f-99a3-6f1929ffc19c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GetCutoffSaddlePoints", "::", "usage"}], "=", 
    "\"\<GetCutoffSaddlePoints[S,{tmin,tmax},{\[Tau]min,\[Tau]max}] finds a \
list of solutions {t,\[Tau],\!\(\*SubscriptBox[\(\[PartialD]\), \
\(t\)]\)S,\!\(\*SubsuperscriptBox[\(d\), \(t\), \(3\)]\)S} of the HHG cutoff \
saddle-point equations {\!\(\*SubscriptBox[\(\[PartialD]\), \(t'\)]\)S=0,\!\(\
\*SubsuperscriptBox[\(d\), \(t\), \(2\)]\)S=0} for action S, in the range \
{tmin, tmax} of recombination time and {\[Tau]min, \[Tau]max} of excursion \
time, where both ranges should be the lower-left and upper-right corners of \
rectangles in the complex plane.\n\n\
GetCutoffSaddlePoints[S,{{{\!\(\*SubscriptBox[\(tmin\), \
\(1\)]\),\!\(\*SubscriptBox[\(tmax\), \
\(1\)]\)},{\!\(\*SubscriptBox[\(\[Tau]min\), \(1\)]\),\!\(\*SubscriptBox[\(\
\[Tau]max\), \(1\)]\)}},{{\!\(\*SubscriptBox[\(tmin\), \
\(2\)]\),\!\(\*SubscriptBox[\(tmax\), \
\(2\)]\)},{\!\(\*SubscriptBox[\(\[Tau]min\), \(2\)]\),\!\(\*SubscriptBox[\(\
\[Tau]max\), \(2\)]\)}},\[Ellipsis]}] uses multiple time domains and combines \
the solutions.\n\n\
GetCutoffSaddlePoints[S,{{urange,vrange},\[Ellipsis]},IndependentVariables\
\[Rule]{u,v}] uses the explicit independent variables u and v to solve the \
equations and over the given ranges, where u and v can be any of \
\\\"RecombinationTime\\\", \\\"IonizationTime\\\" and \\\"ExcursionTime\\\", \
or their shorthands \\\"t\\\", \\\"tt\\\" and \\\"\[Tau]\\\" resp.\>\""}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GetCutoffSaddlePoints", "::", "error"}], "=", 
    "\"\<Errors encountered at tag `1`.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "GetCutoffSaddlePoints", "]"}], "=", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SortingFunction", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"#2", "&"}], ")"}]}], ",", 
        RowBox[{"SelectionFunction", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"True", "&"}], ")"}]}], ",", 
        RowBox[{"ErrorReportingTag", "\[Rule]", "None"}], ",", 
        RowBox[{"IndependentVariables", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<RecombinationTime\>\"", ",", "\"\<ExcursionTime\>\""}],
           "}"}]}]}], "}"}], ",", 
      RowBox[{"Options", "[", "FindComplexRoots", "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GetCutoffSaddlePoints", "[", 
    RowBox[{"S_", ",", 
     RowBox[{"{", 
      RowBox[{"tmin_", ",", "tmax_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Tau]min_", ",", "\[Tau]max_"}], "}"}], ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"GetCutoffSaddlePoints", "[", 
    RowBox[{"S", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"tmin", ",", "tmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Tau]min", ",", "\[Tau]max"}], "}"}]}], "}"}], "}"}], ",", 
     "options"}], "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GetCutoffSaddlePoints", "[", 
   RowBox[{"S_", ",", "timeRanges_", ",", 
    RowBox[{"options", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"equations", ",", "roots", ",", 
      RowBox[{"t", "=", 
       RowBox[{"Symbol", "[", "\"\<t\>\"", "]"}]}], ",", 
      RowBox[{"tt", "=", 
       RowBox[{"Symbol", "[", "\"\<tt\>\"", "]"}]}], ",", 
      RowBox[{"\[Tau]", "=", 
       RowBox[{"Symbol", "[", "\"\<\[Tau]\>\"", "]"}]}], ",", "indVars", ",", 
      "depVar", ",", "depVarRule", ",", "tolerances", ",", "d1S", ",", "d3S", 
      ",", "d2Sdtt2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tolerances", "=", 
      RowBox[{"SetTolerances", "[", 
       RowBox[{
        RowBox[{"OptionValue", "[", "Tolerance", "]"}], ",", "2", ",", 
        RowBox[{"OptionValue", "[", "WorkingPrecision", "]"}]}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"indVars", "=", 
      RowBox[{
       RowBox[{"OptionValue", "[", "IndependentVariables", "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<RecombinationTime\>\"", "\[Rule]", "\"\<t\>\""}], ",", 
         RowBox[{"\"\<ExcursionTime\>\"", "\[Rule]", "\"\<\[Tau]\>\""}], ",", 
         RowBox[{"\"\<IonizationTime\>\"", "\[Rule]", "\"\<tt\>\""}]}], 
        "}"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"depVar", "=", 
      RowBox[{"First", "[", 
       RowBox[{"DeleteCases", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<t\>\"", ",", "\"\<\[Tau]\>\"", ",", "\"\<tt\>\""}], 
          "}"}], ",", 
         RowBox[{"Alternatives", "@@", "indVars"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"depVarRule", "=", 
      RowBox[{"depVar", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\"\<tt\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"tt", "\[Rule]", 
            RowBox[{"t", "-", "\[Tau]"}]}], "}"}]}], ",", 
         RowBox[{"\"\<t\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"t", "\[Rule]", 
            RowBox[{"tt", "+", "\[Tau]"}]}], "}"}]}], ",", 
         RowBox[{"\"\<\[Tau]\>\"", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\[Tau]", "\[Rule]", 
            RowBox[{"t", "-", "tt"}]}], "}"}]}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"equations", "=", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"t", ",", "tt"}], "]"}], ",", "tt"}], "]"}], "\[Equal]", 
          "0"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"S", "[", 
               RowBox[{"t", ",", "tt"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", "2"}], "}"}]}], "]"}], 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"S", "[", 
               RowBox[{"t", ",", "tt"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"tt", ",", "2"}], "}"}]}], "]"}]}], "-", 
           SuperscriptBox[
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"S", "[", 
               RowBox[{"t", ",", "tt"}], "]"}], ",", "t", ",", "tt"}], "]"}], 
            "2"]}], "\[Equal]", "0"}]}], "\[IndentingNewLine]", "}"}], "/.", 
       "depVarRule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"d1S", "[", 
       RowBox[{"t_", ",", "tt_"}], "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{"ConstrainedDerivative", "[", "1", "]"}], "[", "S", "]"}], 
       "[", 
       RowBox[{"t", ",", "tt"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"d3S", "[", 
       RowBox[{"t_", ",", "tt_"}], "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{"ConstrainedDerivative", "[", "3", "]"}], "[", "S", "]"}], 
       "[", 
       RowBox[{"t", ",", "tt"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"d2Sdtt2", "[", 
       RowBox[{"t_", ",", "tt_"}], "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"0", ",", "2"}], "]"}], "[", "S", "]"}], "[", 
       RowBox[{"t", ",", "tt"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"Map", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Association", "[", 
         RowBox[{"Thread", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "\"\<t\>\"", ",", "\"\<\[Tau]\>\"", ",", "\"\<S\>\"", ",", 
             "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)S\>\"", ",", 
             "\"\<\!\(\*SubsuperscriptBox[\(d\), \(t\), \(3\)]\)S\>\"", ",", 
             "\"\<\!\(\*SubsuperscriptBox[\(\[PartialD]\), \(tt\), \
\(2\)]\)S\>\""}], "}"}], "\[Rule]", "#"}], "]"}], "]"}], "&"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"SortBy", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"DeleteDuplicates", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{"Table", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Select", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Check", "[", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"roots", "=", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]", ",", 
                    RowBox[{"S", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{"t", "-", "\[Tau]"}]}], "]"}], ",", 
                    RowBox[{"d1S", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{"t", "-", "\[Tau]"}]}], "]"}], ",", 
                    RowBox[{"d3S", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{"t", "-", "\[Tau]"}]}], "]"}], ",", 
                    RowBox[{"d2Sdtt2", "[", 
                    RowBox[{"t", ",", 
                    RowBox[{"t", "-", "\[Tau]"}]}], "]"}]}], "}"}], "/.", 
                    "depVarRule"}], ")"}], "/.", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"FindComplexRoots", "[", "\[IndentingNewLine]", 
                    RowBox[{"equations", "\[IndentingNewLine]", ",", 
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"Sequence", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Symbol", "[", 
                    RowBox[{
                    "indVars", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Symbol", "[", 
                    RowBox[{
                    "indVars", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"range", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", ",", 
                    RowBox[{"Evaluate", "[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"FilterRules", "[", 
                    RowBox[{
                    RowBox[{"{", "options", "}"}], ",", 
                    RowBox[{"Options", "[", "FindComplexRoots", "]"}]}], 
                    "]"}]}], "]"}], "\[IndentingNewLine]", ",", 
                    RowBox[{
                    "SeedGenerator", "\[Rule]", "RandomSobolComplexes"}], 
                    "\[IndentingNewLine]", ",", 
                    RowBox[{"Seeds", "\[Rule]", "50"}]}], 
                    "\[IndentingNewLine]", "]"}], "/.", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", "}"}], "\[Rule]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"t", ",", "\[Tau]"}], "}"}], "/.", "depVarRule"}],
                     ")"}], "\[Rule]", 
                    RowBox[{"{", "}"}]}], ")"}]}], "}"}]}], ")"}]}]}], 
                   RowBox[{"(*", 
                    RowBox[{
                    "to", " ", "deal", " ", "with", " ", "empty", " ", 
                    "results"}], "*)"}], "\[IndentingNewLine]", ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"OptionValue", "[", "ErrorReportingTag", "]"}], 
                    "\[NotEqual]", "None"}], ",", 
                    RowBox[{"Message", "[", 
                    RowBox[{
                    RowBox[{"GetCutoffSaddlePoints", "::", "error"}], ",", 
                    RowBox[{"OptionValue", "[", "ErrorReportingTag", "]"}]}], 
                    "]"}]}], "]"}], ";", "\[IndentingNewLine]", "roots"}]}], 
                  "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
                 RowBox[{"Function", "[", 
                  RowBox[{"timesPair", ",", 
                   RowBox[{
                    RowBox[{"OptionValue", "[", "SelectionFunction", "]"}], 
                    "[", 
                    RowBox[{
                    RowBox[{
                    "timesPair", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{
                    "timesPair", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], ",", "S"}], "]"}]}], "]"}]}], 
                "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
               RowBox[{"{", 
                RowBox[{"range", ",", "timeRanges"}], "}"}]}], "]"}], ",", 
             "1"}], "]"}], "\[IndentingNewLine]", ",", 
           RowBox[{"Function", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"timesPair1", ",", "timesPair2"}], "}"}], ",", "    ", 
             RowBox[{"And", "@@", 
              RowBox[{"Thread", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Abs", "[", 
                  RowBox[{"timesPair1", "-", "timesPair2"}], "]"}], 
                 "\[LeftDoubleBracket]", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "2"}], "}"}], "\[RightDoubleBracket]"}], 
                "<", "tolerances"}], "]"}]}]}], "     ", "]"}]}], 
          "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"If", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"ListQ", "[", 
            RowBox[{"OptionValue", "[", "SortingFunction", "]"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Function", "[", 
              RowBox[{"timesPair", ",", 
               RowBox[{"f", "[", 
                RowBox[{
                 RowBox[{
                 "timesPair", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}], ",", 
                 RowBox[{
                 "timesPair", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}], ",", "S"}], "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"f", ",", 
               RowBox[{"OptionValue", "[", "SortingFunction", "]"}]}], 
              "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Function", "[", 
            RowBox[{"timesPair", ",", 
             RowBox[{
              RowBox[{"OptionValue", "[", "SortingFunction", "]"}], "[", 
              RowBox[{
               RowBox[{
               "timesPair", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
               "timesPair", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], ",", "S"}], "]"}]}], "]"}]}], 
          "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"6f675c4d-243c-40b7-b9fe-358bcd6ba0c9"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClassifyQuantumOrbits", \
"Subsection",ExpressionUUID->"8a7854b3-4e71-4882-b29a-48d6017d51a4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ClassifyQuantumOrbits", "::", "usage"}], "=", 
   "\"\<ClassifyQuantumOrbits[saddlePoints,f] sorts an indexed set of saddle \
points of the form \[LeftAssociation]\!\(\*SubscriptBox[\(\[CapitalOmega]\), \
\(1\)]\)\[RightArrow]{{\!\(\*SubscriptBox[\(t\), \
\(11\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(11\)]\)},{\!\(\*SubscriptBox[\(t\), \
\(12\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(12\)]\)},\[Ellipsis]}\[Ellipsis]\
\[RightAssociation] using a function f, which should turn f[t,\[Tau],\
\[CapitalOmega]] into an appropriate label, and returns an association of the \
form \[LeftAssociation]\!\(\*SubscriptBox[\(label\), \(1\)]\)\[RightArrow]\
\[LeftAssociation]\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(1\)]\)\
\[RightArrow]\[LeftAssociation]1\[RightArrow]{t,\[Tau]},2\[RightArrow]{t,\
\[Tau]},\[Ellipsis]\[RightAssociation],\[Ellipsis]\[RightAssociation],\
\[Ellipsis]\[RightAssociation].\n\n\
ClassifyQuantumOrbits[saddlePoints,f,sortFunction] uses the function \
sortFunction to sort the sets of saddle points {{\!\(\*SubscriptBox[\(t\), \
\(11\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(11\)]\)},{\!\(\*SubscriptBox[\(t\), \
\(12\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(12\)]\)},\[Ellipsis]} for each \
label and harmonic energy.\n\n\
ClassifyQuantumOrbits[saddlePoints,f,sortFunction,DiscardedLabels\[RightArrow]\
{\!\(\*SubscriptBox[\(label\), \(1\)]\),\!\(\*SubscriptBox[\(label\), \
\(2\)]\),\[Ellipsis]}] specifies a list of labels to discard from the final \
output.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DiscardedLabels", "::", "usage"}], "=", 
    "\"\<DiscardedLabels is an option for ClassifyQuantumOrbits which \
specifies a list of labels to discard from the final output.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "ClassifyQuantumOrbits", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"DiscardedLabels", "\[Rule]", 
     RowBox[{"{", "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Protect", "[", "DiscardedLabels", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ClassifyQuantumOrbits", "[", 
    RowBox[{"saddlePointList_", ",", "classifierFunction_", ",", 
     RowBox[{"sortingFunction_:", "Sort"}], ",", 
     RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
   RowBox[{"Map", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Composition", "[", "\[IndentingNewLine]", 
      RowBox[{"Association", ",", "\[IndentingNewLine]", 
       RowBox[{"MapIndexed", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
          "#2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          "\[Rule]", "#1"}], "&"}], "]"}], ",", "\[IndentingNewLine]", 
       "sortingFunction"}], "\[IndentingNewLine]", "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Delete", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"AssociationTranspose", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"MapIndexed", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"GroupBy", "[", 
              RowBox[{
               RowBox[{"classifierFunction", "@@", "#"}], "&"}], "]"}], "[", 
             RowBox[{"Flatten", "/@", 
              RowBox[{"Transpose", "[", 
               RowBox[{"{", 
                RowBox[{"#1", ",", 
                 RowBox[{"ConstantArray", "[", 
                  RowBox[{
                   RowBox[{"#2", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"{", "1", "}"}], ",", "1"}], 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{"Length", "[", "#1", "]"}]}], "]"}]}], "}"}], 
               "]"}]}], "]"}], "&"}], "\[IndentingNewLine]", ",", 
           "saddlePointList"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "All", ",", "All", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2"}], "}"}]}], "\[RightDoubleBracket]"}], 
        "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{"List", "/@", 
        RowBox[{"OptionValue", "[", "DiscardedLabels", "]"}]}]}], "]"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"377c1ba2-1730-4b71-a034-b07696fb852a"]
}, Closed]],

Cell[CellGroupData[{

Cell["ReperiodSaddles", \
"Subsection",ExpressionUUID->"bec466ac-261d-41f1-a2cc-7b0bc2cca9ba"],

Cell[BoxData[{
 RowBox[{"ClearAll", "[", "ReperiodSaddles", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ReperiodSaddles", "::", "usage"}], "=", 
    "\"\<ReperiodSaddles[{{\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(1\)]\)},{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)},\[Ellipsis]},f] readjusts \
the assigned cycle of the saddle points {\!\(\*SubscriptBox[\(t\), \
\(i\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(i\)]\)}, returning the list \
{{\!\(\*SubscriptBox[\(t\), \(1\)]\)+f[\!\(\*SubscriptBox[\(t\), \
\(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(1\)]\)],\!\(\*SubscriptBox[\(\[Tau]\
\), \(1\)]\)},\[Ellipsis]}.\n\n\
ReperiodSaddles[\[LeftAssociation]\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(1\
\)]\)\[RightArrow]{{\!\(\*SubscriptBox[\(t\), \(11\)]\),\!\(\*SubscriptBox[\(\
\[Tau]\), \(11\)]\)},\[Ellipsis]},\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(2\
\)]\)\[Rule]\[Ellipsis]\[RightAssociation],f] reperiods saddle-point pairs in \
a harmonic-energy-indexed association.\n\n\
ReperiodSaddles[\[LeftAssociation]\!\(\*SubscriptBox[\(label\), \(l\)]\)\
\[Rule]\[LeftAssociation]\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(1\)]\)\
\[RightArrow]{{\!\(\*SubscriptBox[\(t\), \
\(11\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(11\)]\)},\[Ellipsis]},\[Ellipsis]\
\[RightAssociation],\[Ellipsis]\[RightAssociation],f] reperiods saddle-point \
pairs of a classified set of saddle points.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ReperiodSaddles", "[", 
   RowBox[{
    RowBox[{"pair_", "/;", 
     RowBox[{
      RowBox[{"Depth", "[", "pair", "]"}], "\[Equal]", "2"}]}], ",", "f_"}], 
   "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"pair", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "+", 
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{"pair", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
        ",", 
       RowBox[{
       "pair", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
      "]"}]}], ",", 
    RowBox[{"pair", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ReperiodSaddles", "[", 
    RowBox[{"association_", ",", "f_"}], "]"}], ":=", 
   RowBox[{"Apply", "[", 
    RowBox[{"f", ",", "association", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Depth", "[", "association", "]"}], "-", "2"}], "}"}]}], 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"2843384e-848d-4213-936f-0810ecf37512"]
}, Closed]],

Cell[CellGroupData[{

Cell["HessianRoot", \
"Subsection",ExpressionUUID->"5ffa868c-5d0b-4f23-b03a-4cb34e396958"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"HessianRoot", "::", "usage"}], "=", 
   "\"\<HessianRoot[S,t,\[Tau]] calculates the Hessian root \
\!\(\*SqrtBox[FractionBox[SuperscriptBox[\((2  \[Pi])\), \(2\)], \
\(\*SuperscriptBox[\(\[ImaginaryI]\), \(2\)] Det[\*SubsuperscriptBox[\(\
\[PartialD]\), \({t, tt}\), \(2\)]S]\)]]\).\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HessianRoot", "[", 
   RowBox[{"S_", ",", "t_", ",", "\[Tau]_"}], "]"}], ":=", 
  RowBox[{
   SqrtBox[
    FractionBox[
     RowBox[{"2", "\[Pi]"}], 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"0", ",", "2"}], "]"}], "[", "S", "]"}], "[", 
       RowBox[{"t", ",", 
        RowBox[{"t", "-", "\[Tau]"}]}], "]"}]}]]], 
   SqrtBox[
    FractionBox[
     RowBox[{"2", "\[Pi]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"0", ",", "2"}], "]"}], "[", "S", "]"}], "[", 
       RowBox[{"t", ",", 
        RowBox[{"t", "-", "\[Tau]"}]}], "]"}]}], 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"2", ",", "0"}], "]"}], "[", "S", "]"}], "[", 
          RowBox[{"t", ",", 
           RowBox[{"t", "-", "\[Tau]"}]}], "]"}], 
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"0", ",", "2"}], "]"}], "[", "S", "]"}], "[", 
          RowBox[{"t", ",", 
           RowBox[{"t", "-", "\[Tau]"}]}], "]"}]}], "-", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"1", ",", "1"}], "]"}], "[", "S", "]"}], "[", 
          RowBox[{"t", ",", 
           RowBox[{"t", "-", "\[Tau]"}]}], "]"}], "2"]}], 
       ")"}]}]]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"15f19319-f9bd-4d3d-8d5c-aa6a8f12e881"]
}, Closed]],

Cell[CellGroupData[{

Cell["FindStokesTransitions", \
"Subsection",ExpressionUUID->"28899c59-4b10-4514-9edd-cfe3efe91f68"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"FindStokesTransitions", "::", "usage"}], "=", 
   "\"\<FindStokesTransitions[S,\[LeftAssociation]\!\(\*SubscriptBox[\(\
\[CapitalOmega]\), \(1\)]\)\[RightArrow]\[LeftAssociation]1\[RightArrow]{\!\(\
\*SubscriptBox[\(t\), \(11\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(11\)]\)},2\
\[RightArrow]{\!\(\*SubscriptBox[\(t\), \(12\)]\),\!\(\*SubscriptBox[\(\[Tau]\
\), \(12\)]\)}\[RightAssociation],\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(2\
\)]\)\[RightArrow]\[LeftAssociation]1\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(21\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(21\)]\)},2\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(22\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(22\)]\)}\[RightAssociation],\
\[Ellipsis]\[RightAssociation]] finds the set {{\!\(\*SubscriptBox[\(\
\[CapitalOmega]\), \(S\)]\)},{\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(AS\)]\
\)},n} of the Stokes and anti-Stokes transition energies for the given set of \
saddle points, where Re(S) changes sign after the \!\(\*SubscriptBox[\(\
\[CapitalOmega]\), \(S\)]\) and Im(S) changes sign after the \
\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(AS\)]\), and n is the index of the \
member of the pair that should be chosen after the transition (taken as the \
member with a positive imaginary part of the action at the largest \
\!\(\*SubscriptBox[\(\[CapitalOmega]\), \(i\)]\) in the given keys).\n\n\
FindStokesTransitions[S,\[LeftAssociation]\!\(\*SubscriptBox[\(label\), \
\(1\)]\)\[RightArrow]\[LeftAssociation]\!\(\*SubscriptBox[\(\[CapitalOmega]\),\
 \(1\)]\)\[RightArrow]\[Ellipsis]\[RightAssociation]\[RightAssociation]] \
finds the Stokes transitions for the given set of saddle-point curve pairs, \
and returns them labeled with the \!\(\*SubscriptBox[\(label\), \
\(i\)]\).\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FindStokesTransitions", "::", "saddleno"}], "=", 
   "\"\<FindStokesTransitions called with `1` of `2` saddle-point sets of \
length different from 2, with set length structure `3`. Excluding those sets \
from the calculation.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FindStokesTransitions", "::", "multipleS"}], "=", 
   "\"\<FindStokesTransitions found multiple Stokes transitions; using `1` to \
return a single transition.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FindStokesTransitions", "::", "multipleAS"}], "=", 
   "\"\<FindStokesTransitions found multiple anti-Stokes transitions; using \
`1` to return a single transition.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ChooserFunction", "::", "usage"}], "=", 
   "\"\<ChooserFunction is an option for FindStokesTransitions that specifies \
which transition to take if there are multiple transitions in the given \
dataset. The default is Last and gives the one with higher energy; to get the \
full set of transitions found use Full or Identity.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ReperiodingFunction", "::", "usage"}], "=", 
    "\"\<ReperiodingFunction is an option for FindStokesTransitions, \
SPAdipole and UAdipole which specifies a function f[t,\[Tau]] of \
recombination time t and excursion time \[Tau] that will be used to re-period \
the pairs {t,\[Tau]} into the form {t+f[t,\[Tau]],\[Tau]}. The default is \
Function[0], but if pairs are split it can be useful to set \
ReperiodingFunction to \
Function[{t,\[Tau]},Floor[-Re[t-\[Tau]],\!\(\*FractionBox[\(2  \[Pi]\), \(\
\[Omega]\)]\)]] for \[Omega] the carrier frequency. In general, however, it \
is preferable to do this in a single go using ReperiodSaddles.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Protect", "[", 
   RowBox[{"ReperiodingFunction", ",", "ChooserFunction"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "FindStokesTransitions", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ReperiodingFunction", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", "0"}], "]"}]}], ",", 
      RowBox[{"ChooserFunction", "\[Rule]", "Automatic"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FindStokesTransitions", "[", 
    RowBox[{"S_", ",", 
     RowBox[{"deeperAssociation_", "/;", 
      RowBox[{
       RowBox[{"Depth", "[", "deeperAssociation", "]"}], "\[Equal]", "5"}]}], 
     ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Map", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"FindStokesTransitions", "[", 
       RowBox[{"S", ",", "#", ",", "options"}], "]"}], "&"}], ",", 
     "\[IndentingNewLine]", "deeperAssociation"}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FindStokesTransitions", "[", 
    RowBox[{"S_", ",", "saddlesAssociation_", ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "reducedSaddlesAssociation", ",", "actionList", ",", "signsList", ",", 
       "s", ",", "processor"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"reducedSaddlesAssociation", "=", 
       RowBox[{"KeySort", "[", 
        RowBox[{"Select", "[", 
         RowBox[{"saddlesAssociation", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "#", "]"}], "\[Equal]", "2"}], "&"}]}], 
         "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "saddlesAssociation", "]"}], "-", 
          RowBox[{"Length", "[", "reducedSaddlesAssociation", "]"}]}], ">", 
         "0"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"FindStokesTransitions", "::", "saddleno"}], ",", 
          RowBox[{
           RowBox[{"Length", "[", "saddlesAssociation", "]"}], "-", 
           RowBox[{"Length", "[", "reducedSaddlesAssociation", "]"}]}], ",", 
          RowBox[{"Length", "[", "saddlesAssociation", "]"}], ",", 
          RowBox[{"First", "/@", 
           RowBox[{"Tally", "/@", 
            RowBox[{"Split", "[", 
             RowBox[{"Values", "[", 
              RowBox[{"Length", "/@", "saddlesAssociation"}], "]"}], 
             "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"actionList", "=", 
       RowBox[{"ReIm", "[", "\[IndentingNewLine]", 
        RowBox[{"Map", "[", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"reduces", " ", "each", " ", "\[CapitalOmega]"}], 
           "\[Rule]", 
           RowBox[{
            RowBox[{
             RowBox[{"\[LeftAssociation]", 
              RowBox[{
               RowBox[{"1", "\[Rule]", 
                SubscriptBox["S", "1"]}], ",", 
               RowBox[{"2", "\[Rule]", 
                SubscriptBox["S", "2"]}]}], "\[RightAssociation]"}], " ", 
             "to", " ", "\[CapitalOmega]"}], "\[RightArrow]", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["S", "1"], "-", 
              SubscriptBox["S", "2"]}], ")"}]}]}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Apply", "[", "Subtract", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"MapIndexed", "[", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"reduces", " ", "each", " ", "\[CapitalOmega]"}], 
             "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{"\[LeftAssociation]", 
                RowBox[{
                 RowBox[{"1", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    SubscriptBox["t", "1"], ",", 
                    SubscriptBox["\[Tau]", "1"]}], "}"}]}], ",", 
                 RowBox[{"2", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    SubscriptBox["t", "2"], ",", 
                    SubscriptBox["\[Tau]", "2"]}], "}"}]}]}], 
                "\[RightAssociation]"}], " ", "to", " ", "\[CapitalOmega]"}], 
              "\[Rule]", 
              RowBox[{"\[LeftAssociation]", 
               RowBox[{
                RowBox[{"1", "\[Rule]", 
                 SubscriptBox["S", "1"]}], ",", 
                RowBox[{"2", "\[Rule]", 
                 SubscriptBox["S", "2"]}]}], "\[RightAssociation]"}]}]}], 
            "*)"}], "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"With", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"t", "=", 
                  RowBox[{
                   RowBox[{
                   "#1", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "+", 
                   RowBox[{
                    RowBox[{"OptionValue", "[", "ReperiodingFunction", "]"}], 
                    "[", 
                    RowBox[{
                    RowBox[{
                    "#1", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{
                    "#2", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "]"}]}]}], ",", 
                 RowBox[{"\[Tau]", "=", 
                  RowBox[{
                  "#1", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}]}], ",", 
                 RowBox[{"\[CapitalOmega]", "=", 
                  RowBox[{"#2", "\[LeftDoubleBracket]", 
                   RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
                "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"t", ",", 
                  RowBox[{"t", "-", "\[Tau]"}]}], "]"}], "-", 
                RowBox[{"\[CapitalOmega]", " ", "t"}]}]}], 
              "\[IndentingNewLine]", "]"}], "&"}], "\[IndentingNewLine]", ",",
             "reducedSaddlesAssociation", ",", 
            RowBox[{"{", "2", "}"}]}], "\[IndentingNewLine]", "]"}]}], "]"}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"signsList", "=", 
       RowBox[{"Sign", "[", 
        RowBox[{"Times", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Rest", "[", "actionList", "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"AssociationThread", "[", 
           RowBox[{
            RowBox[{"Rest", "[", 
             RowBox[{"Keys", "[", "actionList", "]"}], "]"}], ",", 
            RowBox[{"Most", "[", 
             RowBox[{"Values", "[", "actionList", "]"}], "]"}]}], "]"}]}], 
         "\[IndentingNewLine]", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"processor", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", "ChooserFunction", "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Automatic", "\[Rule]", "Last"}], ",", 
          RowBox[{"Full", "\[Rule]", "Identity"}]}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Keys", "[", 
           RowBox[{"Select", "[", 
            RowBox[{"signsList", ",", 
             RowBox[{
              RowBox[{
               RowBox[{
               "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               "<", "0"}], "&"}]}], "]"}], "]"}], "]"}], ">", "1"}], ",", 
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"FindStokesTransitions", "::", "multipleS"}], ",", 
          "processor"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Keys", "[", 
           RowBox[{"Select", "[", 
            RowBox[{"signsList", ",", 
             RowBox[{
              RowBox[{
               RowBox[{
               "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
               "<", "0"}], "&"}]}], "]"}], "]"}], "]"}], ">", "1"}], ",", 
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"FindStokesTransitions", "::", "multipleAS"}], ",", 
          "processor"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"processor", "[", 
         RowBox[{
          RowBox[{"Keys", "[", 
           RowBox[{"Select", "[", 
            RowBox[{"signsList", ",", 
             RowBox[{
              RowBox[{
               RowBox[{
               "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               "<", "0"}], "&"}]}], "]"}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "}"}], "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Missing", "[", "\"\<No transition\>\"", "]"}], "}"}]}], 
           "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"processor", "[", 
         RowBox[{
          RowBox[{"Keys", "[", 
           RowBox[{"Select", "[", 
            RowBox[{"signsList", ",", 
             RowBox[{
              RowBox[{
               RowBox[{
               "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
               "<", "0"}], "&"}]}], "]"}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "}"}], "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Missing", "[", "\"\<No transition\>\"", "]"}], "}"}]}], 
           "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Sign", "[", 
          RowBox[{
           RowBox[{"Last", "[", "actionList", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "\[Rule]", "2"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "\[Rule]", "1"}]}], "}"}]}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"065188be-5825-47ea-acfd-865235b317d9"]
}, Closed]],

Cell[CellGroupData[{

Cell["SPAdipole", \
"Subsection",ExpressionUUID->"a8a0156e-ea6f-445f-a9a4-18d707f64330"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SPAdipole", "::", "usage"}], "=", 
   "\"\<SPAdipole[S,prefactor,\[CapitalOmega],{t,\[Tau]}] returns the \
saddle-point approximation amplitude corresponding to action S[t,t-\[Tau]]-\
\[CapitalOmega]t and the given prefactor[t,t-\[Tau]].\n\n\
SPAdipole[S,prefactor,\[CapitalOmega],\[LeftAssociation]1\[RightArrow]{\!\(\*\
SubscriptBox[\(t\), \(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(1\)]\)},2\
\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)},\[Ellipsis]\
\[RightAssociation]] returns the total harmonic-dipole contribution in the \
saddle-point approximation from the specified saddle points.\n\n\
SPAdipole[S,prefactor,\[CapitalOmega],\[LeftAssociation]1\[RightArrow]{\!\(\*\
SubscriptBox[\(t\), \(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(1\)]\)},2\
\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \
\(2\)]\)}\[RightAssociation],transition] uses the given Stokes transition set \
to drop the relevant saddle after the anti-Stokes transition.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SPAdipole", "::", "wrongno"}], "=", 
   "\"\<SPAdipole called with a Stokes transition but with an input \
association of length `1` at harmonic energy \[CapitalOmega]=`2`. Reverting \
to unstructured evaluation.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SPAdipole", "::", "invldtrns"}], "=", 
    "\"\<SPAdipole called with invalid Stokes transition set `1`. Reverting \
to unstructured evaluation.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "SPAdipole", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{"ReperiodingFunction", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", "0"}], "]"}]}], "}"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SPAdipole", "[", 
   RowBox[{"S_", ",", "prefactor_", ",", "\[CapitalOmega]_", ",", 
    RowBox[{"{", 
     RowBox[{"t_", ",", "\[Tau]_"}], "}"}], ",", 
    RowBox[{"options", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tr", "=", 
      RowBox[{"t", "+", 
       RowBox[{
        RowBox[{"OptionValue", "[", "ReperiodingFunction", "]"}], "[", 
        RowBox[{"t", ",", "\[Tau]"}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"HessianRoot", "[", 
      RowBox[{"S", ",", "tr", ",", "\[Tau]"}], "]"}], 
     RowBox[{"prefactor", "[", 
      RowBox[{"tr", ",", 
       RowBox[{"tr", "-", "\[Tau]"}]}], "]"}], 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"S", "[", 
         RowBox[{"tr", ",", 
          RowBox[{"tr", "-", "\[Tau]"}]}], "]"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "\[CapitalOmega]", " ", "tr"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SPAdipole", "[", 
    RowBox[{
    "S_", ",", "prefactor_", ",", "\[CapitalOmega]_", ",", 
     "times_Association", ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Total", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"SPAdipole", "[", 
         RowBox[{
         "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", "#", ",", 
          "options"}], "]"}], "&"}], "/@", "times"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SPAdipole", "[", 
    RowBox[{
    "S_", ",", "prefactor_", ",", "\[CapitalOmega]_", ",", 
     "times_Association", ",", "transition_", ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"NumberQ", "[", 
          RowBox[{
          "transition", "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"SPAdipole", "::", "invldtrns"}], ",", "transition"}], 
          "]"}], ";", 
         RowBox[{"Return", "[", 
          RowBox[{"SPAdipole", "[", 
           RowBox[{
           "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", "times"}], 
           "]"}], " ", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "times", "]"}], "\[NotEqual]", "2"}], ",", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"SPAdipole", "::", "wrongno"}], ",", 
           RowBox[{"Length", "[", "times", "]"}], ",", "\[CapitalOmega]"}], 
          "]"}], ";", 
         RowBox[{"Return", "[", 
          RowBox[{"SPAdipole", "[", 
           RowBox[{
           "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", "times", ",", 
            "options"}], "]"}], "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"\[CapitalOmega]", "<", 
         RowBox[{
         "transition", "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"SPAdipole", "[", 
         RowBox[{
         "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", "times", ",", 
          "options"}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"SPAdipole", "[", 
         RowBox[{"S", ",", "prefactor", ",", "\[CapitalOmega]", ",", 
          RowBox[{"KeySelect", "[", 
           RowBox[{"times", ",", 
            RowBox[{
             RowBox[{"#", "\[Equal]", 
              RowBox[{
              "transition", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}]}], "&"}]}], "]"}], ",", "options"}], 
         "]"}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"aab14d09-daf6-4637-ba79-64cfaff7e0f2"]
}, Closed]],

Cell[CellGroupData[{

Cell["UAdipole", \
"Subsection",ExpressionUUID->"68b5e1b2-8571-4510-ba3a-1a0851a78958"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"UAdipole", "::", "usage"}], "=", 
   "\"\<UAdipole[S,prefactor,\[CapitalOmega],\[LeftAssociation]1\[RightArrow]{\
\!\(\*SubscriptBox[\(t\), \(1\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(1\)]\)},2\
\[RightArrow]{\!\(\*SubscriptBox[\(t\), \
\(2\)]\),\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)},\[Ellipsis]\
\[RightAssociation],transition] returns the total harmonic-dipole \
contribution in the uniform approximation from the specified saddle points, \
using the action S[t,t-\[Tau]]-\[CapitalOmega]t and prefactor[t,t-\[Tau]], \
and taking the given Stokes transition set as a reference.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UAdipole", "::", "saddleno"}], "=", 
   "\"\<UAdipole called with `1` time pairs at \[CapitalOmega]=`2`. Reverting \
to the saddle-point approximation for this set.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"UAdipole", "::", "invldtrns"}], "=", 
    "\"\<UAdipole called with invalid Stokes transition set `1`. Reverting to \
the saddle-point approximation for this set.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "UAdipole", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{"ReperiodingFunction", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "\[Tau]"}], "}"}], ",", "0"}], "]"}]}], "}"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UAdipole", "[", 
    RowBox[{
    "S_", ",", "prefactor_", ",", "\[CapitalOmega]_", ",", "times_", ",", 
     "transition_", ",", 
     RowBox[{"options", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "times", "]"}], "\[NotEqual]", " ", "2"}], ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"UAdipole", "::", "saddleno"}], ",", 
          RowBox[{"Length", "[", "times", "]"}], ",", "\[CapitalOmega]"}], 
         "]"}], ";", 
        RowBox[{"Return", "[", 
         RowBox[{"SPAdipole", "[", 
          RowBox[{
          "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", "times"}], 
          "]"}], " ", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"NumberQ", "[", 
         RowBox[{
         "transition", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
          "]"}]}], ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"UAdipole", "::", "invldtrns"}], ",", "transition"}], "]"}],
         ";", 
        RowBox[{"Return", "[", 
         RowBox[{"SPAdipole", "[", 
          RowBox[{
          "S", ",", "prefactor", ",", "\[CapitalOmega]", ",", "times"}], 
          "]"}], " ", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "A1", ",", "A2", ",", "S1", ",", "S2", ",", "Ss", ",", "Sm", ",", "z",
          ",", "\[IndentingNewLine]", 
         RowBox[{"t1", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"times", "[", "1", "]"}], "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}], "+", 
           RowBox[{
            RowBox[{"OptionValue", "[", "ReperiodingFunction", "]"}], "[", 
            RowBox[{
             RowBox[{
              RowBox[{"times", "[", "1", "]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{
              RowBox[{"times", "[", "1", "]"}], "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}]}], "]"}]}]}], ",", 
         RowBox[{"\[Tau]1", "=", 
          RowBox[{
           RowBox[{"times", "[", "1", "]"}], "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"t2", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"times", "[", "2", "]"}], "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}], "+", 
           RowBox[{
            RowBox[{"OptionValue", "[", "ReperiodingFunction", "]"}], "[", 
            RowBox[{
             RowBox[{
              RowBox[{"times", "[", "2", "]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], ",", 
             RowBox[{
              RowBox[{"times", "[", "2", "]"}], "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}]}], "]"}]}]}], ",", 
         RowBox[{"\[Tau]2", "=", 
          RowBox[{
           RowBox[{"times", "[", "2", "]"}], "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"A1", "=", 
         RowBox[{
          RowBox[{"HessianRoot", "[", 
           RowBox[{"S", ",", "t1", ",", "\[Tau]1"}], "]"}], 
          RowBox[{"prefactor", "[", 
           RowBox[{"t1", ",", 
            RowBox[{"t1", "-", "\[Tau]1"}]}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"S1", "=", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"t1", ",", 
            RowBox[{"t1", "-", "\[Tau]1"}]}], "]"}], "-", " ", 
          RowBox[{"\[CapitalOmega]", " ", "t1"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"A2", "=", 
         RowBox[{
          RowBox[{"HessianRoot", "[", 
           RowBox[{"S", ",", "t2", ",", "\[Tau]2"}], "]"}], 
          RowBox[{"prefactor", "[", 
           RowBox[{"t2", ",", 
            RowBox[{"t2", "-", "\[Tau]2"}]}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"S2", "=", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"t2", ",", 
            RowBox[{"t2", "-", "\[Tau]2"}]}], "]"}], "-", " ", 
          RowBox[{"\[CapitalOmega]", " ", "t2"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Ss", "=", 
         FractionBox[
          RowBox[{"S1", "+", "S2"}], "2"]}], ";", 
        RowBox[{"Sm", "=", 
         FractionBox[
          RowBox[{"S1", "-", "S2"}], "2"]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"\[CapitalOmega]", "<", 
           RowBox[{
           "transition", "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{"z", "=", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["3", "2"]}], "Sm"}], ")"}], 
            RowBox[{"2", "/", "3"}]]}], ",", 
          RowBox[{"z", "=", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["3", "2"]}], "Sm"}], ")"}], 
             RowBox[{"2", "/", "3"}]], 
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                "transition", "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"2", "\[Rule]", 
                   RowBox[{"-", "1"}]}], ",", 
                  RowBox[{"1", "\[Rule]", "1"}]}], "}"}]}], ")"}], 
              FractionBox[
               RowBox[{"2", " ", "\[Pi]"}], "3"]}], "]"}]}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         SqrtBox[
          RowBox[{"6", "\[Pi]", " ", "Sm"}]], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "Ss"}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            FractionBox["\[Pi]", "4"]}]}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{"A1", "-", 
              RowBox[{"\[ImaginaryI]", " ", "A2"}]}], "2"], 
            FractionBox[
             RowBox[{"AiryAi", "[", 
              RowBox[{"-", "z"}], "]"}], 
             SqrtBox["z"]]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            FractionBox[
             RowBox[{"A1", "+", 
              RowBox[{"\[ImaginaryI]", " ", "A2"}]}], "2"], 
            FractionBox[
             RowBox[{
              RowBox[{"AiryAi", "'"}], "[", 
              RowBox[{"-", "z"}], "]"}], "z"]}]}], ")"}]}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ")"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"705a3007-cbea-4493-855c-342c294724e9"]
}, Closed]],

Cell[CellGroupData[{

Cell["HCAdipole", \
"Subsection",ExpressionUUID->"13992433-9221-4b9e-82b8-798f35b25dd3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"HCAdipole", "::", "usage"}], "=", 
   "\"\<HCAdipole[cutoff,prefactor,k,\[CapitalOmega]] calculates the HCA \
dipole from a cutoff (in the format \[LeftAssociation]\\\"t\\\"\[Rule]\
\[Placeholder],\\\"\[Tau]\\\"\[Rule]\[Placeholder],\\\"S\\\"\[Rule]\
\[Placeholder],\\\"\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)S\\\"\[Rule]\
\[Placeholder],\\\"\!\(\*SubsuperscriptBox[\(d\), \(t\), \(3\)]\)S\\\"\[Rule]\
\[Placeholder],\\\"\!\(\*SubsuperscriptBox[\(\[PartialD]\), \(tt\), \(2\)]\)S\
\\\"\[Rule]\[Placeholder]\[RightAssociation]) and prefactor (as a function \
prefactor[t,tt]) using the branch-cut factor \!\(\*SuperscriptBox[\(\
\[ExponentialE]\), \(\[ImaginaryI]\\\ 2  \[Pi]\\\ k/3\)]\) at harmonic \
frequency \[CapitalOmega].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"HCAdipole", "::", "wrongcutoff"}], "=", 
    "\"\<The cutoff `1` does not contain the right set of keys.\>\""}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HCAdipole", "[", 
   RowBox[{
   "cutoff_", ",", "prefactor_", ",", "k_", ",", "\[CapitalOmega]_", ",", 
    RowBox[{"options", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "thc", ",", "tthc", ",", "\[Tau]hc", ",", "S0", ",", "\[CapitalOmega]hc",
       ",", "d2Sdtt2", ",", "A"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sort", "[", 
         RowBox[{"Keys", "[", "cutoff", "]"}], "]"}], "\[NotEqual]", 
        RowBox[{"Sort", "[", 
         RowBox[{"{", 
          RowBox[{
          "\"\<t\>\"", ",", "\"\<\[Tau]\>\"", ",", "\"\<S\>\"", ",", 
           "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)S\>\"", ",", 
           "\"\<\!\(\*SubsuperscriptBox[\(d\), \(t\), \(3\)]\)S\>\"", ",", 
           "\"\<\!\(\*SubsuperscriptBox[\(\[PartialD]\), \(tt\), \
\(2\)]\)S\>\""}], "}"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"HCAdipole", "::", "wrongcutoff"}], ",", "cutoff"}], "]"}], 
        ";", 
        RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"thc", "=", 
      RowBox[{"cutoff", "[", "\"\<t\>\"", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tthc", "=", 
      RowBox[{
       RowBox[{"cutoff", "[", "\"\<t\>\"", "]"}], "-", 
       RowBox[{"cutoff", "[", "\"\<\[Tau]\>\"", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Tau]hc", "=", 
      RowBox[{"cutoff", "[", "\"\<\[Tau]\>\"", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"S0", "=", 
      RowBox[{"cutoff", "[", "\"\<S\>\"", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[CapitalOmega]hc", "=", 
      RowBox[{
      "cutoff", "[", "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)S\>\"", 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"A", "=", 
      RowBox[{
       RowBox[{
       "cutoff", "[", 
        "\"\<\!\(\*SubsuperscriptBox[\(d\), \(t\), \(3\)]\)S\>\"", "]"}], "/",
        "2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"d2Sdtt2", "=", 
      RowBox[{
      "cutoff", "[", 
       "\"\<\!\(\*SubsuperscriptBox[\(\[PartialD]\), \(tt\), \(2\)]\)S\>\"", 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"prefactor", "[", 
       RowBox[{"thc", ",", "tthc"}], "]"}], 
      SqrtBox[
       FractionBox[
        RowBox[{"2", "\[Pi]"}], 
        RowBox[{"\[ImaginaryI]", " ", "d2Sdtt2"}]]], 
      FractionBox[
       RowBox[{"2", "\[Pi]"}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", 
          RowBox[{"k", "/", "3"}]}]], 
        SuperscriptBox["A", 
         RowBox[{"1", "/", "3"}]]}]], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "S0"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[CapitalOmega]", " ", "thc"}]}], 
       "]"}], 
      RowBox[{"AiryAi", "[", 
       FractionBox[
        RowBox[{"\[CapitalOmega]hc", "-", "\[CapitalOmega]"}], 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "2", "\[Pi]", " ", 
           RowBox[{"k", "/", "3"}]}]], 
         SuperscriptBox["A", 
          RowBox[{"1", "/", "3"}]]}]], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->
  True,ExpressionUUID->"6cb620a2-bf8e-4f89-8b51-924cd27c278b"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package closure", \
"Section",ExpressionUUID->"9ef34194-5bc5-402e-b25a-b6b648543098"],

Cell[CellGroupData[{

Cell["End of package", \
"Subsubsection",ExpressionUUID->"08b5aa74-0de0-4690-976b-1c4972ab6314"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EndPackage", "[", "]"}], ";"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"7bfde5e2-e60e-49b0-9216-395b306e3c3c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Add to distributed contexts.", \
"Subsubsection",ExpressionUUID->"627f2346-484c-48d4-9453-1b9800679ff6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DistributeDefinitions", "[", "\"\<RBSFA`\>\"", "]"}], 
  ";"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"0b59eb5f-39e5-4fe3-a624-8b4b88bac2fa"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
NotebookEventActions->{{"MenuCommand", "Save"} :> (NotebookWrite[
     Part[
      Cells[CellTags -> "version-timestamp"], 1], 
     Cell[
      BoxData[
       RowBox[{
         StringJoin["Begin[\"`Private`\"];\n$RBSFAtimestamp=\"", 
          DateString[], "\";\nEnd[];"]}]], "Input", InitializationCell -> 
      True, CellTags -> "version-timestamp"], None, AutoScroll -> False]; 
   NotebookSave[]), PassEventsDown -> True},
WindowSize->{1536, 781},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{None, None, 
   Cell[
    TextData[{
     "RB", "-", "SFA", ":", " ", "Rotating", " ", "Bicircular", " ", "HHG", 
      " ", "in", " ", "the", " ", "Strong", " ", "Field", " ", 
      "Approximation", "|", "   ", 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {None, None, 
   Cell[
    TextData[{
     "RB", "-", "SFA", ":", " ", "Rotating", " ", "Bicircular", " ", "HHG", 
      " ", "in", " ", "the", " ", "Strong", " ", "Field", " ", 
      "Approximation", "|", "   ", 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.75, 842.25},
"PostScriptOutputFile"->"~/Desktop/print.pdf",
"PrintingMargins"->{{19.84251968503, 19.84251968503}, {72., 72.}}},
PrivateNotebookOptions->{"FileOutlineCache"->False},
ShowSelection->True,
TrackCellChangeTimes->False,
SpellingDictionaries->{"CorrectWords"->{
 "subpackage", "Pisanty", "subpackages"}},
Background->None,
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 10, 2017)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Code"], FontWeight -> "Plain", FontSlant -> "Plain", 
    FontTracking -> "Plain", 
    FontVariations -> {
     "Outline" -> False, "Shadow" -> False, "StrikeThrough" -> False, 
      "Underline" -> False}]}, Visible -> False, FrontEndVersion -> 
  "11.2 for Microsoft Windows (64-bit) (September 10, 2017)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]

