Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["RB-SFA: High Harmonic Generation in the Strong Field Approximation \
via ",
  FontSize->24],
 StyleBox["Mathematica",
  FontSize->24,
  FontSlant->"Italic"]
}], "Title",ExpressionUUID->"c992c4cc-e4da-461e-95b1-7ac5915dec1a"],

Cell["\[Copyright] Emilio Pisanty 2014-2017. Licensed under GPL and \
CC-BY-SA.", "Text",ExpressionUUID->"68edbf12-60cb-48de-aaa2-255de3e2a789"],

Cell[CellGroupData[{

Cell["Readme", \
"Subsection",ExpressionUUID->"8c2786b7-9ddd-4c7f-bb3f-59415b00d521"],

Cell[TextData[{
 "RB-SFA is a compact and flexible ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " package for calculating High Harmonic Generation emission within the \
Strong Field Approximation. It combines ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s analytical integration capabilities with its numerical \
calculation capacities to offer a fast and user-friendly plug-and-play solver \
for calculating harmonic spectra and other properties. In addition, it can \
calculate first-order nondipole corrections to the SFA results to evaluate \
the effect of the driving laser\[CloseCurlyQuote]s magnetic field on harmonic \
spectra.\n\nThe name RB-SFA comes from its first application (as Rotating \
Bicircular High Harmonic Generation in the Strong field Approximation) but \
the code is general so RB-SFA just stands for itself now. This first \
application was used to calculate the polarization properties of the \
harmonics produced by multi-colour circularly polarized fields, as reported \
in the paper\n\n    Spin conservation in high-order-harmonic generation using \
bicircular fields. E. Pisanty, S. Sukiasyan and M. Ivanov. ",
 StyleBox[ButtonBox["Phys. Rev. A",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
 StyleBox[ButtonBox["90",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
  FontWeight->"Bold"],
 ButtonBox[", 043829 (2014)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
 ", ",
 ButtonBox["arXiv:1404.6242",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://arxiv.org/abs/1404.6242"], None},
  ButtonNote->"http://arxiv.org/abs/1404.6242"],
 ".\n\nThis code is dual-licensed under the ",
 ButtonBox["GPL",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.gnu.org/licenses/gpl-3.0.en.html"], None},
  ButtonNote->"http://www.gnu.org/licenses/gpl-3.0.en.html"],
 " and ",
 ButtonBox["CC-BY-SA",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://creativecommons.org/licenses/by-sa/4.0/"], None},
  ButtonNote->"https://creativecommons.org/licenses/by-sa/4.0/"],
 " licenses. If you use this code or its results in an academic publication, \
please cite the paper above or the GitHub repository where the latest version \
will always be available. An example citation is \n\n    E. Pisanty. RB-SFA: \
High Harmonic Generation in the Strong Field Approximation via ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". ",
 ButtonBox["https://github.com/episanty/RB-SFA",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://github.com/episanty/RB-SFA"], None},
  ButtonNote->"https://github.com/episanty/RB-SFA"],
 " (2020).\n\nThis software consists of the notebook RB-SFA.nb, which \
contains the implementation and generates the package file RB-SFA.m, this \
Usage and Examples notebook, which explains how to use the code and documents \
the calculations used in the original publication, a Quantum Orbits Usage \
notebook that works through the (experimental) quantum-orbits functionality, \
and the subpackage RootFinder."
}], "Text",ExpressionUUID->"5791881c-3f55-43f1-8e30-cb250e10880b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Specifications", \
"Subsection",ExpressionUUID->"05b2713d-060d-420c-8d2c-4b9aacedca20"],

Cell[TextData[{
 "This code calculates the harmonic dipole as per the original Lewenstein ",
 StyleBox["et al.",
  FontSlant->"Italic"],
 " paper,\n\n    M. Lewenstein, Ph. Balcou, M.Yu. Ivanov, A. L\
\[CloseCurlyQuote]Huillier and P.B. Corkum. Theory of high-harmonic \
generation by low-frequency laser fields.",
 StyleBox[" ",
  FontSlant->"Italic"],
 StyleBox[ButtonBox["Phys. Rev. A",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.49.2117"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.49.2117"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.49.2117"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.49.2117"],
 StyleBox[ButtonBox["49",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.49.2117"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.49.2117"],
  FontWeight->"Bold"],
 ButtonBox[" no. 3, 2117 (1994).",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.49.2117"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.49.2117"],
 "\n    \nThe time-dependent dipole is given by\n\n          ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["D",
      FontWeight->"Bold"], "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "t"], 
       RowBox[{
        RowBox[{"\[DifferentialD]", 
         RowBox[{"t", "'"}]}], 
        RowBox[{"\[Integral]", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[DifferentialD]", "3"], 
           StyleBox["p",
            FontWeight->"Bold"]}], " ", 
          RowBox[{
           StyleBox["d",
            FontWeight->"Bold"], "(", 
           RowBox[{
            StyleBox["\[Pi]",
             FontWeight->"Bold"], "(", 
            RowBox[{
             StyleBox["p",
              FontWeight->"Bold"], ",", "t"}], ")"}], ")"}], " ", "\[Times]", 
          " ", 
          RowBox[{
           RowBox[{
            StyleBox["F",
             FontWeight->"Bold"], "(", 
            RowBox[{"t", "'"}], ")"}], "\[CenterDot]", 
           RowBox[{
            StyleBox["d",
             FontWeight->"Bold"], "(", 
            RowBox[{
             StyleBox["\[Pi]",
              FontWeight->"Bold"], "(", 
             RowBox[{
              StyleBox["p",
               FontWeight->"Bold"], ",", 
              RowBox[{"t", "'"}]}], ")"}], ")"}]}], "\[Times]", 
          RowBox[{"exp", "[", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"S", "(", 
             RowBox[{
              StyleBox["p",
               FontWeight->"Bold"], ",", "t", ",", 
              RowBox[{"t", "'"}]}], ")"}]}], "]"}]}]}]}]}]}], "+", 
     RowBox[{"c", ".", "c", "."}]}]}], TraditionalForm]],ExpressionUUID->
  "242cf6eb-7b7c-48d5-b615-c65923275f13"],
 "\n\nHere ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["F",
     FontWeight->"Bold"], "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "a1a3eafc-38ba-412f-833f-01223e91baee"],
 "is the time-dependent applied electric field, with vector potential ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["A",
     FontWeight->"Bold"], "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "bef173c6-ce42-43c5-86ac-b019b09127aa"],
 "; the electron charge is taken to be ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]],ExpressionUUID->
  "23dad312-e23f-494e-86d9-bed7f4f134e4"],
 ". The integration time ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "'"}], TraditionalForm]],ExpressionUUID->
  "20b93d53-0199-4193-9b13-60003f944667"],
 " can be interpreted as the ionization time and the integration limit ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "a683ff90-265a-4c54-a99d-528374399bfd"],
 " represents the recollision time. (Upon applying the saddle-point \
approximation to the temporal integrals these notions apply exactly to the \
corresponding quantum orbits.) The ionization and recollision events are \
governed by the corresponding dipole matrix elements, which are taken for a \
hydrogenic 1s-type orbital with characteristic momentum \[Kappa] and \
ionization potential ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["I", "p"], "=", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["\[Kappa]", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "b4993845-275d-4be3-9d17-3618272fa367"],
 ":\n\n    ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["d",
      FontWeight->"Bold"], "(", 
     StyleBox["p",
      FontWeight->"Bold"], ")"}], "=", 
    RowBox[{
     RowBox[{
      TemplateBox[{StyleBox["p", FontWeight -> "Bold"]},
       "Bra"], 
      OverscriptBox[
       StyleBox["d",
        FontWeight->"Bold"], "^"], 
      TemplateBox[{"g"},
       "Ket"]}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"8", "\[ImaginaryI]"}], "\[Pi]"], 
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{"2", 
          SuperscriptBox["\[Kappa]", "5"]}]], 
        StyleBox["p",
         FontWeight->"Bold"]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           StyleBox["p",
            FontWeight->"Bold"], "2"], "+", 
          SuperscriptBox["\[Kappa]", "2"]}], ")"}], "3"]]}]}]}], 
   TraditionalForm]],ExpressionUUID->"0bfa866d-06b2-4cbc-9355-062dea78abf5"],
 ".\n\n(Taken from B. Podolsky & L. Pauling. ",
 StyleBox[ButtonBox["Phys. Rev.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRev.34.109"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRev.34.109"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRev.34.109"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRev.34.109"],
 StyleBox[ButtonBox["34",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRev.34.109"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRev.34.109"],
  FontWeight->"Bold"],
 ButtonBox[" no. 1, 109 (1929)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRev.34.109"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRev.34.109"],
 ".) The displaced momentum ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["\[Pi]",
      FontWeight->"Bold"], "(", 
     RowBox[{
      StyleBox["p",
       FontWeight->"Bold"], ",", "t"}], ")"}], "=", 
    RowBox[{
     StyleBox["p",
      FontWeight->"Bold"], "+", 
     RowBox[{
      StyleBox["A",
       FontWeight->"Bold"], "(", "t", ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"e974eef5-1aa3-42ba-a769-2cd9c871b6cf"],
 " is used to aid in the generalization to nondipole cases.\n\nThe action \n\n\
    ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"S", "(", 
     RowBox[{
      StyleBox["p",
       FontWeight->"Bold"], ",", "t", ",", 
      RowBox[{"t", "'"}]}], ")"}], "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"t", "'"}], "t"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox["\[Kappa]", "2"]}], "+", 
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox[
          RowBox[{
           StyleBox["\[Pi]",
            FontWeight->"Bold"], "(", 
           RowBox[{
            StyleBox["p",
             FontWeight->"Bold"], ",", "\[Tau]"}], ")"}], "2"]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}], TraditionalForm]],
  ExpressionUUID->"182f2211-d152-419c-bc7e-62a1ec48e067"],
 " \n\nis the governing factor of the integral. It is highly oscillatory and \
must be dealt with carefully. The momentum integral is approximated using the \
saddle point method; this is valid and straightforward since there is always \
one unique saddle point,\n\n    ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["p",
       FontWeight->"Bold"], "s"], "(", 
     RowBox[{"t", ",", 
      RowBox[{"t", "'"}]}], ")"}], "=", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"t", "'"}], "t"], 
       RowBox[{
        RowBox[{
         StyleBox["A",
          FontWeight->"Bold"], "(", 
         RowBox[{"t", "''"}], ")"}], 
        RowBox[{"\[DifferentialD]", 
         RowBox[{"t", "''"}]}]}]}], 
      RowBox[{"t", "-", 
       RowBox[{"t", "'"}]}]]}]}], TraditionalForm]],ExpressionUUID->
  "9e5c9067-4db6-40b1-a669-2ddd40d44703"],
 ",\n    \nas long as the action\[CloseCurlyQuote]s dependence on the \
momentum is quadratic. After the momentum has been integrated via the saddle \
point method, the time-dependent dipole is given by\n\n          ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["D",
      FontWeight->"Bold"], "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "t"], 
       RowBox[{
        RowBox[{"\[DifferentialD]", 
         RowBox[{"t", "'"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{"2", "\[Pi]"}], 
           RowBox[{"\[Epsilon]", "+", 
            RowBox[{"\[ImaginaryI]", "(", 
             RowBox[{"t", "-", 
              RowBox[{"t", "'"}]}], ")"}]}]], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{
         StyleBox["d",
          FontWeight->"Bold"], "(", 
         RowBox[{
          StyleBox["\[Pi]",
           FontWeight->"Bold"], "(", 
          RowBox[{
           RowBox[{
            SubscriptBox[
             StyleBox["p",
              FontWeight->"Bold"], "s"], "(", 
            RowBox[{"t", ",", 
             RowBox[{"t", "'"}]}], ")"}], ",", "t"}], ")"}], ")"}], " ", 
        "\[Times]", " ", 
        RowBox[{
         RowBox[{
          StyleBox["F",
           FontWeight->"Bold"], "(", 
          RowBox[{"t", "'"}], ")"}], "\[CenterDot]", 
         RowBox[{
          StyleBox["d",
           FontWeight->"Bold"], "(", 
          RowBox[{
           StyleBox["\[Pi]",
            FontWeight->"Bold"], "(", 
           RowBox[{
            RowBox[{
             SubscriptBox[
              StyleBox["p",
               FontWeight->"Bold"], "s"], "(", 
             RowBox[{"t", ",", 
              RowBox[{"t", "'"}]}], ")"}], ",", 
            RowBox[{"t", "'"}]}], ")"}], ")"}]}], "\[Times]", 
        RowBox[{"exp", "[", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"S", "(", 
           RowBox[{
            RowBox[{
             StyleBox[
              SubscriptBox[
               StyleBox["p",
                FontWeight->"Bold"], 
               StyleBox["s",
                FontWeight->"Plain"]],
              FontWeight->"Bold"], "(", 
             RowBox[{"t", ",", 
              RowBox[{"t", "'"}]}], ")"}], ",", "t", ",", 
            RowBox[{"t", "'"}]}], ")"}]}], "]"}]}]}]}], "+", 
     RowBox[{"c", ".", "c", "."}]}]}], TraditionalForm]],ExpressionUUID->
  "3686742e-5898-48bc-9fbf-a68e14f9a31c"],
 "\n          \nA regularization factor ",
 Cell[BoxData[
  FormBox["\[Epsilon]", TraditionalForm]],ExpressionUUID->
  "d33cff67-db20-4b49-909f-453a95af53e1"],
 " has been introduced to prevent divergence of the prefactor as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "'"}], TraditionalForm]],ExpressionUUID->
  "1d209ea5-4e39-42c3-82f4-f935abf3ec69"],
 " approaches ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "b7fc444b-cfc5-4bcd-8703-e069d6d03648"],
 ", representing the fact that at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", 
    RowBox[{"t", "'"}]}], TraditionalForm]],ExpressionUUID->
  "ce151555-a20d-4477-b4d5-0e998d84a485"],
 " the ",
 Cell[BoxData[
  FormBox[
   StyleBox["p",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "78c30732-9389-4aab-80fd-ad962078e783"],
 " integral no longer has a quadratic exponent.\n\nThe integral is performed \
with respect to the excursion time ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Tau]", "=", 
    RowBox[{"t", "-", 
     RowBox[{"t", "'"}]}]}], TraditionalForm]],ExpressionUUID->
  "130e0b10-8f75-4998-b96c-b488ff499e56"],
 " for simplicity. To reduce integration time, a gating function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"gate", "[", 
    RowBox[{"\[Omega]", " ", "\[Tau]"}], "]"}], TraditionalForm]],
  ExpressionUUID->"d5101723-3148-49ff-a9e8-67e965f50e18"],
 " has been introduced, and the integration time has been cut short to a \
controllable length. This is physically reasonable as the wavepacket \
spreading (which scales as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Tau]", 
    RowBox[{
     RowBox[{"-", "3"}], "/", "2"}]], TraditionalForm]],ExpressionUUID->
  "f855ed6e-6324-42af-a257-4505500d5f77"],
 ") makes the contributions after the gate negligible.\n\nMore physically, \
suppressing the contributions from large excursion times represents the fact \
that the extra-long trajectories they represent produce harmonics which are \
much harder to phase match (as their harmonic phase is very sensitively \
dependent on many factors) which means that they are rarely present in \
experimental spectra unless a concerted effort is performed to observe them."
}], "Text",ExpressionUUID->"e2aeed0a-e25c-4c30-b668-53a80f69fdb1"]
}, Closed]],

Cell[CellGroupData[{

Cell["First-order nondipole calculations", \
"Subsection",ExpressionUUID->"e701122a-d943-473b-9ec9-12283528f096"],

Cell[TextData[{
 "This code can also be used to calculate the first-order effect of nondipole \
terms, which become relevant at high intensities or long wavelengths, when \
the electron\[CloseCurlyQuote]s speed from the laser-driven oscillations \
(which scales as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "/", "\[Omega]"}], TraditionalForm]],ExpressionUUID->
  "b8dc8578-0422-4ece-ad0b-fd271d25b8c5"],
 ") becomes comparable to the speed of light (equal to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", 
    RowBox[{
     RowBox[{"1", "/", "\[Alpha]"}], "\[TildeTilde]", "137"}]}], 
   TraditionalForm]],ExpressionUUID->"ddf9e1cf-bf27-41db-8096-6366b36076d8"],
 " in atomic units). (More specifically, the nondipole effects on the \
harmonic generation become relevant when the magnetic pushing per cycle, \
which offsets the returning wavepacket by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["F", "2"], "/", 
    SuperscriptBox["c\[Omega]", "3"]}], TraditionalForm]],ExpressionUUID->
  "2a1f74d8-0860-4369-9b02-a131e23879a7"],
 ", becomes comparable with the wavepacket spread upon recollision.)\n\nThis \
code implements a generalization of the theory presented in various forms in \
the papers N.J. Kylstra et al. ",
 StyleBox[ButtonBox["J. Phys B: At. Mol. Opt. Phys.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
 StyleBox[ButtonBox["34",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
  FontWeight->"Bold"],
 ButtonBox[" no. 3, L55 (2001)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
 "; N..J. Kylstra et al. ",
 StyleBox[ButtonBox["Laser Phys.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
 StyleBox[ButtonBox["12",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
  FontWeight->"Bold"],
 ButtonBox[" no. 2, 409 (2002)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
 "; M.W. Walser et al. ",
 StyleBox[ButtonBox["Phys. Rev. Lett.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevLett.85.5082"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevLett.85.5082"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevLett.85.5082"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevLett.85.5082"],
 StyleBox[ButtonBox["85",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevLett.85.5082"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevLett.85.5082"],
  FontWeight->"Bold"],
 ButtonBox[" no. 24, 5082 (2000)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevLett.85.5082"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevLett.85.5082"],
 "; V. Averbukh et al. ",
 StyleBox[ButtonBox["Phys Rev. A",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.65.063402"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.65.063402"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.65.063402"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.65.063402"],
 StyleBox[ButtonBox["65,",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.65.063402"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.65.063402"],
  FontWeight->"Bold"],
 ButtonBox[" 063402 (2002)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.65.063402"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.65.063402"],
 "; and C.C. Chiril\[ACup] et al. ",
 StyleBox[ButtonBox["Phys. Rev. A",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.66.063411"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.66.063411"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.66.063411"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.66.063411"],
 StyleBox[ButtonBox["66,",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.66.063411"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.66.063411"],
  FontWeight->"Bold"],
 ButtonBox[" 063411 (2002)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.66.063411"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.66.063411"],
 ".\n\nThe nondipole-HHG code calculates the harmonic dipole of exactly the \
same form as the standard SFA,\n\n          ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["D",
      FontWeight->"Bold"], "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "t"], 
       RowBox[{
        RowBox[{"\[DifferentialD]", 
         RowBox[{"t", "'"}]}], 
        RowBox[{"\[Integral]", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[DifferentialD]", "3"], 
           StyleBox["p",
            FontWeight->"Bold"]}], " ", 
          RowBox[{
           StyleBox["d",
            FontWeight->"Bold"], "(", 
           RowBox[{
            StyleBox["\[Pi]",
             FontWeight->"Bold"], "(", 
            RowBox[{
             StyleBox["p",
              FontWeight->"Bold"], ",", "t", ",", 
             RowBox[{"t", "'"}]}], ")"}], ")"}], " ", "\[Times]", " ", 
          RowBox[{
           RowBox[{
            StyleBox["F",
             FontWeight->"Bold"], "(", 
            RowBox[{"t", "'"}], ")"}], "\[CenterDot]", 
           RowBox[{
            StyleBox["d",
             FontWeight->"Bold"], "(", 
            RowBox[{
             StyleBox["\[Pi]",
              FontWeight->"Bold"], "(", 
             RowBox[{
              StyleBox["p",
               FontWeight->"Bold"], ",", 
              RowBox[{"t", "'"}], ",", 
              RowBox[{"t", "'"}]}], ")"}], ")"}]}], "\[Times]", 
          RowBox[{"exp", "[", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"S", "(", 
             RowBox[{
              StyleBox["p",
               FontWeight->"Bold"], ",", "t", ",", 
              RowBox[{"t", "'"}]}], ")"}]}], "]"}]}]}]}]}]}], "+", 
     RowBox[{"c", ".", "c", "."}]}]}], TraditionalForm]],ExpressionUUID->
  "e4faef85-2d2e-4bdf-b389-a34e1504cca8"],
 "\n\nwith ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"S", "(", 
     RowBox[{
      StyleBox["p",
       FontWeight->"Bold"], ",", "t", ",", 
      RowBox[{"t", "'"}]}], ")"}], "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"t", "'"}], "t"], 
     RowBox[{
      RowBox[{"\[DifferentialD]", 
       RowBox[{"t", "''"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox["\[Kappa]", "2"]}], "+", 
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox[
          RowBox[{
           StyleBox["\[Pi]",
            FontWeight->"Bold"], "(", 
           RowBox[{
            StyleBox["p",
             FontWeight->"Bold"], ",", 
            RowBox[{"t", "''"}], ",", 
            RowBox[{"t", "'"}]}], ")"}], "2"]}]}], ")"}]}]}]}], 
   TraditionalForm]],ExpressionUUID->"502ec552-aa8c-4e79-8d2e-158d5159a908"],
 "  as before, but with a nondipole term in the displaced momentum, which now \
reads\n\n          ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["\[Pi]",
      FontWeight->"Bold"], "(", 
     RowBox[{
      StyleBox["p",
       FontWeight->"Bold"], ",", "t", ",", 
      RowBox[{"t", "'"}]}], ")"}], "=", 
    RowBox[{
     StyleBox["p",
      FontWeight->"Bold"], "+", 
     RowBox[{
      StyleBox["A",
       FontWeight->"Bold"], "(", "t", ")"}], "-", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"t", "'"}], "t"], 
      RowBox[{
       RowBox[{
        RowBox[{
         StyleBox["\[Del]",
          FontWeight->"Bold"], 
         RowBox[{
          StyleBox["A",
           FontWeight->"Bold"], "(", "\[Tau]", ")"}]}], "\[CenterDot]", 
        RowBox[{"(", 
         RowBox[{
          StyleBox["p",
           FontWeight->"Bold"], "+", 
          RowBox[{
           StyleBox["A",
            FontWeight->"Bold"], "(", "\[Tau]", ")"}]}], ")"}]}], 
       RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"5201e80d-9472-496b-add2-ab3688412ab0"],
 ",\n          \nor in component notation\n\n          ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Pi]", "j"], "(", 
     RowBox[{
      StyleBox["p",
       FontWeight->"Bold"], ",", "t", ",", 
      RowBox[{"t", "'"}]}], ")"}], "=", 
    RowBox[{
     SubscriptBox["p", "j"], "+", 
     RowBox[{
      SubscriptBox["A", "j"], "(", "t", ")"}], "-", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"t", "'"}], "t"], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "j"], 
        RowBox[{
         SubscriptBox["A", "k"], "(", "\[Tau]", ")"}]}], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["p", "k"], "+", 
         RowBox[{
          SubscriptBox["A", "k"], "(", "\[Tau]", ")"}]}], ")"}], 
       RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}]}], TraditionalForm]],
  ExpressionUUID->"3b9998f0-9c77-45b7-971d-f7e749cceb2d"],
 "."
}], "Text",ExpressionUUID->"3835b1d2-17fc-4fc4-be01-0c0c02bb4b3e"]
}, Closed]],

Cell[CellGroupData[{

Cell["Usage and Examples", \
"Section",ExpressionUUID->"a6aefb8e-cba6-49bf-b66e-c0e47c62df7b"],

Cell[CellGroupData[{

Cell["Loading the package", \
"Subsection",ExpressionUUID->"ed0e38d7-7932-4b96-ba80-4066a3266e2d"],

Cell[TextData[{
 "You can use this software \n   ",
 StyleBox["\[CenterDot]",
  FontWeight->"Bold"],
 "  within the RB-SFA notebook itself by simply running the initialization \
cells of that notebook, or\n   ",
 StyleBox["\[CenterDot]",
  FontWeight->"Bold"],
 "  from an external notebook by loading it as a package.\nIn the latter \
case, place a copy of the package file RB-SFA.m on the same directory as your \
notebook and run the loading command"
}], "Text",ExpressionUUID->"ee7b2f8a-55d1-4407-9a70-a7efb0d9be6d"],

Cell[BoxData[
 RowBox[{"Needs", "[", 
  RowBox[{"\"\<RBSFA`\>\"", ",", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<RB-SFA.m\>\""}], 
     "}"}], "]"}]}], "]"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"28dc1de9-ba29-4dd8-8989-e00022ad01c0"],

Cell[TextData[{
 "You can also call the package from another directory by suitably modifying \
the directory call. If you plan on using this package in the long term you \
can use the ",
 StyleBox["File > Install", "Code"],
 " prompt, in which case the package is simply loaded as ",
 StyleBox["Needs[\[OpenCurlyDoubleQuote]RBSFA`\[CloseCurlyDoubleQuote]]", 
  "Code"],
 ", though this is not particularly recommended. (A better choice is to \
include a soft link called ",
 StyleBox["RBSFA.m", "Code"],
 " in your ",
 StyleBox["$UserBaseDirectory/Applications/", "Code"],
 " directory to the file ",
 StyleBox["RB-SFA.m", "Code"],
 ". This works just fine and is easy to undo if required.)"
}], "Text",ExpressionUUID->"95eebcac-8851-4c99-a609-ebaedf2e5322"],

Cell["To print the version of the package in use, use the command", \
"Text",ExpressionUUID->"8fcfdb2e-e60b-4eb2-ad11-d3674cf2acc3"],

Cell[CellGroupData[{

Cell[BoxData["$RBSFAversion"], "Input",
 InitializationCell->
  True,ExpressionUUID->"80b587b9-0b66-457b-bfb5-a9660c4b12a8"],

Cell[BoxData["\<\"RB-SFA v2.2.1, Mon 21 Sep 2020 17:44:08\"\>"], \
"Output",ExpressionUUID->"6e7123a1-5973-4bc4-a0b0-180c5afb9d6c"]
}, Open  ]],

Cell[TextData[{
 "There are also commands to get the ",
 StyleBox["$RBSFAtimestamp", "Code"],
 " directly, as well as the git ",
 StyleBox["$RBSFAcommit", "Code"],
 " hash and message."
}], "Text",ExpressionUUID->"1224d0e4-4d6a-4d52-9f2f-1b7361fea2b3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simple usage", \
"Subsection",ExpressionUUID->"b0a21c0e-a6ec-434a-b6af-c47f2dbb07a3"],

Cell[CellGroupData[{

Cell["Basic usage", \
"Subsubsection",ExpressionUUID->"7b429f4b-fd97-48fc-bcd1-76d979c1f6a2"],

Cell[TextData[{
 "For basic usage, simply call the main numerical integrator, ",
 StyleBox["makeDipoleList", "Code"],
 ", with the vector potential you want to use, and provide any (arbitrary) \
parameters you wish to specify using the ",
 StyleBox["FieldParameters", "Code"],
 " option."
}], "Text",ExpressionUUID->"59e8e65a-85fd-4c8a-8eec-c39048789976"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"simpleDipole", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["F", "\[Omega]"], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
          "}"}]}], "]"}]}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"F", "\[Rule]", "0.05"}], ",", 
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
      RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"c00fb0b2-e072-40bc-957e-518c97043253"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.8672578`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"7f93cfb5-6e2b-4b50-a814-7aec4114c890"]
}, Open  ]],

Cell[BoxData["Quit"], \
"Input",ExpressionUUID->"9080373f-442b-4d0c-a5b2-35b294eb39b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Structure of the output", \
"Subsubsection",ExpressionUUID->"1940b6ed-26a9-457a-8e61-bc6b43682732"],

Cell[TextData[{
 "The output of makeDipoleList is an ",
 Cell[BoxData[
  FormBox[
   RowBox[{"N", "\[Times]", "d"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "d517a40a-b779-4c6f-83db-380ffe6a0d2e"],
 " array, where ",
 Cell[BoxData[
  FormBox["N", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f2661082-9ff4-4c12-84c0-92d03cbf82d9"],
 " is the total number of points in the time axis and ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f7c0deeb-7646-476d-809b-c9f5b8834f07"],
 " is the working dimension (i.e. the length of the vector produced by the \
VectorPotential setting)."
}], "Text",ExpressionUUID->"4e8c4717-f481-495f-ae4b-071c5386f3c8"],

Cell[CellGroupData[{

Cell[BoxData["simpleDipole"], \
"Input",ExpressionUUID->"256c72a7-93e6-4b27-8d22-c132795bf8a1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.018125760380031605`"}], "-", 
      RowBox[{"0.00009974228335413284`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0183149576922377`"}], "-", 
      RowBox[{"1.4444131248451608`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.018089586447102044`"}], "-", 
      RowBox[{"5.341623082981116`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.017131197251102775`"}], "-", 
      RowBox[{"10.574959930735965`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.01538227871795335`"}], "-", 
      RowBox[{"15.80775759025688`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.013212985784864559`"}], "-", 
      RowBox[{"19.94969804660353`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.011111327315597623`"}], "-", 
      RowBox[{"22.41783307022159`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.009171596193794871`"}], "-", 
      RowBox[{"23.14439429816201`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.007051057434900305`"}], "-", 
      RowBox[{"22.418761591775496`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.004543556214642184`"}], "-", 
      RowBox[{"20.68718952402664`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.001976803823377072`"}], "-", 
      RowBox[{"18.39518652583638`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0002224529676776956`", "\[VeryThinSpace]", "-", 
      RowBox[{"15.901033261679615`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0021238837637934894`", "\[VeryThinSpace]", "-", 
      RowBox[{"13.450352206614296`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.003989612890446195`", "\[VeryThinSpace]", "-", 
      RowBox[{"11.186952248059525`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.005553671686812347`", "\[VeryThinSpace]", "-", 
      RowBox[{"9.177306634721734`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.006266474009566413`", "\[VeryThinSpace]", "-", 
      RowBox[{"7.435738189001938`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.006203286831706679`", "\[VeryThinSpace]", "-", 
      RowBox[{"5.94580040583301`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.005975955181108588`", "\[VeryThinSpace]", "-", 
      RowBox[{"4.67619535218625`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.005735355363729706`", "\[VeryThinSpace]", "-", 
      RowBox[{"3.590193704905499`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.00507271389436438`", "\[VeryThinSpace]", "-", 
      RowBox[{"2.6499405267837486`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.003934948334430211`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.8188129295085553`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0027818227055134504`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.0630644504798537`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0017546258309038016`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.3517676825498517`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0004953673499047711`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.3447525877716767`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0010702923973083653`"}], "+", 
      RowBox[{"1.0561542311909804`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.002453614344287197`"}], "+", 
      RowBox[{"1.8124193513002327`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0032962045884281314`"}], "+", 
      RowBox[{"2.644504720955426`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.003832618874939589`"}], "+", 
      RowBox[{"3.5856966476267864`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0044338988024433795`"}], "+", 
      RowBox[{"4.6723747942228835`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.005013621066179925`"}], "+", 
      RowBox[{"5.9429465677620295`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.005120518329287122`"}], "+", 
      RowBox[{"7.434747956128605`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.004472657209522606`"}], "+", 
      RowBox[{"9.178665388715046`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0032199763216289676`"}], "+", 
      RowBox[{"11.190131264240703`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0017252588234713212`"}], "+", 
      RowBox[{"13.454534403119665`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0002142341955527292`"}], "+", 
      RowBox[{"15.905992695719068`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0013492553206845169`", "\[VeryThinSpace]", "+", 
      RowBox[{"18.401091818765597`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0031357841911071375`", "\[VeryThinSpace]", "+", 
      RowBox[{"20.693930010540704`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.005259504764162631`", "\[VeryThinSpace]", "+", 
      RowBox[{"22.425918690554113`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.007680336726575925`", "\[VeryThinSpace]", "+", 
      RowBox[{"23.15168540346981`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.010219325978987826`", "\[VeryThinSpace]", "+", 
      RowBox[{"22.425157661714046`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.012628433794617573`", "\[VeryThinSpace]", "+", 
      RowBox[{"19.956731201468692`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.014667817427911026`", "\[VeryThinSpace]", "+", 
      RowBox[{"15.813795111725648`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.016181620298064674`", "\[VeryThinSpace]", "+", 
      RowBox[{"10.579323528559199`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.01716165975544747`", "\[VeryThinSpace]", "+", 
      RowBox[{"5.34415131593554`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.017749890722625707`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.4454699534684874`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.018125760380031615`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.00009974228335411401`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.018314957692237607`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.4444131248451249`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.018089586447102384`", "\[VeryThinSpace]", "+", 
      RowBox[{"5.3416230829810925`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.01713119725110278`", "\[VeryThinSpace]", "+", 
      RowBox[{"10.57495993073591`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.015382278717953383`", "\[VeryThinSpace]", "+", 
      RowBox[{"15.807757590256806`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.013212985784865034`", "\[VeryThinSpace]", "+", 
      RowBox[{"19.949698046603494`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.01111132731559752`", "\[VeryThinSpace]", "+", 
      RowBox[{"22.417833070221562`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.009171596193794021`", "\[VeryThinSpace]", "+", 
      RowBox[{"23.144394298162023`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0070510574349002125`", "\[VeryThinSpace]", "+", 
      RowBox[{"22.4187615917755`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.00454355621464227`", "\[VeryThinSpace]", "+", 
      RowBox[{"20.687189524026646`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0019768038233763034`", "\[VeryThinSpace]", "+", 
      RowBox[{"18.395186525836394`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.00022245296767721575`"}], "+", 
      RowBox[{"15.901033261679654`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.002123883763793768`"}], "+", 
      RowBox[{"13.450352206614319`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.003989612890447616`"}], "+", 
      RowBox[{"11.186952248059532`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.005553671686809212`"}], "+", 
      RowBox[{"9.177306634721738`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.006266474009569502`"}], "+", 
      RowBox[{"7.435738189001965`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.00620328683170663`"}], "+", 
      RowBox[{"5.945800405833032`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0059759551811074`"}], "+", 
      RowBox[{"4.676195352186252`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0057353553637326474`"}], "+", 
      RowBox[{"3.5901937049055106`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.005072713894363442`"}], "+", 
      RowBox[{"2.6499405267837584`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.003934948334428524`"}], "+", 
      RowBox[{"1.8188129295085613`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0027818227055153764`"}], "+", 
      RowBox[{"1.063064450479866`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0017546258309036195`"}], "+", 
      RowBox[{"0.35176768254985563`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0004953673499044915`"}], "-", 
      RowBox[{"0.34475258777167544`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0010702923973087497`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.0561542311909689`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.002453614344286925`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.8124193513002236`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.003296204588427049`", "\[VeryThinSpace]", "-", 
      RowBox[{"2.6445047209554273`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.003832618874941994`", "\[VeryThinSpace]", "-", 
      RowBox[{"3.5856966476267713`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.004433898802441794`", "\[VeryThinSpace]", "-", 
      RowBox[{"4.6723747942228755`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.005013621066178293`", "\[VeryThinSpace]", "-", 
      RowBox[{"5.9429465677620215`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.005120518329289407`", "\[VeryThinSpace]", "-", 
      RowBox[{"7.434747956128581`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.004472657209522634`", "\[VeryThinSpace]", "-", 
      RowBox[{"9.178665388715032`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0032199763216310216`", "\[VeryThinSpace]", "-", 
      RowBox[{"11.190131264240678`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.0017252588234699495`", "\[VeryThinSpace]", "-", 
      RowBox[{"13.45453440311964`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.00021423419555296357`", "\[VeryThinSpace]", "-", 
      RowBox[{"15.905992695719025`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0013492553206825347`"}], "-", 
      RowBox[{"18.401091818765586`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0031357841911083474`"}], "-", 
      RowBox[{"20.693930010540694`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.005259504764162574`"}], "-", 
      RowBox[{"22.425918690554095`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.007680336726573149`"}], "-", 
      RowBox[{"23.151685403469788`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.01021932597898853`"}], "-", 
      RowBox[{"22.425157661714078`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.012628433794618225`"}], "-", 
      RowBox[{"19.95673120146868`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.014667817427910467`"}], "-", 
      RowBox[{"15.813795111725721`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.016181620298065`"}], "-", 
      RowBox[{"10.579323528559241`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.01716165975544791`"}], "-", 
      RowBox[{"5.344151315935577`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.017749890722625707`"}], "-", 
      RowBox[{"1.4454699534685447`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.018125760380031473`"}], "-", 
      RowBox[{"0.00009974228335396213`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"82abe945-443a-4c98-91f6-26fdecead721"]
}, Open  ]],

Cell["\<\
As a simple check, it is always worth plotting the dipole out in the time \
domain:\
\>", "Text",ExpressionUUID->"8c053351-eb44-4712-9de4-2b4f3a2d7ed6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"timeAxis", "[", 
      RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Re", "[", 
      RowBox[{"simpleDipole", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"b9d33e8d-5ad6-451a-b107-45afc9104345"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw11AlQ1FUcB/BFGiAYr3ASIpFF4wiIFUQIxPcDFlmQa3dhl3NCDhNEuQ9D
EI2YFmu5hRgFhiM5siSgGAwfdi1HUEgNOMPQaGMklBQBu/9VOnjv8Z/5z3/e
/P//937v+/vM48enSZK28Xi86P/vzefWFXJJICgvr8I75bMcrv8b6cf66Njc
3RrrwujGcL1xaRW+evnr9f1J28EDDTnOlFWy98bwuB2K7xSX4+nUYM1ykQnM
qpqfnN55hX2/DxROF8wUd0uxQ+B17Y1X+NCEWyaUI5fZ/wfgaXPMVOWDC/iv
k8bcjJEVZKC6Wp9rmWw+GzCT9uV3HIrD/XkKtf7Kq5BQJ8gQ2TggOr8DHBka
SzY7dRLlv//vmuusI+g+cVEmy9MRXe8Q2G4TJWbiXNQ45a51fsMJnMYWJ3/u
Oo/o+s5wyduc33j6PCqey+FO3DsMqdZGXsfeyke0niNQUFV4e7UwD8Uv3NIk
+LpC+XCW0EKVjWh9brA9t/TDvebpSLiypC4YeB0kKwk9C6OnEK3XHQwS5w+k
4RhktWGlrrY7CqY/NYoyPIDV7wmfF2708xVirG8Qv97deAyyHvXaNZgmYrof
BH12u2LbeGdwjmJS++BdAAule11tUhrL0wuKPm1o97PNxL/uSNWe/dILVOlu
HbaKbEz36w1+nYc/Ai4by2ue13JPvYGb2qFaEmey/H1gT+r9JlVcClaZ3uDe
cRFC8svhSm9hDKZ5CMGr03rw0h577NYk5Han+cJ3HxTMO5rJWD7HYVxQJna9
lYw6Dz7UXO84DvZtovKNshyWlx/4fqLTk5JzEb3UdVFj+9APGjKWP5v/o4Tl
JwI5vNazPKdAVxz3afrN/EHUDXxbQyXL0x9uP16wXqysQM/6BtVe4QFg7lxT
OF1VyfINAMP97Tx9hyp01j1CPaE8ARLqmeUdCL/HEM9oHq+tR44Egt0/xDPL
Pwg8qWcU4lu9/kgnGJ5Rz4j2IxgWR4hnNDwmWM/wCIEg6pl5C4H+IeIZmdgs
aIvcQ6GCeka0X6HwI/WMphb7tcKZUHAMJJ6ZTzEclRDPWHGzRGuYLYYBTDyz
fooheZV4xt7pUu0PuyRgtOq36Zn1VwJms8Qz1jpZaq/elIA/9cz6LYEXLIln
3Lv2JxcTIIXBJuKZ9V8Ksi+IZ3xmAHOWC1LIPkc8Mw9h0K2buOkZHyxQcr+9
HQbDccQz8xEGeuPEM57zjOU+tgiHthLiGVEv4cD7hXhGtTx7LnsoHFb5xDPz
I4OxVuIZBX2l1bhHySCqm3hmnmRwLpl4RnqloxqeWgaVvcQz8yUH03vEM7oj
qtd8Wy2HmiLimXmTQ68u8YzyjN7UvCeIAINx4pn5i4C9ucQzdpx00UgmIqDH
g3jG1GMkLLUSz3ih4jmNSUokfNNCPGPqMxIEWcQzbpZOq+f1ouB7L+IZU69R
oNdFPOOIF1vUba1RYLpIPLPzLAquUc949/10dQpEb3nG1HM02LLz+T83XcT6

      "]]}, {}}, {}, {}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 110.23132117858923`}, {-0.0183149576922377, 
    0.018314957692237607`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"79d8ab5e-8bdd-46a1-813b-5b552f7ac16f"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Using FieldParameters", \
"Subsubsection",ExpressionUUID->"149d6f83-fcc5-4416-80c4-7315767bb1d0"],

Cell["\<\
The vector potential must be provided as a Function object, and it can \
involve any additional symbols required. The option FieldParameters should \
specify the values to use for those parameters.

Thus, a function call of the form below is equally valid:\
\>", "Text",ExpressionUUID->"7c76a0e3-8e25-43f2-ba3c-c99636d8fc86"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"simpleDipole", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["otherF", "other\[Omega]"], 
            RowBox[{"Sin", "[", 
             RowBox[{"other\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", 
           "0"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"otherF", "\[Rule]", "0.05"}], ",", 
         RowBox[{"other\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
      RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"dcecf1ff-30dc-451c-820e-0a807890f228"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.793055`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"3ee159c8-7ec3-4d74-bcff-c818ccfbe41c"]
}, Open  ]],

Cell[TextData[{
 "The core usage is that FieldParameters gets used as a replacement rule:\n   \
",
 StyleBox["\[CenterDot]",
  FontWeight->"Bold"],
 "  given A=Function[t,function[t]],\n   ",
 StyleBox["\[CenterDot]",
  FontWeight->"Bold"],
 "  and FieldParamters\[Rule]parameters,\n then the replacement \
A[t]//.parameters must produce a numerical function:"
}], "Text",ExpressionUUID->"c3a0fbf8-384d-4ce9-8706-22fc3f50cd2d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"A", ",", "parameters", ",", "t"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["F", "\[Omega]"], 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
        "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"parameters", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"F", "\[Rule]", "0.05"}], ",", 
       RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"t", "=", 
     RowBox[{"RandomReal", "[", "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"A", "[", "t", "]"}], "//.", "parameters"}]}]}], 
  "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"e56d48cd-51b8-4113-b7bc-73f4a7fc889c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.0030115174957977033`", ",", "0", ",", "0"}], 
  "}"}]], "Output",ExpressionUUID->"38f934e0-a492-40ee-8017-848bbff4bd12"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], \
"Input",ExpressionUUID->"4e11bc12-69ab-4b50-a9d7-e7c91ddd1dcf"],

Cell["\<\
If the function is called with insufficient parameters, such that the vector \
potential evaluates to a non-numeric output, then the call will produce an \
error message and abort:\
\>", "Text",ExpressionUUID->"ba8bafc8-d017-439c-ac46-e84db9fffcc6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeDipoleList", "[", 
  RowBox[{
   RowBox[{"VectorPotential", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["F", "\[Omega]"], 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
       "}"}]}], "]"}]}], ",", 
   RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}]}], 
  "]"}]], "Input",ExpressionUUID->"eab926a0-ba50-4b8a-af02-8082450d8a27"],

Cell[BoxData[
 TemplateBox[{
  "makeDipoleList","pot",
   "\"The vector potential A provided as \
VectorPotential\[Rule]\\!\\(\\*RowBox[{\\\"Function\\\", \\\"[\\\", \
RowBox[{\\\"t\\\", \\\",\\\", RowBox[{\\\"{\\\", RowBox[{FractionBox[RowBox[{\
\\\"F\\\", \\\" \\\", RowBox[{\\\"Sin\\\", \\\"[\\\", \
RowBox[{\\\"\[Omega]\\\", \\\" \\\", \\\"t\\\"}], \\\"]\\\"}]}], \\\"\[Omega]\
\\\"], \\\",\\\", \\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}]}], \
\\\"]\\\"}]\\) is incorrect or is missing FieldParameters. Its usage as A[\\!\
\\(\\*RowBox[{\\\"2.1098106124571148`\\\"}]\\)] returns \
\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{FractionBox[RowBox[{\\\"F\\\", \\\" \\\", \
RowBox[{\\\"Sin\\\", \\\"[\\\", RowBox[{\\\"2.1098106124571148`\\\", \\\" \
\\\", \\\"\[Omega]\\\"}], \\\"]\\\"}]}], \\\"\[Omega]\\\"], \\\",\\\", \
\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}]\\) and should return a list of \
numbers.\"",2,10,3,27171969030508056641,"Local","RBSFA`makeDipoleList"},
  "MessageTemplate2"]], "Message", \
"MSG",ExpressionUUID->"c9a94aa3-a94f-49bf-b96a-aaf31a89c6d3"],

Cell[BoxData["$Aborted"], \
"Output",ExpressionUUID->"0e2a17bf-225f-4d93-ace3-90b79f2cd7b7"]
}, Open  ]],

Cell["\<\
This means that any symbols remaining in the evaluated output, as produced by \
the error message, need to be provided within FieldParameters.\
\>", "Text",ExpressionUUID->"4826dc20-3528-4b0a-ba1e-37d79ab4ea99"]
}, Closed]],

Cell[CellGroupData[{

Cell["Specifying the carrier frequency", \
"Subsubsection",ExpressionUUID->"a910bd74-27a4-48fc-b13e-193fa8be0b97"],

Cell[TextData[{
 "The carrier frequency should, for good practice, be provided ",
 StyleBox["twice",
  FontWeight->"Bold"],
 ": in the FieldParameters and via the CarrierFrequency option. (This design \
choice is to enable a better factorization of the total sampling points as a \
product of the TotalCycles and PointsPerCycle options.)\n\nIf a \
CarrierFrequency is not provided, it is set by default to  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Omega]", "=", "0.057"}], TraditionalForm]],ExpressionUUID->
  "2e36ccd8-577b-4c79-bc08-a3a6d4335e89"],
 " atomic units, corresponding to a wavelength of 800 nm (and a warning \
message is thrown). The symbol used for the carrier frequency within the \
VectorPotential function, and its FieldParameters complement, is arbitrary."
}], "Text",ExpressionUUID->"f673ad97-92f7-45dc-8280-9430775be1d2"],

Cell[BoxData[
 RowBox[{"makeDipoleList", "[", 
  RowBox[{
   RowBox[{"VectorPotential", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["F", "\[Omega]"], 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
       "}"}]}], "]"}]}], ",", 
   RowBox[{"FieldParameters", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"F", "\[Rule]", "0.05"}], ",", 
      RowBox[{"\[Omega]", "\[Rule]", "0.0456"}]}], "}"}]}], ",", 
   RowBox[{"CarrierFrequency", "\[Rule]", "0.0456"}]}], 
  "]"}]], "Input",ExpressionUUID->"c39cc12f-c78e-4cc2-a2bb-ab3da9a7f68c"]
}, Closed]],

Cell[CellGroupData[{

Cell["Getting and plotting the spectrum", \
"Subsubsection",ExpressionUUID->"5fe19de8-2a42-42cb-8557-145af62457e4"],

Cell[TextData[{
 "To see the spectrum, use the ",
 StyleBox["getSpectrum", "Code"],
 " and the ",
 StyleBox["spectrumPlotter", "Code"],
 " commands, such as"
}], "Text",ExpressionUUID->"a3af0855-df92-4ed1-861c-327298a20bc8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spectrumPlotter", "[", 
  RowBox[{
   RowBox[{"getSpectrum", "[", 
    RowBox[{"Most", "[", "simpleDipole", "]"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "False"}]}], 
  "]"}]], "Input",ExpressionUUID->"46a0fe4f-ba43-46c0-9022-1dfbb90a0436"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      Thickness[Large], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQOPKq4vfinocGADazQQfbC3n/ji/jEDNiifwUHn
3ITf/5LtDnR2gACHA1ul+h/tRFaovIBDL+fHKTv17Q/IHC8EIhGH56JTPROy
xaHqJRyYjjyPnSpkf+Cr5/wvnvNlHPge3rMQtJKC6ldwmH08+5qagf2BNDBQ
cvi7+qnpjmIpqHkqDuF7lyfa7rQ7cEm9FojUHP4dCFvZzyEFNV/DwfXUDNX4
ifYH7F9Otns5WcuhOvP1rtebxKH26Tj4z2q/dGya3YHVq0BAz2F5w1npVTEw
+w0cNn88YjK5we4A97YEIDJ0qBUR2W58WQbqHiOHp4ElLKzL7A8cFMsBImOH
NxckzmUKwtxn4jB/fU/6LRP7A+VgYOpgtd5x24yDUlD3mjmc39jy7kWe3QG9
G026N5rMHbzq9iUYC8hB3W/hIL9u+a+gnbYHnlj0Pbbos3SQfiwY9i1NEeof
K4cvLvFe6xbaHpg1EwSsHZZUi/xwc1OB+s/GYeex3CnCp+wOBPxa4v9ria2D
1nfmz4ad6lD/2jmsXZn0YnaR7QE2kHc32Du0rY6tqpDVhvrfwaHmgmYkp4fd
gXt3QcDBIdXsmvLcb3rQ8HB0MLnhdCncwPaAJch5jx0dJovGFd1tNYSGj5OD
aLV1tuh+2wNT7EAOdnKwWndv6cpVxtDwcnYQu5vQvMLP/sD7dyDg7NDs2FqX
+dwUGn4uDp838v3o1rI74AXyzhcXB8P01QtcLC2g4enq8FRj9fNUoP+W+oM8
6OpgfrRJacZcK2j4ujk0/mA6WF9pdwAAO2dQ9w==
      "]]}, {}}, {}, {}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->800,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 44.977777777777774`}, {-32.13994262715438, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"bdf8370f-87ca-4552-86ec-fccb49d4e379"]
}, Open  ]],

Cell[TextData[{
 "Note here the use of ",
 StyleBox["Most", "Code"],
 " on the dipole when a monochromatic field is indicated. This ensures that \
the signal is actually periodic (i.e. it eliminates repetition between the \
initial and final points, which are separated by exactly one period). If this \
is not done, the spectrum is much noisier:"
}], "Text",ExpressionUUID->"a2007dc0-b4d4-4690-9840-414e88be0cb2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spectrumPlotter", "[", 
  RowBox[{
   RowBox[{"getSpectrum", "[", "simpleDipole", "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], 
  "]"}]], "Input",ExpressionUUID->"244c219d-b7d0-4629-b757-af51970cf6be"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      Thickness[Large], LineBox[CompressedData["
1:eJw1z11IU2Ecx/GTEi0CzVxu67i3o6yUsPW21Vye33Z2nBkVSXbRUVIpKkYl
XZQEhsEoc12okFENI1Z4JnSlIsIgAyMrUjCTzBeGuxiBRaEh0rSMnv8DDw8f
vjxv1rorFefSOI4rWpv/VhpLiJzMer118L9+iOm8qbfy+3pmDlHrhEZRc5g1
CNmTR2KV1DfD9WBDdsdL6lpk+Y/Hv3brmfWQMgZDLde2MeeibHmu+eE76hao
5S0B+amRWUCmZWH87lWeOR8z0Aq+SC6zDQ0rcv9hq4F5B2KNbaOz503MhYjK
mqH7z3XMO/EsOzoz1WZmLkKtuNgz76Dz7Xg/ueuNfpju342+oJSeM0Z9DzoX
zfX+JQvzXohdN10VrfSffbiRTCQu1dD+/QiFwisFj6k74LQ1T4R/0f1OtPuv
txYfo/ceQO+qp8r5is4/COXRtML3kV0YSY0L3kmBuRgbdeucaifZjU26ox2m
j+RDcJTNl9xLkktwOjhVn/mZLML8OxXwJ8iAoVpd/fOTuQmw2QK++DJ1D6Rv
X3pSXB7rHlw4o1TxGmbOi1m3+ul2BnUvwvHGEVFLXYL7TrLphIG6hODZU0LM
SN2HtwPD6i0rdR9ebPkwFMmnLkO52N6ft526jIUueyStgHopeDQEPIXUS3H5
iTEaX/NfWqfJew==
      "]]}}, {}, {}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->400,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 45.}, {-9.583745274416028, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"a04adde5-606e-47bf-a7d8-2138dfaec96c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pulse duration and other timing options", \
"Subsubsection",ExpressionUUID->"d3758228-6bf8-41bf-8503-4f611b392e30"],

Cell["\<\
The default options are built for a periodic pulse for which simple functions \
of the vector potential can be integrated analytically, and for which only a \
single period of integration is necessary. More periods can be specified \
using the TotalCycles option. Similarly, the PointsPerCycle option controls \
the number of points per period.\
\>", "Text",ExpressionUUID->"d4cc0418-73b6-4135-ae9d-53c72a074fb6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"biggerDipole", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["F", "\[Omega]"], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
          "}"}]}], "]"}]}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"F", "\[Rule]", "0.05"}], ",", 
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
      RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}], ",", 
      RowBox[{"TotalCycles", "\[Rule]", "4"}], ",", 
      RowBox[{"PointsPerCycle", "\[Rule]", "150"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"17603eba-1696-4f66-afca-c535bd2a3a55"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"31.5894549`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"8f5a524d-2986-4b15-b630-84b28b42d2e5"]
}, Open  ]],

Cell["\<\
To get a correct spectrum plot, give these settings to the spectrum plotter.\
\>", "Text",ExpressionUUID->"f9f25001-43c8-4d1a-b107-51461959f573"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spectrumPlotter", "[", 
  RowBox[{
   RowBox[{"getSpectrum", "[", 
    RowBox[{"Most", "[", "biggerDipole", "]"}], "]"}], ",", 
   RowBox[{"TotalCycles", "\[Rule]", "4"}], ",", 
   RowBox[{"PointsPerCycle", "\[Rule]", "150"}]}], 
  "]"}]], "Input",ExpressionUUID->"29adf5ff-904b-4e38-a1b6-2444f1623ae8"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     Thickness[Large], LineBox[CompressedData["
1:eJw9l3k81Pkfx6ceaqVjrZxRrpF7V3LknNe4xwxmpigdIrsIi2pLSjVIy6JU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      "]]}}, {}, {}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->800,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 74.75}, {-31.118656604071624`, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"c1b92a9d-8cab-40a0-b867-636f36f65784"]
}, Open  ]],

Cell["\<\
The most convenient way to store these parameters is as a Sequence:\
\>", "Text",ExpressionUUID->"e0a8654b-649d-43ee-85ff-fbe386a5de28"],

Cell[BoxData[
 RowBox[{"conditions", ":=", 
  RowBox[{"Sequence", "[", 
   RowBox[{
    RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}], ",", 
    RowBox[{"TotalCycles", "\[Rule]", "4"}], ",", 
    RowBox[{"PointsPerCycle", "\[Rule]", "150"}]}], 
   "]"}]}]], "Input",ExpressionUUID->"1d919d88-3aa5-4e0f-89be-2a09bf255411"],

Cell["They can then be passed in a single symbol:", \
"Text",ExpressionUUID->"e533c891-723d-4562-be5b-1850a7e9362d"],

Cell[BoxData[
 RowBox[{"spectrumPlotter", "[", 
  RowBox[{
   RowBox[{"getSpectrum", "[", 
    RowBox[{"Most", "[", "biggerDipole", "]"}], "]"}], ",", "conditions"}], 
  "]"}]], "Input",ExpressionUUID->"e7b8bd1f-bb37-4093-9fcb-9aa3bacf5d34"]
}, Closed]],

Cell[CellGroupData[{

Cell["Target species", \
"Subsubsection",ExpressionUUID->"20863c83-8fed-4dc4-becd-ec9cd0b0d8f1"],

Cell[TextData[{
 "You can specify a ",
 StyleBox["Target", "Code"],
 " chemical species using the option"
}], "Text",ExpressionUUID->"73ce62fe-60a0-42eb-ae10-5ab41bf00599"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  "Target"}]], "Input",ExpressionUUID->"be1c17e9-569c-42a3-8a4c-ca594116d475"],

Cell[BoxData["\<\"Target is an option for makeDipoleList which specifies \
chemical species producing the HHG emission, pulling the ionization potential \
from the Wolfram ElementData curated data set.\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info303809697575-1871502",ExpressionUUID->"be97595b-c2b2-4732-ab91-\
8ba7fbe72cf3"]
}, Open  ]],

Cell["i.e. using the syntax", \
"Text",ExpressionUUID->"80c01110-386d-4a7f-970a-ccef302cf534"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"heliumDipole", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["F", "\[Omega]"], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
          "}"}]}], "]"}]}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"F", "\[Rule]", "0.05"}], ",", 
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
      RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}], ",", 
      RowBox[{"Target", "\[Rule]", "\"\<Helium\>\""}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"xenonDipole", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["F", "\[Omega]"], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
          "}"}]}], "]"}]}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"F", "\[Rule]", "0.05"}], ",", 
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
      RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}], ",", 
      RowBox[{"Target", "\[Rule]", "\"\<Xenon\>\""}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"9cb5eb12-31ac-4455-9c7d-3a39022e8dd5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8.3337308`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"fbe988c2-f97e-400e-83e8-a38cfc61c2ae"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"spectrumPlotter", "[", 
     RowBox[{
      RowBox[{"getSpectrum", "[", 
       RowBox[{"Most", "[", "heliumDipole", "]"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "False"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"spectrumPlotter", "[", 
     RowBox[{
      RowBox[{"getSpectrum", "[", 
       RowBox[{"Most", "[", "xenonDipole", "]"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "False"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], 
   "\[IndentingNewLine]", "}"}], 
  "]"}]], "Input",ExpressionUUID->"4c54eda3-4e72-4d0c-a270-a34ad993613f"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJw1kF1Ik1EAhkfhCpPKn/KHIbqmyfa5uTndpm7fq1PLIiwtSkKTxDJ/JhZU
hGktiTSY5UxRYUbOLGckKZU56DikzIsuxGAXlRdquUwzWhdaUt8nZw/v4XA4
f+/7Rp+uzivdJBAI4rnBzz7mBd0L5iCQQb+TnFZYyY09ytiAYLoW4Higf35P
DEjjLZ6tGKjaV/Q1RUT3d8I0/V3E3AYRva3hFIK0aGuRuDeGng+DvXxYVP8a
5HdOtzenW4S+ymzdlu1Sej8Knm960/o1kDMbiJHnQn9XuYy+J8F4Q5lirQJk
au9VTrEwubp+fmln6PtxqHAX3Fz6BcJ6rAaPVYrrpWlDxWUM/Y+Bwjb5Qc35
d/TzyBHqHQlXxDL0/wTU1Tpza3aBbHtezEmJqr6xxagWhvpRoeG+c3xmFGRs
dyWnRByd0jjv1UupPzXMJLI5qwzk0gZJgF6bb1Qx1G8yxkaO6E4FgMjd5ni3
WQNlYJfrmcLnX4tWr6HDfpklc1rLrNaiw7RlpjkylKF5UgBJW/DLEpZ0dvCk
IuT9omxgsy9fGsx/1Qr/ApDDa/bcNbseTR+FnQcdMprXgIgXqxcfp7JEyMcd
ZDHy8N8O04QvP/DgbJNnVQjy+RMPkNh/92nykJz2kY4r+6MeLawYiI63N5sO
u3CisKktgfaTgZb1Er/COyxpNfCGMyA0Tmb0+KtoX0bUVsctH2sH+bHMY4T4
XeOFYUci7S8T4UtSEjHPkgN8HG8mDr1RBb06n0T7zILaee7PEyVIby4fMAt1
LpvVfUJD+83GqMaWPRcG8h/b+kkm
       "]]}, {}}, {}, {}, {}, {}}, {{}, {{}, 
     {RGBColor[1, 0, 0], PointSize[0.012833333333333334`], AbsoluteThickness[
      1.6], PointBox[CompressedData["
1:eJw1kHtIk1EAxdfKkTZSMOcUDXU2tdzy3aZ+9zu6TTLKF0VFQsOYEiphKcve
rJeWjnKCLJkGLUEDH38U5R91lUJ8ZGAPzLQMpaVCJmmEEPV9cv1xLpfLfZ1z
wotOFVikEolEIwxxXqeggVS4qnja7XVM0E/e2u490Ta6ga0l+DItNRXKCK2t
EdmMxeKO/oKA9X0/HLUb8eIjoSEDFYK24frJvhvqXn92XonbbmWxupPQlezW
5ezWEDgvvEl9qgxg98Mw2vxV/mqC0OI1InBWvXgf2kD2XiRaDg6Nuw4TOhZ1
UZAa54P5kUm7gr0fDendurbf+Tzl5xxkzrETXTpHUZ4riP0Xi1sVgw21ekIf
dYhooVzay+V41v+Pgy//t+FyFKFbnpgFxWP/Qphqe6KS+UlA/YfAOEslT/sU
ZYIS4Q4N0sV1KJi/JAQPX8uYF/xb10jGpLm3NMoUxPymoKbqROwdP0K14zbN
uG0P6p8XHml3hjL/OtQNf/PVlHB0Vmef0dn1eHvugP3ZzXCWJxUh9GUMyeHo
PadIGmoPGb3lXZEsXzosxgjFUjWheavu3FU3h8EzV75PxUazvASfkuUGm4qj
MjFuN4+SMevrkV+7WH4g5VJ/udKL0M9TIkB2U+j7gT+7WR8ZmIlx9GAynepF
ezMZeKDaOG0ITmD9ZGJhpfx4aRlHG4loOBOeTT1mZ34S68uAPK1/1lYfni7+
EDFgKL5lnmtOYf0Z4Zn1mct/x9F9YpxlIzobH1c3SfWsTxMgMXY6TxP6MFcM
aELN1X9mVKaxfrMgbzHJcncQ+h9JTEVD
       "]]}, {}}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->800,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 44.977777777777774`}, {-33.90568618189794, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"65ca5f16-f643-4dd4-83cf-af7fbf33b557"]
}, Open  ]],

Cell[TextData[{
 "For convenience, the function ",
 StyleBox["getIonizationPotential", "Code"],
 " gives a public-facing access to this functionality, via"
}], "Text",ExpressionUUID->"a845e188-ab13-452a-86ea-2489ff77eb81"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  "getIonizationPotential"}]], \
"Input",ExpressionUUID->"0bb68a3a-6846-4ccd-bde6-a287aca139e8"],

Cell[BoxData["\<\"getIonizationPotential[Target] returns the ionization \
potential of an atomic target, e.g. \\\"Hydrogen\\\", in atomic units.\
\[IndentingNewLine]\\ngetIonizationPotential[Target,q] returns the ionization \
potential of the q-th ion of the specified Target, in atomic units.\
\[IndentingNewLine]\\ngetIonizationPotential[{Target,q}] returns the \
ionization potential of the q-th ion of the specified Target, in atomic \
units.\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info233809697477-1871502",ExpressionUUID->"6a86c559-efe6-49ba-b44c-\
89fd707a6d59"]
}, Open  ]],

Cell["so that e.g.", \
"Text",ExpressionUUID->"8d789ff4-b47f-4757-b7d0-431a3050d72b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<H\>\"", ",", "#", ",", 
     RowBox[{"UnitConvert", "[", 
      RowBox[{
       RowBox[{"Quantity", "[", 
        RowBox[{"#", ",", "\"\<Hartrees\>\""}], "]"}], ",", 
       "\"\<Electronvolts\>\""}], "]"}]}], "}"}], "&"}], "[", 
  RowBox[{"getIonizationPotential", "[", "\"\<Hydrogen\>\"", "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<\!\(\*SuperscriptBox[\(He\), \(+\)]\)\>\"", ",", "#", ",", 
     RowBox[{"UnitConvert", "[", 
      RowBox[{
       RowBox[{"Quantity", "[", 
        RowBox[{"#", ",", "\"\<Hartrees\>\""}], "]"}], ",", 
       "\"\<Electronvolts\>\""}], "]"}]}], "}"}], "&"}], "[", 
  RowBox[{"getIonizationPotential", "[", 
   RowBox[{"\"\<Helium\>\"", ",", "1"}], "]"}], 
  "]"}]}], "Input",ExpressionUUID->"ed8f669c-54ea-4b95-888a-15f29a9d3f78"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"H\"\>", ",", "0.4997144089712775889`4.9978621112217025", ",", 
   TemplateBox[{
    "13.5979216820215829759`4.996265814102611","\"eV\"","electronvolts",
     "\"Electronvolts\""},
    "Quantity"]}], 
  "}"}]], "Output",ExpressionUUID->"3ef30961-88d3-4fc8-ad1d-892a77611329"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(He\\), \\(+\\)]\\)\"\>", ",", 
   "1.9998098355973269667`4.9978621112217025", ",", 
   TemplateBox[{
    "54.4175974020231108358`4.996265814102611","\"eV\"","electronvolts",
     "\"Electronvolts\""},
    "Quantity"]}], 
  "}"}]], "Output",ExpressionUUID->"8dd364b3-3123-4d01-b6a0-29279dd703c4"]
}, Open  ]],

Cell["An ionization potential can also be specified directly:", \
"Text",ExpressionUUID->"4eef4ace-4d87-4d44-acb1-8f3a43a08faa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  "IonizationPotential"}]], \
"Input",ExpressionUUID->"d2207f0d-aaff-4829-8302-4f5bf23d837c"],

Cell[BoxData["\<\"IonizationPotential is an option for makeDipoleList which \
specifies the ionization potential \\!\\(\\*SubscriptBox[\\(I\\), \\(p\\)]\\) \
of the target.\"\>"], "Print", "PrintUsage",
 CellTags->
  "Info263809697488-1871502",ExpressionUUID->"d6959708-315d-46d3-bd64-\
184beb31ad10"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Other options", \
"Subsubsection",ExpressionUUID->"e7a46c56-a323-4c32-b1cb-965230abae17"],

Cell["\<\
To see the available options for this function (and others), use\
\>", "Text",ExpressionUUID->"607f42e1-6e43-48af-9b68-dda4d5c042e8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "makeDipoleList", 
  "]"}]], "Input",ExpressionUUID->"e2a84b81-31e4-4654-886d-3a0b97a473bf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"PointsPerCycle", "\[Rule]", "90"}], ",", 
   RowBox[{"TotalCycles", "\[Rule]", "1"}], ",", 
   RowBox[{"CarrierFrequency", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"IntegrationPointsPerCycle", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"VectorPotential", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"FieldParameters", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"VectorPotentialGradient", "\[Rule]", "None"}], ",", 
   RowBox[{"ElectricField", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Preintegrals", "\[Rule]", "\<\"Analytic\"\>"}], ",", 
   RowBox[{"ReportingFunction", "\[Rule]", "Identity"}], ",", 
   RowBox[{"Gate", "\[Rule]", 
    RowBox[{"SineSquaredGate", "[", 
     FractionBox["1", "2"], "]"}]}], ",", 
   RowBox[{"nGate", "\[Rule]", 
    FractionBox["3", "2"]}], ",", 
   RowBox[{"\[Epsilon]Correction", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"IonizationPotential", "\[Rule]", "0.5`"}], ",", 
   RowBox[{"Target", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"DipoleTransitionMatrixElement", "\[Rule]", "hydrogenicDTME"}], 
   ",", 
   RowBox[{"PointNumberCorrection", "\[Rule]", "0"}], ",", 
   RowBox[{"Verbose", "\[Rule]", "0"}], ",", 
   RowBox[{"CheckNumericFields", "\[Rule]", "True"}], ",", 
   RowBox[{"RunInParallel", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Simplifier", "\[Rule]", "Identity"}], ",", 
   RowBox[{"QuadraticActionTerms", "\[Rule]", "True"}]}], 
  "}"}]], "Output",ExpressionUUID->"cddfc779-f739-4614-bfb9-f93907e7e73e"]
}, Open  ]],

Cell["All options have suitable information messages:", \
"Text",ExpressionUUID->"8b1dfc38-db08-49b6-bda1-849eb55cbef8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  "VectorPotential"}]], \
"Input",ExpressionUUID->"d595434c-0449-45bc-b1ce-e4775dfb3d25"],

Cell[BoxData["\<\"VectorPotential is an option for makeDipole list which \
specifies the field's vector potential. Usage should be \
VectorPotential\[Rule]A, where A[t]//.pars must yield a list of numbers for \
numeric t and parameters indicated by FieldParameters\[Rule]pars.\"\>"], \
"Print", "PrintUsage",
 CellTags->
  "Info283809697493-1871502",ExpressionUUID->"88bb3f14-8996-40e3-9fe1-\
ac5288bff581"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using numerical integration for the preintegrals", \
"Subsection",ExpressionUUID->"155667f8-3e70-432f-b269-cbdbcce03757"],

Cell[CellGroupData[{

Cell["Dipole case", \
"Subsubsection",ExpressionUUID->"c4c8016c-ceaa-4814-9120-b7a5c6acaa2e"],

Cell[TextData[{
 "To simulate a pulse with an envelope, it can be convenient to perform the \
preintegrals numerically, using the option ",
 StyleBox["Preintegrals\[Rule]\[CloseCurlyDoubleQuote]Numeric\
\[CloseCurlyDoubleQuote]", "Code"],
 ". These cases are generally slower but mainly because they require many \
more periods of integration."
}], "Text",ExpressionUUID->"1e375486-6b8c-4383-97a0-c38275e1eecd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"numericallyIntegratedDipole", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["F", "\[Omega]"], 
            RowBox[{"envelope", "[", "t", "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
          "}"}]}], "]"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}], ",", 
         RowBox[{"F", "\[Rule]", "0.055"}], ",", 
         RowBox[{"envelope", "\[Rule]", 
          RowBox[{"cosPowerFlatTop", "[", 
           RowBox[{"0.057", ",", "8", ",", "16"}], "]"}]}]}], "}"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"TotalCycles", "\[Rule]", "8"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Preintegrals", "\[Rule]", "\"\<Numeric\>\""}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"26c9dab8-48fc-487b-9e52-fe70d87fbf7c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"27.512677`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"ae7bc61b-6960-4ac8-ae40-e832959447ff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spectrumPlotter", "[", 
  RowBox[{"getSpectrum", "[", "numericallyIntegratedDipole", "]"}], 
  "]"}]], "Input",ExpressionUUID->"2b688ef4-7693-408f-9d4c-1590c4466bd8"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     Thickness[Large], LineBox[CompressedData["
1:eJw1lglYjGsbx8u+hg5KqWZ5Z6aZadr3bf6zIhIOWStxEg7Zjr2yfyW7cOzZ
t052TllfjiQOis8aKWWr0KbPFt/Uc/dcc12urlLPfT+//yIcM2VQTDMzM7Px
5mZmDf82nSTfXQcs+4j54y1Hmj68epQ+4v3Baxx9nacOmPGJ73BcwC9PbjiP
1ZEpq1a/aOFA3y9St7b1l3V2FPA9c6aZPqVqtSqeVyXY0c+/VY/vnn547TNr
/lOftNo+aRVql6LbvPFtd/r/lerJ6c93Vv+05Mc1nmp1jaTk+Lwj3en31aq/
7nSb6nPbmr8nSzB96tQ1WaHT/A80/f7PasussKGXKxx49bvU4HepX9VDk9u1
ii6wp7/3XR14xzMrZJuATz/ScH6o/8x1GO9W2TSvGY7G/qjL3iLm258dbfqY
I8F81Ptu92R0n2a4uTl4WcJEIX+l+yTTpzkqLrrpgto0zdsCd1ccGRCfKOBn
N56WuCK8+z7KzJ7u2wpHQlIuj+/eg3d+vFj1eHFrDNsjSNz2rTvdvw2szPOb
ndtvyZf6ri7xXd0Wx9qWJ3281I3maYdnGYmVuiIrfuuWhtMebxxSKgdL7Gi+
DthuIUmZstCOH/B1X9jXfR2x2z5ovuLvnjSvBTh1zeBuNfZ8q4Zxj3eC3dzI
Cx83i2j+zigsq+laohXxhc8bTmdYW1Y+rleKaB9dcO3JnOJPX0W8X8P1Srrg
5SP+R7A7R/uxRHBigcW9eo7fENxwYdPX3oNPL0uS0L5+gbKt4fX5VBH/8UPD
+QWDEzPqe7sKaX9dMfhcRIrRz54PaRintivmlpaXvevYtM9uaOkSd0Z9TMjv
D2sYsBuMHk8n/7FRTPvtDlld3rBLx0Q8o9kKH7+9GbWvUkT7tkJlTlaXZT/F
fOP4La2xY8w3y5oXYtq/NRwGHfl6PEHMN47bvgeWdf1ZUfeKo/fogXMT3bZ+
0HB8l8Zjg4j5t9YvecPR+9gg4Glf18gNEn5S48C26HO4OEQ9jqP3ssXvs/o/
dVBL+MZxe/bE5MjlrQedlND79cTia1dyuGQRL2o8dhCc8rjfa4CY3tMOetXQ
2bo9Yj6hcWB7bGjX72ClA0fva4+wqLjOqyZxfOO4KgfcCyt9WdZdQu/tgL5Z
lRcu2NN9egjQ5UTXh7bzm/QtwN29MnPDUjG733YBHM8sLbk3nCMeBGjfsfZp
zWkxu6+DEFXt4t0jW3HEhxDOs9Zt6qySsPvvEWJAs/iF0w9yxIsQqtflzsee
cmweToTR8nzN1xAx8SNC5o1dsRW+QjbfQRFebMy+KdwtIp5EWGsxT1JpL2Hz
KsT4vuZG263DpcSXGDMKZmTnrab5M8SYVjNr7n9ecsSbGEMNZVNP7+bYPlw5
NO/guv2OJUf8cbCbfNp5ZHeO92g4pzhkP7V6MGQeRzxysHqy6ufy6xwf3TCw
twRpQ7T2MZUc8SmB07UuI9LiJHzjuJkSzD+XbSPKlRCvEhS/vl49ZgPHXzhv
OgFS5JTwqXyZiPiVYtLZ+LrCTwK+EadLUpM+kp90aisknmWYOqP9sKm2Yt6q
YVyNDC8KLhyrWNvEtwz+obcWTTkh4vUN55oM4r9PXV96WkS8O2JDUOswwUYR
P71h4F6OEK49ZN1W1sS/Iz79vPzgs0HEN46b64jS8qNVpZOb9CBH0oj0VUtv
iPjb/5pOPzmqawMOThGJSR9yJK/2i4jsyPGNuN6V4+z8jtcPSsSkFwWswoO5
+EyOd2wYd5ACay4ODHFOFJJ+FMiqXrZqSG8BP6ThPFBgdcl1+W9dhKQnJR7M
fN33cgDHL2nAe5gSmimzh3zeJSZ9KXHPM1N29Dv5eYESjpaiJ+P6E889nfBN
+Yq7ZJQwniOcMGHn5rhEOfGc5gSHvFZRgzaT/xc5Yacx5ffot2LSowqTXjz6
PHOgmPE8VoWduTljD+c26VOFoUJnUa0t+eFrFRad8Cr2r2rSqzNKFakxu81l
jOcJzri8r/yYSCMm/TpDfeVuumeugPFc4YzlcwtSRvoLSc8u8M7vVNTqf2LG
c5wL+od1XnDvi5j07YKlOx5Pjx5BPFe54Le4d2YTbKWkd1eUbzvabGoR8ejv
CrMXtpPLr0hJ/664tcBi4C6NI+Nzvivqevn5t+Q58gNX1PR1SpCs4xivF12h
n9bcuvt/m/zBFdoeA8J994oZvz9MP39k/LZP+U1+4YY1dr5HO08TM57hhp/h
y2+sXN6UL254sj3UvGy2kPG9yA3vU6dnTOxDfrjHDYm9f4ZYm+Zr5P2qGz5N
LT7RZge9R4kb5uTX67P7yBj/LdwRnGTj+UTR5Dfu2JXm+If1YY7pweCO9LaR
c/aelZD/uOO9Wbbi8xqO6SPJHetfO2zqnSchP3LHyBOywxE6CdPLDXe480t9
ondKyJ/c4Tmn9QHPVVKmn7Ye+CVU/KPseZNfeSBuaIz9M38501NfD/wd6MIF
veXIvzxQemiw4FugmOlrpQf+GpI5ISZRTH7mgUXTR1TOkkqY3u54IFBiXyd9
JiF/80B02MyTztmkv06e8G8z+1yVhvzf1RMPPovS/dIlTI8DTd93Pzyw+eQm
//PErHuuM6+/kjB9rveE3UPnDt9PNfmhJyadmtcjdCHl3X1PXCyQ5DyIkZA/
eqJFhP08254c0283L3xzDed+xDf5pRd+CM+OvtGcY3oO94J7WOHBhGZi8k8v
zMufkrbmlJDpe7MXBkWVd/xnlIj81AsDe8cn1cdTfj3xwqfHDv/bfogjf/XC
rNBL3I+TlGe23qi3Gv3n2kAJ+a03xv5TYdz1nPJ3lDf+rU5KiBFIyH+9YTt5
SFSEu5TxvMMbpbKJO9ymc+TH3nj8pGNE/4mOjOcX3ug6Z8+XnWop+bMPOhvr
377zlDCeBT4IK9hb+Nb0XsyvfZAhEBsnruUYz2N8kOdVOzEkTkz+7YMK79Rn
oz8KGc97fRDz3fzDx6lNfu6D2Il3BsRCwngu9UGz9ckheanEc0tffKpo2fXz
FOJZ6osX8XfGnuwlIb/3hSzO9Shn8oNGnmN9MW7ZJOdjL4jnZF8c/jjdeD5V
yng+7Iv+UTGdgwKI51xf4HxRdOwd6htlvrj48GHmfb2M8sEPF1tUCRUWlMdO
flhkO8TZOUdKeeGHX6y3YWmglPE82Q8RNZVb5z9r6ld+qFmv6e8cS/521A/v
uLrtmSa/Y3nihxWbXoXWFsoYz5V+qKqd+2WT6b1YvvijdY//Jk8NlzGe3fzx
1ipG2fy5lPLGH8ukLuOKjksZzzP8cWHl7pjz+TLKH3882tTTfP1IKeP5tD8+
R1xbGW7yB5ZH/rCaO8Ws2EnCeK7zx5zSq52iPkgpnwKwW98nY9V6GePZJwDZ
hYk3pWaOlFcB8L7U/FGAo5zxPCcAuUmxlS1aySi/AlD7ZEF1YgT587kArL17
+UaUgPy5IADvU3iL+ijy528BCFTHXS2dIKN8C8TyVfHmibNkjOegQMxILZ6z
31pGeReIV5nTvtdYyBjPiYE4kP2iv02YjPIvEHmF0jPfkolnPhB2R6KuHF5P
PBcFYkjISsenI4hn8yD8HPHruOU5MsrHILx1O/rA1rT/Rp61QbDutE2aUuVE
eRmEkyuuD5+R4ch4XhqE6L/2HGsT4Uj5GYTC+gffPkvkjOfsIKRad+x9pNKR
8jQIfcIHHqjxdWQ8tw6Ge/u7Z6xt5JSvwRj6+nbZ4xo547l3MAptXI++2San
vA3Gm3kHgxe0kDOelwfDq8J5RV+hnPI3GImzCr7EBJA/3wpGOO7vH9dHQXkc
jLoUC2OcvYLx3EGNy49eHRyul1M+q/Fj6wRu4UI547m/GhPuTA1Nf6igvFYj
/1CPwuobCsbzGjW61iXMDBMpKL/VKG0xIWFfroLxnK+Gw0bDm15z5ZTnarys
9B/ecYGCzdMW6DB//xZZpoLyHfDGwaXr7tN8cuBJ/pdmrVPllPfAsCxj933T
aN4QwOdUuNw4T075D0Qd0GWf/pfm/x2ICMnUpi9UUB8A9grSHMrXKdk+VsKU
T9fSFP9xon4A5Gyw3dhiqBPbz19A1oy+y+6qnagvALqpD753sFGxfd0GbuS+
NVz9oqT+AOzOnWdjmK1g+/sAWJbGZn27KKc+YZrnEj8u9Lic7dNCA43Itq84
T079QgPZgHnbO7yWs/26aJA+K2p2yGM59Q0NbmYuud8sV872PUAD0YD27UT3
5NQ/NPj9QO3AFWVytv9pGpzQfBHu9lFQH9GAD2u9bttyBXuPdRoUnuqhXXxW
Qf1EA7+ci80lNUrmNyc1qK4xjNkuUFFf0eDVrPAr98oUzH/ua9Apb//R2n8U
1F80ePjqqsPgpwrmRzUabK3pVi4br6Q+o8Vtl00lWK1k/tRVi8E2A4yTXyqo
32gxqkjtsL+rgvmVlxbBhxOWNbtEejJo8czd8o7O9L6N/hWuRc8bmyt6pSmo
/2gRmWuuHXRTyfxslhb6UMPm8ZVK6kNa5B4aPNN6uor5259aLO+rXdHKQkn9
SAtdW+Nv1Y+UzO8ytUipmHOyIlpBfUmLnElV+x2OkP891qJFRqvignTS5zst
+s/4d+TKKcTzFy1UY8+UbI9TUJ/S4eZSvNEsUjCebXSoP5CScd5OQf1KhyfV
AUWh/RSM5wAdDqUa5m9UKqlv6ZChWLHl3Fcl43mkDhu+W6X/tcWJ+pcOzyb1
VYSY3qeR53gdbq2cu21EMul9pQ5zdO3/aJOvYDzv0MFU4X8dZamkfqZDaXE/
nd8E4vmiDh2syt9Ft3aivqbDqypjSL/nxHOhDtd7pLxud5t4/qDDZzdJrUOp
gvH8U4fL2uh/1i4lv+ikx7vvJSOMs5WMZ4EeLbOrb7mVkn+46nEmdUL54noF
4xl6FH0Yl7TAy4n6nh7Ff6zzbZuoZDxH63EwumOkyx0l9T89Sm/n5YfsUjKe
F+vxcuZMC3mCgvqgHtkhwxf1+SRnPO/Ro82lsmulJXLqh3pYmC8qCapTMp7/
0SMjK8uDDyCe7+uR8mXYrYKXcsZzqR5D1oXrxt6VU3/UI67vpb3GVCXjuYUB
h6csUa8JUFKfNOB25Euh60knxrPEgP3VoTYppvuzfmnAg4SACOkRJePZaEAP
0ewxB7KJ53ADUhbbdB0Q68R4jjVgvteFqc9inKh/GrAjb/Lz44OcGM9JBkQW
pkTelztRHzXgxMLEP9qY3reR50MGZG+peuD/WEn91ICdm/6et22wC+M514Bf
NX5JlzOV1FcNuHzySuTgZOL5nQEVPl3cBMHE81cDNG99YqJGKxnP7YzIcsnR
7Mkgnm2NcE1M3TDUXsV4VhqxsZljp5DWztRvjVjf+VBxuUrFeO5nhMNtT/73
BSrqu0bo+O092+8mf55kxM60+rzki+TPCUZc/VFeKHF1ZTyvMmKZR/3fxZ9U
1IeN2FY1Ku3REBXj+agRt+2SRKE3nKgfG2EbUOcT76NiPN8xInbP+FbXdqqo
LxvhPq7X9yW1Toznj0a8HdvFEPZNxf8f6y1oTw==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->800,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 45.87222222222222}, {-16.188077862373355`, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"57030fac-e3fa-4666-b42b-df6ef8b59e41"]
}, Open  ]],

Cell[TextData[{
 "When using flat top pulses, and other waveforms that depend on ",
 StyleBox["Piecewise", "Code"],
 " functions, it is possible that the function will return errors caused by \
an Indeterminate derivative being evaluated at the corners of the envelope."
}], "Text",ExpressionUUID->"bc984b54-2c6d-45b0-99f1-9d313a9255d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"flatTopPulseDipole", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["F", "\[Omega]"], 
            RowBox[{"envelope", "[", "t", "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
          "}"}]}], "]"}]}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}], ",", 
         RowBox[{"F", "\[Rule]", "0.055"}], ",", 
         RowBox[{"envelope", "\[Rule]", 
          RowBox[{"flatTopEnvelope", "[", 
           RowBox[{"0.057", ",", "8", ",", "2"}], "]"}]}]}], "}"}]}], ",", 
      RowBox[{"TotalCycles", "\[Rule]", "8"}], ",", 
      RowBox[{"Preintegrals", "\[Rule]", "\"\<Numeric\>\""}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"19957bd9-b01c-43ac-b6ee-2a26e7ff7430"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"29.457703`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"082a9273-3d56-410a-882d-484aeccdf019"]
}, Open  ]],

Cell["\<\
In these cases, use a numeric test to diagnose what\[CloseCurlyQuote]s \
happened\
\>", "Text",ExpressionUUID->"1fff0471-9019-4325-ad7d-6a44a2486610"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tally", "[", 
  RowBox[{"flatTopPulseDipole", "/.", 
   RowBox[{
    RowBox[{"_", "?", "NumberQ"}], "\[Rule]", "\[Checkmark]"}]}], 
  "]"}]], "Input",ExpressionUUID->"b8ec5a31-61c4-4000-864a-742638bd44ce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Checkmark]", ",", "\[Checkmark]", ",", "\[Checkmark]"}], 
     "}"}], ",", "721"}], "}"}], 
  "}"}]], "Output",ExpressionUUID->"af9de8de-e03b-4efb-9039-e3ec987e576c"]
}, Open  ]],

Cell[TextData[{
 "and if the function is returning non-numeric values, it can help to fiddle \
with the ",
 StyleBox["PointNumberCorrection", "Code"],
 " option."
}], "Text",ExpressionUUID->"c2036a60-9458-41e1-a99b-9c6e591f80ec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  "PointNumberCorrection"}]], \
"Input",ExpressionUUID->"6ff538e1-5b28-47a8-9470-f218c2ce04e3"],

Cell[BoxData[
 StyleBox["\<\"PointNumberCorrection is an option for makeDipoleList and \
timeAxis which specifies an extra number of points to be integrated over, \
which is useful to prevent Indeterminate errors when a Piecewise envelope is \
being differentiated at the boundaries.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->
  "Info-e56f1197-4157-4650-abf0-7b6fc5088cab",ExpressionUUID->"94d46383-77cd-\
420b-9244-d8dfe96d549e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nondipole case", \
"Subsubsection",ExpressionUUID->"9350f1b0-5263-437f-bcd8-94cb7466d338"],

Cell[TextData[{
 "The numerical ",
 StyleBox["Preintegrals", "Code"],
 " can be used in the nondipole case but they\[CloseCurlyQuote]re obviously \
much slower. The number of preintegrals to find numerically increases from \
two in the dipole case (",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Integral]", 
    RowBox[{
     RowBox[{
      StyleBox["A",
       FontWeight->"Bold"], "(", "\[Tau]", ")"}], 
     RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}], TraditionalForm]],
  ExpressionUUID->"709a6ddc-f6b7-4ee6-8f9e-3820c795a6dd"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Integral]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       StyleBox["A",
        FontWeight->"Bold"], "(", "\[Tau]", ")"}], "2"], 
     RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}], TraditionalForm]],
  ExpressionUUID->"8539784b-3e8f-4fa6-848c-127a5e49cca4"],
 ") to eight with the nondipole contributions, three of them parametrized by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "'"}], TraditionalForm]],ExpressionUUID->
  "053d26ea-3959-4cf8-aac8-c7aa3bd4c2b9"],
 ". The main load, however, is not in numerically calculating these integrals \
via ",
 StyleBox["NDSolve", "Code"],
 " constructs, but rather in the added strain of accessing the preintegrals \
as ",
 StyleBox["InterpolatingFunction", "Code"],
 " objects once they\[CloseCurlyQuote]ve been calculated, from the main \
integration loop.\n\nThe numerical preintegrals for the nondipole case should \
currently be considered experimental."
}], "Text",ExpressionUUID->"b5485ffd-ede8-4879-b0ee-5ec3a2a9af15"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"numericallyIntegratedNonDipoleCaseDipole", "=", 
    RowBox[{"makeDipoleList", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["F", "\[Omega]"], 
            RowBox[{"envelope", "[", "t", "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
          "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"VectorPotentialGradient", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"k", " ", "F"}], "\[Omega]"]}], 
              RowBox[{"envelope", "[", "t", "]"}], 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
            "}"}]}], "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}], ",", 
         RowBox[{"F", "\[Rule]", "0.055"}], ",", 
         RowBox[{"envelope", "\[Rule]", 
          RowBox[{"cosPowerFlatTop", "[", 
           RowBox[{"0.057", ",", "8", ",", "16"}], "]"}]}], ",", 
         RowBox[{"k", "\[Rule]", 
          RowBox[{"\[Omega]", " ", "\[Omega]"}]}], ",", 
         RowBox[{"\[Alpha]", "\[Rule]", 
          RowBox[{"1", "/", "20"}]}]}], "}"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"TotalCycles", "\[Rule]", "8"}], ",", 
      RowBox[{"Preintegrals", "\[Rule]", "\"\<Numeric\>\""}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Beep", "[", 
  "]"}]}], "Input",ExpressionUUID->"2ee4a8b1-b7cd-4aca-9fa0-dbd72add4f07"],

Cell[BoxData["\<\"Fri 13 May 2016 17:20:24\"\>"], \
"Output",ExpressionUUID->"83703ef0-9b66-4a90-b87d-6d36dabb4356"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"146.097378`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"0dea7bef-1dda-4abd-acbb-948304ac0af7"],

Cell[BoxData["\<\"Fri 13 May 2016 17:22:50\"\>"], \
"Output",ExpressionUUID->"7f27aa15-bb2b-49d7-a2e7-e07a682c661a"]
}, Open  ]],

Cell["\<\
This requires some attention - currently taking too long to calculate.\
\>", "Text",ExpressionUUID->"f6717032-91eb-4bf4-bc45-f67da2fd6344"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spectrumPlotter", "[", 
  RowBox[{
  "getSpectrum", "[", "numericallyIntegratedNonDipoleCaseDipole", "]"}], 
  "]"}]], "Input",ExpressionUUID->"b4f286cb-b259-4f77-bdee-01728ab4430e"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     Thickness[Large], LineBox[CompressedData["
1:eJw1lglczPn/x0OXKAptOlRzNlfXdE7HvGaaiXKzyX0tkiMl5I9ciwppKy2h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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->800,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 45.87222222222222}, {-16.184261577601433`, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"b5c4315a-aff3-47d7-9c98-0c4cf023f7c2"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Parallelization", \
"Subsection",ExpressionUUID->"c68d9034-c433-4f96-9621-f1cfd0c598d8"],

Cell[CellGroupData[{

Cell["Parallelizing single instances", \
"Subsubsection",ExpressionUUID->"d7c86541-8ed2-4065-911b-d61b2c6419c6"],

Cell[TextData[{
 "For faster evaluation of a single instance, it is possible to parallelize \
the evaluation, by adding the option ",
 StyleBox["RunInParallel \[Rule] True", "Code"],
 "."
}], "Text",ExpressionUUID->"89a246d8-5b55-4a4d-a0cf-6de9f68a4cd2"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{
   RowBox[{"directDipole", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["F", "\[Omega]"], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
          "}"}]}], "]"}]}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"F", "\[Rule]", 
          RowBox[{
           SqrtBox["10"], "0.05"}]}], ",", 
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
      RowBox[{"PointsPerCycle", "\[Rule]", "400"}], ",", 
      RowBox[{"RunInParallel", "\[Rule]", "False"}]}], "]"}]}], ";"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{
   RowBox[{"parallelizedDipole", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["F", "\[Omega]"], 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
          "}"}]}], "]"}]}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"F", "\[Rule]", 
          RowBox[{
           SqrtBox["10"], "0.05"}]}], ",", 
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
      RowBox[{"PointsPerCycle", "\[Rule]", "400"}], ",", 
      RowBox[{"RunInParallel", "\[Rule]", "True"}]}], "]"}]}], ";"}], 
  "]"}]}], "Input",ExpressionUUID->"fe70fbcc-fb68-4a77-9e45-96d6316603ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"50.712111`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"68dfdc0d-e928-4bff-ad29-af19fbb4c6b5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"52.868135`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"914cf332-d231-45d2-acaf-87fa2e670285"]
}, Open  ]],

Cell["\<\
NOTE that this requires further attention - it appears that the \
parallelization is not working at the moment.\
\>", "Text",ExpressionUUID->"0e2d7c95-56c2-469c-9952-487e1479e9b0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"spectrumPlotter", "[", 
     RowBox[{
      RowBox[{"getSpectrum", "[", 
       RowBox[{"directDipole", "\[LeftDoubleBracket]", 
        RowBox[{"1", ";;", 
         RowBox[{"-", "2"}]}], "\[RightDoubleBracket]"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "False"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Darker", "[", 
        RowBox[{"Blue", ",", "0.15"}], "]"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"spectrumPlotter", "[", 
     RowBox[{
      RowBox[{"getSpectrum", "[", 
       RowBox[{"parallelizedDipole", "\[LeftDoubleBracket]", 
        RowBox[{"1", ";;", 
         RowBox[{"-", "2"}]}], "\[RightDoubleBracket]"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "False"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Darker", "[", 
        RowBox[{"Blue", ",", "0.15"}], "]"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}]}], 
   "\[IndentingNewLine]", "}"}], 
  "]"}]], "Input",ExpressionUUID->"b0605beb-b20a-4387-968a-a9bbcfbfacce"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.009166666666666668], 
         AbsoluteThickness[1.6], 
         RGBColor[0., 0., 0.85]], 
        PointBox[CompressedData["
1:eJw1lglYTesax5NIShmiIlR7N0tza7Vrt/97194KqUiOQ8hBhq4iJMUlSmXq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         "]]}, {}}}, {}}, {DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 45.77}, {-26.113007042473527`, 3.2877694206965953`}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 600, 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0, 45.77}, {-26.113007042473527`, 3.2877694206965953`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],
   GraphicsBox[{{}, {{{}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.009166666666666668], 
         AbsoluteThickness[1.6], 
         RGBColor[0., 0., 0.85]], 
        PointBox[CompressedData["
1:eJw1lglYjGsbx9MpJFuFEmmamUqbtqn3LdX8Z5qZRJStM58tSxRKEQ4SsqUP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         "]]}, {}}}, {}}, {DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 45.77}, {-25.344481335180316`, 3.2877694206966064`}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 600, 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0, 45.77}, {-25.344481335180316`, 3.2877694206966064`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}]},
  "RowDefault"]], \
"Output",ExpressionUUID->"7d7bdfdd-6c2b-4956-81aa-ceda2e51e5ab"]
}, Open  ]],

Cell[TextData[{
 "Unfortunately, the in-package single-instance parallelization can be \
unstable on occasion; this is probably due to a bug in ",
 StyleBox["ParallelTable", "Code"],
 " (which can, under enough load, return different results to ",
 StyleBox["Table", "Code"],
 ", in which case results typically differ run-to-run) that has proven so far \
very difficult to diagnose.\n\nIn such cases, the ",
 StyleBox["RunInParallel", "Code"],
 " option takes a third possibility - an explicit set of commands, ",
 StyleBox["{TableCommand, SumCommand}", "Code"],
 ", to use in the iteration."
}], "Text",ExpressionUUID->"6977774e-6f69-4a24-bd28-ece4ad9adfc5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  "RunInParallel"}]], \
"Input",ExpressionUUID->"f8c14c8a-b21e-4bbc-801c-a35e909e4c32"],

Cell[BoxData[
 StyleBox["\<\"RunInParallel is an option for makeDipoleList which controls \
whether each RB-SFA instance is parallelized. It accepts False as the \
(Automatic) option, True, to parallelize each instance, or a pair of \
functions {TableCommand, SumCommand} to use for the iteration and summing, \
which could be e.g. {Inactive[ParallelTable], Inactive[Sum]}.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->
  "Info73668342420-7270520",ExpressionUUID->"54f0b8d4-a632-46d4-8df1-\
25de38ff7b1c"]
}, Open  ]],

Cell[TextData[{
 "This is meant to be used by changing those commands to dud versions which \
can be sprung up later. The ideal use case (in v10 and up) is via ",
 StyleBox["Inactive", "Code"],
 " commands, which return as"
}], "Text",ExpressionUUID->"21b6721e-70ee-43f7-a899-33cbb7456e98"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"makeDipoleList", "[", 
   RowBox[{
    RowBox[{"VectorPotential", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["F", "\[Omega]"], 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
        "}"}]}], "]"}]}], ",", 
    RowBox[{"FieldParameters", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"F", "\[Rule]", 
        RowBox[{
         SqrtBox["10"], "0.05"}]}], ",", 
       RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
    RowBox[{"Gate", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"1", "&"}], ")"}]}], ",", 
    RowBox[{"PointsPerCycle", "\[Rule]", "400"}], "\[IndentingNewLine]", ",", 
    RowBox[{"RunInParallel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Inactive", "[", "ParallelTable", "]"}], ",", 
       RowBox[{"Inactive", "[", "Sum", "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"RBSFA`Private`t", "\[Rule]", "t"}], ",", 
    RowBox[{"RBSFA`Private`\[Tau]", "\[Rule]", "\[Tau]"}]}], 
   "}"}]}]], "Input",ExpressionUUID->"cbe92b55-d8d0-4bf6-aae4-6583773a2949"],

Cell[BoxData[
 RowBox[{
  TemplateBox[{"ParallelTable"},
   "InactiveHead",
   BaseStyle->"Inactive",
   SyntaxForm->"Symbol",
   Tooltip->"Inactive[ParallelTable]"], "[", 
  RowBox[{
   RowBox[{"0.27557830294647306`", " ", 
    RowBox[{
     TemplateBox[{"Sum"},
      "InactiveHead",
      BaseStyle->"Inactive",
      SyntaxForm->"Symbol",
      Tooltip->"Inactive[Sum]"], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"56.718523228976515`", "\[VeryThinSpace]", "+", 
             RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "48.665399510132026`"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
                    RowBox[{"48.665399510132026`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], ")"}], 
                  "2"], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                    RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
                  "\[Tau]"}]]}], "+", 
               RowBox[{
                FractionBox["1", "2"], " ", "\[Tau]", " ", 
                RowBox[{"(", 
                 RowBox[{"1.`", "\[VeryThinSpace]", "+", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "48.665399510132026`"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
                    RowBox[{"48.665399510132026`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], ")"}], 
                    "2"], 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                    RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
                    "\[Tau]"}], ")"}], "2"]]}], ")"}]}], "+", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"7.694675284702987`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.5`", " ", "t"}], "-", 
                    RowBox[{"4.385964912280701`", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"0.114`", " ", "t"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{"7.694675284702987`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.5`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "-", 
                    RowBox[{"4.385964912280701`", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"0.114`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", 
              RowBox[{"0.1`", "\[VeryThinSpace]", "+", 
               RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]], ")"}], 
            RowBox[{"3", "/", "2"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{
                RowBox[{
                 RowBox[{"-", "48.665399510132026`"}], " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
                RowBox[{"48.665399510132026`", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"0.057`", " ", 
                   RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                  RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
                "\[Tau]"}]]}], "+", 
             RowBox[{"2.773927772077526`", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"0.057`", " ", "t"}], "]"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"0.`", "\[VeryThinSpace]", "-", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"0.`", "\[VeryThinSpace]", "+", 
                 RowBox[{"0.5694100347337419`", " ", "\[ImaginaryI]"}]}], 
                ")"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"0.057`", " ", 
                 RowBox[{"(", 
                  RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "48.665399510132026`"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
                    RowBox[{"48.665399510132026`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                    RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
                    "\[Tau]"}]]}], "+", 
                 RowBox[{"2.773927772077526`", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], ")"}]}], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1.`", "\[VeryThinSpace]", "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "48.665399510132026`"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
                    RowBox[{"48.665399510132026`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                    RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
                    "\[Tau]"}]]}], "+", 
                    RowBox[{"2.773927772077526`", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], ")"}], 
                  "2"]}], ")"}], "3"]]}], ")"}]}], ")"}], "/", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1.`", "\[VeryThinSpace]", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "48.665399510132026`"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
                  RowBox[{"48.665399510132026`", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                    RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
                  "\[Tau]"}]]}], "+", 
               RowBox[{"2.773927772077526`", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"0.057`", " ", "t"}], "]"}]}]}], ")"}], "2"]}], 
           ")"}], "3"]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0.`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"0.1`", "\[VeryThinSpace]", "+", 
             RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{"0.`", "\[VeryThinSpace]", "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"0.`", "\[VeryThinSpace]", "+", 
               RowBox[{"0.5694100347337419`", " ", "\[ImaginaryI]"}]}], ")"}],
              " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"0.057`", " ", 
               RowBox[{"(", 
                RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "48.665399510132026`"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
                  RowBox[{"48.665399510132026`", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                    RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
                  "\[Tau]"}]]}], "+", 
               RowBox[{"2.773927772077526`", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"0.057`", " ", 
                  RowBox[{"(", 
                   RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1.`", "\[VeryThinSpace]", "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "48.665399510132026`"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
                    RowBox[{"48.665399510132026`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                    RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
                    "\[Tau]"}]]}], "+", 
                  RowBox[{"2.773927772077526`", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], ")"}], 
                "2"]}], ")"}], "3"]]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0.`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", 
            RowBox[{"0.1`", "\[VeryThinSpace]", "+", 
             RowBox[{"\[ImaginaryI]", " ", "\[Tau]"}]}]], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{"0.`", "\[VeryThinSpace]", "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"0.`", "\[VeryThinSpace]", "+", 
               RowBox[{"0.5694100347337419`", " ", "\[ImaginaryI]"}]}], ")"}],
              " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"0.057`", " ", 
               RowBox[{"(", 
                RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "48.665399510132026`"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
                  RowBox[{"48.665399510132026`", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                    RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
                  "\[Tau]"}]]}], "+", 
               RowBox[{"2.773927772077526`", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"0.057`", " ", 
                  RowBox[{"(", 
                   RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], ")"}]}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1.`", "\[VeryThinSpace]", "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "48.665399510132026`"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", "t"}], "]"}]}], "+", 
                    RowBox[{"48.665399510132026`", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                    RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
                    "\[Tau]"}]]}], "+", 
                  RowBox[{"2.773927772077526`", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"0.057`", " ", 
                    RowBox[{"(", 
                    RowBox[{"t", "-", "\[Tau]"}], ")"}]}], "]"}]}]}], ")"}], 
                "2"]}], ")"}], "3"]]}], ")"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\[Tau]", ",", "0", ",", "165.34698176788382`", ",", 
        "0.27557830294647306`"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
    "t", ",", "0", ",", "110.23132117858921`", ",", "0.27557830294647306`"}], 
    "}"}]}], "]"}]], \
"Output",ExpressionUUID->"b27f428e-ce1e-4fe9-ad86-0004a0695908"]
}, Open  ]],

Cell[TextData[{
 "and which can then be sprung into action using ",
 StyleBox["Activate", "Code"],
 ":"
}], "Text",ExpressionUUID->"217b5206-3d76-4c35-ade3-46917cd9acbc"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{
   RowBox[{"postActivatedDipole", "=", 
    RowBox[{"Activate", "[", "\[IndentingNewLine]", 
     RowBox[{"makeDipoleList", "[", 
      RowBox[{
       RowBox[{"VectorPotential", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"t", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             FractionBox["F", "\[Omega]"], 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
           "}"}]}], "]"}]}], ",", 
       RowBox[{"FieldParameters", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"F", "\[Rule]", 
           RowBox[{
            SqrtBox["10"], "0.05"}]}], ",", 
          RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
       RowBox[{"PointsPerCycle", "\[Rule]", "400"}], ",", 
       RowBox[{"RunInParallel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Inactive", "[", "ParallelTable", "]"}], ",", 
          RowBox[{"Inactive", "[", "Sum", "]"}]}], "}"}]}]}], "]"}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"spectrumPlotter", "[", 
  RowBox[{
   RowBox[{"getSpectrum", "[", 
    RowBox[{"postActivatedDipole", "\[LeftDoubleBracket]", 
     RowBox[{"1", ";;", 
      RowBox[{"-", "2"}]}], "\[RightDoubleBracket]"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "False"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Darker", "[", 
     RowBox[{"Blue", ",", "0.15"}], "]"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], 
  "]"}]}], "Input",ExpressionUUID->"a7e83c8d-1bb7-4e81-90b9-a8dfc946e8e3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6.14601`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"26ccb9a7-3ab3-49b0-bdaf-39ba65cbf7f0"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0., 0., 0.85], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1lglYjHkcx1GsSHJ2iGaa0aG7qXmnY5rvTDNTchU2R7TlaEOkJFG2UK7K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      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->600,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 45.77}, {-25.197568865019683`, 3.2877694206964945`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"b40b63b9-12ef-4aad-8c3c-4fc38bfde26b"]
}, Open  ]],

Cell[TextData[{
 "This looks like it shouldn\[CloseCurlyQuote]t change anything, but it can \
help fix a noisy ",
 StyleBox["ParallelTable", "Code"],
 " output. It can also, inexplicably, be rather faster than the in-package \
parallelization. (For a cleaner example of the latter, see ",
 ButtonBox["this mathematica.stackexchange question",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://mathematica.stackexchange.com/questions/111448/paralleltable-\
behaves-differently-when-it-is-run-inside-a-package"], None},
  ButtonNote->
   "http://mathematica.stackexchange.com/questions/111448/paralleltable-\
behaves-differently-when-it-is-run-inside-a-package"],
 ".)"
}], "Text",ExpressionUUID->"5994d03d-1c3a-414e-a16f-e5907b8a7019"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multiple instances in parallel", \
"Subsubsection",ExpressionUUID->"18681a5b-c20a-49f7-90f9-e70ac954ffa3"],

Cell[TextData[{
 "Alternatively, one can also parallelize over each run by using ",
 StyleBox["ParallelTable", "Code"],
 " and similar commands. In general, this requires some careful handling of \
contexts; in this package this has been resolved by calling"
}], "Text",ExpressionUUID->"b6c89be4-ce3d-4e39-99fd-e60072eb023a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DistributeDefinitions", "[", "\"\<RBSFA`\>\"", "]"}], 
  ";"}]], "Input",ExpressionUUID->"70635c8f-2d4c-4a27-b1d6-a421eb351c05"],

Cell[TextData[{
 "at the end of the package, which should pre-load all the RB-SFA definitions \
into each subkernel as it is launched, even if a kernel dies or is \
re-spawned. If parallelization seems not to be working (calculations taking \
too long and using a single core), there is a chance that the parallel \
kernels are returning the ",
 StyleBox["RBSFA`", "Code"],
 " functions unevaluated to the main kernel, which is then doing the work. \
This can be diagnosed by inserting an appropriate print statement of the \
$KernelId to force the calculating kernel to identify itself (0 for the main \
kernel, >0 for subkernels), and it can be fixed by suitable use of the ",
 StyleBox["DistributeDefinitions", "Code"],
 " function and the ",
 StyleBox["$DistributedContexts", "Code"],
 " variable.\n\n\n\nIn addition to this, if a variable or function is used to \
store the results, this must be synchronized using ",
 StyleBox["SetSharedFunction", "Code"],
 " or ",
 StyleBox["SetSharedVariable", "Code"],
 ", as usual."
}], "Text",ExpressionUUID->"3ea11685-3a0e-441d-8a32-87255d840085"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SetSharedFunction", "[", "wavelengthScanDipole", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ParallelTable", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"wavelengthScanDipole", "[", "\[Lambda]", "]"}], "=", 
       RowBox[{"makeDipoleList", "[", 
        RowBox[{
         RowBox[{"VectorPotential", "\[Rule]", 
          RowBox[{"Function", "[", 
           RowBox[{"t", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               FractionBox["F", "\[Omega]"], 
               RowBox[{"Sin", "[", 
                RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}],
              "}"}]}], "]"}]}], ",", 
         RowBox[{"FieldParameters", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"F", "\[Rule]", "0.05"}], ",", 
            RowBox[{"\[Omega]", "\[Rule]", 
             RowBox[{"45.6", "/", "\[Lambda]"}]}]}], "}"}]}], ",", 
         RowBox[{"CarrierFrequency", "\[Rule]", 
          RowBox[{"45.6", "/", "\[Lambda]"}]}], ",", 
         RowBox[{"PointsPerCycle", "\[Rule]", "400"}]}], "]"}]}], ";"}], 
     "\[IndentingNewLine]", "]"}], "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"\[Lambda]", ",", "800", ",", "1600", ",", "100"}], "}"}]}], 
  "]"}]}], "Input",ExpressionUUID->"60fadb57-9c4b-48de-826e-e0d6a238c3db"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"58.536616`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"52324021-31c0-41ce-aea8-a418d19e0437"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"59.330287`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"f019b648-add5-4934-96a2-2b284498a2d7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"60.148893`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"c1ba3650-d629-44f3-803c-d0ee42aa5d35"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"61.479333`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"1f92e08d-df96-47c0-b277-2cdc91b0c0ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"60.505309`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"bc7ad4ee-fd95-4167-930a-1b59f618a469"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"61.483226`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"20604eec-b480-496c-8c0a-d99d2889740a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"61.133371`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"bbe23f69-3153-487d-af71-95f140b37dd1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"61.062454`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"4b50b816-3054-48ec-aa24-60a94c87d7c8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"52.588974`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"1d1f3839-4a8c-436e-9b5e-cc2920b2f93a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "Null", ",", "Null", ",", "Null", ",", "Null", ",", "Null", ",", "Null", 
   ",", "Null", ",", "Null", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"7c1a096b-46dc-454d-9b03-304d6ad229c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"Table", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"spectrumPlotter", "[", 
     RowBox[{
      RowBox[{"getSpectrum", "[", 
       RowBox[{"Most", "[", 
        RowBox[{"wavelengthScanDipole", "[", "\[Lambda]", "]"}], "]"}], "]"}],
       ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Blue", ",", "Green", ",", "Red"}], "}"}], ",", 
         RowBox[{
          RowBox[{"\[Lambda]", "/", "800"}], "-", "1"}]}], "]"}]}], ",", 
      RowBox[{"CarrierFrequency", "\[Rule]", 
       RowBox[{"45.6", "/", "\[Lambda]"}]}], ",", 
      RowBox[{"Joined", "\[Rule]", "False"}], ",", 
      RowBox[{"FrequencyAxis", "\[Rule]", "\"\<Frequency\>\""}], ",", 
      RowBox[{"PointsPerCycle", "\[Rule]", "400"}]}], "]"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"{", 
     RowBox[{"\[Lambda]", ",", "800", ",", "1600", ",", "100"}], "}"}]}], 
   "]"}], "]"}]], \
"Input",ExpressionUUID->"2780c5f1-aa76-4e28-b7d3-6504724dbbb1"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0, 0, 1], PointSize[0.009166666666666668], AbsoluteThickness[
      1.6], PointBox[CompressedData["
1:eJw1lgk0lekfx5Gd7K7t4m4uQtpI8jzvT0OmGKVRo0ZNOSlaSNO0SMrfGDVa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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[0, 
       NCache[
        Rational[1, 4], 0.25], 
       NCache[
        Rational[3, 4], 0.75]], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1lgs4VVkbxznKJZcOx/16LhhF6iOEvfZ+q0nKZbrnlpnyZZJybQxS0lAz
KhVd1TDSDaWoUQhrGOU23Sj5RFGTSqJcUpJvn9Pa63nOc579nPOsvd73////
3iVaF75sPU9OTq6O/Ui/uUUlF4QMzkXY3CtvzthAHpNn7za1JGyw6utzKVP/
3rkjYTGF2z9u33hjSw3j6JwcFDn8jvxez4jyC03dAhF2vBui8LvjXUZZOD6m
9psq+X8z01gz0PNZlcY7JIfutRc/ZH6/6R4jX2xI3tfGWD3Ez459Q+O6mMps
w5kdjOutBuddx03Jfk+Z/ZXZ4x8aaayyfqjkwoMuxueT/LZWJzHZ/xkT1fbC
7qUNjS+mqZg2Cf5l5u60uJbwi4i87wUTGOIVeqUH4WXXTVN6l75kSnRW6HUe
EZL3v2IyVVasfNvA4JEu+zdTDvQySuVzdIMDxeQ8fYyTmWW3ZwXCJ1QXLZ9+
+y3TntKUJNkuIecbYBR+WFegeAbhP9jDmyu+YyrLike9sIic9x1z09fijEkp
wlGXSg/MPvOe6XHv6h6asCDnH2SyvfKvVrvQ+FvZGmKisjTicnhiUs8wwzxO
Tj93hca6bbc/LH82zFyse3HWKVZM6hth9rzpMBtsQfjVZt+CoJ0fmF339PzH
eiSk3lHm9WXR9B8MaFzOex4YLfrIFCpZXszvtyD1f2RmZ85M7vyOxvuOhmn9
gj8xuQ650UnBVqQfY8zD1KmTxKkIf2/zsTb9+8/Mg53aFXkO1qQ/40zGjQOl
vDCE7f76Je7Ul3Hm8VPbZH9vW9KvL0yG7j6nBTcQnrRKY0bx7xPM6dfv+vWa
Z5H+yYGPfbQkmO1f6E+eAz9kyUH6ooPNlzLtSD/lYfusM5I6N4RbqjQbXm6W
B9E0b9Fw/GzSX3l4XetVaaJGYzSlNTcC8cDo7pG2xEhH0m8eTHttX9CXTeOz
K05uG1VTgL2euW9ebJ1D+q8AT1dYF5UG0ZifvXb1jscKoDz/+v7QTBeixyQQ
Lt6RnriKxnGvLP+jfGESnEqMO/ieh4g+kyGwrYQKX0njbmm7tk6GAr6//Lfz
OL0mw8D5TSNbNWnssb3ouZ6HItSpXinwv8DlQRFSQoqvtT1H+KqsoUpArVG9
qb2RJnoqgeHuNN9VZQibCKhj37xWgpnHy2O7j3N+Vobna52pQjka71ojz5as
DLTGqEfTZUT0VgH+XvfgMnb//nM3PZx+U4HRQ3IOds400V8F5LqHWzdNorHv
+z0WVT5TwO/okpb76gzxwxTg+5Wglh4aV1NLJ9ysVCHlMeX9YB9N/KEKGdUe
B07k09h6t7RiVdgk3BxT9Izzixo0Nus1npNnsLTaVbfUIHH62FpnFS7v6rDi
utPTRWY0HjfK2dt5RB2oh7XpF/Vp4id1ELiOjp4eQjhYtjSgvanoWoQHl0cN
yJtrc3l/EcJ3LlvDW4ep0OO/5+SdLxTx21SYiDpXRl1EWKp+OY8P220Gc045
crziQ+j2QwKVGhrfE0sdwYen+Xu9PHNp4kc+VLiNnBhNQnhyXcWLeff5sDbN
bqGtNZd3TYgamtE3pI2wy+Y/mhVdNCGpNm2L0JHzqyY8SCrqDcIIS7vZkKMJ
0d84eupPIOJfTRhNVS7o1aJx7rX1rKW0IC3oYcWTfkT8rAXN/6rdnTyO8KMA
98xlkVpQkUDlKQfQxN9aEGSeHF7bQWM1nlQBLVArr+rkq3N+F8AAP95ulPX3
3HPqW/4HAiip2HT85SOa+F8AV63krgYdRlhW7nkBPDnmc/VWPiJ5EECn+aH5
MScQzn9332sdXxtUVqsmidi8f82HNhzxt7pWex/hziN/uljGasOogKd8kD3v
17xoQ3v3hjuSvxGW2feJNqTc3fjEfA7Hax3w1FT0NO1F2L0rXrtwoQ5MBN5S
Wsbq9TVPOqBNteYmdyCcIDO4DlCOj84qjiCSLx3wquRbzslicJFUfj1d8Omu
Tvx8AZG86QJWzTU6Wonwv3elAuvCzwHeK1c6cPnTBc3wKnWhK40NY6QK68Lb
V6sLYSdN8qgHMMx7PMH209vo5dUkbz04HxPRSh3meKsHrXMs45vY/aXqLijR
A9o9/f2HBC6v7LOP7c872TzK5DXVBwsdm4+F1lx+9aGvxiU4/iDC0mr/SdEH
25t/HXKNRiTP+jDA7NXsPktj0eWoDQf79OHks1mGl7I4nhtAfUReaZ8+witl
ywD80h5fMgAu7wYwU6OppY99Tv3kNM+gwgAqR3hvzi/g5r0B3KDXHP5ix2DZ
9DU3hN7o3TuUkzgeGEK/o42CC8uvwW+lCTWEo9nGbZOKuXlhCNEpBUtyxxBm
xVVeP2QIi1vuJQYFcbwwgrhij3C4jXDA/uphqwAjKMw43HjrO0T4YQQZtxc+
Wnoa4YOzz3S/qTGCj9EChet9iPCE/X1DjEBI0bi2bTcbcWOYcrZ6XqAyxxdj
8J4fd2nGIoQ/Se2cYQzPR+Ti27oowhtjsBPGLk1wR9hWVrAx3D/ZME8vguOP
CYyujOo3W0vjoPqZRz6vM4FcVDTe8TMiPDIB9cSd7/OyEZaV22ACZcfO/HOq
iJt3JrAj4M/wJ+Y0Zmd1eLKdKTC7/tFvL6AJr0xh+8j9nhlsvXKlrWyCTSHc
PuxLfTfHL1MYb8vpcmX76xBYtkiNZwbW/u3ym2xpwjMzWNro8MGT5cdG6e0q
xAxMA0OVrO1pwjczMEiw8J3G5i/rfCLraDNw/Vu3KVlEE94JIe4atWcglvWr
NI7GQmj+21M+a5Am/BMCXivIeuOLcDJbzb4lQsirXJexKxcRHgrBomMB9SoF
YVNZgUK48deXHy82cPNaCLVh/p0i9n4gs/N1IbQHv1yd6MfxUgiN9Zl5fDYv
yyKliguhEPaOTvPh+CmCrl9p+DMK4b6aHx/pCEVgVvtHztZImvBUBDvmJm4L
30BjmR2Wi2DBT9NvPW3i+CqCaceW+975CWFRyGLWIiLIOhm9xZfheCsCOkJn
jLpC4Rvl0iWCMrFbwCWaIvwVQeJ/MOWsR2FZO/tFkJFZs3vYlCI8FoOf+ulC
JpLCUjomSsSAXjsdCtvG8VkMCo9slgfsp3DqlaksMcWQkrX1WZoORXgtBkWq
jqodcMUWikmH5+8RA2+qc1GMgCL8FkNxzjvdqg0UrvKRBk4MdqOfZhkNU4Tn
YvivPx4PY/svuw0MikEUMjj9dBjHdwk4r6mM8K6n8dB4S+wrSwnMjky/XpnM
8V4Cyc83BvjPpHHaErfwRj8JhB4LjZj8K8d/CYQl/Zo3pkBjK1nBEtBYEj8l
NZYh80ACPqmJC2t/ZPPMpnd/tQQisx0Uex9y9yUJCP12b7AvRHiNtNwRCTBn
s29urOLmhTkYll+hQ08i/CFTanhzWG0vSi9h+fp/psPZkw==
       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[0, 
       NCache[
        Rational[1, 2], 0.5], 
       NCache[
        Rational[1, 2], 0.5]], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1lgs4lNkfxxlU5Na4zzBmRFFE0UbmvOenQiVtSDGJrpu0LEJtF7IVuimV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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[0, 
       NCache[
        Rational[3, 4], 0.75], 
       NCache[
        Rational[1, 4], 0.25]], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1lgk01VsbxjnmKbNjHkOllJuLyt77TVQuqeuEkqFLpXRLuXIrQtKASjLE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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[0, 1, 0], PointSize[0.009166666666666668], AbsoluteThickness[
      1.6], PointBox[CompressedData["
1:eJw1Vgk41Vkbt+/7cl1cPoSUaxs7/c95bZWRokWaaoqi5Uua+EpKQzOKSmiZ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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[
       NCache[
        Rational[1, 4], 0.25], 
       NCache[
        Rational[3, 4], 0.75], 0], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1lgk4lWkbx61ZjnJwNkfKerIVSmXC+9wVLZYSEqUFaYZvtMenqDTIUpZK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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[
       NCache[
        Rational[1, 2], 0.5], 
       NCache[
        Rational[1, 2], 0.5], 0], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1lgk41Nsbxy2DrDOGMXT1KI1BRWWpxJzzFir64xZpUTdXliQtlpYrW3VL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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[
       NCache[
        Rational[3, 4], 0.75], 
       NCache[
        Rational[1, 4], 0.25], 0], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1lglYjNsfx9unvZlpKpQuVzWTsrWL95wfpSikhUS4KFESbomQtYh0659k
aVW4yU1lK6JjaSWlkCVdUlJxb5sWLe47/mfe55lnnnlm5n1/5/f7fD/nTFwX
5OYrIyUlVc6+xO+S6+bg/tS5pxhS8seM0CkTU7G9tjXnzWBv8f8/X8WCjrmv
u6Rmk+cmvmOblt/CesWyRzjR3fT7Yvzl8fWona6zydvBcP+i4If4gfWpj9tG
FOjvy/Bx93kXuKcZ8mSVczmHeYxN/D2N7K4I6POq8dfWgQsJZoj8/V4lPuvg
M2xo9WBcXdEv9H51uDxAT112OiL1/O451Rte4FM3219H3zWg96/Ha+UnupZk
IlJj/6qz1+k1Ptxf/MAmyoA+7y12meVzeP9viFTsuJc6bto7vGVPfuj3AgP6
/L+xb4Dl93sfEVnr4SZMi3qP5WLSVxhzDGk9H/Afk51/tMchsiqwZDR/dxPG
3/kZYwtFtL6PODhh1MHoHiJekTYvSwKbsdJdvHmKyIDW24Krs/DpgWRElqVm
//VqzSd8fMHJxTtXTqL1t2LeCvOsWrZ+twL9iA7Xz1g1r/mNWvwkup42PGki
d7h8LiKLn8V5j9q1424pbywVbEjX14E5vjOPt0pj4twuZ8Gz+oLjPPNdkkIN
6Xq/4shP63x83RBxlN2pYiD6B+/8dCMvW9+Qrv9fvLXJouzrB0R+jQnZpqvW
ib3eWUeVloloPzpx9hVjubowTNLY5hkodGElq7J+kbekP1244d/GgeBBRPQv
fZ4/9UcXNl/FUVPLNKL96sYJJ5R+ZLL/TzI/f916oBtHcjy7M6QMaf96sKXj
jJIzapiMIysnzOnqwcwJu2kpLka0n7040ejaQ58+RE4v1Ip2au/FjdYbU7Os
jWh/v+Hh7pzjhWcQ0Xn9tN/94ze8Iyz8tj9XSPvdhyseVa0fuYZIgu/R9asa
+nBO7ijuSjei/e/Hf1zYBOkTMNH8iVc/TgtZ1xg0YkjnMYAPrlZ9F7YQkbjw
IdutTwfw/UY9T1WeMZ3PIDa/cyTZqwQTDZUbF3eVDeIFG8K/jpkrpPP6jteN
mOaW3kbkROIW/iHyHYenHurR+mhE5zeEd1w1ey5IwIQdTnh04RB2bXDiGVw1
pvMcxu6B26pgLibHcj+0JeQP48l37DWsho3ofEfw9oCxph7bMVFkzi1NzR7B
n8o/n9vsLaLzHsW2hyerX1fCJLLC4/6fmaP4VrXuA7V9Qjr/HzjYsdT7UBMi
csvUp+Qn/8Av5j+Z3v5BSHmQgm/rz4TWJyEyp2s9W7IU5O9sGjpSJ6R8SIFS
6nrtnmOI7L8FB5vKpGCJsMj9iUBEeZGGM8nnOw2XY1K8d7yNn7005AcdXjO9
UEj5kYbYWZX6r4oRYXv1tYNIgwc/rdba0JjyJA1NJp4Of/oiwijXZ2xlZGBV
w4XqzEgh5UsGMg6YL335FyJ7a655fSuUAceW6trETmPKmwzEXWSS548iUnQq
ViPMShamrxwOblaV5FcWHpblFLwQYjLkLb6hLHg6rh1neUtIeZQFByHjco9B
xHaS0+5D0+QgcNlvGT7PjSmfcjCIG67NVURkV5vRDMUrcjChvWf1gTwR5VUO
nrcf2ZCrjkjBVdnWaJE8nFLkLhKmCSm/8nBG+lLglh6G9Ie8T+JdkIe8ES/1
ggQh5VkefEqtXrxh1281+67bqYkKsH9GQv4xBRHlWwESFj7614/lP0TmrKJu
igJ4LRzyGlMporwrwIf/2Saf6MfkerkYGA6EZttfdqgypvxz4NnTTKHPRkR6
YtyDDRI5sLEjX69VzoTmgQPqtk+CLRZgYrZ0+uQsTUWwPvCeG7fJlOZDEaYl
cXwaViHCwvJ+Sqwi5FtGFvV8m0LzogiNeNfMQgVM8sT4qirB0mkVZzkXp9H8
KMGkvTmyykaIdF4qdbaOUoJBacvfXe5Mp3lSgl961iaLyhCZtiVDukheGeLO
6o7E5c+g+VKGoDdTbaY0MmSLhZhAZYCMUtmCW2Y0b8ogszCoNaUXkb++iwes
DAVyUyzrK8xp/lTgTfbpk7elEPlCZrITVoGkez6Gws8WNI8qcN/EwvO1GiIm
R7TZiagAvrndT4lvRfOpCn2hZLXPd0T8F4k7qAq58cNkl4M1zasqbBT2a3k/
ZEiWpnjFqqB/vmVoNMKG5lcN2p6am6g5IfL59RW2QjUIdd/7OOfpTJpnNSg6
cG+3jzMibNjYO6qBOT6DHXRn0XyrQ4dV5xM9F0Q2/LzUQUXGNaLi6Gyad3VY
gzuETCYmF0zt9Dqa1MHrzexm/0zJfq8BNpmx8oIdiLR0/1IbtEYDXnomL4mO
lfhAA0IWeGjbDmBiUDh8pPetBrgtOpkWsgtTP3AhovJKRwk7v7ziLymzTbkQ
WXHoHyuRxBdcGMfJceuyA/LsV3HiuOCxz0iQvkmy33LB+p7zr9KbGdIZIS6Y
C8X7ZIFbyFCfcGFfXad+gTki3LZbbIK40Ll8gU7WVUT9woOqczUtc80ZMn3h
RWUHQx7sqvcb+jGVob7hwbDm290p3gxxuXqSTQQPJpxVEhndZah/eDDoZb3Y
woIhQSwtlek80PRPHVAwYKiPePDIb86LJDeG/Fzuex7YtMOr3G6G+okHJotC
B4pbGJLzas0OF30+VAfnjK1oY6iv+HD8Tu2eh5UMqZolJpYP7r9ftnsZhKm/
+KC18TanWwGRr2z3np/lQ/zwledzrkt8xofGm4X1avMQUZURE8iH8SXBjnXd
iPqND6LakEVJNYiYiuOsownuixvaujdJfKcJjV7NzaU7ERHTfm6pJlQ+fRVu
thtT/2nC1Lfl0HcHkwCTvsR38Zqw5/bMolxbRH2oCScunl6Zzp5fjsU0s4Ro
QlWdrpJREKJ+1IT17TUK0S2IXO6qXbSOKwCXofTJfGmJLwVg6SS9y9YYkUox
josFoJvSvVHPWnJeEkDM77ejlz9B5Od4owWwJnmtllkMQ30qgEQ991ZL1u9K
uimrjR8LYOX4zOzATwz1qwBgbMmtviGGiNMaoKQFsQU3pD1HGOpbLZhXPcPN
cisi8z+ECXIctaCtcnTdXQ3JeVILnJUDKtfxEfGz3xTUGaEFy8rPHz1/H1Ef
a4Fx8Yovhg8YcuSSZ6XZIy0w9bf9fLNKct7QgndFpFetABExfSEy2tCSYaay
OUDia23YZueyMq+TIaWBYkFpw7ua7fpO3pLzoDZ88ajXfxXP5q9GHBBtMHH0
L5roJ/G5NgSsMPDesg8RedY2s+9qw1Qdnalfx0vOM9qsP12LXY+y+Uz8ERs+
pA2ufktWmvRKfK8Ddt7Lrc+x/bUX4zxTB5wDdzfu9ULU/zqwpM7VYzNg4rOq
wUF2pw7MiZm1VfMy0P1ABwbSvO94sOc7cTrm3dQBe9lDD1rDEN0fdCAsKi9+
Bg+TjEliQehAxLuwTwvKEd0vxkCU6OjBJjlMHkSKGzgGVkTYn91zA5H/ANvj
3Lo=
       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[1, 0, 0], PointSize[0.009166666666666668], AbsoluteThickness[
      1.6], PointBox[CompressedData["
1:eJw9lgk4lWkbx3Hs6znHOaqZMtZzji18RcJ5ntso1IwslWH4mpRENUmWkYqW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       "]]}, {}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->800,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 11.343}, {-32.75934621029835, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"c31f80bb-06de-44f9-a41f-40e0cd531911"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Writing output to file", \
"Subsection",ExpressionUUID->"33b9f218-584d-43d7-b49f-770959d68a78"],

Cell[TextData[{
 "For very large calculations (many integration points per cycle, in \
particular), the limiting factor is available memory. In these situations, it \
can help to write the data directly to a file on disk. This is slower (by a \
factor of about 2) but it has a roughly constant RAM footprint, so it enables \
calculations of a bigger size than would be possible otherwise. (Of course, \
this can also be done from non-parallelized calls!) This is done via the ",
 StyleBox["ReportingFunction", "Code"],
 " option:"
}], "Text",ExpressionUUID->"3123d7c4-e727-4c3c-855d-d24b3a069ca6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  "ReportingFunction"}]], \
"Input",ExpressionUUID->"a1165a1e-2c83-468e-9c67-d97c0dcd49d0"],

Cell[BoxData[
 StyleBox["\<\"ReportingFunction is an option for makeDipole list which \
specifies a function used to report the results, either internally (by the \
default, Identity) or to an external file.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->
  "Info3652203643-1090000",ExpressionUUID->"7e664114-1083-40ae-862f-\
36558083f068"]
}, Open  ]],

Cell[TextData[{
 "In essence, the integration loop consists of a ",
 StyleBox["Table", "Code"],
 " construct, which goes over the time ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "fe3410b8-ce1f-4b0e-91fc-1f162ed47b46"],
 " at which the integral is performed, and an inner integration construct. \
Setting an option ",
 StyleBox["ReportingFunction\[Rule]f", "Code"],
 " interposes the function ",
 StyleBox[" f ", "Code"],
 " between these two steps, as\n\n        ",
 StyleBox["Table[  f[  integrator[t]   ]    , {t, tInitial, tFinal}]", "Code"],
 "\n\nThe default is ",
 StyleBox["f=Identity", "Code"],
 ", which returns its input untouched, but it can also be replaced by a ",
 StyleBox["Write", "Code"],
 " construct that can shunt its input to the hard disk without telling the \
kernel what it is, so it is not kept in memory."
}], "Text",ExpressionUUID->"ac4dc021-d1c9-4f51-abec-fbefcc183b65"],

Cell[BoxData["Quit"], \
"Input",ExpressionUUID->"3b732c12-3b2c-4d22-8930-ea4ab39555b1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"directory", "=", 
   RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"filename", "[", "F_", "]"}], ":=", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{"directory", ",", 
       RowBox[{"\"\<Field scan data at F=\>\"", "<>", 
        RowBox[{"ToString", "[", "F", "]"}], "<>", "\"\<.txt\>\""}]}], "}"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ParallelTable", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"makeDipoleList", "[", 
       RowBox[{
        RowBox[{"VectorPotential", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"t", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              FractionBox["F", "\[Omega]"], 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
            "}"}]}], "]"}]}], ",", 
        RowBox[{"FieldParameters", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\[Omega]", "\[Rule]", "0.057"}], "}"}]}], ",", 
        RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}], ",", 
        RowBox[{"PointsPerCycle", "\[Rule]", "400"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"ReportingFunction", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"Write", "[", 
           RowBox[{
            RowBox[{"filename", "[", "F", "]"}], ",", "#"}], "]"}], "]"}]}]}],
        "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", "]"}], 
    "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"F", ",", "0.05", ",", "0.2", ",", "0.025"}], "}"}]}], 
  "]"}]}], "Input",ExpressionUUID->"433d3763-3272-4b3f-9b05-dee8885962db"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"61.072836`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"6a0c7eab-8ba3-4083-97af-3a8d3175aa79"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"61.68875`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"de19d6c9-bb01-45a0-820e-1ae8851326f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"61.903233`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"ecca53d5-fe41-47aa-9558-5525fe74b976"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"63.909191`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"00738bff-c8a7-4712-9718-79f288b4b61e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"54.008285`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"9a2d8341-b2fb-446f-aa44-4ebf7c769e96"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"55.151061`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"40b5eb07-a118-4f96-9b3e-9e927df7d80d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"55.122707`", ",", "Null"}], "}"}]], "Print",
 ShowCellLabel->True,ExpressionUUID->"0725d91a-abd1-4925-b6ba-23ae3cfbdef6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "Null", ",", "Null", ",", "Null", ",", "Null", ",", "Null", ",", "Null", 
   ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"90d2070e-1344-4998-b7ff-a2abebbfe246"]
}, Open  ]],

Cell["\<\
The data in the files can then be pulled in quite simply using e.g.\
\>", "Text",ExpressionUUID->"ac924fce-1b36-4fab-9ff4-3890033f3a2c"],

Cell[BoxData[
 RowBox[{"Do", "[", "  ", 
  RowBox[{
   RowBox[{
    RowBox[{"intensityScanDipole", "[", "F", "]"}], "=", 
    RowBox[{"ReadList", "[", 
     RowBox[{"filename", "[", "F", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"F", ",", "0.05", ",", "0.2", ",", "0.025"}], "}"}]}], 
  "]"}]], "Input",ExpressionUUID->"cf1a642e-19ba-4b37-9a10-16f48c58cbd9"],

Cell[TextData[{
 "This tends to litter the directories by creating lots of files for \
different parameters, so it is usually cleaner to ",
 StyleBox["Save", "Code"],
 " them into a single file, e.g. using"
}], "Text",ExpressionUUID->"13b6ccaf-9a74-4d73-82f4-f82c62b8e99e"],

Cell[BoxData[
 RowBox[{"Save", "[", 
  RowBox[{
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<Field scan collected data.txt\>\""}], "}"}], "]"}], ",", 
   "intensityScanDipole"}], 
  "]"}]], "Input",ExpressionUUID->"d3d16168-1c0c-499e-9df3-853a467c4099"],

Cell["which in turn can then be pulled in using", \
"Text",ExpressionUUID->"bc760ff5-a1cf-41e3-9570-c10c20721aac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", 
   RowBox[{"(", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], ",", 
       "\"\<Field scan collected data.txt\>\""}], "}"}], "]"}], ")"}]}], 
  ";"}]], "Input",ExpressionUUID->"4e5861a9-8586-4af3-a32a-8e07901c0595"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"Table", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"spectrumPlotter", "[", 
     RowBox[{
      RowBox[{"getSpectrum", "[", 
       RowBox[{"Most", "[", 
        RowBox[{"intensityScanDipole", "[", "F", "]"}], "]"}], "]"}], ",", 
      RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}], ",", 
      RowBox[{"Joined", "\[Rule]", "False"}], ",", 
      RowBox[{"PointsPerCycle", "\[Rule]", "400"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Black", ",", "Red"}], "}"}], ",", 
         RowBox[{"F", "/", "0.2"}]}], "]"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "33"}], ",", "5"}], "}"}]}]}], "]"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"{", 
     RowBox[{"F", ",", "0.05", ",", "0.2", ",", "0.025"}], "}"}]}], "]"}], 
  "]"}]], "Input",ExpressionUUID->"f6004cd9-6388-424e-8e48-d85531c757b7"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.25, 0., 0.], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw9Vgs41OkeVi1RCquQ2EbJPSLk7iVMLrkOBoOZMTeppO1UVOJ0s6lNOZay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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[0.37500000000000006`, 0., 0.], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw9Vgs0lekalhJJ41YyhTahpuSIEIkHIXf2lst22Xc2Zqai6aJiq7U6R03X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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[0.5, 0., 0.], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw9lglU01cWxkGgKi4QAVmkCCiLBJVFFBDlYxEUpBD2LWQP0SrFpThC1Fgj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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[0.625, 0., 0.], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw9lgtUjekax5NLyCWZdJV0pDgRXXQx8u9C99tud93Vvl/qzBgxyITZk5Iy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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[0.7500000000000001, 0., 0.], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw9lgtYzOkexyfpIhlFjsKp6aKI0kU3Yb7dVFSaLlM01dxnxJGDdimr0TmH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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[0.875, 0., 0.], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1lgs41Okexydp0XZEsUnsuhSljFCux/pGMRj3y7iEuc+kLa0UWjGVbJet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       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[1., 0., 0.], PointSize[0.009166666666666668], 
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw9lAtYzOkex8fGWWnXkUKtS0lEk0yX1XXrSzem0nS/TTX3iWRUrstmFHLb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       "]]}, {}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->800,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 199.}, {-33, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"3fbc615f-8edb-42ca-b6a5-89703584e7cf"]
}, Open  ]],

Cell[TextData[{
 "As written, though, this has the disadvantage that each subkernel must \
access the hard drive for ",
 StyleBox["every",
  FontSlant->"Italic"],
 " timestep of the computation, which obviously responsible for (at least \
most of) the slowdown. A middle ground is also possible by choosing an \
appropriate ",
 StyleBox["ReportingFunction", "Code"],
 ": a function which will cache a specific number ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "624941de-f448-4e8b-ace1-44e4c6ad8a92"],
 " of results on RAM, and then write them to file all in one go. This is on \
the development to do (wish) list, and will hopefully be implemented soon - \
if time allows."
}], "Text",ExpressionUUID->"5b3f0893-7fe1-4e6d-8bc9-37d1219c37fe"]
}, Closed]],

Cell[CellGroupData[{

Cell["Time and memory use", \
"Subsection",ExpressionUUID->"8b2828a7-36ab-4b40-9e44-5f59e8cda2a6"],

Cell[CellGroupData[{

Cell["Benchmark evaluation", \
"Subsubsection",ExpressionUUID->"3996365f-f69d-4e3a-be8b-981f3b487dc9"],

Cell[TextData[{
 "The benchmarks below were taken on a desktop machine with 8-thread, 4-core \
Intel i7-3770 CPU at 3.40GHz, 16GB RAM, running ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 10.0.1 over Ubuntu 14.04. The time taken per computation depends most \
strongly on the ",
 StyleBox["PointsPerCycle", "Code"],
 " used to sample and integrate, and the dependence is therefore quadratic."
}], "Text",ExpressionUUID->"8d617629-5ebe-4c72-9187-5281f4aac9b3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"timingsList", "=", 
  RowBox[{"Table", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", 
      RowBox[{"AbsoluteTiming", "[", 
       RowBox[{"MaxMemoryUsed", "[", 
        RowBox[{"makeDipoleList", "[", 
         RowBox[{
          RowBox[{"VectorPotential", "\[Rule]", 
           RowBox[{"Function", "[", 
            RowBox[{"t", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                FractionBox["F", "\[Omega]"], 
                RowBox[{"Sin", "[", 
                 RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", 
               "0"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"FieldParameters", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"F", "\[Rule]", 
              RowBox[{
               SqrtBox[
                FractionBox["n", "100"]], "0.053"}]}], ",", 
             RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
          RowBox[{"PointsPerCycle", "\[Rule]", "n"}]}], "]"}], "]"}], "]"}]}],
      "}"}], "\[IndentingNewLine]", ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "100", ",", "1000", ",", "100"}], "}"}]}], 
   "]"}]}]], "Input",ExpressionUUID->"c7d7892f-7623-4dda-bddd-5e3419bbaa63"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"100", ",", 
     RowBox[{"{", 
      RowBox[{"2.361672`", ",", "4905296"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"200", ",", 
     RowBox[{"{", 
      RowBox[{"9.406022`", ",", "19018888"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300", ",", 
     RowBox[{"{", 
      RowBox[{"20.687761`", ",", "43497000"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", 
     RowBox[{"{", 
      RowBox[{"37.246061`", ",", "78976528"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", 
     RowBox[{"{", 
      RowBox[{"57.584723`", ",", "118770848"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", 
     RowBox[{"{", 
      RowBox[{"82.710104`", ",", "173233496"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", 
     RowBox[{"{", 
      RowBox[{"112.081764`", ",", "232621352"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", 
     RowBox[{"{", 
      RowBox[{"150.095825`", ",", "301125912"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", 
     RowBox[{"{", 
      RowBox[{"187.297956`", ",", "387140808"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", 
     RowBox[{"{", 
      RowBox[{"233.122495`", ",", "473885368"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"4ce334b3-cc4c-488c-9fa0-f8b67bcff7eb"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Timings", \
"Subsubsection",ExpressionUUID->"5e6ed078-3203-418c-b728-588d7e95b95e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"timingsModel", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Flatten", "/@", "timingsList"}], ")"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "n", ",", 
       SuperscriptBox["n", "2"]}], "}"}], ",", 
     RowBox[{"{", "n", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Flatten", "/@", "timingsList"}], ")"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}]}], "\[RightDoubleBracket]"}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"timingsModel", "[", "n", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"timingsList", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"timingsList", "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "\[RightDoubleBracket]"}]}], 
        "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]",
    ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Row", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<time in seconds=\>\"", ",", 
       RowBox[{"timingsModel", "[", 
        RowBox[{
        "100", "\"\<(\!\(\*FractionBox[\(PointsPerCycle\), \(100\)]\))\>\""}],
         "]"}]}], "}"}], "]"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<PointsPerCycle\>\"", ",", "\"\<Time in seconds\>\""}], 
     "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], "\[IndentingNewLine]", 
  "]"}]}], "Input",ExpressionUUID->"4b12e076-023f-4f28-8806-ffefdb266e20"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{{100., 2.361672}, {200., 9.406022}, {300., 20.687761}, {400., 
       37.246061}, {500., 57.584723}, {600., 82.710104}, {700., 112.081764}, {
       800., 150.095825}, {900., 187.297956}, {1000., 
       233.122495}}]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVxnk4lAkAx3FbjQdZbVg5yplKTcVWKOz+dDqSQRrDkKvR8JIrUnJNxjnv
tBSpFG1JyG5ZbY3jmZEaPBuylKVjUe4ygwmLtbt/fJ/P18D/lOuJZXJyck7/
9b/9zYr/LQPTDQwF6wAKTMPc68pWM9BUo0vVOkdBgmrxVncjBvK44fsVcynQ
8rJUKTvIgGaOwNXwKQW0cVabG4+BuqThjxbr5VGv0uhyV9sT6bXlg5IReVx1
Szh2ZJcXNlS2uVzlKMDt7eTx68HeSI/jtbZMrIQ4OFzPRNsPmnKFyUvbVeE9
GmgSdCwA5vzyCkKkAcHQ/R9D0k7gz5uP8kQdOjhHn3u/MBSEtVEaE6cX9VHt
0GAn1QuGUZEN25K6Hkd/4eVHphHgPrnhcE22EU9y7+8XDIShq8KTJlpBheN5
Y+7DrHDYGPoJ1FVMMc6WMY/URaD+n1UfyPDvYK+5QnStJxJyAvmLZzp2IoNi
c/TwZBR85lV+/cvJAgtbYj2fGpzGA7/FT3Yme7BFXfJpzDoGejdqvjaZt0b2
ruDpnlOx8NBR9nTWBl5eVtm8tfAMpnDOzPqZLTp+k46bPorD2B5D4gVrHyhq
rwznB8+iWD9Wvg8HML197mPM8njUNe8dtV11CBrcdWufWJxHtddPdtNa9tDR
IZJ9WAnYF8i0WW3miDcRc1HVSYkoKYuveGfhhGG5RoLNSIKBpDRfkOgM4b3N
g7ThJHTv7M2L6aFBKXLDDDs6GVSjdO+xWRd8enXLlqWcgoKeghHzPW6ovF7v
anU1BW1RYQOfTx2FwpJn4dQODuy7LbsCWtzRmZSd+LaFg5aPpbOhJnQkBHhv
KqJfwB21aFH+WQ+I+iuVDkouYE34Jo/eSQb6G25WNSakwu/N6xRVphdONxhP
RytxUdlO1HLFTBT7UMMUbnFBv5xc5M/0QblXR2X09jRIHy5vn35/HM6y2U2N
TWmgq/UI2WJfvJyoZ4/T02FddSij8LIfGhW19x78kA53hVlpQqA/XIQyN058
BjgTtIFtDgGofR1OLVDKBC9Vn8YxDoQwi/g+53YmpKWqLQWaJ2B+fHGo1ioL
UVOWwwJlFjJzt3oIm7KgZOZZyJCxEBv47qu7ftkY/DnuyMiXIOzN2xbJkmTj
kvttR9/xk0gcUjtLj+ehO8OIXt3HhntXXM0WdRIprq3thtJgKK5PfNpdTCI+
SxbhMRWCS7ccfF1ukxDr91t+mAmBroHGYnMJCeGOBp/whRDs1L1vXlNOoqmD
Kc6gEPDV7L1XWE1CRza/UrSGwGNli4v+zSRetfT521oTYMk+M8clJHgCx0MZ
qQSkUYK5wCkSA5TScf1MAvGTqXlvZSRGW2ckj0kCORNr21v/JqHUE6Exmk+g
fsRh34MVfPA62zppZQS+fVdiEqPJxx3PHXqmbQSKmJHPP2vzsSxZXPXiDwKb
e20CgtbxoWLsfDekmwC6O697GPKxe9CyvLSPANGx7BsrKh9dh2M2bJwmMENr
rajaxke1b8lD8SyBlLYCe6oZHwcmmwtPLhK48rspZ505HzHk2MVy+VAYOS7o
5VnyoVkwcsVpZSgqm8W1KlZ8BBv0Lk2sCsVuu1xGmg0fIRuFz3LUQ9H43OfL
0g986JZfGd2lFYp/AWdFQi0=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"PointsPerCycle\"", TraditionalForm], 
    FormBox["\"Time in seconds\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageMargins->0.,
  ImageSize->600,
  Method->{},
  PlotLabel->FormBox[
    TemplateBox[{"\"time in seconds=\"", 
      RowBox[{
        RowBox[{"2.3726007159090896`", " ", 
          SuperscriptBox[
          "\"(\\!\\(\\*FractionBox[\\(PointsPerCycle\\), \\(100\\)]\\))\"", 
           "2"]}], "-", 
        RowBox[{
         "0.5303426931818149`", " ", 
          "\"(\\!\\(\\*FractionBox[\\(PointsPerCycle\\), \\(100\\)]\\))\""}], 
        "+", "0.8311955499999355`"}]}, "RowDefault"], TraditionalForm],
  PlotRange->{{0, 1000.}, {0, 233.122495}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"46df171e-f0e4-43d7-8191-af2e578428c4"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Maximum memory used", \
"Subsubsection",ExpressionUUID->"43078e9d-d08c-41de-9fea-5b27a349e9a3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"memoryModel", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Flatten", "/@", "timingsList"}], ")"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "n", ",", 
       SuperscriptBox["n", "2"]}], "}"}], ",", 
     RowBox[{"{", "n", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Flatten", "/@", "timingsList"}], ")"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"memoryModel", "[", "n", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"timingsList", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"timingsList", "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "\[RightDoubleBracket]"}]}], 
        "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]",
    ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Row", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<Memory used=\>\"", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"memoryModel", "[", 
          RowBox[{
          "100.", "\"\<(\!\(\*FractionBox[\(PointsPerCycle\), \
\(100\)]\))\>\""}], "]"}], 
         SuperscriptBox["10", 
          RowBox[{"-", "6"}]], "\"\<MB\>\""}], "]"}]}], "}"}], "]"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<PointsPerCycle\>\"", ",", "\"\<Memory used\>\""}], "}"}]}], 
   ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], "\[IndentingNewLine]", 
  "]"}]}], "Input",ExpressionUUID->"3780a1dc-30ae-4369-8bac-7c814e81d278"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{{100., 4.905296*^6}, {200., 1.9018888*^7}, {300., 
       4.3497*^7}, {400., 7.8976528*^7}, {500., 1.18770848*^8}, {600., 
       1.73233496*^8}, {700., 2.32621352*^8}, {800., 3.01125912*^8}, {900., 
       3.87140808*^8}, {1000., 4.73885368*^8}}]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVxnk4lAkcwHGVyq0tlR1XdLgrj0Jm6fdT2ZLsMI5Gzgo5VjkyiRjHUDPM
WyZKsY6oJURCvC+PY9ZEh6jUKoVEB4VYEWvbP77P56t5+LiDz2IJCYkDP/rf
gTbpH8uC0xKJg03yTNwa7FRf/BMLhvy2PRbqMDFmZZ6h03oWmA38fYm9i4k/
HzJTKLZmQYqiJBkeyUTGiG8HM5UFs7bPGHuGmNigILK/QXOFTw6BdTtbHPEK
M8bZbvshWMf34WbynJHZO+GZFeAOvSVps312rigOOKGhS/MG8037P8TXeKP7
x6O6fs5HQCPc2rT1gi/WDZdeCEz2gfYH4vPt/YEY5TLzZm7YD8KKCm2UtUKw
yqZ577hGACgaOopD/MLRsTz1UmhyEHC+1t5k7D6FtcLS3XVvg8Gs5o3rOe9o
3H9mY9Jt/gmw9W+ZaQUOjvhPudnVh4CxVE/XycJ43Kcs2XS1JxQYqYoC9eVc
PLfUwtF2Igw6ud7SqpxknNNnu7ZonoSVvwqi2M481FcaG/30SwSsbZEfZ2mm
Ysr2gMme42xw9bryl6fOeexMV9AzzD4F1XN2NrSHF7CrZnxka3UkbFhWXify
E+LSVd1a34dOA//3a1ytHek4uWXmXcSSaCgzHm2l/5uBa5LUVGtNzwCjxl4l
Z/4yqqgExXn4xgBrLU3RXeoqvgqZCavixIKNFW/8zOJsfC8hCvJnceDjZ0Lk
Sc/BxiK9IcZ7DjQp5TZVl+eiTOimaf/wOHB6WzJqLM7D0e589JWLB/GQ/DvL
hXwsy2pwoF+JB/6+5zrN+gUoteCa/dU4AXIifQ5kRxXiU05KbG97AtBkMmuy
O65jzBF3nVyXRPhSEF3xafWf2DRQJmM9lgid/eJj9+OKcKA5p1IUw4Vnk/it
93UxnmzeOBkukwQPFjw8+ixKMM/DIFgqPwmihF1WuaJSvHmoqyx8SzKky2j3
Rpjfwt+mvumI7iVDO9d04ENQOXZ+afAfcTkL9LS8inTjChRJ06ysB8+CqIAt
1zFbgfaNU8yE6HPgNJNaOfD8NlLPTxhkyvAga7r72GBxJTbygyzTCniwa8fa
nsKLd9DEc36YovNBm90RaRtbhTyh4cHGe3zo2xPHuO9Rjeyjrxfd8E4Bf279
AW3nGrTK2BzqO5YCmoXi4Yd4F2OHV512iU6FDs+JKEvDWnR6FknqKwmguslL
mG9Uh9IbYlte5AlAWjWz3kqXxIv5Nl72BQJYvW5F/h+GJKprrplvuy6Ae0rz
b2aNSNymXmpC3hSA8WOzY3fMSfRSflmUXSUAOcK0WN+WxLtypucPtwlAbOAw
qXecRN+pz24jYwLweP89N6iKxPGwupmjXwUgWmR050ktidET3IzeKQF0y75a
R28gMe2L6uNHswKYHhcukxWT2PDBZleFJAGWy/hLbr0gcfXr67oRygQ8scto
WT5HYq5baOtnGgFDoXrB4RIU6r20OOKnRsC15G2h/ZIUwounWQe1CNBKKE6i
5CkM6lq8gm5AgHqzWn+EBoXTjEcllZsJ4AV6uwytpzC+I3OfgREBOUtVtJ11
KLz8YGuCmgkB7bJjXSZGFK7fP6eRYUZAH1v21o3tFJa1iSkFOgF5T7MGlc0p
3LFXyEq2IEBeqyCMZ0mhqNXjn4WdBGzw0nSbs6LwP+ErTLE=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"PointsPerCycle\"", TraditionalForm], 
    FormBox["\"Memory used\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->600,
  Method->{},
  PlotLabel->FormBox[
    TemplateBox[{"\"Memory used=\"", 
      RowBox[{"4.68799033333333`", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"1.`", " ", 
              SuperscriptBox[
              "\"(\\!\\(\\*FractionBox[\\(PointsPerCycle\\), \
\\(100\\)]\\))\"", "2"]}], "+", 
            
            RowBox[{"0.11960066160287998`", " ", 
              "\"(\\!\\(\\*FractionBox[\\(PointsPerCycle\\), \
\\(100\\)]\\))\""}], "-", "0.05415014009915504`"}], ")"}], " ", "\"MB\""}]}, 
     "RowDefault"], TraditionalForm],
  PlotRange->{{0, 1000.}, {0, 4.73885368*^8}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"40f95f1a-759e-421f-956a-0e34ad9193a9"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["In parallel", \
"Subsubsection",ExpressionUUID->"062af534-ed00-4ebf-a69f-a994758f58ec"],

Cell[TextData[{
 "Inside parallel environments the timings are somewhat slower, by a factor \
of about 1.8. The timings below were taken with 7 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " kernels running in parallel."
}], "Text",ExpressionUUID->"471d2f9f-ca7e-4522-9a85-5ec7a89c9819"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DistributeDefinitions", "[", "\"\<RBSFA`\>\"", "]"}], 
  ";"}]], "Input",ExpressionUUID->"116be288-4c76-4679-b2a5-056a8950eb45"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"parallelTimingsList", "=", 
  RowBox[{"ParallelTable", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", 
      RowBox[{"AbsoluteTiming", "[", 
       RowBox[{"MaxMemoryUsed", "[", 
        RowBox[{"makeDipoleList", "[", 
         RowBox[{
          RowBox[{"VectorPotential", "\[Rule]", 
           RowBox[{"Function", "[", 
            RowBox[{"t", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                FractionBox["F", "\[Omega]"], 
                RowBox[{"Sin", "[", 
                 RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", 
               "0"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"FieldParameters", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"F", "\[Rule]", 
              RowBox[{
               SqrtBox[
                FractionBox["n", "100"]], "0.053"}]}], ",", 
             RowBox[{"\[Omega]", "\[Rule]", 
              RowBox[{"45.6", "/", "\[Lambda]"}]}]}], "}"}]}], ",", 
          RowBox[{"CarrierFrequency", "\[Rule]", 
           RowBox[{"45.6", "/", "\[Lambda]"}]}], ",", 
          RowBox[{"PointsPerCycle", "\[Rule]", "n"}]}], "]"}], "]"}], "]"}]}],
      "}"}], "\[IndentingNewLine]", ",", 
    RowBox[{"{", 
     RowBox[{"\[Lambda]", ",", "770", ",", "830", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "100", ",", "1000", ",", "100"}], "}"}]}], 
   "]"}]}]], "Input",ExpressionUUID->"2b097156-f270-45ce-82a8-4e27b2430cbd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100", ",", 
       RowBox[{"{", 
        RowBox[{"4.718328`", ",", "7949312"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", 
       RowBox[{"{", 
        RowBox[{"18.25669`", ",", "19028920"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", 
       RowBox[{"{", 
        RowBox[{"39.681825`", ",", "43507248"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", 
       RowBox[{"{", 
        RowBox[{"68.082464`", ",", "75529984"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", 
       RowBox[{"{", 
        RowBox[{"108.269979`", ",", "118772272"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"600", ",", 
       RowBox[{"{", 
        RowBox[{"154.871499`", ",", "173234856"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"700", ",", 
       RowBox[{"{", 
        RowBox[{"211.181868`", ",", "232622488"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"800", ",", 
       RowBox[{"{", 
        RowBox[{"275.072148`", ",", "301126208"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"900", ",", 
       RowBox[{"{", 
        RowBox[{"350.060823`", ",", "387140984"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1000", ",", 
       RowBox[{"{", 
        RowBox[{"424.30979`", ",", "473885664"}], "}"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100", ",", 
       RowBox[{"{", 
        RowBox[{"3.716903`", ",", "7949264"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", 
       RowBox[{"{", 
        RowBox[{"17.482396`", ",", "19028912"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", 
       RowBox[{"{", 
        RowBox[{"40.155591`", ",", "43507248"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", 
       RowBox[{"{", 
        RowBox[{"68.13476`", ",", "75529984"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", 
       RowBox[{"{", 
        RowBox[{"109.399417`", ",", "118772272"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"600", ",", 
       RowBox[{"{", 
        RowBox[{"153.630582`", ",", "173234976"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"700", ",", 
       RowBox[{"{", 
        RowBox[{"211.956183`", ",", "232622248"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"800", ",", 
       RowBox[{"{", 
        RowBox[{"279.290171`", ",", "301126208"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"900", ",", 
       RowBox[{"{", 
        RowBox[{"353.099514`", ",", "387141104"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1000", ",", 
       RowBox[{"{", 
        RowBox[{"429.038617`", ",", "473885664"}], "}"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100", ",", 
       RowBox[{"{", 
        RowBox[{"4.708314`", ",", "7949264"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", 
       RowBox[{"{", 
        RowBox[{"17.345061`", ",", "19028912"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", 
       RowBox[{"{", 
        RowBox[{"40.182594`", ",", "43507248"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", 
       RowBox[{"{", 
        RowBox[{"68.995092`", ",", "75529984"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", 
       RowBox[{"{", 
        RowBox[{"109.869859`", ",", "118772272"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"600", ",", 
       RowBox[{"{", 
        RowBox[{"156.142607`", ",", "173234976"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"700", ",", 
       RowBox[{"{", 
        RowBox[{"209.361107`", ",", "232622488"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"800", ",", 
       RowBox[{"{", 
        RowBox[{"279.289632`", ",", "301126208"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"900", ",", 
       RowBox[{"{", 
        RowBox[{"350.78387`", ",", "387141104"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1000", ",", 
       RowBox[{"{", 
        RowBox[{"418.914476`", ",", "473885664"}], "}"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100", ",", 
       RowBox[{"{", 
        RowBox[{"4.279905`", ",", "7949264"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", 
       RowBox[{"{", 
        RowBox[{"18.627336`", ",", "19028912"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", 
       RowBox[{"{", 
        RowBox[{"40.455279`", ",", "43507248"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", 
       RowBox[{"{", 
        RowBox[{"67.583287`", ",", "75529984"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", 
       RowBox[{"{", 
        RowBox[{"107.493356`", ",", "118772272"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"600", ",", 
       RowBox[{"{", 
        RowBox[{"151.73791`", ",", "173234976"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"700", ",", 
       RowBox[{"{", 
        RowBox[{"211.564862`", ",", "232622368"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"800", ",", 
       RowBox[{"{", 
        RowBox[{"276.236601`", ",", "301126208"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"900", ",", 
       RowBox[{"{", 
        RowBox[{"352.375809`", ",", "387141104"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1000", ",", 
       RowBox[{"{", 
        RowBox[{"429.841635`", ",", "473885664"}], "}"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100", ",", 
       RowBox[{"{", 
        RowBox[{"4.800715`", ",", "7949264"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", 
       RowBox[{"{", 
        RowBox[{"17.979704`", ",", "19028912"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", 
       RowBox[{"{", 
        RowBox[{"38.294414`", ",", "43507248"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", 
       RowBox[{"{", 
        RowBox[{"68.784353`", ",", "75529984"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", 
       RowBox[{"{", 
        RowBox[{"105.406404`", ",", "118772272"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"600", ",", 
       RowBox[{"{", 
        RowBox[{"151.986167`", ",", "173234976"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"700", ",", 
       RowBox[{"{", 
        RowBox[{"216.018013`", ",", "232622488"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"800", ",", 
       RowBox[{"{", 
        RowBox[{"279.115752`", ",", "301126208"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"900", ",", 
       RowBox[{"{", 
        RowBox[{"361.033211`", ",", "387141104"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1000", ",", 
       RowBox[{"{", 
        RowBox[{"424.589208`", ",", "473885664"}], "}"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100", ",", 
       RowBox[{"{", 
        RowBox[{"4.249556`", ",", "7949264"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", 
       RowBox[{"{", 
        RowBox[{"17.178216`", ",", "19028912"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", 
       RowBox[{"{", 
        RowBox[{"40.199101`", ",", "43507248"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", 
       RowBox[{"{", 
        RowBox[{"67.269327`", ",", "75529864"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", 
       RowBox[{"{", 
        RowBox[{"108.852088`", ",", "118772032"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"600", ",", 
       RowBox[{"{", 
        RowBox[{"156.147484`", ",", "173234736"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"700", ",", 
       RowBox[{"{", 
        RowBox[{"210.960379`", ",", "232622008"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"800", ",", 
       RowBox[{"{", 
        RowBox[{"279.971448`", ",", "301126208"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"900", ",", 
       RowBox[{"{", 
        RowBox[{"352.398709`", ",", "387141104"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1000", ",", 
       RowBox[{"{", 
        RowBox[{"423.345151`", ",", "473885664"}], "}"}]}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100", ",", 
       RowBox[{"{", 
        RowBox[{"4.480898`", ",", "7949264"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", 
       RowBox[{"{", 
        RowBox[{"17.627216`", ",", "19028912"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", 
       RowBox[{"{", 
        RowBox[{"39.652011`", ",", "43507248"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", 
       RowBox[{"{", 
        RowBox[{"67.753839`", ",", "75529984"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", 
       RowBox[{"{", 
        RowBox[{"107.413123`", ",", "118772272"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"600", ",", 
       RowBox[{"{", 
        RowBox[{"156.83347`", ",", "173234976"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"700", ",", 
       RowBox[{"{", 
        RowBox[{"213.902321`", ",", "232622488"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"800", ",", 
       RowBox[{"{", 
        RowBox[{"276.711263`", ",", "301126208"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"900", ",", 
       RowBox[{"{", 
        RowBox[{"352.447201`", ",", "387140984"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1000", ",", 
       RowBox[{"{", 
        RowBox[{"423.85784`", ",", "473885544"}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"b4ba8978-c088-455b-8793-20ba94944119"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"parallelTimingsListAveraged", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"parallelTimingsList", "\[Transpose]"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{"k", ",", "1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
      RowBox[{"Mean", "[", " ", 
       RowBox[{
        RowBox[{"parallelTimingsList", "\[Transpose]"}], 
        "\[LeftDoubleBracket]", 
        RowBox[{"k", ",", "All", ",", "2"}], "\[RightDoubleBracket]"}], 
       "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"parallelTimingsList", "\[Transpose]"}], "]"}]}], "}"}]}], 
   "]"}]}]], "Input",ExpressionUUID->"351d2fc4-e706-4b2c-ac4f-919f75e4c22c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"100", ",", 
     RowBox[{"{", 
      RowBox[{"4.422088428571429`", ",", 
       FractionBox["55644896", "7"]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"200", ",", 
     RowBox[{"{", 
      RowBox[{"17.785231285714286`", ",", 
       FractionBox["133202392", "7"]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300", ",", 
     RowBox[{"{", 
      RowBox[{"39.80297357142857`", ",", "43507248"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", 
     RowBox[{"{", 
      RowBox[{"68.08616028571429`", ",", 
       FractionBox["528709768", "7"]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", 
     RowBox[{"{", 
      RowBox[{"108.10060371428573`", ",", 
       FractionBox["831405664", "7"]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", 
     RowBox[{"{", 
      RowBox[{"154.47853128571427`", ",", 
       FractionBox["1212644472", "7"]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", 
     RowBox[{"{", 
      RowBox[{"212.13496185714286`", ",", "232622368"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", 
     RowBox[{"{", 
      RowBox[{"277.9552878571429`", ",", "301126208"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", 
     RowBox[{"{", 
      RowBox[{"353.1713052857143`", ",", 
       FractionBox["2709987488", "7"]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", 
     RowBox[{"{", 
      RowBox[{"424.8423881428571`", ",", 
       FractionBox["3317199528", "7"]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"aa0464e6-74df-45b9-8254-0bc3ba27d459"]
}, Open  ]],

Cell["Timings", "Text",ExpressionUUID->"72fb597d-6206-4b0f-900a-a3a7ac2173a0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"parallelTimingsModel", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Flatten", "/@", "parallelTimingsListAveraged"}], ")"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "n", ",", 
       SuperscriptBox["n", "2"]}], "}"}], ",", 
     RowBox[{"{", "n", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Flatten", "/@", "parallelTimingsListAveraged"}], ")"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}]}], "\[RightDoubleBracket]"}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"parallelTimingsModel", "[", "n", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"parallelTimingsListAveraged", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"parallelTimingsListAveraged", "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "\[RightDoubleBracket]"}]}], 
        "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]",
    ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Row", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<time in seconds=\>\"", ",", 
       RowBox[{"parallelTimingsModel", "[", 
        RowBox[{
        "100", "\"\<(\!\(\*FractionBox[\(PointsPerCycle\), \(100\)]\))\>\""}],
         "]"}]}], "}"}], "]"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<PointsPerCycle\>\"", ",", "\"\<Time in seconds\>\""}], 
     "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], "\[IndentingNewLine]", 
  "]"}]}], "Input",ExpressionUUID->"e76bdc11-2470-4767-bf8e-cfc6131ccc47"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{{100., 4.422088428571429}, {200., 17.785231285714286`}, {300.,
        39.80297357142857}, {400., 68.08616028571429}, {500., 
       108.10060371428573`}, {600., 154.47853128571427`}, {700., 
       212.13496185714286`}, {800., 277.9552878571429}, {900., 
       353.1713052857143}, {1000., 424.8423881428571}}]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVxnk4lAkAx3GltlhNKmuta6LjyW0rkxL9VKsQMXJMM44Mg2ky7mle9xGV
aV7REklNq1qKJ+mQsBrzODqILbVyPFttjhiUYZWy7R/f5/M1COTTgxcqKSm5
fOt/X7epfFsGiqeDuLKuZbAM96wvX8GAhNObz11KQdJKiZnnGgYyzix332hH
wU9Ma0q5AwNvjcrC15dT4DbK6fA4xYCqTZmrJH05Gigy96vaB5EQL38aUaKO
Io8kL1crJsq5J5wcglbCo++DfzHXF99psl78YqiJFm4E1Uj7EKaTrWLG1lHh
OxJkFOLFRlFE33yd11rUDlacPpwVjPKvj820jhsh3nt2YG4wBHN8gV7BHxa4
7STdO0nlIrqQvblQbRMO3DhVEJXFg26a1bS8jYZ7eRW7a9+EY/VD5YxNTdvg
nLgu82Z2BBg1gXLrejuMhilYrvWRGG7qbdl53R6OWosenOuJgmhtsbrh9C6c
WGx7YN+HaMQqTXaVeTpgzkRwsMkgFjKf97XzyxxhojEx9n57HBre3+0sqXWG
yIo71cMX4KhBvb+02RWdv1KMzc4fRfQjbX9S4Yauu5OjlneE+Ppy943ORDoW
r+o2/PyOQI/GHnXlbQcwZTH7T5xyAqrl5+i0EU9oZurp3tuSiEwNncq7nd7Q
0eGl+nGSIBrSZUqbGOiNnI2+nZIMp8WfOu5dZmJIScYLY6Rgy+HiGcsmXzSW
Gb9zG0rBE3qsfUq7P1Sj1s+ExaTCvqKp9ceJAIx1X7LnqKXhc7xZd61WICqL
G+g2RWm4VuVKdaGxsXT+4PmPm9KhmJmiMmKD8CxFlNz3MB2nw4dTt9YEI4nt
u+GidwZOb5ctUJJz8OB1parDRAbmHluJvPeE4rX0QrUs6RhCnhAXsnPDECtd
NxWjmgmmxdBwygAXEj/T8KWXMmFdYe6+gs7DNWZXZYxFFpxZ+1+l3TqC/Yp/
N8haszD4W6hkux0fneMNYaPex6FLMzzEYUZApqK90+HtcYwwK6gmWpFwb1R4
pCecQLt0jFY0HIm6FxGmhaonoWjxuBBbFYXGbJ5dbulJUMcDhrrE0aD5fxms
s8nG5R1/b5znxeBknplPY2s2Eic12nMRC0FQ/4Krh0QYS94Yess4DjvzzaM4
EyIke75wqVERIHlwFeGdcArqqwuMU4cE8HwuvG+iIUbpc52Mvv6jUFmb3PRS
IkZ7omSRfpsQZy45BbiXiqFMK8izfSKEvoHml7YrYnT35sf5dgqxWb+Cdv+a
GMHT1dYlfwkRoPWq7PxtMSiM4Io1I0LUqG3JCWwTI6e31MfuewIchZw1OiGG
R2/+nZsuBCaja2eDPorxe+jD5l53AgkfjuX3KcQoebPEZIkXgdxx3aftn8Q4
cvniOMuPQMOw066qRSTO+jiGqfEJ/NB/xShOi4RuokA/PofARVZUs1ybROpH
R375GQLGr2zZIXokMn3Wa/ScJYCXz4p9DEnEyOcY2yQEeF0L1W1MSQw4GnR/
rSIw49Z+vdqchIvVrhbLOwTSOgodTX8mwVrOV2PXEjj72DJdj0aCSb7NbZUS
WOM8R823JrHPyvzZ52YClW0tdRQbEv1tqWEWjwhs3ZvHyLIlsdJlgM7uICBr
9pue30FisMEhp+BPAv8BnjZBzA==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"PointsPerCycle\"", TraditionalForm], 
    FormBox["\"Time in seconds\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->600,
  Method->{},
  PlotLabel->FormBox[
    TemplateBox[{"\"time in seconds=\"", 
      RowBox[{
        RowBox[{"4.199855169372292`", " ", 
          SuperscriptBox[
          "\"(\\!\\(\\*FractionBox[\\(PointsPerCycle\\), \\(100\\)]\\))\"", 
           "2"]}], "+", 
        RowBox[{
         "1.078993858982708`", " ", 
          "\"(\\!\\(\\*FractionBox[\\(PointsPerCycle\\), \\(100\\)]\\))\""}], 
        "-", "1.5509370738096333`"}]}, "RowDefault"], TraditionalForm],
  PlotRange->{{0, 1000.}, {0, 424.8423881428571}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"80e08b75-a91f-422f-b73b-b2693ad2e719"]
}, Open  ]],

Cell["Memory", "Text",ExpressionUUID->"b47b9911-2eab-4255-9245-4d7483045e94"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"parallelMemoryModel", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Flatten", "/@", "parallelTimingsListAveraged"}], ")"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "n", ",", 
       SuperscriptBox["n", "2"]}], "}"}], ",", 
     RowBox[{"{", "n", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Flatten", "/@", "parallelTimingsListAveraged"}], ")"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"parallelMemoryModel", "[", "n", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"parallelTimingsListAveraged", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{"parallelTimingsListAveraged", "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "\[RightDoubleBracket]"}]}], 
        "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]",
    ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Row", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<Memory used=\>\"", ",", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"parallelMemoryModel", "[", 
          RowBox[{
          "100.", "\"\<(\!\(\*FractionBox[\(PointsPerCycle\), \
\(100\)]\))\>\""}], "]"}], 
         SuperscriptBox["10", 
          RowBox[{"-", "6"}]], "\"\<MB\>\""}], "]"}]}], "}"}], "]"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<PointsPerCycle\>\"", ",", "\"\<Memory used\>\""}], "}"}]}], 
   ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], "\[IndentingNewLine]", 
  "]"}]}], "Input",ExpressionUUID->"991be902-5f90-435c-9e05-b23b7f649831"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{{100., 7.949270857142857*^6}, {200., 1.902891314285714*^7}, {
       300., 4.3507248*^7}, {400., 7.552996685714285*^7}, {500., 
       1.1877223771428572`*^8}, {600., 1.7323492457142857`*^8}, {700., 
       2.32622368*^8}, {800., 3.01126208*^8}, {900., 
       3.8714106971428573`*^8}, {1000., 
       4.7388564685714287`*^8}}]}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVxnk4lAkcwHEVlalmk9YjiVD71JCQqJ3Y3896hKwcSWMQEpGKEap1HzPl
mJeciTArU0KOkHnf7JTZMiqhkkrsMx06XDnWEWvbP77P56vlc8rp6GI5Obnf
vve/Mqni92WBSnXvw3ohCw1OutwpV2LB+6zxvUV/sjB6Tck2Fx0WfHEQKl5+
wcJ17F30cisWlNq/95Auc0OHQb8nzmksEHuRNosC3LCZLnEUqrlBaf8T/T59
NuY7Rx+038mGjdb5+nat7uj8ZuxwQaAHjHi7xc+peuGDwGDNrWreoNY6pHrD
xhc9Pvtu9T94BPR7lao82o+haKAy4zjvKPjFLW178PgE/u460z834A/tO3Jn
dw6HYL3tPeuvmoGg7HDq5Q56GB6oTsvl8IKg0jtg3RnJGWzKrLQUvT0JKxQa
W2ruROK+qM3c2pRg6FhO+/ezZywOBky6298JgRMM7X7zuni0UZW/e/kVBwQW
lg/jlibhBQWzA3ZjoVAtzJow4vBwTjfCrUUrDF4uiRTRmMmou3Z06MuecLid
Ta/Rm03F1J2BE69ORUDaKMmW0dOxM5vO2FZ4Bv7S7hywrcrArsavgwYNZ6Ev
UOxx3DITFZS7tb99OAeHMuaGnZSycWL7zPvwJZEQ1eD7qborB1W4G9SbTKNg
Re6jsbj2PFy/PijO0y8azk3uj9/VnY+9ITOh9bExMGV30Wz8cQF+lJMEBbBi
gdiSaF8rX4Ti64wPDh9jQY4la8jLKkYa56epgNNxEKG0cZBbXoJD3QL0WxkP
64t8Yg1lAqwqaHZi5seD4OO7oQx6KS5fcCsc35EAPex3RxM8r+Kz2NSYN20J
cO2PbF53bRlGH/HYUuyaCKtmp8eFM0K8K6uiWY0mgubUQ46j33WU3Suqk0Qn
wVrEOVdJOYbd2zxxmsaFPb3WN6M2VWCJp97J5QIu9Eh5q25VVOINdlfV6e08
6DAv79HYdBP3T05vkbTywLt4VXeDTzV2jjQHDLqeB72IBX1/Rg1KFNUsrN6d
h766xL2isRp0FE86J0RegFtXjs2rd9Yi9SJY7xItGYLVP/8QerUOxSlB5hdL
k4Fb+iqyJf0WmhyeH6CYKfD80t9Oq6PqMTlz2yFxawp8c8m2MPZswAjfvkVC
71RYs/spEe7aiBY5+hy/0VRQE75WWbC8jTEDyudcI9OATzPc62PUhC7Pz5K6
a/kwYp1VLLdbhIqbYlp6SvigLPo5oMOIxCyBrZdjKR+009vtTExJ1NBSmZeW
8YGe+ymlgEmisUalCXmDD5mm9eqBliR6qb6+XljPB6MWwXnFgyTeXmma7iPl
Q4f8iwussyT6TQ67D47yIc6w1NBcTOLXUNGM7zgfHutocG9KSIwcS8p5M8mH
b1aaJlpSEi+OqHe0z/JhXrPxmkIXic2fbH+tkScgT92sp+stiT/2lW0NVyVA
FwRe0csoLHbn3B9WIyAbiBOTKyhkvDY74r+BAFnIku6g1RRCz7OCQ9oEaPvH
NbmvozCoa/Fqph4BzIKnbaBL4ZRDe0WdPgENOrN1ou0Uxj+5ZKNnSIByr3Da
2JjCvEcGCRtMCAjtz8timFGos29OM2cXAWGM3i9XkcIq6QOKziSAXVZ2RcuK
wt3WmSyeGQFaztMVhbYUSu57/rPwCwFtBp0qavsp/A9HoE8H
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"PointsPerCycle\"", TraditionalForm], 
    FormBox["\"Memory used\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->600,
  Method->{},
  PlotLabel->FormBox[
    TemplateBox[{"\"Memory used=\"", 
      RowBox[{"4.796327129870126`", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"1.`", " ", 
              SuperscriptBox[
              "\"(\\!\\(\\*FractionBox[\\(PointsPerCycle\\), \
\\(100\\)]\\))\"", "2"]}], "-", 
            
            RowBox[{"0.15325687842092184`", " ", 
              "\"(\\!\\(\\*FractionBox[\\(PointsPerCycle\\), \
\\(100\\)]\\))\""}], "+", "0.5554409614368468`"}], ")"}], " ", "\"MB\""}]}, 
     "RowDefault"], TraditionalForm],
  PlotRange->{{0, 1000.}, {0, 4.7388564685714287`*^8}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"44e1005d-51c6-4038-bd25-9ebb9274be0d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Decoupling integration and sampling", \
"Subsubsection",ExpressionUUID->"7b679b15-aced-4e04-be99-2677f0615dcc"],

Cell[TextData[{
 "If the quadratic scaling with respect to ",
 StyleBox["PointsPerCycle", "Code"],
 " becomes too onerous, the sampling rate for the evaluation and for the \
numerical integration can be decoupled by providing an explicit option for ",
 StyleBox["IntegrationPointsPerCycle", "Code"],
 ", which will set how many points are used per cycle in the numerical \
integration."
}], "Text",ExpressionUUID->"3a40f553-eefb-44d4-ade8-d7375eb96435"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  "IntegrationPointsPerCycle"}]], \
"Input",ExpressionUUID->"d9ff3e06-e891-4d17-ad7a-14274f16b50c"],

Cell[BoxData[
 StyleBox["\<\"IntegrationPointsPerCycle is an option for makeDipoleList \
which controls the number of points per cycle to use for the integration. Set \
to Automatic, to follow PointsPerCycle, or to an integer.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->
  "Info3663680914-9420698",ExpressionUUID->"3f167dae-0315-464d-939a-\
65e033de216e"]
}, Open  ]],

Cell[TextData[{
 "Obviously, if this option is taken, then the outcome should be checked for \
numerical convergence with respect to ",
 StyleBox["IntegrationPointsPerCycle", "Code"],
 "."
}], "Text",ExpressionUUID->"cb44724b-9691-41ba-97ab-3d35c738c88c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"decoupledTimingsList", "=", 
  RowBox[{"Table", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"nSampling", ",", "nIntegration", ",", 
      RowBox[{"AbsoluteTiming", "[", 
       RowBox[{"MaxMemoryUsed", "[", 
        RowBox[{"makeDipoleList", "[", 
         RowBox[{
          RowBox[{"VectorPotential", "\[Rule]", 
           RowBox[{"Function", "[", 
            RowBox[{"t", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                FractionBox["F", "\[Omega]"], 
                RowBox[{"Sin", "[", 
                 RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", 
               "0"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", ",", 
          RowBox[{"FieldParameters", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"F", "\[Rule]", 
              RowBox[{
               SqrtBox[
                FractionBox["nSampling", "100"]], "0.053"}]}], ",", 
             RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], 
          "\[IndentingNewLine]", ",", 
          RowBox[{"PointsPerCycle", "\[Rule]", "nSampling"}], ",", 
          RowBox[{"IntegrationPointsPerCycle", "\[Rule]", "nIntegration"}]}], 
         "\[IndentingNewLine]", "]"}], "]"}], "]"}]}], "}"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"{", 
     RowBox[{"nSampling", ",", "100", ",", "500", ",", "100"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"nIntegration", ",", "100", ",", "500", ",", "100"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"DateString", "[", 
  "]"}]}], "Input",ExpressionUUID->"bc0cefc7-fd83-4cb8-9dac-935263ed436e"],

Cell[BoxData["\<\"Fri 5 Feb 2016 17:08:36\"\>"], \
"Output",ExpressionUUID->"29cf853f-1aea-4339-9a50-547813302271"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"100", ",", "100", ",", 
       RowBox[{"{", 
        RowBox[{"2.391394`", ",", "4789112"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"100", ",", "200", ",", 
       RowBox[{"{", 
        RowBox[{"4.768616`", ",", "9473168"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"100", ",", "300", ",", 
       RowBox[{"{", 
        RowBox[{"7.073357`", ",", "14241584"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"100", ",", "400", ",", 
       RowBox[{"{", 
        RowBox[{"9.399924`", ",", "19138656"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"100", ",", "500", ",", 
       RowBox[{"{", 
        RowBox[{"11.796375`", ",", "24035936"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "100", ",", 
       RowBox[{"{", 
        RowBox[{"4.729365`", ",", "9447040"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", "200", ",", 
       RowBox[{"{", 
        RowBox[{"9.375795`", ",", "19017072"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", "300", ",", 
       RowBox[{"{", 
        RowBox[{"14.164736`", ",", "28478336"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", "400", ",", 
       RowBox[{"{", 
        RowBox[{"18.882546`", ",", "38195832"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"200", ",", "500", ",", 
       RowBox[{"{", 
        RowBox[{"23.448413`", ",", "47916856"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"300", ",", "100", ",", 
       RowBox[{"{", 
        RowBox[{"7.022262`", ",", "14177120"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "200", ",", 
       RowBox[{"{", 
        RowBox[{"14.067049`", ",", "28434560"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "300", ",", 
       RowBox[{"{", 
        RowBox[{"21.527078`", ",", "43233320"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "400", ",", 
       RowBox[{"{", 
        RowBox[{"28.41525`", ",", "56993480"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "500", ",", 
       RowBox[{"{", 
        RowBox[{"35.239939`", ",", "70747672"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"400", ",", "100", ",", 
       RowBox[{"{", 
        RowBox[{"9.41508`", ",", "19027632"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", "200", ",", 
       RowBox[{"{", 
        RowBox[{"18.695714`", ",", "38108104"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", "300", ",", 
       RowBox[{"{", 
        RowBox[{"28.159019`", ",", "56949288"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", "400", ",", 
       RowBox[{"{", 
        RowBox[{"37.526759`", ",", "75259432"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"400", ",", "500", ",", 
       RowBox[{"{", 
        RowBox[{"46.829952`", ",", "95676600"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"500", ",", "100", ",", 
       RowBox[{"{", 
        RowBox[{"11.667205`", ",", "23882240"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "200", ",", 
       RowBox[{"{", 
        RowBox[{"23.522496`", ",", "47786456"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "300", ",", 
       RowBox[{"{", 
        RowBox[{"35.096629`", ",", "70660928"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "400", ",", 
       RowBox[{"{", 
        RowBox[{"46.730847`", ",", "95634048"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "500", ",", 
       RowBox[{"{", 
        RowBox[{"58.507813`", ",", "118501720"}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"d48b3ae9-3cad-4a06-a453-0a9767f11ee2"],

Cell[BoxData["\<\"Fri 5 Feb 2016 17:17:24\"\>"], \
"Output",ExpressionUUID->"b3d3efe1-062a-419d-9ac1-31563988c626"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"decoupledTimingsModel", "=", 
   RowBox[{"LinearModelFit", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Flatten", "/@", 
        RowBox[{"Flatten", "[", 
         RowBox[{"decoupledTimingsList", ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "}"}]}], "]"}]}], ")"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}],
      "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "nSampling", ",", "nIntegration", ",", 
       RowBox[{"nSampling", "\[Times]", "nIntegration"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"nSampling", ",", "nIntegration"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot3D", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"decoupledTimingsModel", "[", 
       RowBox[{"nSampling", ",", "nIntegration"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"nSampling", ",", "0", ",", "500"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"nIntegration", ",", "0", ",", "500"}], "}"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<npps=PointsPerCycle\>\"", ",", 
         "\"\<nppi=IntegrationPointsPerCycle\>\"", ",", 
         "\"\<Timing (s)\>\""}], "}"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<time in seconds=\>\"", ",", 
          RowBox[{"decoupledTimingsModel", "[", 
           RowBox[{
            RowBox[{
            "100", "\"\<(\!\(\*FractionBox[\(npps\), \(100\)]\))\>\""}], ",", 
            RowBox[{
            "100", "\"\<(\!\(\*FractionBox[\(nppi\), \(100\)]\))\>\""}]}], 
           "]"}]}], "}"}], "]"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"ImageSize", "\[Rule]", "650"}]}], "\[IndentingNewLine]", "]"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{"ListPointPlot3D", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Flatten", "/@", 
         RowBox[{"Flatten", "[", 
          RowBox[{"decoupledTimingsList", ",", 
           RowBox[{"{", 
            RowBox[{"{", 
             RowBox[{"1", ",", "2"}], "}"}], "}"}]}], "]"}]}], ")"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "Large", "]"}]}], "}"}], "}"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], 
  "]"}]}], "Input",ExpressionUUID->"61bc975d-be2c-48cf-8669-e182b1db76ac"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJx1nHc4Vv/7wO0tK0L23nuv59hJCWUVQkOSUVYpTUVokULZhbSQaKeICA2i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    "], {{
      {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
        GrayLevel[1], 3], 
       StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1mXngTVX3xu89e58kczJThoSkMhdKhpAxklRKkRQJIUpKGTI3aEKT0iDS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           "]], Polygon3DBox[CompressedData["
1:eJwtmnngVkMfxe/M3BaVVEob7bSTfV9KUtpLsrRb3ghlL4VEZc2WSJaSQiIl
Sfte5EXZC1lb7Fu8RL3n49w/5jdzZu7zPPfOnfme8z3zqztgcLfLY5Zl/9Gf
XPWHqhurDqqvVschKctGCrcV/lm4qco9wreFLPtL7WEaXyh8v8aXCL+gervw
DpVZaj+vvgd07SThM3TtN+o7Xu19Vd+osU2qmwon1dcKj9Q1K4QfEV4qfLTw
7cJdhH8R/kB1I+FM9VXCN2n8bcGHhauX0HcKvyX8kHA14Wd1zV36/QfU10pj
7YVXq71YfTU13kz4XuHbhXep/bk+d5jwXqqHCjdUuU14pMZ/V/scfccM4Ss0
vkf4f6rbCddVPUr4I9VNuD3V1wgP1vXLmC/hvbkf1V8If6PyotoXq0zUd08W
7qxrD8o938PUt1PtY9V3h3BXXfer8A3CbwpPEK6q77tOeJ3wPcIVha8XXi/8
gHDlEn4/rwvfJ7yv8DXCa4TvFt5H+E/VZwjXU32Lvn+oxl8Tvle4ksavFV4r
PE64gvBG3dcGlSnCT6oM1/gbGh+vdhWNDxGeI3yH8CJ931XJ832XcHmNz+e+
hT/TdyzT+MnJ83929PNeIfyS8J3Ci4XPFn5WeIjwbuFnVO7UZ+9XX0uNnZS8
Hntq/DeN3Sr8vvBjwvvr9zarbiacq75O40+r3KHP36e+U3TtLSrvqf1o9HoY
Ifxf4QeF9xOequtv0fV3qu84jT0pPCr4nfBunuI3he8SPl74nOi1xDPxbNM0
Plr4buEThEerfKD247ruAH3/Q8yRxoerr4nGGuf+bn7jf7nXeAu1j8689g8Q
Pl/tXur7Tu0RKi3Vbqu+7Tyz8AC1z1Pft7n38KFqH1PsbebgiOA9uLlYo4cJ
H5t57R4pPJ37U1+u+zuKORN+QriE8NG8A+HJwiWFmws/xPoT/lvtg1UeZv0I
/0P8UJnI+gt+f4erPMF+FY76/BG51z57IAn/rjmoLVxVeBXrP/d+e1K4tMaP
yb0epgiXEm4h/AjxJ3g//qHP1xGuJrya9UTMUvtw9b1TxJxTg9c8saiaSlvh
LsI/qf2PPt9C7UbqW098UWmndlf1/azxIcJNgmPERuHBwo2FDxXeIPyc8Djh
B4Vb67t2Jq/3MupbqbG/hBsK1xFex/1Gv7s6qm9mf6u0Co4pO4o92U34nMx7
dZc+f7DaB6nvNY39ScwQri28NncM6qr22ZljEzH1cOHjMsdafqOLcM/Mv91I
5WzhfsRUfddhGn+c+Km+oPkdLnyK2qerb5uuPYEYr/bT6iur8TrCFwn3Ff5R
7Y7Jn79I1/4pXFvlQuE+Gv9B7TbJ66NvdDydoXK3xsar71SNtU1eL/00/kfu
OW8lXD36XdRSuUC4tz7zvdr14SDicTA/1FX5D58X/ol7VRmv9qPqa6/v/iJ6
LZRRPUxjDVSuF74yOL4Sg1mPA6P5oGfyeh8cvZ5n5l5rrLl2GuuUvJ7hT/iw
R/J+gVTZD1zDtf2j9/MY4Q/ZT8K1NH9jhT9iPwnXFm6taxYIzwmO16XVf4za
pxAzidW5+eTVYL5rJ7xUeH4w37UVXiL8SjA/nCr8qvDs4HjeRniR8MvB8fp0
4cXC84LjXaPcfHtz8Py3UpkPVwXzy4nCs4SfES4nfJvuf1NmLqgrfIrG5wm/
EMwvLYVfEZ4VzB9w6rFqt8zMtScLv6z288H8cJLwi8LPBvPl8cLPC08XLlPC
7+y44DXBu+ybfP3Q6PjRNZnrBwnP1rWPqQzX9aPUd6jGjoVzhQcSk3n/6hsI
F6h/PFqB9aOxweqrorF56i+p9qfq6wX3sN7Vvlx9+2p8kcbLqf21+gZorFTy
3muh/tHCpZP37qHCY4h97HFde6v6DtfYOOFLhK9gjcP17Bfhy4QrwoXx322Z
bSYGaGxuodM+Fj5XjR81uEp4kXANPf896huk9pXqq5l8D+wF9gT3tlCfL6v2
V+rrz9wL62PZJ8Ln8e7ZX2pfqr594EJiuvBRPCPxQn2D1G6l9gTWluq9eBe6
pm/umERsOoTvjF6/jYt4yfsmpjYq4iXrmZhCbNlH9Vsa+0p1a+Fyqt/IrdmY
q17RWm6r6jbC5VW/mfueThPeO/peF6guI/wlMU34dZWGwTF9S/Q9naR2ieh7
RY+U5t50TR/ht1WODL7mO41NgQOExwgfmawZWEvnRmsJNMgt8G20NiGmE9vR
qPA1z8jeLVU8O/dwsnDJ6HuD85nrU6O1wGJ0ovBWfcf5uZ/xkIL/eXY4DW6r
K/w2MYU4oFKv4J+1cBpcpr6Lde12eFm4kspyjT2svqvVN0K4aTLHwrVw5pvR
13DtDvVdoLFV6DrmgjUkvAIdCXcKXyj8oMoQta9T34HsPeHBwtcK109eI8RW
Yixrp2V0rCZmNxa+X+OXC18jXBfuEB4RPKeHCX+rslHt14PzAX6DPTu++O17
VS7V2FW65gD13yd8mfDVcGLymmpR6B/W2kp0sdrfqu8i1qtwDeFfhAcJj1UZ
oPYlrCm0LZpL7Z3s+dwcDpczx8z1cuG/2KsqS6M5GC6G498Xvk34/OA9UzY5
BvQPjjnEhtnx31Qm2wRns34Eqgv/zD3kfqe82z+DtcZklRvVHq2+I/T5R+Ev
4ZuJOWh9dKzav7KHc2uU+sJ/BWsXNFAD4V3B2qhddK4xMnOutx4NqfZvxCCN
T1S5Ru0b1NcMLhO+VvhG4ebJa5y1uafQM1xDbDwt+rPMAbFjd6FPiMG8q/bR
sXlQMh/dShxRIDo3mauvEn6ZWJzMPzdF683LkvltTLT+uFj4OeFRwgtyzwGx
74zouSHnRJufH52LEnNZax2jYzF7gFjbutgb/ObU4O/kXjYIHxW8Z3/QNXOE
HxWeKtwtOSaw9jsXsYJ3wtrvFP2uBibz78hovcqcwS1toudybm5ti8Ylt+R5
4P+bo/XuAHIM4RHCr+bWMOQSF0RrG/YIa71D9N65PFkPjI3m5z7JfH1dtN5m
D7AXKkRrOzQm2rBStPYkhyAXqBidW/RK5t9rWKQl/MxotUuLueierHUvE36J
vZisJ0ZH83XvZL14bbSeRBMTS/tEa2X0EbnVgGhtxTPODM4Befb5ws8F55T9
hV8RniE8W7if8EXJ+uLG6PxkWLR2QBOgDdCU7JXe0VrzgmR9ckN0fsOc401c
Gf0u+A3e7fDo30ZDTNL3PZlZW8ChcOkhGv8yd467QOPLM+e+t0drs2WZc/9j
hM+Bq1W+yZ0zkut1i84lSyTr4+bCn+eOccS6DZm9kInwVLDHgddRMllvH6z+
L3KvebQia4a1wxrtpHaV6LVLjCIW/Rgcu9ZE5ws/CK8Qfk/4SOF/hNfkzrkX
Bnsw5OJwDNz5RzD3/CjcWXg/1Rtzc2RH4crR3AmHwP2/B3NLnqzXm8GFuXMs
cq2qqt8R/l31WcK1VH8gjNjpp6ohXC28R3Vf4YNUfyy8W3UfuEb1ZuEXVR7R
b01RXxd99h/191a7gepNGtuluhdcpPqj3GuGd3l99FoiZsN924JjeUzOn5uo
/9Pca/qx4D3IWieHJ/b1iM7td6ruAfeofl/4N9VnCu+v+r3cORa5Vm3VH+a+
R7yLS6LvPSXn802Ft+Tm80aFXmHu8Rzg6u7RXgQeA7H4zGjv4VfV3YVrqn5X
uIo++63wVyoziHnRntxnwuPINYL5qoLKd8TO5P2PB4AX8JJw+8w5Mrnys8nx
Ag7Fi5iRHB/wFPAWyLH6FXzWoOD3AQXfwffPM2eZPQe8h5nJ3gM5Kbkpa7B0
cI7M2ny50M/kqOSq8wr9TE5Lbntr7v3UX32Bva9ybuYcmVwZD3JFsOeF94XH
VDJY46H1+Ew3tRtHf9cLybkEOQm5yezk3BtPhfg3J9krICcnPv7r4RXxZ3Cx
32cU8Yn9T87GflxY/D7+Hn7T/cX6XK/2d2pvVZkUnWORa+H5kPuSI+L9EBOJ
jXOL+8WDIP8lpyK3Iubh5ZGTkZvBMXiBs4h5mXMkcqUXk/0FcnjiPTkWuRYx
EG/uS93DEWqXVX197pwX/wp/jFyYnI3cDQ7GCyTHxfvF3yL3JYfHGyVnJLdH
szcPjiloeWJKreCYQ6x5KtmPa1Doi6nJ/m/9Qq88kqy3Khf69+FkPVMhOF95
Jvl+mxb6ZZpwc+JBoc8WsoaL+b+EvZ7sx9Yr9N305FykcaGn0JBoyTXqX4v2
SNZb1Qv9e2Zuv3Wt8IGai4nJ+qhScL43OVnr1yn09pRk/7xuod+W6JnLF3ux
kT7fI7c/vY45gU9z+6erhesLd8/tP64RbiA8Xt+3n3AenH8+kKzHY3C+xj1z
7wepNCS2JOvbLDg/fDrZ72hS6L93dR8HCv8tfKXwfcl6fnfm/PKX6PVTQ/VI
4VfQLcJbdH1v5itZ+6KByZe65vabVwnXw89M1tPlg/OvCcl6tlxwftgpt1+9
LNj/6JJ7r7Jn6wiflZvr4LyGwp1z+9HLg/0R/FX07qjMuRiexuyC//Cu8ZCH
FXoY/5U5Xlfw593Jc8rc8k7vTPYs8C7ws/l9YjR7hT1D7OaZeDbe0e3Ja4C1
wDu8KznmnxSck+4sOLlzcMyHq4m/8Dk5zM/Je+z44Dlm7/EOmgWvad4Na4C1
wBq4Q9dX5f0XOgK/gjlYXsQ3vCPm6LVCLxDfJ+ma64gVwgcLz0GnZD5zIN5P
SuaGr1V+SObck4NzcLj4a9Z8MIeWT/aY8Zrh8P35rHD3YE4tk+zB4cWhYWoJ
bxfuGczhlYV35PYXidc8Bx4gXiAapo7wQOEDgtfk6mjPGu8aTqyRrLHgAjgB
7cUeYi/xDN8nr8lSwXuEtbpVuEewRqiQ7I8Qa7ep/JTsyeFV40Hi1W0TPitY
Y1QSvodnynyGxftiD5wRHIPZG6xZ1i5rEi8PD39p8JrG28cDxQtFI9ZL1iyn
B2uePUXOgneKJieXQePgP+Mvo33wY9sVvwdXoZnxYvEY0dJoarwwNDVaG02P
lz45s9ZH8+PNoX/JBfAA8QLJCTg7wiPCK+JMpmfuMw/OwjgT4iwEDxEvcVnm
szT0J/oWPYgexTPEO0Tjc/aDZ4h3SE7G2QmeJPp3eWa9+nhyvlkzON9G43QI
1khoHzxVzgrwfPFa0UwnBns6aClyPs4a8PzJBcmh8P7Jl8it2BN4eUMy7xU0
PWcXeLBofc6AlgSfYXE2RI7AWQaeLrkDGrJNsKbdXWjE1sGadleRg5GfkQ+i
rznD4CwDT5ezKTR7p2ANi5ZHc54WrMHRopxJ4BeTY5BroIE7BmtGtDH5CvoV
TYo2xcPkLGRK5vzlseT8vUaw33Jvsj+Dp4Nf8ETy3tk/2J8pn/tZWHOsvQ3J
+RaeAfko+o8zSNI5vIe3kv01PBfyx3eStQcahPzk7eT8Cc+SfLks7y/zHDFX
7MfnojkbrmMPsxe/D97baNITgj09tOq+uZ+dOWPu4Hy4H47Gu9io3xub2XMj
n94791zyjnhX5XK/G+aYua6Uey0xp8wtZ55zgz0FzkL/m8wVcAZ+wD659yJ7
jr0HR8KVcCDe6vu6flzmMzv0/YnJsfQsjU3PzRcrgzkP75sYy9o7PTr2vpec
n3MmiD5H46B10Dh4Kx8m+9OcYeIXVsyt39kT7A00DFoGjYT39G6yf8EZJPr/
zWRvDE8b/6Rj7rVNDCIWbUrOxzlTId/9IFl7okHxKz9Kzt85E8dPRbOgXcgR
yRU75I4F7Bn2DhoGLYPGwZuCAzerPbXgRnJacltypmrEI+Yss4dKPphye6l4
KOSjpXPvbTgT7tyTrBXxmPFv4WC0AHPMXOPX8xt8N/44HPeZrn8mmvvg4E+F
p0dzM+Y4fhOeKd4p/7OA34+/jr8F53+i9rRoLYCmQluhqfD6y+TmQjQAWgBP
alqwB4JXtVdurocz4U44+mPhpwru3g/+ysyRcGX13FwEx8A1nImNDT6z5qwM
TYo2RTPiRZbI7Rdz5kN+zJn20GB/jrNuPJgJwWdseDOVc8ceNAfaI+T248jX
8D7RXGgvNBtePZoN7Ua+RT6U5/a2jg7O59GTQzN7umjjGrm5EU6H26vm5n40
AlqhSm6tA0fD1aVy73ViOLG8Wm4tASfDzeTU7YPXPLk2mmyL2k9Ha7U3iv2G
x4g/xpkefjH+Mf8LQgwkFqLR8aLR6Gj1upm9a56BZ2EOfyw8BuayZWbvgZxg
JvspOlfgzA9/Gk8Gb2abytzMHhReFJoYbUzM5Sxme3Ju8a/nklvjonXRuJw9
4KdynoMHiRdJTCY2w4F46fjx+Pd1MnsPW5O9Ljwu/CZyHnIfcgzOAjifJjcl
R+Us9BtdvzKzR4NXsyOZm+FovKgvhKdl9izwLs6DQ4Sv1mfnCX+e7GXgYeLf
wSFwScWCD75M5jo4Dz+MmDcmOCYSC78q5g+PFK+UHIhciByNs7DPkv0zPDO8
s0+S/Vz+Bwj/9evkXJmcGf9lSzL3wYH4IZ8W98uZLf4m9/xU8G/yLLOEHwy+
pgN7L5lb4Vj8ww5F/L4w+lo0B9oDDsX7J4cklyRH4SxsZbIfzJkBZwfkVORW
5FCcjc1P9jbwODhLe1X44swePl7+ZuEJmc/88TP/Tva/OHPifOf1ZL+GMxf8
5YXJ5z2cCXA2sDjZL+fMj7O/mrm1M5oZ7bw+2W/Cg8dPX5LsH3MGyVnk0oJ/
OLPk7HJRsp/NGR5neei9mdEaGC28LHltskY5e1yQ7NXg2XD2sSrZv+ZMhrOZ
dcl7gz3CWc5ryX4U/7PCedWKZP+ZMxjOYlYn++GcAXEW9Guy14TnhL+2PNn/
54ySs8r/A87JwHM=
           "]], Polygon3DBox[CompressedData["
1:eJwt13ncTXUaAPD3vfdSiBJpWjCyNFmzl7Xs2Rprja2xZrJVlnxsKWQJCUWT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           "]]}],
        Lighting->{{"Ambient", 
           RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
          "Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{0, 2, 2}]}, {"Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{2, 2, 2}]}, {"Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
      {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0rsvpFEYwOGPcRsMK6Jd0RAFpSgoN4pViSjoiGK3WIlsQakQOh1/AS0R
+k3o3MfMuM2ystkIu2Tjfg3PSRS/eU7mO5nznsxX0zvQ8S0niqJR3SqsL/Vb
87lR9IE/WM0NNvKQrTxnO5/Zw9JYFCX01bqew2zmONs4xS7OsJ+L/M5l/ucJ
77Wta/3TioFSXGWaa8xwnTthJu5yk3vcYlL74Xd4wBSzTPMnMzzkDo+4y1+c
dY9TPuhYN+GOmjBbkiNc4iAX2MdpdnKSnzjGJg6xjrX6Yh1nNx+d8Zl/2cIs
G8K9+JEX9v3hncp1FfaqyoxlrGSCFSwNe1jCBItZwng4j0UsYL4KrWMsCP9x
+I6vytNLeKYnGSOa83H2/j68Acy/Svc=
        "]]}, 
      {GrayLevel[0.2], 
       Line3DBox[{690, 1004, 473, 689, 1112, 912, 691, 1113, 913, 692, 1114, 
        914, 693, 1115, 915, 694, 1116, 916, 695, 1117, 1010, 1216, 696, 1118,
         917, 697, 1119, 918, 698, 1120, 919, 699, 1121, 920, 700, 1122, 921, 
        701, 1123, 922, 702, 1320, 1005, 923, 1006}], 
       Line3DBox[{704, 1011, 1217, 703, 488, 705, 1124, 924, 706, 1125, 925, 
        707, 1126, 926, 708, 1127, 927, 709, 1128, 1012, 1218, 710, 1013, 
        1219, 711, 1129, 928, 712, 1130, 929, 713, 1131, 930, 714, 1132, 931, 
        715, 1133, 932, 716, 1134, 933, 717}], 
       Line3DBox[{719, 1014, 1220, 718, 1015, 1221, 720, 504, 721, 1135, 934, 
        722, 1136, 935, 723, 1137, 936, 724, 1138, 1016, 1222, 725, 1017, 
        1223, 726, 1018, 1224, 727, 1139, 937, 728, 1140, 938, 729, 1141, 939,
         730, 1142, 940, 731, 1143, 941, 732}], 
       Line3DBox[{734, 1019, 1225, 733, 1020, 1226, 735, 1021, 1227, 736, 520,
         737, 1144, 942, 738, 1145, 943, 739, 1146, 1022, 1228, 740, 1023, 
        1229, 741, 1024, 1230, 742, 1025, 1231, 743, 1147, 944, 744, 1148, 
        945, 745, 1149, 946, 746, 1150, 947, 747}], 
       Line3DBox[{749, 1026, 1232, 748, 1027, 1233, 750, 1028, 1234, 751, 
        1029, 1235, 752, 536, 753, 1151, 948, 754, 1152, 1030, 1236, 755, 
        1031, 1237, 756, 1032, 1238, 757, 1033, 1239, 758, 1034, 1240, 759, 
        1153, 949, 760, 1154, 950, 761, 1155, 951, 762}], 
       Line3DBox[{764, 1035, 1241, 763, 1036, 1242, 765, 1037, 1243, 766, 
        1038, 1244, 767, 1039, 1245, 768, 552, 769, 1156, 1040, 1246, 770, 
        1041, 1247, 771, 1042, 1248, 772, 1043, 1249, 773, 1044, 1250, 774, 
        1045, 1251, 775, 1157, 952, 776, 1158, 953, 777}], 
       Line3DBox[{781, 1159, 954, 779, 1160, 955, 783, 1161, 956, 785, 1162, 
        957, 787, 1163, 958, 789, 1164, 959, 791, 1165, 569, 793, 1166, 960, 
        795, 1167, 961, 797, 1168, 962, 799, 1169, 963, 801, 1170, 964, 803, 
        1171, 965, 805, 1173, 967, 807}], 
       Line3DBox[{806, 966, 1172, 804, 1264, 1057, 802, 1263, 1056, 800, 1262,
         1055, 798, 1261, 1054, 796, 1260, 1053, 794, 1259, 1052, 792, 1258, 
        568, 790, 1257, 1051, 788, 1256, 1050, 786, 1255, 1049, 784, 1254, 
        1048, 782, 1253, 1047, 778, 1252, 1046, 780}], 
       Line3DBox[{809, 577, 808, 1174, 968, 810, 1175, 969, 811, 1176, 970, 
        812, 1177, 971, 813, 1178, 972, 814, 1179, 1058, 1265, 815, 585, 816, 
        1180, 973, 817, 1181, 974, 818, 1182, 975, 819, 1183, 976, 820, 1184, 
        977, 821, 1185, 978, 822}], 
       Line3DBox[{824, 1059, 1266, 823, 1060, 1267, 825, 1186, 979, 826, 1187,
         980, 827, 1188, 981, 828, 1189, 982, 829, 1190, 1061, 1268, 830, 
        1062, 1269, 831, 601, 832, 1191, 983, 833, 1192, 984, 834, 1193, 985, 
        835, 1194, 986, 836, 1195, 987, 837}], 
       Line3DBox[{839, 1063, 1270, 838, 1064, 1271, 840, 1065, 1272, 841, 
        1196, 988, 842, 1197, 989, 843, 1198, 990, 844, 1199, 1066, 1273, 845,
         1067, 1274, 846, 1068, 1275, 847, 617, 848, 1200, 991, 849, 1201, 
        992, 850, 1202, 993, 851, 1203, 994, 852}], 
       Line3DBox[{854, 1069, 1276, 853, 1070, 1277, 855, 1071, 1278, 856, 
        1072, 1279, 857, 1204, 995, 858, 1205, 996, 859, 1206, 1073, 1280, 
        860, 1074, 1281, 861, 1075, 1282, 862, 1076, 1283, 863, 633, 864, 
        1207, 997, 865, 1208, 998, 866, 1209, 999, 867}], 
       Line3DBox[{869, 1077, 1284, 868, 1078, 1285, 870, 1079, 1286, 871, 
        1080, 1287, 872, 1081, 1288, 873, 1210, 1000, 874, 1211, 1082, 1289, 
        875, 1083, 1290, 876, 1084, 1291, 877, 1085, 1292, 878, 1086, 1293, 
        879, 649, 880, 1212, 1001, 881, 1213, 1002, 882}], 
       Line3DBox[{884, 1087, 1294, 883, 1088, 1295, 885, 1089, 1296, 886, 
        1090, 1297, 887, 1091, 1298, 888, 1092, 1299, 889, 1214, 1093, 1300, 
        890, 1094, 1301, 891, 1095, 1302, 892, 1096, 1303, 893, 1097, 1304, 
        894, 1098, 1305, 895, 665, 896, 1215, 1003, 897}], 
       Line3DBox[{911, 1009, 685, 910, 1319, 1110, 909, 1318, 1109, 908, 1317,
         1108, 907, 1316, 1107, 906, 1315, 1106, 905, 1314, 1105, 904, 1313, 
        1312, 1104, 903, 1311, 1103, 902, 1310, 1102, 901, 1309, 1101, 900, 
        1308, 1100, 899, 1307, 1099, 898, 1111, 1306, 1007, 1008}]}, 
      {GrayLevel[0.2], 
       Line3DBox[{251, 474, 1112, 252, 488, 280, 1221, 503, 295, 1226, 518, 
        310, 1233, 533, 325, 1242, 548, 340, 1253, 563, 1160, 355, 578, 1174, 
        370, 1267, 593, 385, 1271, 608, 400, 1277, 623, 415, 1285, 638, 430, 
        1295, 653, 445, 1307, 668, 460}], 
       Line3DBox[{253, 475, 1113, 254, 489, 1124, 281, 504, 296, 1227, 519, 
        311, 1234, 534, 326, 1243, 549, 341, 1254, 564, 1161, 356, 579, 1175, 
        371, 594, 1186, 386, 1272, 609, 401, 1278, 624, 416, 1286, 639, 431, 
        1296, 654, 446, 1308, 669, 461}], 
       Line3DBox[{255, 476, 1114, 256, 490, 1125, 282, 505, 1135, 297, 520, 
        312, 1235, 535, 327, 1244, 550, 342, 1255, 565, 1162, 357, 580, 1176, 
        372, 595, 1187, 387, 610, 1196, 402, 1279, 625, 417, 1287, 640, 432, 
        1297, 655, 447, 1309, 670, 462}], 
       Line3DBox[{257, 477, 1115, 258, 491, 1126, 283, 506, 1136, 298, 521, 
        1144, 313, 536, 328, 1245, 551, 343, 1256, 566, 1163, 358, 581, 1177, 
        373, 596, 1188, 388, 611, 1197, 403, 626, 1204, 418, 1288, 641, 433, 
        1298, 656, 448, 1310, 671, 463}], 
       Line3DBox[{259, 478, 1116, 260, 492, 1127, 284, 507, 1137, 299, 522, 
        1145, 314, 537, 1151, 329, 552, 344, 1257, 567, 1164, 359, 582, 1178, 
        374, 597, 1189, 389, 612, 1198, 404, 627, 1205, 419, 642, 1210, 434, 
        1299, 657, 449, 1311, 672, 464}], 
       Line3DBox[{261, 479, 1117, 263, 493, 1128, 285, 508, 1138, 300, 523, 
        1146, 315, 538, 1152, 330, 553, 1156, 345, 568, 1165, 360, 583, 1179, 
        375, 598, 1190, 390, 613, 1199, 405, 628, 1206, 420, 643, 1211, 435, 
        658, 1214, 450, 1312, 673, 465}], 
       Line3DBox[{265, 481, 1118, 266, 1219, 495, 287, 1223, 510, 302, 1229, 
        525, 317, 1237, 540, 332, 1247, 555, 347, 1259, 570, 1166, 362, 585, 
        377, 1269, 600, 392, 1274, 615, 407, 1281, 630, 422, 1290, 645, 437, 
        1301, 660, 452, 1314, 675, 467}], 
       Line3DBox[{267, 482, 1119, 268, 496, 1129, 288, 1224, 511, 303, 1230, 
        526, 318, 1238, 541, 333, 1248, 556, 348, 1260, 571, 1167, 363, 586, 
        1180, 378, 601, 393, 1275, 616, 408, 1282, 631, 423, 1291, 646, 438, 
        1302, 661, 453, 1315, 676, 468}], 
       Line3DBox[{269, 483, 1120, 270, 497, 1130, 289, 512, 1139, 304, 1231, 
        527, 319, 1239, 542, 334, 1249, 557, 349, 1261, 572, 1168, 364, 587, 
        1181, 379, 602, 1191, 394, 617, 409, 1283, 632, 424, 1292, 647, 439, 
        1303, 662, 454, 1316, 677, 469}], 
       Line3DBox[{271, 484, 1121, 272, 498, 1131, 290, 513, 1140, 305, 528, 
        1147, 320, 1240, 543, 335, 1250, 558, 350, 1262, 573, 1169, 365, 588, 
        1182, 380, 603, 1192, 395, 618, 1200, 410, 633, 425, 1293, 648, 440, 
        1304, 663, 455, 1317, 678, 470}], 
       Line3DBox[{273, 485, 1122, 274, 499, 1132, 291, 514, 1141, 306, 529, 
        1148, 321, 544, 1153, 336, 1251, 559, 351, 1263, 574, 1170, 366, 589, 
        1183, 381, 604, 1193, 396, 619, 1201, 411, 634, 1207, 426, 649, 441, 
        1305, 664, 456, 1318, 679, 471}], 
       Line3DBox[{275, 486, 1123, 276, 500, 1133, 292, 515, 1142, 307, 530, 
        1149, 322, 545, 1154, 337, 560, 1157, 352, 1264, 575, 1171, 367, 590, 
        1184, 382, 605, 1194, 397, 620, 1202, 412, 635, 1208, 427, 650, 1212, 
        442, 665, 457, 1319, 680, 472}], 
       Line3DBox[{277, 682, 1320, 683, 278, 501, 1134, 293, 516, 1143, 308, 
        531, 1150, 323, 546, 1155, 338, 561, 1158, 353, 576, 1172, 1173, 368, 
        591, 1185, 383, 606, 1195, 398, 621, 1203, 413, 636, 1209, 428, 651, 
        1213, 443, 666, 1215, 458, 685, 686, 687}], 
       Line3DBox[{459, 667, 684, 1306, 444, 652, 1294, 429, 637, 1284, 414, 
        622, 1276, 399, 607, 1270, 384, 592, 1266, 369, 577, 354, 1159, 562, 
        1252, 339, 547, 1241, 324, 532, 1232, 309, 517, 1225, 294, 502, 1220, 
        279, 487, 1217, 250, 473, 681, 688}], 
       Line3DBox[{466, 674, 1313, 451, 659, 1300, 436, 644, 1289, 421, 629, 
        1280, 406, 614, 1273, 391, 599, 1268, 376, 584, 1265, 361, 569, 1258, 
        346, 554, 1246, 331, 539, 1236, 316, 524, 1228, 301, 509, 1222, 286, 
        494, 1218, 264, 480, 1216, 262}]}, {}, {}}},
    VertexNormals->CompressedData["
1:eJx0nHk01P37/yVkKUKhFEmyJEtakbEUKVGylRZKKdmyFEJUypIte9kzw1iH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     "]], 
   {GrayLevel[0], PointSize[Large], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhiIdIDRIufydCcrMjugimc6bNs1R0hAWBhV/ECR
A9/u9xJy3jJo6isdEo+uvHbojBKquEO9g+WWE2X7pqvDzYXJxyVPX3HvlRCa
eKaDFsMx44wDSqjiQHvnfnrhFhGig6a+0sHY/H7Hu4dGqOJAe19LHjI8XWQO
1w+z1+hY+83TYjJo4pkOTaUy9iFKOqjiQPp1QcnUd22maOorHf6s/HjJN8sG
VRxobyWLedC2eY5wdTB724oWxbZeUUITz3TojeMNkNpkhCoONC+gUKZiq4YN
mvpKhyvvD13LOeyEKg609+f8P3ets9zhfJi9k0rOPpkdqo4mnulQ7OXgc6jV
HFUcaK9+ztmwuB5HNPWVDrM2/E3piUUzH0i/2GvIwuDo6wAAelWFjg==
     "]]}},
  Axes->True,
  AxesLabel->{
    FormBox["\"npps=PointsPerCycle\"", TraditionalForm], 
    FormBox["\"nppi=IntegrationPointsPerCycle\"", TraditionalForm], 
    FormBox["\"Timing (s)\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  ImageSize->650,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotLabel->FormBox[
    TemplateBox[{"\"time in seconds=\"", 
      RowBox[{
        RowBox[{
         "2.33612536`", " ", 
          "\"(\\!\\(\\*FractionBox[\\(nppi\\), \\(100\\)]\\))\"", " ", 
          "\"(\\!\\(\\*FractionBox[\\(npps\\), \\(100\\)]\\))\""}], "+", 
        RowBox[{
         "0.026024480000000117`", " ", 
          "\"(\\!\\(\\*FractionBox[\\(nppi\\), \\(100\\)]\\))\""}], "-", 
        RowBox[{
         "0.004049740000000018`", " ", 
          "\"(\\!\\(\\*FractionBox[\\(npps\\), \\(100\\)]\\))\""}], "+", 
        "0.047092060000002774`"}]}, "RowDefault"], TraditionalForm],
  PlotRange->{{0, 500}, {0, 500}, {0., 58.56009140884732}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{2.2548793961677775`, -1.2591220322595174`, 2.186350982028435},
  ViewVertical->{0., 0., 
   1.}]], "Output",ExpressionUUID->"89c351ae-125b-4cd8-a42c-e673a7cc1990"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"decoupledMemoryModel", "=", 
   RowBox[{"LinearModelFit", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Flatten", "/@", 
        RowBox[{"Flatten", "[", 
         RowBox[{"decoupledTimingsList", ",", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}], "}"}]}], "]"}]}], ")"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "4"}], "}"}]}], "\[RightDoubleBracket]"}],
      "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "nSampling", ",", "nIntegration", ",", 
       RowBox[{"nSampling", "\[Times]", "nIntegration"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"nSampling", ",", "nIntegration"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot3D", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"decoupledMemoryModel", "[", 
       RowBox[{"nSampling", ",", "nIntegration"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"nSampling", ",", "0", ",", "500"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"nIntegration", ",", "0", ",", "500"}], "}"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<npps=PointsPerCycle\>\"", ",", 
         "\"\<nppi=IntegrationPointsPerCycle\>\"", ",", 
         "\"\<Memory (B)\>\""}], "}"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<Memory used (B)=\>\"", ",", 
          RowBox[{"decoupledMemoryModel", "[", 
           RowBox[{
            RowBox[{
            "100", "\"\<(\!\(\*FractionBox[\(npps\), \(100\)]\))\>\""}], ",", 
            RowBox[{
            "100", "\"\<(\!\(\*FractionBox[\(nppi\), \(100\)]\))\>\""}]}], 
           "]"}]}], "}"}], "]"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"ImageSize", "\[Rule]", "650"}]}], "\[IndentingNewLine]", "]"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{"ListPointPlot3D", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Flatten", "/@", 
         RowBox[{"Flatten", "[", 
          RowBox[{"decoupledTimingsList", ",", 
           RowBox[{"{", 
            RowBox[{"{", 
             RowBox[{"1", ",", "2"}], "}"}], "}"}]}], "]"}]}], ")"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "4"}], "}"}]}], "]"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"PointSize", "[", "Large", "]"}]}], "}"}], "}"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], 
  "]"}]}], "Input",ExpressionUUID->"a8d77673-c8a2-4836-9b25-f1938317ecc5"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJx1nXc4V//7x5H2ppTSEg2jMiIh70OJZMvO3nvvvWVkRpK29tLQjqho0JSS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    "], {{
      {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
        GrayLevel[1], 3], 
       StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1mgf8ldMfx+99zjk0qVQaRoWohDYNlZK0h7SoNGlvlBFRmdl7z4REiZLs
EaFIRIuGaJr/Mv/vj8/1ejm+79+5z33u85zxHZ9T1YFjuo3OcrncJ/wvYDdj
f8V+hi2az+X+B39LOyLmcmWwJ2Fr81kr+Cw+rwe3hfvA9eEz4b5wA7gdfA78
ON/ZD9fBTqX/Ifh5+q+B58GvwePhu+A58ET4HngufAn8MPwCPAV+EJ4PHw+f
BneHj4ZPgdvDR8Enw+3gw+F6cGv4CLg+fDr8E1wN/ogX/gLeBr+O/ZL2HfyG
3o/WCx7O9a3h3vAIuAncFR4I14Jbwt3gY+DGcAe4OtwE7gi3h8+Dx8NN4W7w
IPha+Dn9LnwF/CT8EnwlPAd+GZ4OPwUvhl/mWT+A72EMF9H/NbyT/gXwWvh7
+Gl4JfwN/Ay8SnMHN+Y7v8EnYg/m74NomzXuwdes5drFtA3wHv0WvB7eDb8E
r4N3wa/Am+Af4QNpvxTWxlz6P8Fuou9v3R8+ATuP/tXwFvgFjS+8HT4HvgK+
BR4EXwPfDV8PPw+/CV8Fz4WXwBPgu+Gn4MHwtRoHeCR8M/wIPAK+CX4Yfh7+
Av4Ong+vgbfBc+CP4A3wGnirxgB7HW2+5p3+5+DP4a3wz/BR8MeMUx4uBx+u
94aP1p6h/3H4FXgF/bPhx+BF8CmM9aeaX655lv434dWFeXlD+6vwvlrbC+Ab
4EfghfCN8KPwi/B9hTF5C74ffgF+G34AXgC/A98BPwO/Ct8OPw0v1frnGUpr
LrA96B8BX0L/TPh+eB48BJ4KXw+fDY+EL4V7wqPgy+De8Bh4WmHuxsHT4T7w
WPgKuBc8Gr4cHgBPgmfC58GT4VnwMPhS+Eb4Avhy+Cb4fPgyeHZhTrU2boUH
whfC18BD4UvgG+Al8EZ4L3wWPByeqjUJV4JrwL/pb/kt7K+0A+DDsL/TisHV
sftoReBq2P20ovDRml9agithV2feK0u1LmhbNM7YjFYersI1f9FKwsdj/6SV
gGti/6AVh4/DbuP6sppH1kOCK8DH0N8dPh+eomeEK8LHwhXg4+FT4Yzv1IW/
0Dqk1YFL8nkp2jFwQ+25wlqtDx9cWJ8N9E7wYXBtvTd8uPwAXBY+Dm4MHwrX
gpvB5eGacFO4HFwDbgIflvkZWsnvRXNpnqUI/ZXhWvT3hyfCM+Cn4I/hjfBd
8KvaR3ALBvZi/p7APd6M/o2vuU8T+odrDdFXB+6Q2XeeAc/CTqH/ZLiv1jHc
MjkeTISbJ8eM8XDTZF8wBj4tOd5Mghsn+45R8KnJPmUc3Cw59oyFu8B3wtN1
TXT8a459gvYz/CbP+WK0L1gJL4se9y+1x6PX1vvw09Fr6134mei19R78WvTc
rIWXRs/HGviV6Hn6HJ4Tvf7ehpdEj+9qeHH0+v4Mfjl6rXwKvxS9nlbBrZJj
yWT6WifHkgvh05NjyUVwR/gWeJriOHyG4hNcH+4MD4OPh9vAA+Cj4cZwL7gW
fDrcH24Ad9Ha1VqAO8JD4HpwJ3go3DV57q+CO8O3wVfCJ8Ht4MHwifCZ8CD4
BLgtPBA+Cj4F7gnPi95Ly3nHavSfTP/Z9B0LN4f7wu2S/filcJvk+HEx3AG+
Wb4G7gTfKv8Ct4dvkt+B2ybnIlPhM5Nj8yXwKcnxaSRcEz4N7gfXgFvC58LH
wS3gc+CGcFf4ArgR3E2+Ca4Onwr3gZ+L9hEf8C7zo33Hh/ALcC5zTlIFezp/
ns1npQr7XfnZY9EsH3CUxg7+W3tdYworgTuIdoJ8C30lg685Vusu+JoacFU1
+Qds5PvHwifzW1X4uwpcD3ukmmI9n1eLvuc/8CG0RnBbrn8kOo9SPlWG1hA+
oxCzFOM+zXuMF8Hv5j0PL8Hv5b0GX4bfz3tdLIE/yHt+FsPL4bvhZXp3+B74
NXglfC/8OrwKfgh+F16j54Hfh7+EH4bfk8+EH8ucO30FPwovh9fCD8LvwJ/D
T8Ir4PW6JtqXKv5Xkw+Ce9HfSHMOj4LraA3Cw+CGmn94ZN5rsx88Ou/12x8e
A9fVWobPh/sGx7LfsWNYG8X5rBW/+Xx0/rSC/qei49Y78BvR/voruC/XPwHf
SN9YuATcOnqPDuCeY/lOVbgN3BM+Ce4BD4VPhM+Ch+S9fofCF8LfRseh/wWv
5SH0T857vQ+DL8p7nw2GJxVi7hT4WrhNcH4rX601PgieqHhB/6mKido79HeB
B9BfA+4M9887f1YufV7eebXuMw4+Fu4Inwv3U6yAr4bPlY+Hr4JHyZfAt+Ud
C7UvWuY9llrzzbXHMq/PepoXnmNPYV9UzPxsnRSvsTtyXut/03bmvAe20/7K
ueYpxXWH5F0naLy1j1rknVOrvxS2Tt576n0+LwmXoeU1f5njfmW4fvQ9mkR/
T9/X382if0v7sZjyhpzztpPyfpb3MtddepY3gnOQfd7uuXL5Qj/X1NV9c45T
lfm7Bdwl73uq/lJt0zDabuLztzJfX5HPj6N/b8FXVKK/Odw573cpTfvmv3ct
vK9qRNUSyo3KFK7TNYqb+nxr5lqyiNZX5lrhX875/fRMeo79BS5deCb1qQ4r
kXeNwX//1qAHFr5bNLjWU85QgtYU3oAtHlxzrccWC67F1mFDcA2oGP1PYTw1
rsUL99e9SxbmSj+mdaP1s0L7QbkRXBU7NzqnbIF9OLpueBK7JfM8KD9UXaUx
AXNZYUxyhd/R+/xSeI/ihfdqqtid93r4OnNt9VXm8dZ3dY/1mcdYeehPhXEq
m3fNptptM1xb+Ulhr31S2AunaU7hTnC/vGPHh/z9qmoCbAP629D/enQeebqe
hReprn7lF8Fx4Qz44+iav7PygeDY1FX5VbB/U+xuF7z3Ffc7BPsK5RKdgv2J
8oRuwf5EMbFLsP9RrFT82pXzPlbep/riyrxjnPaj/FvI/GyN6D9SPg/uAXfN
e52vpK9ccAxqx/XvR9f8beU7g9/3TLh8cPxqr5jG593hwbpn8H06aZ4zz/tp
igPBv9UFPhxuBnfQvYP3SEfFzGAdQP5sUXRt0FK5W7AWIb/9dbSP1Pv1Dq5Z
5EfrBftk5TD1g321com6wc+mnKFxcHxRPtYwOI4oD2kQHIOUhyhmvcv9FkbH
5bfhBdhPM69H7UHVgVo/WkdlC2tJuofWrPazrqvJNT/mnCc0VbzJOd9rCw/M
Ocf7NFrL6K28I9iHy3+3Do5ByutaBMdB5XLK2afBN/M7/YPnV3Xk99E1pPL5
Y4JjVjf41OA4q7y0dvAaVr5XPTgWd4ePhztoDOFawfGih3Ki4FijfPWE4Fij
HLJZ5uefwDNUL8QCxQT5cfnzjzLHD+2dj+GlwfXLA1yzPXOtp1j8SrCGcD/9
C4NzjzvgJcH5w33yr5m1AuXw5bmnUjvVjK8G6yQP0nF/sP4zA34wuMZX3jQv
OLe5VblicB4lzWBZsLbzEP0vBOctt8MPBGsXM+EF8NvwbfCi4Fzoruh66wH4
OZ7lomD9RLXSsOA4rppoTHDdrfpbddhs/RbXX0j/rJzro8nBWo3qpjuCdSrV
ES8F51R3w4vhD+F74ReVs8A7uM9dwXqO8v87g3Ut5eEvBudpd8Kjg9eJarf7
grXBq6NrsqWaI+4zDp6h98pbG5T+8yg8Cb5OY6h3VH6kcYYnw9drvuBL4Vvg
x+Cr4Xs1tvAM+D74WVhi6HSNLTwWvlrPBk+Db4efhC+Hb4OfgC+Db4Uf11jB
N2jNyN+qVoRnaWzpv0rrhP5lmddDBfjZ4Jz2FjqeDq6Rb9JeDs6Zr4GLJus7
qknvVZ2Zcz31THBufDNcIlmHUk44N3isZsNzgvPqG+Ang/Pq6+EngnPv6+DH
g3Pya6PzSs3dOp7tnGCt5g/sW9G6gOLpL9Hajer0S4PXiWrwynB7eAv2fNrF
OddNFYM14W+x+zPrCapbf8+sM6iebRmsNe3CtgrWkXYrzgTrTnu074O1pr3y
qcGayffKBWgXwD8o/gdrXDvkm4O1rJ3YfZm1DtXIZxb8j/zwH5l1D9XXf2bW
W1SDHxKsb2/CxmDdWDV7mWDNeSO2QrDu/U2wHvJTzrG3UrDuvRlbN+/8c7ni
Sb6Qm8G/ZtZtpCHsyazJqAbcnVmrUW24K7Ouopp3L3xEznXBX3DtnHWDv6LX
urSUXoW9rJjSI1g3+w07g3ZnzpqAdBStn2Va/8F6u/SBmcH6qvSBWcHau2rn
mKwVSnu5nf4ncq6XbwvWq1VTXx68B7UXZwfrmdI1bwzW+VWP3xCs26umvj7Y
F6nWvixYs5U+0ydYh9yP/SGzPib9ZGdmTU+6SsfgWuAn+fVgrelnrbvguuBH
bE/aRfA+bPdg7fFXbNdgTfIXbLVgHX4rtmpw/FLsrgn3gbdjawRr/t9h6wTX
JopxxwWfC2wLzo+VA6yif0dm7U46z/Bk3Vyx4NxgbfNP7LvROprWz/ponUTv
siFae9G7bI3WYVUbSoSUrylD37pojUXvmE/2R4co10j2ZWXhfsGa6l/YbdEa
rvbvuGC/V0R5VLK/K6eYmxwXFceV02p9qob4LlrP1TPvidZhA/aH6Brsb/p3
RNdm/8BfRes52pspWcsur7gZrR3reXZG64Nyfgcka9yHwnujNegoH5KckynP
3BWtI+exu6N15Aw7PtjfFo3OjSNzsCFzLr0ROzm5jjhA9Qh2SHC80HeHwjNz
fpdBwT5ZzyOdfHPO51ODg32+fndCsJ8vBk8M9v/F4WuDNXaN+cDgeKFxmB6s
/2u+tkRr7lrPV9Eez3m+zguuWzWGA4JjrnKhm4O1fY1b2eQcV7nrxmidTeu2
UXStKq1AOVygrctcC6igUO1wRLI2oTxqeHBM1NgenJxDKy/9Jlqbkn/YFK1Z
aY/ofEg1qTRP1bOqhzWGpZNrBtUI1wWfNWj9rI3W7uSfxxb8gPKHNdH6oXzv
6ujzM/nnldFnhNpTn0drifLVX0brfvL5X0RrkooFn0SfL2qvvRd9niefvCr6
fFH79O1o/Vp130fR54La1+9Ea+iqDcsla2rK/x8OPoupBD8UnF8p7yqZfE5z
GP03Bedj8mOlkjUy1QKP0P8W/ZW1V5K1MNVHZZL1L9VN9wSfB1WEf4w+t0jY
z6LPFBWzfoo+CzkAeyt/L1Q+AP8cfRZyoPxEsl7zb92RrOOo5qqUrKeoTvk1
WgfRvv4w+gxScefv6FynlOYzOqfRfvlfdC6i9TwqOEfSb40Mzlv0PCOC8yU9
877oHEhrvkjy2ZLe65/ovKc09sDkcy89/+/ReVhJ7P7oXK0E9s/o3Ohg7EHJ
dbXq6EOT9TXVYuWTdSvVbhWTdSLVVs8Hn6NpXj6IPutVLlEhWSdSLbYi+sxV
uccf0TnfQdjl0efBitHFks/PNO/zg2tn5dXFk8/SNKdXBp+76b1uCT5fk4+6
IvhsTuOps2z5m0l8b2DyeaHy8POSzzuVew9IPotVDt8/+XxUOV61wv7VPh6S
fCaq/HxQ8jml6ojByeeXyoerJGuLqnEm8Qx35DyeqvcVcyYm5xzKPVT/Su/a
nXOdrxpHGsa4ZG1H9c345HPJXEE/ODJZl1Q9pbpPdc+E5PNi+Rb5mGH8vTDz
uXO/5HMd5ZwXJJ9DK88fkXxmrJpIGvJ/OpM0ZOlb0r1GJ58fq37plqztKrcf
mXz2rDprVPLZnuqjocln26opeifrtspdeyXrvMpdz00+01XOfE6yhqu8t0ey
tqvc+6xkvVj1UfdkHVk1V59kXVi5cc9kvVg58NnJmrJyb+kRuwr5W9Vk/Vc1
5tTgekFrTOdCW3I+G5wSXFNo/UvTUwz6T2f7PueaXP/eQPqXYtUlweew2heq
C7bmfC6tQnx7IVeUfvhDzrW9/k2G6nT5/GmFXEt51/8BKagGhw==
           "]], Polygon3DBox[CompressedData["
1:eJwtmgf8V9Mfxu8ZX1saFFkVUTJKS0WlskIoFWkokqJhh0R2kpmMjLIL8bcz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           "]], Polygon3DBox[CompressedData["
1:eJwt13fcl+MaAPDXb7SNlI5RKA2lQVtCkaJQRGmJtrS00ZC2ljQ1pZ0GSoOM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           "]]}],
        Lighting->{{"Ambient", 
           RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
          "Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{0, 2, 2}]}, {"Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{2, 2, 2}]}, {"Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
      {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0UkrRlEcB+Brnl/DQjJGkoS94hOwsiDsLIQFK2FlI+yFvbAX9opP8Jq9
xjLPSlmJ55TF7z6/c+v2P+fc6v7RzpGkKIqmJFcJPcfjm7fJUVTAAutPvUr/
ZTNjKVHUxgp2sJF9bA3vZVjv4SQHOcdxLnGGa1zgFle4yw3u8ca8/TCfB7zj
Ie95xAce85EnfOKznOovTPCVZ3zjOd95wQ9e8pNXTDhPkl4k19aFTJZte4lb
r3OHy9zkPFc5zUWOcZYDnGA3u2RIb2EvG9jOMraGe2YTf8yuDHtiPpvNjYW7
ZF74jrmsZw7rmM1aZrGGmaxipWTo5UxnKdNYwlQWMyXcrVmxcEY97vH1/9//
AEj+PVE=
        "]]}, 
      {GrayLevel[0.2], 
       Line3DBox[{741, 1086, 1087, 1071, 1082, 498, 1070, 1053, 1073, 1189, 
        1397, 961, 1072, 1054, 1190, 962, 1074, 1185, 1191, 963, 742, 1192, 
        964, 743, 1193, 965, 744, 1194, 1088, 1294, 745, 1195, 966, 746, 1196,
         967, 747, 1197, 968, 748, 1198, 969, 749, 1199, 970, 750, 1200, 971, 
        751, 1201, 972, 752}], 
       Line3DBox[{753, 1055, 1076, 1083, 1084, 1398, 1075, 1056, 1078, 736, 
        1085, 1077, 1057, 1202, 973, 754, 1186, 1203, 974, 755, 1187, 1204, 
        975, 756, 1205, 976, 757, 1206, 1089, 1295, 758, 1090, 1296, 759, 
        1207, 977, 760, 1208, 978, 761, 1209, 979, 762, 1210, 980, 763, 1211, 
        981, 764, 1212, 982, 765}], 
       Line3DBox[{767, 1058, 1079, 1091, 1391, 766, 1059, 1092, 1392, 768, 
        1060, 525, 769, 1188, 1213, 983, 770, 1214, 984, 771, 1215, 985, 772, 
        1216, 1093, 1297, 773, 1094, 1298, 774, 1095, 1299, 775, 1217, 986, 
        776, 1218, 987, 777, 1219, 988, 778, 1220, 989, 779, 1221, 990, 780}],
        Line3DBox[{782, 1061, 1080, 1062, 1393, 781, 1063, 1064, 1394, 783, 
        1065, 1066, 1395, 784, 719, 1067, 785, 1222, 991, 786, 1223, 992, 787,
         1224, 1096, 1300, 788, 1097, 1301, 789, 1098, 1302, 790, 1099, 1303, 
        791, 1225, 993, 792, 1226, 994, 793, 1227, 995, 794, 1228, 996, 795}],
        Line3DBox[{797, 1100, 1304, 796, 1068, 1069, 1396, 798, 1101, 1305, 
        799, 1102, 1306, 800, 555, 801, 1229, 997, 802, 1230, 1103, 1307, 803,
         1104, 1308, 804, 1105, 1309, 805, 1106, 1310, 806, 1107, 1311, 807, 
        1231, 998, 808, 1232, 999, 809, 1233, 1000, 810}], 
       Line3DBox[{812, 1108, 1312, 811, 1109, 1313, 813, 1110, 1314, 814, 
        1111, 1315, 815, 1112, 1316, 816, 571, 817, 1234, 1113, 1317, 818, 
        1114, 1318, 819, 1115, 1319, 820, 1116, 1320, 821, 1117, 1321, 822, 
        1118, 1322, 823, 1235, 1001, 824, 1236, 1002, 825}], 
       Line3DBox[{829, 1237, 1003, 827, 1238, 1004, 831, 1239, 1005, 833, 
        1240, 1006, 835, 1241, 1007, 837, 1242, 1008, 839, 1243, 588, 841, 
        1244, 1009, 843, 1245, 1010, 845, 1246, 1011, 847, 1247, 1012, 849, 
        1248, 1013, 851, 1249, 1014, 853, 1251, 1016, 855}], 
       Line3DBox[{854, 1015, 1250, 852, 1335, 1130, 850, 1334, 1129, 848, 
        1333, 1128, 846, 1332, 1127, 844, 1331, 1126, 842, 1330, 1125, 840, 
        1329, 587, 838, 1328, 1124, 836, 1327, 1123, 834, 1326, 1122, 832, 
        1325, 1121, 830, 1324, 1120, 826, 1323, 1119, 828}], 
       Line3DBox[{857, 596, 856, 1252, 1017, 858, 1253, 1018, 859, 1254, 1019,
         860, 1255, 1020, 861, 1256, 1021, 862, 1257, 1131, 1336, 863, 604, 
        864, 1258, 1022, 865, 1259, 1023, 866, 1260, 1024, 867, 1261, 1025, 
        868, 1262, 1026, 869, 1263, 1027, 870}], 
       Line3DBox[{872, 1132, 1337, 871, 1133, 1338, 873, 1264, 1028, 874, 
        1265, 1029, 875, 1266, 1030, 876, 1267, 1031, 877, 1268, 1134, 1339, 
        878, 1135, 1340, 879, 620, 880, 1269, 1032, 881, 1270, 1033, 882, 
        1271, 1034, 883, 1272, 1035, 884, 1273, 1036, 885}], 
       Line3DBox[{887, 1136, 1341, 886, 1137, 1342, 888, 1138, 1343, 889, 
        1274, 1037, 890, 1275, 1038, 891, 1276, 1039, 892, 1277, 1139, 1344, 
        893, 1140, 1345, 894, 1141, 1346, 895, 636, 896, 1278, 1040, 897, 
        1279, 1041, 898, 1280, 1042, 899, 1281, 1043, 900}], 
       Line3DBox[{902, 1142, 1347, 901, 1143, 1348, 903, 1144, 1349, 904, 
        1145, 1350, 905, 1282, 1044, 906, 1283, 1045, 907, 1284, 1146, 1351, 
        908, 1147, 1352, 909, 1148, 1353, 910, 1149, 1354, 911, 652, 912, 
        1285, 1046, 913, 1286, 1047, 914, 1287, 1048, 915}], 
       Line3DBox[{917, 1150, 1355, 916, 1151, 1356, 918, 1152, 1357, 919, 
        1153, 1358, 920, 1154, 1359, 921, 1288, 1049, 922, 1289, 1155, 1360, 
        923, 1156, 1361, 924, 1157, 1362, 925, 1158, 1363, 926, 1159, 1364, 
        927, 668, 928, 1290, 1050, 929, 1291, 1051, 930}], 
       Line3DBox[{932, 1160, 1365, 931, 1161, 1366, 933, 1162, 1367, 934, 
        1163, 1368, 935, 1164, 1369, 936, 1165, 1370, 937, 1292, 1166, 1371, 
        938, 1167, 1372, 939, 1168, 1373, 940, 1169, 1374, 941, 1170, 1375, 
        942, 1171, 1376, 943, 684, 944, 1293, 1052, 945}], 
       Line3DBox[{947, 1172, 1377, 946, 1173, 1378, 948, 1174, 1379, 949, 
        1175, 1380, 950, 1176, 1381, 951, 1177, 1382, 952, 1178, 1383, 1384, 
        953, 1179, 1385, 954, 1180, 1386, 955, 1181, 1387, 956, 1182, 1388, 
        957, 1183, 1389, 958, 1184, 1390, 959, 729, 1081, 960}]}, 
      {GrayLevel[0.2], 
       Line3DBox[{278, 701, 725, 499, 1190, 279, 706, 512, 1202, 306, 713, 
        525, 321, 718, 1395, 539, 336, 1305, 553, 351, 1314, 568, 366, 1325, 
        583, 1239, 381, 598, 1253, 396, 613, 1264, 411, 1343, 628, 426, 1349, 
        643, 441, 1357, 658, 456, 1367, 673, 471, 1379, 688, 486}], 
       Line3DBox[{280, 702, 726, 703, 1191, 281, 707, 708, 1203, 307, 714, 
        715, 1213, 322, 719, 720, 337, 1306, 554, 352, 1315, 569, 367, 1326, 
        584, 1240, 382, 599, 1254, 397, 614, 1265, 412, 629, 1274, 427, 1350, 
        644, 442, 1358, 659, 457, 1368, 674, 472, 1380, 689, 487}], 
       Line3DBox[{282, 500, 1192, 283, 709, 710, 1204, 308, 526, 1214, 323, 
        540, 1222, 338, 555, 353, 1316, 570, 368, 1327, 585, 1241, 383, 600, 
        1255, 398, 615, 1266, 413, 630, 1275, 428, 645, 1282, 443, 1359, 660, 
        458, 1369, 675, 473, 1381, 690, 488}], 
       Line3DBox[{284, 501, 1193, 285, 513, 1205, 309, 527, 1215, 324, 541, 
        1223, 339, 556, 1229, 354, 571, 369, 1328, 586, 1242, 384, 601, 1256, 
        399, 616, 1267, 414, 631, 1276, 429, 646, 1283, 444, 661, 1288, 459, 
        1370, 676, 474, 1382, 691, 489}], 
       Line3DBox[{286, 502, 1194, 288, 514, 1206, 310, 528, 1216, 325, 542, 
        1224, 340, 557, 1230, 355, 572, 1234, 370, 587, 1243, 385, 602, 1257, 
        400, 617, 1268, 415, 632, 1277, 430, 647, 1284, 445, 662, 1289, 460, 
        677, 1292, 475, 1383, 692, 490}], 
       Line3DBox[{290, 504, 1195, 291, 1296, 516, 312, 1298, 530, 327, 1301, 
        544, 342, 1308, 559, 357, 1318, 574, 372, 1330, 589, 1244, 387, 604, 
        402, 1340, 619, 417, 1345, 634, 432, 1352, 649, 447, 1361, 664, 462, 
        1372, 679, 477, 1385, 694, 492}], 
       Line3DBox[{292, 505, 1196, 293, 517, 1207, 313, 1299, 531, 328, 1302, 
        545, 343, 1309, 560, 358, 1319, 575, 373, 1331, 590, 1245, 388, 605, 
        1258, 403, 620, 418, 1346, 635, 433, 1353, 650, 448, 1362, 665, 463, 
        1373, 680, 478, 1386, 695, 493}], 
       Line3DBox[{294, 506, 1197, 295, 518, 1208, 314, 532, 1217, 329, 1303, 
        546, 344, 1310, 561, 359, 1320, 576, 374, 1332, 591, 1246, 389, 606, 
        1259, 404, 621, 1269, 419, 636, 434, 1354, 651, 449, 1363, 666, 464, 
        1374, 681, 479, 1387, 696, 494}], 
       Line3DBox[{296, 507, 1198, 297, 519, 1209, 315, 533, 1218, 330, 547, 
        1225, 345, 1311, 562, 360, 1321, 577, 375, 1333, 592, 1247, 390, 607, 
        1260, 405, 622, 1270, 420, 637, 1278, 435, 652, 450, 1364, 667, 465, 
        1375, 682, 480, 1388, 697, 495}], 
       Line3DBox[{298, 508, 1199, 299, 520, 1210, 316, 534, 1219, 331, 548, 
        1226, 346, 563, 1231, 361, 1322, 578, 376, 1334, 593, 1248, 391, 608, 
        1261, 406, 623, 1271, 421, 638, 1279, 436, 653, 1285, 451, 668, 466, 
        1376, 683, 481, 1389, 698, 496}], 
       Line3DBox[{300, 509, 1200, 301, 521, 1211, 317, 535, 1220, 332, 549, 
        1227, 347, 564, 1232, 362, 579, 1235, 377, 1335, 594, 1249, 392, 609, 
        1262, 407, 624, 1272, 422, 639, 1280, 437, 654, 1286, 452, 669, 1290, 
        467, 684, 482, 1390, 699, 497}], 
       Line3DBox[{302, 510, 1201, 303, 522, 1212, 318, 536, 1221, 333, 550, 
        1228, 348, 565, 1233, 363, 580, 1236, 378, 595, 1250, 1251, 393, 610, 
        1263, 408, 625, 1273, 423, 640, 1281, 438, 655, 1287, 453, 670, 1291, 
        468, 685, 1293, 483, 729, 730, 731}], 
       Line3DBox[{484, 686, 1377, 469, 671, 1365, 454, 656, 1355, 439, 641, 
        1347, 424, 626, 1341, 409, 611, 1337, 394, 596, 379, 1237, 581, 1323, 
        364, 566, 1312, 349, 551, 1304, 334, 537, 1393, 716, 319, 523, 1391, 
        711, 304, 511, 1398, 735, 727, 704, 276, 498, 732, 723, 739, 738, 
        722}], Line3DBox[{485, 687, 1378, 470, 672, 1366, 455, 657, 1356, 440,
         642, 1348, 425, 627, 1342, 410, 612, 1338, 395, 1252, 597, 380, 1238,
         582, 1324, 365, 567, 1313, 350, 552, 1396, 721, 335, 538, 1394, 717, 
        320, 524, 1392, 712, 305, 737, 736, 728, 705, 277, 1397, 734, 733, 
        724, 700, 740}], 
       Line3DBox[{491, 693, 1384, 476, 678, 1371, 461, 663, 1360, 446, 648, 
        1351, 431, 633, 1344, 416, 618, 1339, 401, 603, 1336, 386, 588, 1329, 
        371, 573, 1317, 356, 558, 1307, 341, 543, 1300, 326, 529, 1297, 311, 
        515, 1295, 289, 503, 1294, 287}]}, {}, {}}},
    VertexNormals->CompressedData["
1:eJx0e3k01e33tjFFGkgDilSSSqUBlZtKkamBSiQkJBpESYjQJHNImZUyZZYy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     "]], 
   {GrayLevel[0], PointSize[Large], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhiIdECm77kEOaKKZ4LpSYJJqOIHisD0M81sNPWV
YLrNoQhV3KEeTKu9KXNENhcmf4ElCU0cQl9XKkIVh9q7Q6MaTT3Y3gOTzZpQ
xSH2HrC82eaIrB9mbw5XNpo4RB+HXDWqOIR2aJzbgqYebK+DmW43qjjE3gSJ
exMckcMFZm+2ahGaONheh3vaTajiUHsvqnejqQfTCyo+TkQVh9j7YNH5aY5I
fLi9C46VoYmD7T3gd7INVRzqj7M3JqCph9jDdRbNfKh/jzrMcQQAtPJd0A==

     "]]}},
  Axes->True,
  AxesLabel->{
    FormBox["\"npps=PointsPerCycle\"", TraditionalForm], 
    FormBox["\"nppi=IntegrationPointsPerCycle\"", TraditionalForm], 
    FormBox["\"Memory (B)\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  ImageSize->650,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotLabel->FormBox[
    TemplateBox[{"\"Memory used (B)=\"", 
      RowBox[{
        RowBox[{
         "4.72185704`*^6", " ", 
          "\"(\\!\\(\\*FractionBox[\\(nppi\\), \\(100\\)]\\))\"", " ", 
          "\"(\\!\\(\\*FractionBox[\\(npps\\), \\(100\\)]\\))\""}], "+", 
        RowBox[{
         "104696.23999999976`", " ", 
          "\"(\\!\\(\\*FractionBox[\\(nppi\\), \\(100\\)]\\))\""}], "+", 
        RowBox[{
         "65224.72000000449`", " ", 
          "\"(\\!\\(\\*FractionBox[\\(npps\\), \\(100\\)]\\))\""}], "-", 
        "214228.55999998667`"}]}, "RowDefault"], TraditionalForm],
  PlotRange->{{0, 500}, {0, 500}, {-214228.49931332725`, 
    1.1868178531553945`*^8}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{
   Automatic, Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"de89ec8e-eeb6-4146-9f76-1f2ec01e46f0"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Cutting off the long trajectories", \
"Subsection",ExpressionUUID->"f98f6572-4a47-4742-a6eb-3a1de0460153"],

Cell["\<\
This section shows, as an example of the use of the package, the use of the \
integration gate to eliminate the contribution from long trajectories. This \
can be tested by the reduced presence of quantum path interference patterns \
in the spectrum, and more practically by examining the dependence of the \
quantum phase on the field intensity.\
\>", "Text",ExpressionUUID->"b07b811f-09d3-4516-8a72-cf1ac3a8ce3c"],

Cell[CellGroupData[{

Cell["The gating cutoff time", \
"Subsubsection",ExpressionUUID->"5060d0b7-0238-45ef-89e1-78833b4ddca0"],

Cell["Given the classical trajectory,", \
"Text",ExpressionUUID->"ad304c4c-559f-447a-afc5-ebd9b21c8524"],

Cell[BoxData[
 RowBox[{
  RowBox[{"trajectory", "[", 
   RowBox[{"\[Omega]t_", ",", "\[Omega]t0_"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"x", "[", "\[Omega]t", "]"}], "/.", 
    RowBox[{"First", "@", 
     RowBox[{"DSolve", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"x", "''"}], "[", "\[Omega]t", "]"}], "\[Equal]", 
          RowBox[{"Cos", "[", "\[Omega]t", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "'"}], "[", "\[Omega]t0", "]"}], "\[Equal]", "0"}], 
         ",", 
         RowBox[{
          RowBox[{"x", "[", "\[Omega]t0", "]"}], "\[Equal]", "0"}]}], "}"}], 
       "\[IndentingNewLine]", ",", "x", ",", "\[Omega]t"}], 
      "\[IndentingNewLine]", "]"}]}]}], 
   ")"}]}]], "Input",ExpressionUUID->"e37f3e97-9663-49d4-ad6e-866c0d89f14b"],

Cell["\<\
the recollision kinetic energy and excursion time can be found as\
\>", "Text",ExpressionUUID->"23b08a47-9a46-489a-a7ca-d1ffc31241bb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"recollisionKE", "[", 
   RowBox[{"\[Omega]t0_", "?", "NumericQ"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"trajectory", "[", 
         RowBox[{"\[Omega]tt", ",", "\[Omega]t0"}], "]"}], ",", 
        "\[Omega]tt"}], "]"}], "2"], "/.", 
     RowBox[{"\[Omega]tt", "\[Rule]", "\[Omega]t"}]}], ")"}], "/.", 
   RowBox[{"First", "[", 
    RowBox[{"Quiet", "[", 
     RowBox[{"NSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"trajectory", "[", 
           RowBox[{"\[Omega]t", ",", "\[Omega]t0"}], "]"}], "\[Equal]", "0"}],
          ",", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "\[LessEqual]", "\[Omega]t", "<", 
          RowBox[{"2", "\[Pi]"}]}]}], "}"}], ",", "\[Omega]t"}], "]"}], "]"}],
     "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"recollisionExcursionTime", "[", 
   RowBox[{"\[Omega]t0_", "?", "NumericQ"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Omega]t", "-", "\[Omega]t0"}], ")"}], "/.", 
   RowBox[{"First", "[", 
    RowBox[{"Quiet", "[", 
     RowBox[{"NSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"trajectory", "[", 
           RowBox[{"\[Omega]t", ",", "\[Omega]t0"}], "]"}], "\[Equal]", "0"}],
          ",", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "\[LessEqual]", "\[Omega]t", "<", 
          RowBox[{"2", "\[Pi]"}]}]}], "}"}], ",", "\[Omega]t"}], "]"}], "]"}],
     "]"}]}]}]}], \
"Input",ExpressionUUID->"02608973-eef0-4e59-879d-554b25f23468"],

Cell["\<\
and the excursion time at the cutoff can be found by maximizing the kinetic \
energy.\
\>", "Text",ExpressionUUID->"c2decc17-a998-41d7-91dd-f21964c14042"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FindMaximum", "[", 
  RowBox[{
   RowBox[{"recollisionKE", "[", "\[Omega]t0", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]t0", ",", "0.3"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox[
   RowBox[{"recollisionExcursionTime", "[", "\[Omega]t0", "]"}], 
   RowBox[{"2", "\[Pi]"}]], "/.", 
  RowBox[{
  "Last", "[", "%", 
   "]"}]}]}], "Input",ExpressionUUID->"273ab914-20a4-4e8f-a390-41211bc609be"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.5865682833393322`", ",", 
   RowBox[{"{", 
    RowBox[{"\[Omega]t0", "\[Rule]", "0.3134075388859197`"}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"b3612343-7dda-4612-aeae-55fbdf98b0ca"],

Cell[BoxData["0.6502392848120567`"], \
"Output",ExpressionUUID->"6c5fb224-fc21-4919-bc46-004c95ff80d4"]
}, Open  ]],

Cell[TextData[{
 "In other words, the cutoff trajectories occur at excursion times of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Omega]", " ", "\[Tau]"}], "=", 
    RowBox[{"0.65", "\[Times]", "2", "\[Pi]"}]}], TraditionalForm]],
  ExpressionUUID->"72f5acf4-0b34-4531-817a-e2a5ecb3c6f8"],
 ", i.e. at a gate number of 0.65 cycles."
}], "Text",ExpressionUUID->"8a81dc3d-2b02-44c6-91d6-0d8e660d37ef"]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculation", "Subsubsection",
 CellChangeTimes->{{3.658075599564479*^9, 
  3.658075600724428*^9}},ExpressionUUID->"dd021953-f65e-4b16-867a-\
2ea1ae45458f"],

Cell[TextData[{
 "This calculation runs a standard linearly-polarized field with intensity \
between ",
 Cell[BoxData[
  FormBox["0.8", TraditionalForm]],ExpressionUUID->
  "85eaf81f-4765-4691-a5a5-be7509e9bc9b"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Times]", 
    SuperscriptBox["10", "14"], " ", 
    RowBox[{
     StyleBox["W",
      FontSlant->"Plain"], "/", 
     SuperscriptBox["cm", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "d8f7184f-1022-4b81-bd19-448a55118d4e"],
 ", with a fine intensity resolution. We compare the standard, non-gated \
calculation against a calculation with nGate set to 0.65, as per the above, \
and a sharp ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["sin", "2"], TraditionalForm]],ExpressionUUID->
  "fd52a034-be7a-4953-9df8-53425cff7d49"],
 " cutoff of 0.05 cycles."
}], "Text",ExpressionUUID->"d7a27088-684c-4aa2-b1d7-4769ae9cc7c5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"intRange", "=", 
   RowBox[{"Range", "[", 
    RowBox[{"0.8", ",", "2.", ",", "0.002"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nppsl", "=", "150"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetSharedFunction", "[", 
   RowBox[{"quantumPhaseScan", ",", "fourierDipole"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LaunchKernels", "[", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nFlat", "=", "0.65"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nGateRamp", "=", "0.05"}], 
  ";"}]}], "Input",ExpressionUUID->"a38b3f6c-3d40-4bce-8075-ce4606e36f18"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"LaunchKernels", "::", "nodef"}], "MessageName"], ":", 
  " ", "\<\"Some subkernels are already running. Not launching default \
kernels again. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/LaunchKernels\\\", ButtonNote -> \
\\\"LaunchKernels::nodef\\\"]\\)\"\>"}]], "Message", \
"MSG",ExpressionUUID->"112e2d55-ff10-4da5-803d-9bb6a3aabb42"]
}, Open  ]],

Cell["The actual calculation,", \
"Text",ExpressionUUID->"2644c4ef-1130-4ab6-9756-8b6ce750c355"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ParallelTable", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"quantumPhaseScan", "[", 
        RowBox[{"trajectories", ",", "int"}], "]"}], "=", 
       RowBox[{"makeDipoleList", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"VectorPotential", "\[Rule]", 
          RowBox[{"Function", "[", 
           RowBox[{"t", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               FractionBox["F", "\[Omega]"], 
               RowBox[{"Sin", "[", 
                RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}],
              "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"FieldParameters", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"F", "\[Rule]", 
             RowBox[{
              SqrtBox["int"], "0.053"}]}], ",", 
            RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"PointsPerCycle", "\[Rule]", "nppsl"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"trajectories", "===", "\"\<Short\>\""}], ",", 
           RowBox[{"Sequence", "@@", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Gate", "\[Rule]", 
               RowBox[{"SineSquaredGate", "[", "nGateRamp", "]"}]}], ",", 
              RowBox[{"nGate", "\[Rule]", 
               RowBox[{"(", 
                RowBox[{"nFlat", "+", "nGateRamp"}], ")"}]}]}], "}"}]}], ",", 
           RowBox[{
            RowBox[{"##", "&"}], "[", "]"}], ",", 
           RowBox[{
            RowBox[{"##", "&"}], "[", "]"}]}], "]"}]}], "\[IndentingNewLine]",
         "]"}]}], ";"}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"int", ",", "intRange"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"trajectories", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Short\>\"", ",", "\"\<Long\>\""}], "}"}]}], "}"}]}], 
    "]"}], ";"}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"DateString", "[", "]"}]}], "Input",
 CellChangeTimes->{{3.658062342965777*^9, 3.658062408347286*^9}, {
   3.658062914862811*^9, 3.658062915030579*^9}, {3.658063065957646*^9, 
   3.658063133220373*^9}, 3.6580632963403807`*^9, {3.658063940014585*^9, 
   3.658063941141179*^9}, {3.658064002537537*^9, 3.658064010272477*^9}, {
   3.658065238145611*^9, 3.658065251450799*^9}, 3.658065326458932*^9, {
   3.6580653947626057`*^9, 3.658065425150484*^9}, {3.658066312325864*^9, 
   3.658066322247067*^9}, {3.658066358166215*^9, 3.658066371198634*^9}, {
   3.658073203531199*^9, 
   3.658073329498837*^9}},ExpressionUUID->"d0d4a86c-a793-4e9e-9edf-\
637e335ec416"],

Cell[BoxData["\<\"Wed 2 Dec 2015 19:28:50\"\>"], "Output",
 CellChangeTimes->{{3.658073302116456*^9, 
  3.6580733307133617`*^9}},ExpressionUUID->"9ddc11cc-1256-4754-8e29-\
c7d765987fcd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1216.799284`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.658073302116456*^9, 
  3.6580745474628487`*^9},ExpressionUUID->"b0fc5b08-83b7-4cd8-86de-\
d30bc89f98dd"],

Cell[BoxData["\<\"Wed 2 Dec 2015 19:49:07\"\>"], "Output",
 CellChangeTimes->{3.658073302116456*^9, 
  3.658074547464881*^9},ExpressionUUID->"b98add43-02a4-4ace-a98c-c0622829fada"]
}, Open  ]],

Cell["and the energy-domain dipole.", \
"Text",ExpressionUUID->"bd1ca736-8603-482a-a323-0aca73278d96"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fourierDipole", "[", 
        RowBox[{"trajectories", ",", "int"}], "]"}], "=", 
       RowBox[{"Fourier", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"quantumPhaseScan", "[", 
            RowBox[{"trajectories", ",", "int"}], "]"}], 
           "\[LeftDoubleBracket]", 
           RowBox[{
            RowBox[{"1", ";;", 
             RowBox[{"-", "2"}]}], ",", "1"}], "\[RightDoubleBracket]"}], 
          "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"FourierParameters", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", " ", "1"}], "}"}]}]}], "]"}]}], ";"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"int", ",", "intRange"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"trajectories", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Short\>\"", ",", "\"\<Long\>\""}], "}"}]}], "}"}]}], 
    "]"}], ";"}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.6580749387993317`*^9, 
  3.6580749561285877`*^9}},ExpressionUUID->"833a8397-d9d3-462c-85b5-\
d3da611979ba"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.093762`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"1ba5beb9-324e-4eff-b59c-0f95c9fadeb7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis", "Subsubsection",
 CellChangeTimes->{{3.658075620124022*^9, 
  3.658075622196405*^9}},ExpressionUUID->"32f3840e-e959-48f4-a3c2-\
218674d192b6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", "background", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"background", "=", 
     RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Table", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", 
                RowBox[{
                 RowBox[{"nppsl", "/", "2"}], "-", "1"}]}], "]"}], ",", 
              SuperscriptBox[
               RowBox[{"Abs", "[", 
                RowBox[{
                 RowBox[{"fourierDipole", "[", 
                  RowBox[{"trajectories", ",", 
                   RowBox[{"m", "[", "intRange", "]"}]}], "]"}], 
                 "\[LeftDoubleBracket]", 
                 RowBox[{"1", ";;", 
                  RowBox[{"nppsl", "/", "2"}]}], "\[RightDoubleBracket]"}], 
                "]"}], "2"]}], "}"}], "\[Transpose]"}], "\[IndentingNewLine]",
            ",", 
           RowBox[{"{", 
            RowBox[{"m", ",", 
             RowBox[{"{", 
              RowBox[{"Min", ",", "Max"}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"trajectories", ",", 
             RowBox[{"{", 
              RowBox[{"\"\<Short\>\"", ",", "\"\<Long\>\""}], "}"}]}], 
            "}"}]}], "]"}], ",", "1"}], "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{"ImageSize", "\[Rule]", "420"}], "\[IndentingNewLine]", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Red", ",", 
            RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", 
            RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}], ",", 
          RowBox[{"{", "Red", "}"}], ",", 
          RowBox[{"{", "Blue", "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{
        "\"\<Harmonic dipole, \!\(\*StyleBox[\"Short\",FontColor->RGBColor[1, \
0, 0]]\) vs \!\(\*StyleBox[\"Long\",FontColor->RGBColor[0, 0, 1]]\);\\nsolid \
at \>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"Max", "[", "intRange", "]"}], "]"}], "<>", 
         "\"\<\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"Min", "[", "intRange", "]"}], "]"}], "<>", 
         "\"\<\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\).\>\""}]}], "\[IndentingNewLine]", ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Harmonic order\>\"", ",", "\"\<\>\""}], "}"}]}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"Frame", "\[Rule]", "True"}]}], "\[IndentingNewLine]", "]"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"SlideView", "[", 
     RowBox[{
      RowBox[{"Table", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Row", "[", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Show", "[", 
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"RegionPlot", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", "\[Phi]", "]"}], ">", "1"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"int", ",", 
                   RowBox[{"Min", "[", "intRange", "]"}], ",", 
                   RowBox[{"Max", "[", "intRange", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"\[Phi]", ",", 
                   RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
                 RowBox[{"PlotStyle", "\[Rule]", 
                  RowBox[{"GrayLevel", "[", "0.9", "]"}]}], ",", 
                 RowBox[{"Method", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"\"\<AxesInFront\>\"", "\[Rule]", "False"}], 
                   "}"}]}], ",", 
                 RowBox[{"BoundaryStyle", "\[Rule]", "None"}]}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Table", "[", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{"Table", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "+", "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "-", "2"}]}], "}"}]}], "}"}], 
                    "&"}], "@", 
                    RowBox[{"{", 
                    RowBox[{"int", ",", 
                    RowBox[{
                    FractionBox["1", "\[Pi]"], 
                    RowBox[{"Arg", "[", 
                    RowBox[{
                    RowBox[{"fourierDipole", "[", 
                    RowBox[{"trajectories", ",", "int"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"HO", "+", "1"}], "\[RightDoubleBracket]"}], 
                    "]"}]}]}], "}"}]}], "\[IndentingNewLine]", ",", 
                    RowBox[{"{", 
                    RowBox[{"int", ",", 
                    RowBox[{"intRange", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ";;", 
                    RowBox[{"-", "1"}]}], "\[RightDoubleBracket]"}]}], 
                    "}"}]}], "]"}], ",", "1"}], "]"}], "\[IndentingNewLine]", 
                   ",", 
                   RowBox[{"{", 
                    RowBox[{"trajectories", ",", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Short\>\"", ",", "\"\<Long\>\""}], "}"}]}], 
                    "}"}]}], "]"}], "\[IndentingNewLine]", ",", 
                 RowBox[{"PlotStyle", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Red"}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"PointSize", "[", "0.01", "]"}], ",", "Blue"}], 
                    "}"}]}], "}"}]}], "\[IndentingNewLine]", ",", 
                 RowBox[{"Joined", "\[Rule]", "False"}]}], 
                "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"1.2", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], ",", 
             RowBox[{"AspectRatio", "\[Rule]", "0.6"}], "\[IndentingNewLine]",
              ",", 
             RowBox[{"PlotRangePadding", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"None", ",", "Automatic"}], "}"}]}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
             RowBox[{"ImageSize", "\[Rule]", "450"}], "\[IndentingNewLine]", 
             ",", 
             RowBox[{"PlotLabel", "\[Rule]", 
              RowBox[{"\"\<H\>\"", "<>", 
               RowBox[{"ToString", "[", "HO", "]"}], "<>", 
               "\"\< phase, \!\(\*StyleBox[\"Short\",FontColor->RGBColor[1, \
0, 0]]\) vs \!\(\*StyleBox[\"Long\",FontColor->RGBColor[0, 0, 1]]\)\>\""}]}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"FrameLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)\>\"", ",", 
                "\"\<Harmonics phase/\[Pi]\>\""}], "}"}]}]}], 
            "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Show", "[", 
            RowBox[{
             RowBox[{"{", "background", "}"}], ",", 
             RowBox[{"GridLines", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", "HO", "}"}], ",", "None"}], "}"}]}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"HO", ",", "1", ",", 
          RowBox[{"nppsl", "/", "2"}], ",", "2"}], "}"}]}], "]"}], ",", "7"}],
      "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"d024bb05-214e-4187-b2bf-05d797b8317f"],

Cell[BoxData[
 TagBox[
  DynamicModuleBox[{Typeset`var$$ = 7}, 
   InterpretationBox[
    TagBox[
     PanelBox[GridBox[{
        {
         ItemBox[GridBox[{
            {GridBox[{
               {
                TagBox[
                 TooltipBox[
                  ButtonBox[
                   StyleBox["\<\"\[FirstPage]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                   Appearance->"Palette",
                   ButtonFunction:>If[Typeset`var$$ =!= 1, Typeset`var$$ = 1],
                   Enabled->Automatic,
                   Evaluator->Automatic,
                   ImageSize->Small,
                   Method->"Preemptive"],
                  DynamicBox[
                   ToBoxes[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"], 
                    StandardForm]]],
                 Annotation[#, 
                  Dynamic[
                   FEPrivate`FrontEndResource[
                   "SlideshowToolbarText", "TooltipFirstSlide"]], 
                  "Tooltip"]& ], 
                TagBox[
                 TooltipBox[
                  ButtonBox[
                   StyleBox["\<\"\[LeftPointer]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                   Appearance->"Palette",
                   ButtonFunction:>If[Typeset`var$$ > 1, 
                    PreDecrement[Typeset`var$$]],
                   Enabled->Automatic,
                   Evaluator->Automatic,
                   ImageSize->Small,
                   Method->"Preemptive"],
                  DynamicBox[
                   ToBoxes[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"], 
                    StandardForm]]],
                 Annotation[#, 
                  Dynamic[
                   FEPrivate`FrontEndResource[
                   "SlideshowToolbarText", "TooltipPreviousSlide"]], 
                  "Tooltip"]& ], 
                TagBox[
                 TooltipBox[
                  ButtonBox[
                   StyleBox["\<\"\[RightPointer]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                   Appearance->"Palette",
                   ButtonFunction:>If[Typeset`var$$ < 38, 
                    PreIncrement[Typeset`var$$]],
                   Enabled->Automatic,
                   Evaluator->Automatic,
                   ImageSize->Small,
                   Method->"Preemptive"],
                  DynamicBox[
                   ToBoxes[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"], 
                    StandardForm]]],
                 Annotation[#, 
                  Dynamic[
                   FEPrivate`FrontEndResource[
                   "SlideshowToolbarText", "TooltipNextSlide"]], 
                  "Tooltip"]& ], 
                TagBox[
                 TooltipBox[
                  ButtonBox[
                   StyleBox["\<\"\[LastPage]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                   Appearance->"Palette",
                   
                   ButtonFunction:>If[
                    Typeset`var$$ =!= 38, Typeset`var$$ = 38],
                   Enabled->Automatic,
                   Evaluator->Automatic,
                   ImageSize->Small,
                   Method->"Preemptive"],
                  DynamicBox[
                   ToBoxes[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"], 
                    StandardForm]]],
                 Annotation[#, 
                  Dynamic[
                   FEPrivate`FrontEndResource[
                   "SlideshowToolbarText", "TooltipLastSlide"]], "Tooltip"]& ]}
              },
              AutoDelete->False,
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}]}
           },
           AutoDelete->False,
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          Alignment->Left,
          StripOnInput->False]},
        {
         ItemBox[
          StyleBox[
           PaneSelectorBox[{1->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9nHdcjf3/x9tpahrZZIXsbO/snZB027ISskJW2ZuQkZEZkh2SnZGREYmG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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw9nHVYFd3ah+nuUsFARex8bdEHAwO7xUDAwsBABQO7UVFU7MbuBlHBDmxB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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H1 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{1}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 2->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9nHVcU28bhxEVuxFQMRBMysKWGxW7sVsxCBFQUAkJkVBEQBAsxMLujp+K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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw9nHVYFGsbhzlYCIoKit2goijYmA9ioIitCHYSCiooKQYhJSgCFnYXdmBj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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H3 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{3}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 3->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw93HVYFHsbxnEWRQELFQts7EJRDMJndJG2GxuVklaUsMVjd2NhKygqKha6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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83Hk8VPsfx3GjXZsWrdpsqVTatPcZJJQkbUIqlKJViFKUsrRvt420ao9K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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H5 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{5}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 4->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HlcDP8fwPHdhIQUlauQqyglV6K8R0LIWaKUo9wkObrklg46FHKU3BWJ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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fwPFzb2SlCJUkI4mKZEe8T4qvnUgiUrYQkozMrAhNGSlFg0p7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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H7 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{7}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 5->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83Hk8VN8bB/DKmFvapE1pL/Jt1aJFy3NbtZdIKrSh0r6XNtGuPVokSQtt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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83HlcDP8fwPGwu0OuKEmiJBWh5D7fI3dCQhLf3EWR+8gtpBxFydUhIYQk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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H9 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{9}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 6->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HlcDP8fwPF2t0uUXBEVX+RIcivCe9xF5eigQoQQUkKuJFIKiRy5qdAh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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fwPE7GmYSIZIkOyQlRO+PTZG9EhmVkSQjWRkZIUSSiiiSkTJC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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H11 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{11}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 7->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83Hc8Vf8fB/BzjUoqVCrtoZTSHop6a1BSIlEphZIGbfmWprJaIjIiMjKS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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83Xc8Vf8fwPF7r1U0UVqK1lfRVBrofUolSUaSdtpbVJKGklHaiZSmKNoJ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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H13 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{13}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 8->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83Hk8VG0bwHFmRPsiW1IqFSVKKRV1TdpFi0S0UKK0SlS0Ekmp9FRooSLa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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83Xc8Vf8fwPG7jEJUWhSFULSn1vs2Vdr6SkpDQ0rSElJKW3sXqaRERaiM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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H15 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{15}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 9->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83Hk8FP8fwPG90EW3StJ9qKRTd+/tUpGSSkpJp9CB7luUlL5ISkqRUjpE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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fwPF7b0uSESWr+maEIqIU8b6yR6KMbEkIZZRQUUZmlJFQFBKS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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H17 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{17}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 10->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fwPG7KiMrWSEr2ZlpoPc1QmQ2EFmFskeICBWRlZWZjFS+QkUy
4nNESNpbQ/cW7d3do9+pe94///wez4fz9eveM+75vO67M2zznpVbOCwWq6sO
i9X+v3dut/+pAuNBZQW3zYsAfdpl5oze/lw+Wmzuf66gSUrmnd9ZoXhaBWYT
Hznq5hcCusI6O4DtxeWjp3isqlZ2lpH6Y2C6/n0VzJ/TMPn84UJA21TO2tq0
m8tH757oN3XwcBm5tVvPl/pZBe5NLm/79CsE9ARv3TjhZi4fHcatuGJpKSNz
Nv5NH15YBdU/Hpo+e/Mb0IMtXm/NceTy0d8u3pzisFJGale8NTxdUwWu3iGt
ixx/A/pXw7X1SYu4fPS2oflzdm2XkaC57S+oChK/iqBVVADo22/V/p+suHx0
2iVOo4+PjPDpV2OjWw3fzMdtDrtRAOgB26x/vZ7C5aNTJx/cFnRHRqqNJ3eK
HFQNzjfanmw0LQB0ZDPRjzTm8tFPDU7mhsfIyPX+PMfuE6qhpSrWcXhOPqCt
PuYuCjXg8tG+p1duj/spI1Zd8h7vnVUNl7TXU9Ue+YDOpLquDu7O5aPXeVcu
SxTKSKXiaVPmkmoY/3LQpHf6+YD+d4NrfJPD5aNNs6WvMuQycrWufQdWg8Hb
/a0XXucBmrvq0v0rYg4fLV9RllCkJycz/yy7eHN3NSzi+Tpvsc8D9LmNUc8u
VHP46HqrkIh/Y+XkH733ZN70zzt61cfZrbmANvj7n9nZEg4f/cv0v8CGOXIS
mCAave5yNfRJHO427HouoB+v5k3wy+Tw0R+WSp5InOTE8vWPQ59CqqFx1+nX
3Gm5gP70PPDQyW8cPtovtESvbb+clD+5+3VoVDVMHJSsqMjKAfQZlyNtx95z
+OhW825s7fNyculm+wFbDclDxt1JOZADaJmL9asjLzh8dDfzg7d1H8uJ+bnZ
9BFbDSIHrYZXvXMATf4rPX7oEYeP9v3Pitf7g5wIj+q/WCCohgVVg53vvMoG
9JiPjxcfCOLw0S9Ov3UbkCUnF9pPz6ZqcOiTt+ikXTagnwmdOu8N4PD/b8tF
dUNq5GR6++HKqYHna92Hb2nJAvShcUtCd3pz+Og+T7fEGXMVpLR99+nVgEHE
gJULr2UBmms6t4v7fg4fLb9xpGbCQAUJaH85w2vgx7tdtmOmZgHaIu7imC1b
OXz0pSvlkaZTFWTa1PY/NTBs1/qzOlmZgA5N6dq00YnDR791rRxstVhBSoy0
T92YWwOb9M6eEu7PBLQtZ/LydUs5fLSbInjDAhcFOdu3IFViVwPrH61++04v
E9C2+l3NVs3h8NFueVVXVngpyBT67HRyrQHDlBkxF2IyAB16ZEHQiukcPvqt
7r6sddcUpEjmvT3eowb8c77KnFZmADr6jvmGxWM5fPT9n5dmuz9TkDM1HRck
mGOea2jUnA7oTt9/+84z5PDRjfsWSQ99UZBJxe0vqAZ0hN/eVFxJB/Tsonzx
TD0OH+29YKnemUIF+U2/mrInNeA3+PS6J5PTAR31OPDZNG0OHx3ytiQiqEVB
/KifD63f1ABv1u5N7x6lATq9rG/QODmbj95onpkV0VVJTGKCG8K/1UBAr5hX
BsJUQA8YNuPZsHo2H5328dzT+BFKkk9fjbrk1cC6pKhOu4elAjpI93xpXyGb
j87+V2WVOUNJfG60X4BrYO1ip8SYjSmAfhPqML5rLpuPvvHGPrzKTknG+bfv
QHp/yf44VYb8AvTVtuen1UlsPrqIFdrK2akkOZ5V9BW4FjqNLprf/U8yoE8m
7Cpv/Mjmo9uOGpkZ+inJCXrvXetfC+8GePQ2MkwG9L3ZZrOF0Ww+OunYleMz
7inJmHWX6StSLWyK9Vg1xvknoB0XH76R+YTNR9u798pxeq0kWUs291xtUQsC
P/c3g+8lAXrpra2Fn2+z+WjXtCk2x34pyfH2j1ebWrB2fVHKKvwB6Hn/unSP
usjmow9PrS4LKVeSUe0fN061sMba61rmgB+AdnxtNib4FJuPdrgZ+DxRqSQZ
7Zff7bWwLLD61tXV3wGt9fTSmHMH2Xy0+Lkwsk5fRbzaL0dHa6H+tew7/+Y3
QC+7e0LXw53NR29OYlX0m6AiI9tPz/O1YCrw5RXnJAK6t9XCdGdnNh9d4Ltn
wzxrFUlrP1zv1sKMqWawTT8R0NMOtByYv4LNR98eMKD/AWcVOdK++yJrIV7u
e/DPyq+AjoTVkgnWbD464uSyXqEHVWRE+8uJr4X3pmeira98AfQ6l/5r9S3Y
fLSNRZpN3kUVSfnV/qcWHm6u6nwnLQHQY4PuP5CNZ/PRkVkJn3TDVOTwpxCD
icW18PfMt4dF3RIAvdtt0M/ioWw+esTE7zvmfVKRYVH73a7U0ftr/7GIbraf
AW383f83pc/mo2P3NS7yzlWRZPrsbFHVwuDlPmsmBFCA5oy8lfOoE5uPVsam
2b+vV5GD19pvKOpAtdFdejiQALrT4i/EV8nioxvdj5yUaqvJkNPtFyT674st
vh/Q/QToylSL+y6NLD560uYLX8yHqEnSofYXVAekaEvR0rPxgP5nUnZoTjmL
j572yELPy0xNDtCv5hjUwfDwqV278D4A2iJ4zfKh+Sw++lKi7QayTE0GO7nO
+LOsDsIDn88MO/EO0Kd3/p2sSmbx0WJj03tabmryfbEZ/QlbB6I12nuMFHGA
Tp/iOaKAsPjoTXd6vFtyUk32zWq/gaoDp43Nr08fegNo7rXwCa9fsfhoeUFU
6M1bajJwYvsFuA7c10mmJTe9BnTZ+/A1l8JZfLRFQJRtWZSaJA7t2IFAFsWM
Fu98BWjHq9bR2+6y+Gj7Qo/gSUlqsqf99vhhHcTE9C7SqYwGdFBwqRX/MouP
zvlq5XNCoCYD2m8XY+rg3NJrkWyXKEB73HHt1t+XxUf3S57+N02mJl/ab58S
6mC8fWzPnx+eA3pFzpzRDYdYfPQGh6Mvh+m1kV3ttxOZdbDlburvrdH/AXq3
5Y67idtZfPTI82OSPMa2kX7tH69ldZAQvyijKCwc0C1jrQ/cXc/iow3+Ozgg
aU4b+dz+cdNSB8bzeWMn3gsF9IBeEfF7V7L46LTil2cM17aRHe2XX149hO9p
mLbpykNAk49ZftbzWXy0r99qsceBNtKn/XKkXw8RIxe8rtUNBvTiS24FAyxZ
fLR7mcmSX+fbCGk/PY3q4caq6Inl4iBAv9y84UfdBBYf/chy9h6j0Dbi3n64
mtbDvkHRrKjSQEBbbGZv/DyMxUdfmqGC4/FtpHf77rOuh8RrQX9eXD8N6Ovt
7MPio/Mz+Y9ys9vIx/aX41gPrT0Trvun7Qd0p00/v2zrzOKjG2bt8JxU10a2
bW3/Uw/b+0e+uzLW8f+WX7+y9qC8DdC+pmYrEzksqtdqC/oOuR6OVl8t1fl7
nKD77hoiNRC2AfqgTaNvc3cW9YG+WxznXw/NlVo6CUPOE7RJa5MXldQG6Kr2
vx7IorbMaF8Q1EPglkwf77BrBL39TavW1ug2QCeHaqlsR7GoHhPabyjqoeQU
Fa338TZBy1TmsV1vtwGad8pl5NGpLOqdYfsFid4/1QO/38gKIWiHwLKI6JNt
gM4xuzQuHFiUS8/2F1QP7IexyrbWRwQtXWnAWu3WBmi/3Oa2rMUsqhun/Y6i
HiRzvnw2YoURdOXfpgL1sjZA63bTucZazaLiWlTZnlX0/pDfsjft+pSgx5iv
dQgzawN0rcvKnPGuLGpT+/JWVg/L3xQVT+gbSdBLDXpdWTqkDdAF+w/Hrd7L
orq2L/e6NMBG/XmXuwx7SdDOf04/k2i3AXplz1lj/Y6xqNj25Y9BA4x0a8gs
6xNN0N6dMxIe1qsBPdvrpuHLsyxqQ/tyYFwDVOlMfDPpbgxBn+oR3GqbqwY0
eEafLrjOojpuj2c0AP/eM8PtQ18T9Mz5fdbLPqoBLVwnWs59yKI6bhcXN8CU
T5/nXHoSS9CDy7MGhj9RA7q5W9/945+zqI7bp3UNwPNTbr47No6gKbN0G8eL
akAPLe9XaP+ORXXcTuxsgJOzJiZffvmWoEfrLuHqHFQDuvbIGu9jiSyq4+p7
rAFSvp7Pcp/2nqBfzf2++d06NaCN199b+jiDRXV83FxsACOLWMGodx8Iendk
+ald89SATnraDZKKWVTH5TeYfr3vUt1/zPpI0Lv0XY6MGK8G9M+DS+fWV7Go
jsvRiwawEZ9usEn4RNB3H+hsKuytBnTMxGPL9MQsquP0/NQAns8v+DqMoAh6
xfZLy24oVIDO/2m+2pTDpjoO19QGyH07ftzBvxRB/3W747SiTAXoi8kxK1d1
Z1Mdu+9PA0zrnrXIN/wzQVvefxLUI1kF6LJJz6d5GrApzcuh93/fAwtPuCcQ
tHlwU9/0GBWgXSf7t940ZlOsjj+N4OU467rbuC8EPdnBs+7qHRWg3XLmnnsz
hU1p7tcbYfb5vk+t6r4Q9C2T4rGrfVSAfu12pTrLik3915RJ31E3QuRE3W7s
l18JusvR9SVDtqsArUhI79m4iE1p7u8bwSr+24qXexMJ2nP09z7VK1SA/rpj
kKjLKjZlX9YeDBoh1EWmbzPlG0FfyNpY/MZCBWjLoGVXjFzYlGY90AjSs2ms
1JZvBC3o/g/ODFMBOlCqWzpzD5tSZ7e/oEaY/m/Vr1mx3wnagntw/urOKkC7
eCcW2XmxKc36oRGMC+tm3Dr0g6DvzvORjm9SAjqm+JOvuz+bivjWfkPUCFtN
HwwrNksiaDtZ8lpegRLQjlyDzOPX2JRmvdEIscVBzrqyJIK2MVriUUIpAV24
qyAxMIRNrWxf3a5ohBf9DpWMfP+ToLvMmjzvQ4QS0F6bKpwfPWNTmvVJI6yZ
8PnhGK9kgnb4/T35TqAS0Ll6g+7ExLEpZXvO2twI201mvO438xdBT73j2fm4
pxLQFTFzvT5/YVOa9UwjdLZeMKVR+YugN/SLk23aqAT0Cg8jbloamwprz0H7
G+HK9IULX31MIWgTmTjIZqES0O6+ftMKC9mUZv1D758PbVM2eacS9O1ODwqm
TlIC+rViYu9/FWxqeXtO8W2EO4S+x7RKI+huCzlvh/ZXAlpeqH7c0MKmNOul
RhhiHZXi3ZZG0OskNsY9WUpAr+QV1kra2JS8PUdcawStvlPCJBvSCfrE0QN9
OZUKQH+e861V3ZVDadZX9Pl2mTvEmEonaONB4ClOUwC6bl/pF15/DhXavpx/
3AibM3cNXDw0g6DdzhtZ1MUpAG37fpdLZyMOpVmPNULL64r6rSczCPqL3vx5
/0IUgL4vLirWncShlrYfrq8bwRr2i4+UZhD0xL0uPgJ/BaCrFqRa9ZjJoTTr
t0bwG5d2y4+fSdBDTH8VlOxRAHrv3wHXei7kUNL2l/O1EXrufTff/0EmQSsf
rzApWaUANMckr7KnPYfSrPcaYYfDUC8fVhZBP6k22/QHFIB+3sV1Wc+NHOpR
+3Ism36/zm35cGhjFkGfDjZeIRylALRV9M687js5lGZ92Ah51vdvulJZBB2w
u//vfz0UgP7wo+WqrieHsm1fzvxthGcn8/+zHZpN0Dl/bHJqJXJA9+m59kZn
Pw6lWU82Qj8T17sTT2YT9NFW4wGtf+SA/nJ6Z4tWIIcSty8HRPTP4zxsYPfS
bIIOiDA7ovwuB/SHca5f2Pc4lGb92Qg332ZVVEIOQf/u1fWbVpQc0L0Pywep
wjnUg/bbae0m4FR6JVMhOQTN0h6W0uOWHP7v43sGSF9xKM16tQn2xsbdC2rL
IehQvczVBiflgH4hDspqJhxqUfvtaN8mkHqMgR0bcgk64ZHppJFuckCHmPzd
VpfMoTTr2yZYdb/iMZBcgt7eX7vfpOVyQCe3HGutyONQre23c8ZNMG6TKEl/
SB5Bx4b7pFiaywE9MtLqtrCMQ2nWw01wd0HipxrvPIIe8GJpT+uhckC3ROQf
Lm7gUPfbb4fMmsDr7rf7iSV5BD1szdJbSzvJAb0nK/9VvoJDadbPTfCgQn3j
sVU+Qfeff9JgVaMM0K1FZH+2Dpda2H47saAJJMKo0jP38wl6zvesBevzZYDe
MKhvUXpvLqVZbzdB8ftev/aq8wna5orilwslA/Q6M58BqUO4VHP7x+vqJrjn
1T1u8/oCgh6waebKbREyQHukCRx/jeNSmvV5EyyfOKL3+k8FBD1+mpmXW6AM
0NVbXBOSzbjUvfbLr1sTnLGy3uJq+Jug10e9+LfVUwbojPCIC7/mcinNer4J
ms3L5h/2/k3QXycvMNm8UQZow21FlanLuNT89tPTswlmaiu33ir5TdD71Px/
axbKAP3j5B/drLVcSrP+p9+fTsvPJ1kVEnSSalzwkkkyQA9ib59csI1LNbbv
vnNNYOX34opuSCFBN66/XjizvwzQZ9NNrwoOcClNL2gCpzOb97m0FRL09vXh
I0axZIBOXj5+d+0JLqX5/q8J5EsSZqZvKCJon51pjV0rpYAmNrd05Oe5lKYv
NEG0rHy4A1VE0Nc/z4+rTpMCenrIutAut7iU5vtC+njb6LOvdWgxQedvCylL
iJMCWt920iXDUC6l6RFNsOUK+2bUqWKCDr8Lv6+FSAE9YUqp3vQoLqX5frEJ
9CZ9MLogLCZo5dQM8Tp/KaA5W2/6rYjnUpp+0QSOxgczzs0tIejtbx6dH7xH
CujkUBPLfT+4lOb7yCbQ5RoeiwwtIehZJ6Sl2Y5SQG+mfC/fyOZSmt7RBHXr
0kwkWn8IOnG07TQfKymg79cU/P1UyqU031/S53+nIcN3bftD0JJZnnFGxlJA
awnmhtbVcilNH2mCg0d+UL2S/hD0Y0HK5Q/dpICe2GOA+XAZl9J839kExpZF
Dh59Sgm6Ttgrx1okAXRA98N9nLV4lKanNEGY19w/R+eXEvSEOesDE4okgK4u
SY+734tHab4fbQK/ZdMD7h8uJWir/PL3k75KAC24dvFRxWAepekvzTBzruCM
IKKUoDevvzzz8jMJoNOWv91kPpZHab5PbQb/BT3Gzf9dStAz13lWF12VAFqY
8SXgynQepek1zfAx5LIotauAoIdPMj/d/6gE0A0VLh9b5vAozfevzRC7qu2K
9ywBQRvbs+L4mySArss5EbphGY/S9J1mWDKOW7xqj4CgnbZ797JfKAF01k++
JGctj9J8X9sMjdPYVc4PBQR9dsuJrismSgA9cwn/6Co3HqXpQc2Q+nQH93qW
gKAHjFukNu0rAbRH9W/WXw8epfl+txmW2kS/V2kJCXrN2vDhbJUY0PYrI3ef
OMWjNP2oGUQx1eX3zYUEfSYs4GJUmRjQHyMt3426xKM03wc3Q9LVjeFeO4QE
fe/NsvFzfooBHWOUX1Vyh0dpelMzjD7a5cSt+0KCrk04Sr2KEgM64H7CkLBw
HqX5/ph+v5aOXyTPEBJ0UH7Vb85NMaBje5+/6v2aR2n6VDOkhFjZhWmVEbRB
1Mbc8cfFgG4JT7vu/plHab5vpvf/fEfnRxZlBN1QZJ9h4iIG9NkrDjfdUnlU
R9451AyOc2xiWneVEXTO+sIwLRsxoIOWXx1/vJBHab6fboY3p35PCX1URtAj
ydV/z03EgN794I3u00oe1ZFH/Jth0eF57m/zygh67Vfn5BH6YkBnDl5hUC/i
UZrvs5th4Jrz9y26lRP0frv3k1xkIkAvyH20bSlXi+rICzebIflTn5ZJc8sJ
+s7Qg2e2lYgA/WpP4sxfPbUozfffzbBq9QiviCPlBJ1ttzth3BcRoPvm/jDc
bqhFdSzPw5vhVMLvDc+iygmauq+3/L9wEaAfRInzxo7XojTflzeD9cNUrfmV
5QS9/mV/VdF5EaBXRBw41ctSi+pY7r1thlZrXcszQ/8StHaxTBi/RwTo4718
Lw1bqEVpvl+nj5/fvG1ea/4SdNDV47Zz7ESAjp3+uWC9oxbVsRz4QZ8fPo2Z
06/9JejsT/5BrtNFgA4aGv86xVWL0nwf3wzdP7yoSk75S9BHHo3uajBABOiv
L3bI9x/QojpuFwuaIf5z2PXlnf8R9PCQyNhVilZA74kaM9LeR4vSfH/fDM/1
Uh4XW/8j6P8ODTDpVdwK6GfzWtwOX9GiOm4nqpphalPi4su+/wh6q85gJ/NP
rYBecqwps+yBFqX5vp/e/4fGfzqd8I+gX32tGvrxfiugwwaf3/MwSovq+LiR
NcOxB+7Cv5wKgk6YmNz9oncroIe43fF8R2lRmvmAFpjQb43Z73kVBL3dw678
qnMroJOtcy9Oz9CiOi5HXVpgkN3mymtnKwh6f25q1zczWgH9/Xp/uZFQi9LM
E7TApP6lI2xTKwi6sqVHfUH/VkDraks7XWvRojoOV4MWOLJQ9tW6byVBf13r
O7i4tQXQhiut9l3R0qY08wctYD4hwy1tYyVBu7rfXHwrrQXQSxdP+z21vzbV
8XLGtUDgM6r7/BeVBG3+X4i0KKIF0OVjo3yvjNOmNPMKLUCpi3f1b6sk6Aes
XkkHTrYAOurE4YHfQJvppS0Q0XDCPNmuiqDHd6JcDBxbAF2tGJLabK9NaeYb
WuCAb9ttdWQVQc+3Yr06OaYF0MWlJ8JghzbTV1vg8dRTDge7VhO0yVZwsJY3
A7rKdqNDsY82pZmHaIFvk3g9DfdWE3RwhUrS+L0Z0FN02X4697SZHtsC6e4j
vYcUVRN0/8V1/MYrzYD2cDr3RydOm9LMT7TAz7/a2yqX1xD0wIvHfp1f1Qzo
/e8+D7DM1mb6bQsEBY6NnJdeQ9CxcdVPi/s1A9o4tMu4Xq3alGbeogUednGM
9VxXS9BRcvsnXzKaAB3h4zDBsJ8O03tbYGJC5zOu0lqCrjRUxKf4NgH6wl6f
YQOsdKiO5d7pFli7oCb1RXgdQa9cF3Br9PgmQOdlvH9V467D9OEWOP23YKJo
dz1BW3Xr7Xb6RyOgNx0RL/54V4fqWA7caIH7qxd+Eds1EHR01tr7PMdGQI/u
mxmlytZhenILaPfOcXN91ADohHmmBrcrdfjo44duJKeYNJKO28UnLdBUde+B
2856QB+zHDXa4K4OH93pfPTL5KRGpjfT50OR388MTh2g9c0e7n/N1+GjC658
NLjp3UQ6bife0P8+LP14alMNoJWX7fZszNfmozuVrh4Gy5qZPt0CPPbF8Izz
VYCezS9zb92szUd7n7AY38+yhXR83HxrgUdN0sbYwApAu820OjahXIuPnujv
q/PErJXp2S3Q9ur6uKMBfwHNmvA34P5mLf7/HWZanWApIh2Xo7wW0KsonLvs
Zhmgv8rE6Vl/eXz0YV299auniZn+Te+f9U4fylIFgI68mVv/9gCPj45IXzn8
Un8J6ThcK1rgxezO4b9mlgJ65/KEMVN78PjoMRu8Im8LJEwvb4Edu4O0U74U
AzolJfPBkbdcPnqLq9Mn3ctSZh6mBW5+tTsQt68Q0Nc8t9dP383lo393Hzfi
6ggZ09dbwTa7yneSRwGgAyyP9zxjwuWj6wK0/rQ8kjF9vRX2jGv8r398HqB3
a63v4yvh8NFGork5sp5ypq+3gs+N3DUWM3MBHZVpOc7/O4ePfuAU8LRpr5zp
662QZvnJ701VNqCdvt9Mnx7M4aNt96Wvv5ooZ/p6KxRfqHpW9iEL0PcmHz94
7DCHj066p9VHp5eC6eutMIjzn7jiWSag5/Fz1MccOHz0kRMOHG0HBdPX6c/Z
c63WG15nANrsyqfK89M5fPTVYh+TyqsKpq/T//49ztROGemA9rPbqD3MgMNH
y1ZDy8dkBdPXW+G/fSk7eao0QA/M+zU/vY3NRyev2Lp/Awvnf1oh55xDL1OP
VEAHr+6zYm4Fzv+0QuLSHOcjk5VMX28F+2MKvUXcFEAnxk18OC2dzUcfCnzw
MWgDzgvRn+PFpzkfw5IBneU8On3He5wXaoU1815uGH1eyfR1ev82jVQ9W/sT
0P03ZJL3T9h8dPrstScDXuN8USs8HvvBIG5IEqD/i3m2T3EF54taIfJOxKDO
RUqmr7eC/vY/ZX8bvwP6oXjW+u4n2Hz0Jz2/uWVsnEdqBT3b1vSrKTiP1Aqf
5/WYULAT55FawfuQ4MkSYxXT11vBZGWG49rXiYAe0WdXrPVaNh/9PmfkDQ8b
nF+if76X57f1Dv0KaMV7z+mzF+H8En1fE9D92vEdKqavt0JNjujGh7tfAL3B
ecO7DxZsPnqu9eyLZy/gvFMr3K04CEfuJAD66HrJtfAxOO/UCt3m9sqPilQx
fZ1+v6d+mx8Y8hnQU1x28mQD2Hx0sMUoSbdfOB/VCv/6tWiv/48CtPfkPaVP
uuB8VCtwg4fB62oV09dbIX687aH/PAigt26KsXuiYPHR02bdXR3bSc30dfr8
G7lqmSj4I6AnvDv6X0Mti48Ou9jl2VBjNdPX6f2/t/rt17QPgD5t932kdwmL
jxat3veaO1fN9PVW2Pw+uNyp83tAZ9UZ5S1KZ/HRTkZvVmzfoGb6eisYOx52
6LnoLaCj3z/zWZ7A4qPvB0TI13upmb7eCpO9+GT5lTeA/s2Vnw54zeKjl0i7
tlYHqZm+Tp9PNuHbbpW8BvRSy1lfWsNYfLTr+dNH+saomb5OX1+m+jTtm/wK
0Pd6Xbh8/jaLj/5RVFFa+UvN9PVW+P5+8QmPc9GAznWWP158gcVH28/r+tat
Qs30dfp6Wr9kht+vl4B+b1bXc8oJFh99PnBkyV12G9PXRWDVY0WW7uVIQM+a
t2TqzP0sPvrM4S23/Qe2MX1dBA4X/2RUr3kKaFPvBc+2bcH5MRHc4O57Osm0
jenrIvBWl/e9MT4M0PJra+1jVrP4aN38havuLm1j+roIBu/478Fl7ceAjnzq
Y2Vgi/NmIgiPlPskb2tj+roI9rivHpadGgLorKg5EcHA4qOd7h99+fVkG9PX
RbC8sH/iseDbgI6bHCCznIrzaSK4dq9GN+B2G9PXRTCywuLuBs9rgE49MJ00
GrP4aJf+104ZxrQxfV0EB65xx4V/DAB0Bw1wnk0EBdKn0X4/25i+LoJ7q7cm
y+irN3r8q7/HHnRn8dHht6dpE2Eb09fpn6fflpqpn+0B/XjnceNbHJx/E8F7
Y61XafI2pq+L4Hp0glb82/3/99JZ8rkL6toAvUbAWb+uM4vp7SJoi/7SpJx1
mqDveQ7S9stpA3RM+1/3YTG9XQTrntef/34mkKAXW6cLyj+2AXptcb/L3Yax
mN4ugnmO1gl1W4IIOrxavNAtrA3QzwP8CpPHs5jeLoKUr+Nv/pp5j6DrbB+n
6F5uA3TAGpPbR8xZTG8XwYpZhwcUaT0k6D7zpw3JONwGaFHRlr395rGY3i6C
UfeNOp2oekzQPQo/6bze2AboI1eHKp8sYzG9XQQ/5o3/sT8pjKB/B39yf23T
Buje0UOTR65lMb1dBE1P/CH/yVOCTk/gWmVMaQP0LUP1xptbWUxvF0HVk86J
Kd6RBJ0Rk3el86A2QN8y1jdT7GMxvV0EJj1/OOyxf0nQJ8iK0+u02gA9e+iq
jyuOs5jeLoJFo29v3tE7mqC9duXaJNWrAT0nSX/t3bMsprfT5+Ozaa3dvGII
emls/NBl+WpAr3nycE/+NRbT2+n363jM+rGCVwQ9Ol/fqe6zGtC110QrO4ew
mN4uAsdF47//tI4l6LUzLto9fqYGtN1mC0eT/1hMb6fPV/2Ss9KINwQda7j/
8N4bakCHNc7/uiCWxfR2EXwZHjk3vstbgs6elTjD/oQa0H03DRY6UCymt4uA
17a8avCOdwTds3H7sKXuakBL/Rc1rE5mMb1dBGk3HJOMfr4n6MdB218526kB
/eL1IuMVuSymt4ug/Ivsbt6oeIJOcOGf8ZmlBvSQ1D/xVgIW09tFsPmk/oWZ
fh8JWh5nZRY/Sg1obujG8mG1LKa3i2FR6Uj+mj+fCFrxULWji54a0JyJ7J9y
MYvp7WKw67Vg3+1BFEHnDs7L2KlUAbrPPv2bSWw21XH7pC+GH77n9Ct+UATt
n7Z7cNk/FaBn3lq475Ium+ntYvDuUvL8psdngo6ymtdlV4YK0BGlxUdt+rGp
jo9XIzG0lpyf8HxIAkEP91vq1CVeBeiGj/mZ8mFspreLoZOWYuWYnwkEvSHk
Qc77MBWgl0dNvPFoPJvquPyaimFOxcqX3Ty+EHT/x30WeV9RAdrDRPSbb8Zm
ersYnGr+hK8d/JWgb3B45+2PqQD9Rn38fc5sNtVxelqL4eGIeZ76374S9AUv
yd5Z21SAtpzjt2CTLZvp7WJI7n9kmsXuRIKuKNpbYL5SBeiLVxZcK3NkUx27
z1EMLomhP3/2+UbQ9tuehc2fpQK0o+1/kes2sZneLga36995P+O/EfSBbtvI
1tEqQM8/Yvvg1w421ZHTt4rB/ce8ADOX7wTdsjWu++3eKkD724Z6Tj3EZnq7
GCZZ2wh6d/5B0E55ub7FaiWg7a7rW105yWZ6uxhSj/beu+HFD4IOC1T1mlat
BPRzM7bkbwCb6e1iOLXJ0NvALomg06fOjLqXowR0/3+C8Mk32ExvF0O4erKp
tSSJoMdRa9b0+6wEdPUQOzuPEDbT28UQ8mXtoz93fhL0Bf/XXUMjlYC2jB8p
f/6UzfR2MUz4m/amalYyQTtxjZPm3FIC2k69827JKzbT28Xw0/rNQpfSZIJe
YFYV1OKrBLSz6/lp2p/YTG+njx/nst62Pr8I2va67/E3e5SA/m1q9dnoB5vp
7WIoJifePx6RQtC8TlFnz69VAlqtCJ9hmclmersYPoy7n+j+NYWgz1naft+/
QAnoeOGae/OL2ExvF8Or8wlPgl1TCTrgxYLFO6cqAf1h9LrfNv/YTG8Xwzwr
p1dWvDSCNn97fYznECWgyx+b1sxtZDO9nf7vtxlPtH2cRtCdpw48GtRVCehj
W5sTpsnZTG8XwyCl7UPh0HSCllGRq75LFID2CxljP4jHYXo7ffxm9jmZvSed
oOeel//pUq4A9Pr3nEB5Nw7T28WwenTqZK9P6QRdffDC1E3pCkB3TbTYmtaP
w/R2+nxNGzAmVzeDoLUvvDv4M14BaJXFiMQ7wzhMbxdDdr5nSrlTBkEnJz38
Nf+pAtAGA1/eXjeOw/R2CcRYrPMKi8gg6OtNozfl3lAAerr/jjR9Uw7T2yUw
+Y6pn4E4g6A9bjevP+KjAPT8V2eWf7HiML1dAjfB14Q/N5OgDSZtaJ24RwHo
lm3pWm4LOUxvl8Ca9LzYvoGZBF3dNWClfK0C0F3l73M5KzlMb5fAjDUli4KL
Mgk62n3h8/yFCkCPSl779NpaDtPbJVD+0ql31ugsgtaxHzMj2VQBaKXDjs0G
WzhMb5fA64PGY+M8sgj62uZDppnDFYB+kzrvb9BuDtPbJXD42diQhVQWQQ93
MM2v66EA9B6Hv707e3KY3i4Bt0WOh890zSborbvGbjZUyQG9JKk6de8pDtPb
JSC6eSVyj2M2QXPvFOq7VssB3TblqiglgMP0dgn8/fJiAvdhNkHrLLs+jeTJ
AX08P3bL0OscprdL4GHwqhKoySboW/23d5qUKAf065afim3BHKa3SyDDTxpk
ZJpD0L9KZv9+EyMH9J2ef66GhnGY3i6Bni8jjKK8cwh6ZnaO2O6BHNDCPjd4
uS85TG+XwNPhPW0E33MI2lHy4bnOJTmgHXjDxyjfcpjeLoF+yYvev+mZS9CW
S3atyPSSA9pljU1e3wQOpfl9SPr9OZg0fOKaXIL2f7TE7LW7HNAfTdaUj0zm
ML2d3j/7Jw2zeZhL/u+yV3HPV8kBvaS7sdGYbA6l+f1JCTwLm7qQW5VL0A59
WyYQazmgczy03YcWc5jeLoHWhL2G6yblEfTcNBdp5VQ5oNf3T/Xt+o9DaX7f
kj7edBYYrjycR9DDrXZ7jhsuB3RD6Y+51fUcZt5bApeHP48t+5hH0Oviruv5
95QDemVo7KF4CYfS/H6mBD4l8eb34OUTdGCKt4lSLQO0+W2q8hSLy8yHS+DQ
rdoRWTb5BC0s4Jmdr5MBuse1466WnbmU5vc5JSDI63FzwuV8gu7UZeadaUUy
QCvlgpi/vbjMPLkETjm3FgzKzifoB5U+SdKfMkBHnbe662vApTS//ymB7KJv
A0L6FxB08sJLFvnvZIC+U2he1nsEl5k/p4+PKSMPxawrIOhtrw5tzoqQAdo2
7OvSoHFcSvP7ohKItK9gOTwoIOicsd9I9U0ZoIOqBz3oMo3LzKtLYNGhfx/9
ygoIevfmM+mG/jJAJ6XG39w7k0uN73g5EigRJzwC498EvXDOsn57D8kAXbR+
dev3eVxmvl0K9kkRQb5uvwn6WYqDwZ8tMkCPHZCzv+cSLpXb0dOl0Bilt3/p
f78J+qudl8tOBxmgDR3npNo4cJn5dtqbLqiDa34T9NuKdSf7W8sAbXQhgxxw
5jLz7VKwyjwg3jO+kKD3dnXhlE+TAXrh0VT1xS1cZr5dCoNPv+Ml7Cwk6Hf3
M7zTjGSADp10k39rF5eZb5fCsgMPvl6JLCTo8WV5lwr1ZYDe3v26+dWDXGa+
XQruXsc/F9UUErTxwwdpnbRkgN71cuItr+NcZr5dCiOjDh16MLaIoCV2m4Wr
RFJAa+Wmdrc/zWXm26Vg9nTO0t9uRQQd47BnZ9JfKaBHOfywGXiRy8y3S+GC
c+Uj/7Aigg6utO63PlcK6Jiuzq3p17nMfLsUUgJPfHxSVkT+74EPAvt+lwLa
oPllnMc9LjPfLoUPc5pzJg8tJugVe3wDWuKkgF618JOldiiXmW+XQuYrojdm
XTFB6/Ze/kEUIQX0UfGq4aefcZn5dvrvx38+e/ZmMUGrXqcVD74jBbTPyP69
mmK4zHw7/XMqGy2XZBYTdC01N3rneSmgA4asD7d5z2Xm26XwOmKagYduCUFn
5eyXCY9JAd33xnzfS5+5zHy7FKJ7jNWSW5cQtP6xWO9Tu6WAFs9+wic/uMx8
uxS2cGXfC71LCHoUYXe32SgF9K6hbZ6FaVxmvl0KHrZjBvWNKyHoskiRp+VK
KaAvjTn9RZjLZebbpVCx1zviSX0JQX9zKb3hOE8K6MGpPWKzi7nMfLsUZt4u
YPmP/EPQ0beT4P50KaBHTx1YGlXOZebbpbDm+fCwN2v/EPR/9ocd9cZIAf3M
4Wv2oRouM99Ov640C+3JV/4QtNmFfZ9eDZQC+q/F96HGzVxmvl0K4RlNXs2J
fwg66Dx3k293KaBNLb2XfZJymfl2+v3d0WeZRPaHoDlPLMf7sKWAPvFcWGXV
xmXm26XgnzPjd3DfUoKe2UeoF90qAfRm0aVD4Vo8Zr5dCmppp4riiaUEfcrX
S7dXpQTQfKuEI5KuPGa+XQqEfSvn3cJSgh7aNrXP40IJoPeyth400eMx8+30
+TLCMXTiplKCHl6fPcEtTQLohrN9qhb35zHz7VLYIb6/cNaRUoL+6Re1dtMX
CaDvfhy1cpkhj5lvp98P67oXpYGlBH3C+VzE5TgJoPkrPowzN+Ix8+1S6BXW
90O/iFKClkZ6DG99JgG039PEeq2xPGa+XQYh5VcXln4qJeioi28KLz+QAHr0
OyO9txN5zHy7DHZvSh9rnlNK0DZpN6td6PsS9Lr+r7ssNeUx8+0yuOsfNGFw
TSlBT4mf5r4vQALoiodbFn+35DHz7TL4/Phwn4ssAUEPNZl38N0JCaAbK52t
R/B5zHy7DM7ttntwuo+AoOMX5k6cdVAC6EeF+m6brHnMfLsM3B/XnOaNFRC0
rUmXj6rtEkD/rjw67NQiHjPfLoPZMy546lgJCHqj8N1c5UYJoNO7jyg5tYzH
zLfLIOLpj5EXVggIevyzgXUWqySA3j52f2cXex4z3y6DzA/LzAJdBQTdb/jq
8rglEkC31md1M1rDY+bb6c+p+jy7XocFBF3bSd/x8DwJoAMUIvuvzjxmvl0G
Fo9HDu12TkDQriZ1e47Q6wp0qlvnhXM385jeLoO44RP4p+4ICDp0d9UGMkUC
6BcLuy5/sJXH9HYZrB+6cvWOZwKCzmjItVs0VgLo/mf1c39v5zG9XQZbj3/r
nvRBQNBLPt/zHEivu9BOIdFzm3fzmN4ugw8DunS7lSwg6OEtR2VT6XUdes+Z
Odx/+3lMb5fBIo+L7NzfAoIutLZou06vG9F6zi4nYw/xmN4uA2G858OTVQKC
vvxw7kvoKgG0+cT1ozce5TG9XQa9am79d0MiIGjPgFdjTXkSQH+1DNv+9ziP
6e30+3nB46+elpCgQ99ZXzykEgPaZITzu3mneExvp//9PedGiXsJCdpz4Yxa
nkQM6K9rheeO+/GY3i6DEZteO8wyFBL07rSRDoJGMaBt+u9yuOzPY3q7DIyN
vm79N0ZI0HV1wb90a8SA7tI5+vaRAB7T22Ww/5/Z1oZpQoL+rltue/avGND3
ZBcLZlzkMb1dBsXKMYcdQUjQV9k7vtqXigFtduJncM5lHtPbZdDiuzVvgI2Q
oLU/2eofKBQDWvWg4OD8qzymt9PXA4/nQrOVQoJutH7avTxXDOhOzs+kF6/z
mN4ugwL+kL4vnYQEfX1Do0dEphjQ09P9E58F8ZjeLoPjCzN7e28WEnRCYV8x
lSoG9JCrrX4ht3hMb5dBQ9alsMfuQoLuFPR2vEmyGNDK14+r3O7gfDu9f6gX
iYZ7hQSdFDI6uPG7GNCDonZE69zD+Xb6/S8bdLv+oJCgF1za96pTohjQReYL
wryCcb5dDnPe7Tmu5yUk6A0jFn4+lCAG9PL6tSFf7+N8uxyuvRvQKeCEkKCn
j2hRWFJiQG/Zre0jDMH5djkMzI/o6uArJOjma+OOOnwSA1pnevWcnAc43y6H
9Khu9w6cERL0rVGyyd/ixYCetpNbce8hj+ntcjCsFuj9Oysk6KYul8UXPogB
ffboWz+LRzjfLofYSaG9nwcICTqsYsKhp+/FgJ6gWzXvGb29pqfL4fiSP5eT
zgsJes6anuYD6e3RG7IkLs2PcL5dDllvJyXPvIDz7XIIerztjuAdzrfLwdTk
15Qej3lMb5eDr9nwDZ3o7dFW5bvTFfT2aMHFH/04j3G+XQ6j1iZZmZzH+XY5
7Fx5t9TtPc63y+GnY8zlZPrn0fR0OWReMXwfdU5I0P3iGh+Not8ftEeov8nO
RzjfLoeSd6qTV/1xvl0OvUacItPjcb5dDp674UE5/f5rerocziVST3L9hAQ9
M3jI8+sfxYDePHnvU9OHON8uB1njlpCTp4QE7aezJAoIzrfTr/9YwaiND3C+
XQ61a6Ysvn5cSNBdsrb+Nv2M8+1y8Ar6pbclBOfb5TDWI6GuzxEhQdckGnY+
+AXn2+n/Pnivl/V9nG+Xw4BOXlO7eAgJutVrzj95Is63y0E7oeQCJxjn2+n/
vydLJh3aLSToORMKKr7+EAN6g3vvC8F3eUxvl4PN3sT1G9yEBF20IHh5On2+
o/XWRef1o893TU+XwxGe3f3kTUKC/no8d5JBmhjQhp+vV+ynryeank4frzfS
Jn2mr1fo7aa3toXQ1yv04r9TbaPo65Wmp8thKZkSN99OSNBrHmwNXUdfD9HZ
L389z6Cvh5qeLoekI54TXBYLCXrQl7nuS3+LAb3fcH1yPn291fR0OayriPs7
eK6QoFfqGnXbVyIGdJ5s15HvgTymt8uhwX+3j7elkKA7xf/4RAnFgFY+vPsg
5BKP6e1ymOyk03hhspCgK1cq/S0qxIC+kMue6XKBx/R2OYyZH+68YrSQoGvX
jV+RR39+oQMy3Ffp059fmp4uBzuzJabZ9Ocj2tF1zd8b9OcjOmeJXbdY+vNR
09PlsC3VobdhHyFB/+rvIN4rEgP6zoEcvwWneUxvl8O4wEMfzboKCbo6bt4w
V7kY0F1DnRtSfHhMb5dDJMwfMJYtJOixpetatreJAV1zecWZRSd5TG9XwKRp
O4arxQKCrtzys/4kfb+B1k25c5bQ9xuanq6A+QPPlcbXCgjaef+Hyw87SwCd
OX+4+UQvHtPbFfBkVBfnPUIBQZvUHl3xo7sE0FXn5uTd9eQxvV0BC6f/uWWY
LyDoItfAV429JYC+mmIWpkPfX2l6ugIijtv5ZKUICHr87FyrvgMkgN7+53qp
xwEe09sVoLrQoyboi4CgfSw8A6YZSgANZV/e/93LY3q7Ak5GbvXe905A0NTT
X/wFIySAHvrs9oZ19P2kpqcrYFiQztsdLwUE3ThNOWLRaAmgz/5l1//ewWN6
uwIyfo0uvPhEQNC3bu/Qs5ggAfS0qT8PubjzmN5O///Vzqv+c1dA0I3nirv0
pO+f0Z1mXJFL6PtnTU9XwLHcIyHuVwUEnaA/d1LydAmgQw6WbLvjymN6uwKs
Um5vmULfz6M3DZiaspW+n0cvP7D1ti19P6/p6QpYO0ixYvZJAUFn7uOs+gMS
QPf77m3fcyOP6e3062vsPiSYXl+gX/t77p1Mry/QxvFfFlTQ6wtNT1eA18zE
UbZ7BASdsGlw7ZqFEkAPWdbUOWstj+nt9P5ZTLnYbxMQ9NDfQ1IdbCWAbtRr
7J9Dr3c0PV0BBjNWuX7YICDoA5uzlwxfLgH0t9Q+BfWreExvV8CpFa4rz6wW
EDQ/LyU33k4C6I36t68Pc+QxvV0Bf7Pza9/R6zX0pRvXOo+g12toC9PpXrvp
9ZqmpytgQ2D3s06LBQSdHif9sNJJAuj+odxHuSt5TG9XQMnZX912WgsI+sqH
ATIbZwmgzYcf4K5dwWN6uwIc9VtUTSAg6JyD2mwder2J7pt47ISSXm9qeroC
3jkk7GmwFBC0UY7hwrObJYDefaOx8MNSHtPb6fOP87z3tukCgq72HnPol6sE
0Of5NV9vL+ExvZ0+/2MjTNdOERC07pNxWzK3SgB9dML2lCBbHtPbFXD5Xy1J
MREQ9NsLnYfedpMAOtRCsefVYh7T2xWQdrWXFTVOQNC3pktKh9DrcfRrV78e
jfR6XNPTFaCI8S6dOkZA0D5hVI+tOySAJpFDpLb09pqeroAXEw1PjhklIOgx
lY2wY6cE0LXndTb+tOExvZ3e//fmPHo4UkDQ76JLTCbukgDaKDzQzY3eXtPT
FXD/Xuyxe0YCgo6e/ORzNL09evS2CUNG0dtreroSpDpC2QB6ezRP2Z3bQm+P
Vp/y9Namt9f0dCVYLuv+sX17tEu+57D27dGp1+buad9e09OV8GZmsPFdenv0
k03RO2Po7dEmy8KTjOntT3b0dCVUZy1eHUy/XnTXvr/tJtPbo+Wteo7b6O01
PV0JwY0uFkPo9xMdo7PUZS/9fqJHKVenfqe31/R0JdyRFx0dQu8v9CufK3P2
0vsLHWYVV7KA3l+anq4EOyPXu/fo4wGdW7ckZjJ9PKD7dC4wrqC31/R0JSSO
X1BznT7e0Pfd1wXE0scbenJyhuUT+njT9HQlCA7MCtSmj2d0z/mCOCV9PKOl
63qEnqKPZ01PV8Kw/7qeazAVEHTj2KMzOm2RAPps9RyhF32+aHq6EvQetUUt
oc9HtMTk5KgC+nxE+1XCzmv0+ajp6UpI6THniyF9vqMNpOvv76XPd3SLb3rU
d/p81/R0JZTVKp03zhMQ9KVz7Iw0+nqCtphxol9/+nqi6elK2BbloNVzkYCg
f41yUEno6xXaYKcD24++Xml6uhJW11oaj1suIOjsc8Kd1fT1EN33w6WkLvT1
UNPTlXBgl9aAl44Cgp5vc/xAhL0E0M5rZ3975sBjersS0g7UjbjtLCDo/vM7
7566QgLo1nWKhVvp67mmpyth2Wn74/9cBQS9+qPD5wtLJIC2H+YQYkF/Xmh6
Ov3z8f8uub5TQNCiDd0KYm0kgNZefqT3SPrzSNPT6fen7lxMiIeAoG07fzCO
spYA2snrUe0o+vNO09OVYJ4y45PWcQFBuw4QDj0+WwLopS2X9szewGN6uxJO
m0V6fTktIGir8jFzDGdJAC3oVlOydxOP6e1K+OqYVJ9zSUDQ9+3vdrphLgF0
tEOMV6wLj+ntSni3YWhfy1sCgjZKb2gVTpUAur7f2dPd6fsNTU9XwsoYw9ra
hwKCzgtrPNd5ogTQ1yN1Zni58ZjeroRQ9VS3mmcCgn7B+re4y1js7Up42qb7
W74de7sSOjXnnpjyRkDQyjP61D8j7O1K8IkXhVzYhb1dCZOW7B5FKAFBuxUs
3PlgCPZ2en9cK0yauBd7O/3+mAy1u5QsIOj7lXtyzQ2wt9PvT9cf18v2Y2+n
rxfNZyX3cgUELT4zwy9aH3s7vX9mCmeFH8TeTp9vP9Z2qRQICPrMwEx51x7Y
25UwqzmIc9QTe7sSpg2o99lZJyDorS1nP9l0xt6uhCVnPgxd64W9XQUBl186
jZIJCHqGecTKnVzs7SoQlj3LtfHG3q6CA8MCL/bREhL0/AYzi4MqMaCdO7m6
WJ/C3q6CJx4OBtN6CQn6hXVO8xaJGNBjnG9oL/HD3q6CdB0B5+RgIUH3P3ZZ
DU1iQLfOfsva6I+9XQX2a9xsxWOEBO2YlVzAo9dfaIe+BteOB2BvV8H7qQ/a
rk0XEvSIfxNZb8rFgK7XrWwLvYi9XQUHHYpGO9LrTfT8nCs19vR6E+3cxywg
JxB7uwqkx4zyLZYLCdrvc13vsjwxoK2GdD7U/Tr2dhWYFMCwmc5CgnbvvbFh
U4YY0LbiZZ2W3cTeroJrP+MGOm0XEvQbA6PmzJ9iQD9prjsTdAd7uwrY6kxh
4GEhQbNOBV0y+yoG9Eny2rw8GHu7ChIun7tR7Cck6CHmM0yvfBQDutFl8xaz
h9jbVfBX/4DjrKtCgr508Ju94I0Y0BaJ9xwuh2JvV8HgTS8XPw8REvT+ZaOd
xkSJAb0gv2ZlTTj2dhWUP/p5f+xzIUFfenEnavtTMaDfRcSEL3qGvV0FqwKD
j8W8FxJ0tln057BHYkD3dR0VEvkCezv9768Z22fODyFBd8/aLiq5Kwb0kaBF
p3vGYG9XQf6fQ3dzc4QErR84L0b/hhjQ4rjisIOx2NtVMP2Pq/WuMuztKtgS
uMTZ5hL2dhWkmq1ZUfgWe7sKfjw/u5jbhL1dBYOeznDy9sfeTr9f44SZ/Hjs
7fTrbVBX3lBjb6fPh7Mnu8aexN6ugtwPcPQJwd6ugm5ls9cO1y0j6KPdN2TW
H8HeroIvnulBnb5gb6ePJ5Fa8GRAGUGbnGb1mHAAezt9vH484en+DXu7CubG
134aPKqMoEsenhu6byf2dhX0mvhhz/ck7O0qiJ77yNR/WhlBjy4x2RK/BXu7
CmoD3VKGpWBvV8Gctj3n/8wuI+gNrIWWPTdgb6evH22FwsPp2NtVoJVoqWO0
rIygvYM3K3etxt6ugtnRqeykLOzt9PH8ck3TinVlBN19tJ1O3grs7SqQ7XA8
pp+HvZ3e322Hrm11LyNorZPz3tguxt6uAjUpDl3zG3u7Cpp/eJhvOFRG0P53
E13S52FvV8HMKYNTbxZjb1dBldJhvIVvGUFfYOe4u1hhb1eB5Yk+i1NLsber
gTNifHzT5TKCPlFfNUzHHHu7GqhOXfcoy7C3q2HE5S7Tz9wrI+jdb+Xl8ZOx
t6sh6bHPxWEV2NvVILnYVtkSUUbQPIuTXc+Mw96uBu8ykM+sxt6uhqcG+iPN
Y8sIOrL5YJ3LSOztavhP27rz0jp8nowarBpWzlj+uYygN511FK4aIgZ0+ofs
7vaN2NvVkLAu77hFShlBh6zQn+0yAHu7GiblHdywtAWfJ6OGl6QcmvLLCHr0
g24b/XuLAV07UbZsphh7u5q+X9LJ9SgvI2grV+X1xG7Y29UgSDllOliGz5NR
w9I9VkGfG8oIes2P0mlDOuHzZNSQfffylkYF9nb6v+83NT9bXkbQPT3+XbvB
wd6uBmmi7vRYNT5Phv739DxFz7TKCTpbPFdrrEoE6CDeetV2thbT29VQU5Zn
M69nOUF36a5fWCwRAVohPajXi6fFPE9GDaJDL6feNSgn6DPzRm+NaRYB+mNx
za8wbS2mt6thl9JR/4VROUH/PJUtiqgTAXog6XN6XGct5vnJapj15fbyoybl
BL3Z8FVeQqUI0Gl7ja/f76rF9HY1NKhnrVCZlRP0WdamVexyEaDjTyyzb+um
xTxvmf553IJ9p80uJ+ifiyd/2vJHBOiBThVDl/TUYnq7GhJDlzkNXoTPk1HD
/Qn5K5t+4/Nk1DC56pqjv54W83xmNYzdVrEkdmU5Qe+w1V3zJFcE6J8FR+ye
6+PzZNRgP+5LscwJnyejBsfthr18M/F5MmrI+bn38Ke+WszznNXw8HpzYOXm
coKOij0Tdz5VBOjRT2Yave+Pz5NRw9RpkyXe2/F5Mmr4t2WbX/vvBaG7Lfn1
McRAi3n+sxp83kuevt9XTtBkOO/Z8O8iQD+oP/7f7kH4PBk1DBkfuuS2ZzlB
N1ZNWPPqCz5PRg2durrbGRtqMc+LVkPE+PdX+58oJ+jIqkdvDlAiQI89/8Lo
2xB8nowaLsXOMJt+upygLUZuLnf9iM+TUYNrXerFJcO0mOdLq6GHzsBOjQHl
BO15rFnh/14E6K+ftTnxw/F5Mmq4af5NODewnKBfl93rXhInArTxpWhpTyMt
5nnUarAJ//Vm4o1ygl4XedvILVYE6Mwxr+oWj8Tnyajh/f37/tG3ywn6cdSk
maNeiQD9Irxi005jLeb51Wpwr9u6+3twOUHbnvu1cFC0CNBOH24X7huFz5Np
g9GO6rt7HpYTdG02a8rClyJAB9xo+7d2tBbzvOs2qNkmdYoILSfoLr98M589
FwFaMeBT37Fj8HkybSBO/tFrb3g5QWvdGShZECkCtHrKfl4Rvb3m+ddt0Kc3
yzrxaTlBHxKfcB78TAToRB5/xb6xWkxvb4Oi1/dvhz0rJ+irTya9Gv+fCNBm
z7eFVdHba56X3QYGS47l6T0vJ+gDBbOvH3oqAvT83n9i543TYno7/d8rqJpO
L8oJ2tVnSIAiQgToVKtGSx96+84dQa4N/L121/jT26NnJizsEk9vjxbeL5Q/
pLfvyK1z28AoUdTnMr09evdgrYNv6e3RNvuOJz6mt9f09DYIfJWTN5jeHm1u
3Ee/id4eXb5TdNCf3r4jx9m1wSKBVcpU+vWi117eOGAr/XrRK98ua7Glt9f0
9DbwGfv2azr9fqJJ9ePgfvT7iX7Q5X813F9IU3EUB3Cxrvhg6gxEknSRSQ81
1/9kxAliSf/IeimEqZWUIeEeFssHZ0X019Yo2ZQIcWojqIHNqdPRb+YeDENt
QRmaVP78B4XgvGm1+nXw53n8wIXL7j3n/NiXy9FtW8DnuRzXlGF9zL7qXcD3
RTbc0zYq+L7IZ7sr9dV4vczTBZRUmEQj1gO58PCJOD3WA3mk6KOYxnpY/jtv
EfC4r20+gvVG3p7luenEeiNPm58Hd+L1Mk8XEHQUH7NjPZPdnYWf9mI9k/Na
Tj06h/Us98UIOMPHRQT7hTx8P/VqOvYLOSOwyCzYLzJPF+DTdhjc2I/kp3M5
33TYj+Stt3/Yy7Ef5b4YAfZDlst/6zgj548ajdew38llaSYTYL/LPF3AhObW
+akHnJGTrcG3SV0qkKvCTQ2/NiohuS9GQBMbSi7BeUXWa+uvDOO8Is/M+fpc
OK9kno7P87fqv3iDM/LLeGXTAM5DssdWfWkdzkO5L0ZA68PK74k2zsje3f13
/uC8JT/jmYbrOG9lno739+6qBStn5JnNk/mlYRXItRVrJobWKyG5L0ZA4lJ2
INXMGTm2yty8iOcFOf5fgW41nhcyT8f582H8S005Z+S7dY6U0IAK5B7/nqVs
PI/kvhicNy57t6OUM7KtvcvdOaQCube1WZeD553M0wWYIp+NBac5I0fSNaax
9yqQXRbrOw2ep3JfjABn+PUbz3HOyP4nWZlbRlQg57aZ52fXKit5O/6e0Z5I
x0HOyDVpbmfLmArk0E9v+wuNEpKf6wvYcKRBX7WPM7K5yHfhwFcVyP0nc48W
pygreXvc/snBwWh0B2dke31GQsKUCuSALxqLJSmh/xoeZj8=
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fwPF7b8OWvfcqUjKyove1CdlJxFcSyoyQkYRUFEVDlERDQtKg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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H19 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{19}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 11->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M
d96X92O+O1fekZ3ZOUnK1NzMnEJmdqqbFca1GgBqfFYLKAoUA6rrGb+poWsR
oLbeFwfq6FoCqA+UAkoDKUAZoCxQV+9LAvV05Xc1NR7nWw+M19gNNAZ/v47r
1LqaAZWAykBjoDxQAWiia0Wgud5XAVYBY7S/tcA4zdkIKKffrwYytdc1wFjt
taHWzu+aamzOvQGYoH2nAW2BdsBWYLL2vQmYqL1uBiapNu2BdGAgcCYwRfNs
A7K0p+1Atva0A5iq+XcC01SDLcDpqtNG4DTVeAYwXTXoB7QEWmm+dpo/FWgN
tAEG6NpW6+L7DsAgXTsCQ4HOQBegv8bj7wfrfSdgiK78ri/QQnOfBZyheg/T
GF2BEUA3oLuF76hPVSAD6AH0BEbp2svCg9X1XcKLvKcH6Rd6o4RqQF2KSGd+
V1TveT9a4/UGRmp+zpfwMceaDczUHspp7dSotOpNHctIZ96Xl278LuFF3leW
DtSrlH5HP1SUnvyukt7zPtEb3MNw1Yk12gXMUj1bqL59gANAjjTbC8yTlvuA
+dL0IJArLQ8BC6XZ2UCe9DgG5Guuw8AiaXkEWCxN9wMLLDy0B5hr4YGjwBKt
dTcwx8IfXGs/rfUEsFxangRWSAN+11/fcaxU3XMO+pW9dQ6wTBol/JqqvaXp
/jiwVFpugpkqevRJwsfpVuDRwdrnCNWYexuqd6zFMN1zrJH6jnNn6J7+Y55U
1fUU8YRfM7S30brvqnk4Lj2RZeETejdT4/GePdJQ2rOX6UV6lrlH39KX4/WM
Hpmob+mpSXrG3zNPUvQbZh3938AiK+rr3WQ947uxWgvnm6B56MtsrZe1ylc9
qOks6UbPssb0LT0+Xc86qsaD9N0cK8iaedKNmC+dCfqqvZAj3ejzmZqTc0zV
uvgu1wpyZ5E05PqWSivqmKfaE0u0D75bJq2I5dKKOqySFhxrscbgO3q1t64r
xTn3Qs3P+q1WDVnvNaordVsrHVjX9aottd2gelPDjdKRGm6SjtRqs/SiVluk
F7XdKg3pF54f1DzLImcbSbdt0o412666UasdqiW12im9WONdSdruTtJtj7Rj
r+9N0nBfkob7kzQ8kKThwSStDiXV7LDqRi/zXK8lDY+o9tTtqHSjViekFTU8
ZgV+PC7NqeFJacWD5EaLviwMfos0KQp+m+Z08JukeSHwm6UhvcOsoUeK4Pmt
0rAY+O3SkL5gbtIbJfD8TmlYEvwuaVgK/G5pWBr8HmlYVlr9/zcRnt8rPSuA
PyitioPfIY+UA79f2pYHf0DalgW/T/oz5x6StpXAH5a2zcEfk7Y9wV+WPn3A
X5U+g8DfVu3TwN+UPv3BX5du3cBflM5twZ+WLzqAPytfdAZ/Xr4YB/6pajkF
/GuLvhkB/r60rQx+rkVujgL/UNoOBX9XNc4E/1g6J/xH733DOnn0araH3tT6
E83Nea/m2B5euY46eHjoGou/dembL6iVh3euZb09tP+MOnv4jtfP5cGvtB/u
5XrW3sNz0zz8RC99y9p7ZMEcDw/RPzM8fEaPzfLwJT35HfXxyIvvgdkeefGR
9p+vNX4pj6eDX27RP03A/7Xo4VrgP1lkSg3wHyz6Kgv8BovMquJRO9atNvjP
FrnTEPwvi7xoBP63RV40Bv/HIi/qgf9mkUF1wX+1yKbqHuvmmuuA/2KRXw3A
/7DIphTwPy2yqT747xb5Vc1j/9x7VY/asW41wX+0yMpO4Bda5E5v8Ess8qUr
+EUWGdQP/FKLrBkOfqVFfw4Bv8IiUwaAX2aRQWM8/EFv9AC/2CK/xnr4g95o
CX6eRSa2B7/AIgczwK+yyKbJHj6gB8Z7eIj+aQN+vkWGTvTwH71HTeZ66ELd
Nntox9qs9qhPnkeOMEOWeWQHc4NzjvaYl/oP9vDABxb9w955y6Kf2cvc9zCP
vb9h0dvsa9ZgoEcdWKeRHrV6x6L32HdPAi08/v5lDVp71OEpi/5n7z9n0fPs
96YeucPMeQRo5vH/x+NAK4/z5FGLPGIWUc8uHpo+Y5Ej7G3WrJ1H3V6yyCzm
Fb0w38MP1KGjhxYvWGQTc4le6O7hh/cssiZP8z9hsQb6er2Ht1d45C+zd4NH
/jJ753mcEzwj6PelHp6nR3p5+IT+Xe7hYfZcjkff0YOpHj5c55HX2eCrPPKa
Wf2KRf4ye9lbGz36i72y0qNf2ItrPfrxNYssZg6v8TgPssAXeJxJPI9yPc4M
nhf5HmcPzx324mKPfmTf9PXonUUe5xbPLPbxEo9eZh4s9MiE/wDEuW/v
                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83Hc8Vf8fwPG7UCptoaGp0h5SVO/T3ntS34ZKKqW0l/ZCgyiVStGSlCQ0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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJxE3Xc8le//wPFzjuOQZBQaUhEampRUH73vhpL23mlRGak0tbQnTVK0F2mI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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H21 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{21}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 12->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fwPE7WjahFLIjFFJCeB+i7E34JkTJJsrOioykElE22TNJWZ+j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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fwPG7GmSEMkPG1ypJZor3icomW2ayNw1CKCtEkShRCEmFSvb4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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H23 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{23}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 13->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HlcTN8bB/BZWij7EorsWcsSCfFca2SLEiUJ8RVClmTfIlRIirKTFrJV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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fwPG7KiV7Z4WGlR0h3scoK1lJKqKShKLiS2SHjEKyEqFkhEpG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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H25 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{25}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 14->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HlcTOsfwPFZm5DseyqyE6ns8j227FtClmsnZEllqci+U0KELKEQUkhZ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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83HlcTG0bwPGZqZlRdkKUPdkSylbSdRSRNVuFhJCtLBGebCEVQiSUsmQp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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H27 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{27}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 15->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR
5kIDdUOdigkoKEtnpE1rqDU1TC0ETyDIwkylEENQ3jkeeTmc5ny+180e/2Gf
Pdv543dfv/u+HL0sfsEKV5PJ9JWLyfTk72cdKWezsuq1hTfmDPT3by8c/NGG
1Y7cB+IfLyWOiDjcKJ7vbSm9nN8sTiw+pWVUtYjfdfgNDbrZKn5xyskW+602
8d3lPsX51e3q9zO/yzPXdIhTrOM/97xnE4eYjiworHskHjl1jLelwS5uij7o
Nrbxsfj8/pdvVTZ3itPLsgrS2rrEZjev7QG2bvHEGRkrGuw94s5VAwMPdDnE
V3J3DJnn6BXvqvBodjqdYvL76dOQ8DKfVskPkx8mP0x+mPww+WHyk9/X88Pk
h8kPkx8mP0x+mPww+WHyw+SHyQ+THya/00+tkR8mP0x+mPww+WHyw+Qnv6/n
h8kPkx8mP0x+mPww+WHyw+SHyQ+THyY/bOivZuivZuivZuivZuivZuivZuiv
ZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivFjTBuWfu
gQat4fXrW0Z4txTW7ux850TeQzH54i/t7bZBR5vEOyevD525qEUcFtnh3bi4
VTxpn6XfQXObuKek6VZIWLu4pDf2lGtEhzjbr357QaRNvDLqyb9H4oDsu4FD
Y+ziZ0rDvUpiH4v/dLnTnBzXKT48zXzFx9IlXhdz41B1Qrf47ZyFSbsSe8SD
yiven5XkEP/TL2SiLblXfDzgD9ejG51i8sTkWffUGnli8sTkickTkycmT0ye
mDwxeWLyxOSJyROTJyZPTJ6YPDF5YvLE5InJE9Nn8qXPmD5j+ozpM6bPmD7L
7+t9xvQZ02dMnzF9xvQZ02dMnzF9xvQZ02dMPuRFPph8MPlg8sHkg8lHfl/P
B5MPJh9MPph8MPlg8sHkg8kHkw8mH2PfriUsc/E2qbysTy15YfLC5IXJC5MX
Ji/5fT0vTF6YvDB5YfLC5IXJC5MXJi9MXpi8MP3Dkz7Z4bnE0iD5lfy+9Zdz
iQ/FUb6b40dtaBK7XQ0ccPHNFnF579n7CbNaxQf9Xv11XFCbOD7qdFbV7Hbx
G9n+a7fN7RB7lp6cM3OeTfy3i+/YxpBH4mPTjnXnhtrFSTETKkMWPRYH5xw5
7rqkU+xVPia1wNwlrut36OOosG7xqYAR04dG9IhTV2c/XxLpEIce8qpLjuoV
j67MKPSJcYrJD5MfeYa3xg8LLFImT9y7eNXVPKsy84vJG2dfWL7BvUKZ/PHw
jBNfF8Qqcx74QdGk+Kg4Zc4H/9yd/95QizLnhbdNHj+qJEGZ88MfRh5+nJyo
zHni8ftGl/skKXO+2FaSm1+drMx54996h2/atVGZ88d7/LKWzkpRZh5wZNQQ
f9tmZeYDT8ne43E0TZl5wS6lA2oXb1NmfnCZy45z/dOVmSfJe5rH3nM7lJkv
vCZm65q4XcrMG56R4x40KkOZ+435437D3G+Y+w1zv2HuN8z9Jr+v32+Y+w1z
v2HuN8z9hrnfMPcb5n7D3G+Y+w1zv2H2M8x+htnHMPsYZh+Tfuv7GGYfk/tS
38cw+xhmH8PsY5h9DLOPYfYxzD6G2ccw+xhmH8PsY3j3+ba30i+r99N3XGNb
c7GaL2t63TehZWq+Vnb8+8GZSjVfbr5Nmzwb+7wHEbHmwmaVX97e+/6Wtj7v
QfGK58baVH6ao6a20t7nPZgSfj6tS+V3e/ntvQGOPu9B5tK4BqfKL9laFXTA
VeUVbFo4cp67yuulqRV257Mqr7ro+dd+6K/yOrPf+m2kp8ortSw4ZfAAlVeo
W9GSokEqL/qI3eOuH0trUGb+6Cv54p7dHv/1X6f2E+YTkz/O7HLfF5ek9hfm
F3M+ePoy0+yKjWq/Yb4x54frl3/RM+yi+s78y3ujn6+8F5ldldbL6jv9kPdH
P3+8xbr++41F6jv9wcyHvCcmW+orJeo7/ZL3SZ8fPG7q2rAaq/pO/zDzJe9N
dPP0jDL1nX7K+6XPH760f/ULQRXqO/3FzKe8R2X1dfZK9Z1+y/umzy+OcIu+
kF+lvtN/zHzLezWjNtN8U5n7Qd4/ff6xc1WExfO2MvcHph/ynuXeCS6sVuZ+
kfdR7w/OqTCPsdQoc/9g+iXv3TN/dY25p8z9JO+n3j8887VF1yvrlLm/5D3V
+4npo3Efk/tb7x9mH8P0Te5zff/C9Auzf2H6hNm/MP0R6/sXpi+Y/QvTD7G+
f2H6gNm/MPMv1vcvzLxj9i/MfIv1/Qszz5j9CzO/Yn3/wswrZv/CzKdY378w
8yj/H9H3L8z8ifX9CzNv+H+BjgH0
                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fwPG7L5GR7IyUFZVN1vsYKSPZe4ZkKyR7lZG9srNKoYwUUjlH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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fwPG7rxH6qoxkl51N9vvYFJHMyEhGyoxkS0bZGnZmJDtSmeeI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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H29 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{29}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 16->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fwPG7L1kZX7JXVqKMkPU+ZY8ie2Ykkk1WJFtkZJWVEJUkK4ni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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fB/DbnUo26UuyskchI8n7EIqyMiM7SWZmIVsqJKuyhezMVIjP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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H31 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{31}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 17->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fB/C7ry2zrJCQkZmZvA+hrBAS+dp7lMiIhCLZhIyyZyEJLfQ5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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fB/C7L1nZlT2TmYS+1vvI3iPK3oTsTcgoIooyQqKQvUJG6nNQ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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H33 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{33}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 18->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJxE3Xdcjf/7wPGzDxkpMyMlRCSbUNeNZI+sRJQd+WQnWVFR9ohQNlGyEpLx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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fB/C7upGdipKsZFZWvgjvQ/bKCFnZRFZKSGYSkllkK0JllxD1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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H35 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{35}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 19->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83Hc8Vf8fB3DclZGGqGgvRUNpkbyPhopvkYbSICntoVKhvXe0JxqSCu3d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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fB/DbnbaQEKJklhAZGe9jVrZsQmZWEVFWsmdEQpIyiy8JyfY5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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H37 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{37}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 20->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M
d96X92O+O1fekZ3ZOUnK1NzMnEJmdqqbFca1GgBqfFYLKAoUA6rrGb+poWsR
oLbeFwfq6FoCqA+UAkoDKUAZoCxQV+9LAvV05Xc1NR7nWw+M19gNNAZ/v47r
1LqaAZWAykBjoDxQAWiia0Wgud5XAVYBY7S/tcA4zdkIKKffrwYytdc1wFjt
taHWzu+aamzOvQGYoH2nAW2BdsBWYLL2vQmYqL1uBiapNu2BdGAgcCYwRfNs
A7K0p+1Atva0A5iq+XcC01SDLcDpqtNG4DTVeAYwXTXoB7QEWmm+dpo/FWgN
tAEG6NpW6+L7DsAgXTsCQ4HOQBegv8bj7wfrfSdgiK78ri/QQnOfBZyheg/T
GF2BEUA3oLuF76hPVSAD6AH0BEbp2svCg9X1XcKLvKcH6Rd6o4RqQF2KSGd+
V1TveT9a4/UGRmp+zpfwMceaDczUHspp7dSotOpNHctIZ96Xl278LuFF3leW
DtSrlH5HP1SUnvyukt7zPtEb3MNw1Yk12gXMUj1bqL59gANAjjTbC8yTlvuA
+dL0IJArLQ8BC6XZ2UCe9DgG5Guuw8AiaXkEWCxN9wMLLDy0B5hr4YGjwBKt
dTcwx8IfXGs/rfUEsFxangRWSAN+11/fcaxU3XMO+pW9dQ6wTBol/JqqvaXp
/jiwVFpugpkqevRJwsfpVuDRwdrnCNWYexuqd6zFMN1zrJH6jnNn6J7+Y55U
1fUU8YRfM7S30brvqnk4Lj2RZeETejdT4/GePdJQ2rOX6UV6lrlH39KX4/WM
Hpmob+mpSXrG3zNPUvQbZh3938AiK+rr3WQ947uxWgvnm6B56MtsrZe1ylc9
qOks6UbPssb0LT0+Xc86qsaD9N0cK8iaedKNmC+dCfqqvZAj3ejzmZqTc0zV
uvgu1wpyZ5E05PqWSivqmKfaE0u0D75bJq2I5dKKOqySFhxrscbgO3q1t64r
xTn3Qs3P+q1WDVnvNaordVsrHVjX9aottd2gelPDjdKRGm6SjtRqs/SiVluk
F7XdKg3pF54f1DzLImcbSbdt0o412666UasdqiW12im9WONdSdruTtJtj7Rj
r+9N0nBfkob7kzQ8kKThwSStDiXV7LDqRi/zXK8lDY+o9tTtqHSjViekFTU8
ZgV+PC7NqeFJacWD5EaLviwMfos0KQp+m+Z08JukeSHwm6UhvcOsoUeK4Pmt
0rAY+O3SkL5gbtIbJfD8TmlYEvwuaVgK/G5pWBr8HmlYVlr9/zcRnt8rPSuA
PyitioPfIY+UA79f2pYHf0DalgW/T/oz5x6StpXAH5a2zcEfk7Y9wV+WPn3A
X5U+g8DfVu3TwN+UPv3BX5du3cBflM5twZ+WLzqAPytfdAZ/Xr4YB/6pajkF
/GuLvhkB/r60rQx+rkVujgL/UNoOBX9XNc4E/1g6J/xH733DOnn0araH3tT6
E83Nea/m2B5euY46eHjoGou/dembL6iVh3euZb09tP+MOnv4jtfP5cGvtB/u
5XrW3sNz0zz8RC99y9p7ZMEcDw/RPzM8fEaPzfLwJT35HfXxyIvvgdkeefGR
9p+vNX4pj6eDX27RP03A/7Xo4VrgP1lkSg3wHyz6Kgv8BovMquJRO9atNvjP
FrnTEPwvi7xoBP63RV40Bv/HIi/qgf9mkUF1wX+1yKbqHuvmmuuA/2KRXw3A
/7DIphTwPy2yqT747xb5Vc1j/9x7VY/asW41wX+0yMpO4Bda5E5v8Ess8qUr
+EUWGdQP/FKLrBkOfqVFfw4Bv8IiUwaAX2aRQWM8/EFv9AC/2CK/xnr4g95o
CX6eRSa2B7/AIgczwK+yyKbJHj6gB8Z7eIj+aQN+vkWGTvTwH71HTeZ66ELd
Nntox9qs9qhPnkeOMEOWeWQHc4NzjvaYl/oP9vDABxb9w955y6Kf2cvc9zCP
vb9h0dvsa9ZgoEcdWKeRHrV6x6L32HdPAi08/v5lDVp71OEpi/5n7z9n0fPs
96YeucPMeQRo5vH/x+NAK4/z5FGLPGIWUc8uHpo+Y5Ej7G3WrJ1H3V6yyCzm
Fb0w38MP1KGjhxYvWGQTc4le6O7hh/cssiZP8z9hsQb6er2Ht1d45C+zd4NH
/jJ753mcEzwj6PelHp6nR3p5+IT+Xe7hYfZcjkff0YOpHj5c55HX2eCrPPKa
Wf2KRf4ye9lbGz36i72y0qNf2ItrPfrxNYssZg6v8TgPssAXeJxJPI9yPc4M
nhf5HmcPzx324mKPfmTf9PXonUUe5xbPLPbxEo9eZh4s9MiE/wDEuW/v
                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fB/C7uikiCcmsb2SvyPY+ZW+VGWVHZCeRXRTJHmWGiBTK1vic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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fB/A76mYL2YSQnRkqvE+SLWQnocjmK0VUlJ2UlRWijAgVJUr6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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H39 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{39}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 21->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJxE3HVYFN/bBvDtNRHsBEVF7EBFRXlGLAQ7sANBDBAwsbEVA0zEDhQb/aIi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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XVYFF0bBvDtfW0F7BbBQLEDEZ9BRUxAsBvFxsAOwsBuxQBRUbELEVEU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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H41 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{41}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 22->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fB/C7ry0kRPbKTEb2+6BsCVH2+NoyMsoMkR0pO1JCRooykvI5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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83Hdcje0fB/A6024gVEiyZ0JUfG+yV2WPirJlhoSQWUIKqSiyV49EFNJ1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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H43 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{43}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 23->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR
5kIDdUOdigkoKEtnpE1rqDU1TC0ETyDIwkylEENQ3jkeeTmc5ny+180e/2Gf
Pdv543dfv/u+HL0sfsEKV5PJ9JWLyfTk72cdKWezsuq1hTfmDPT3by8c/NGG
1Y7cB+IfLyWOiDjcKJ7vbSm9nN8sTiw+pWVUtYjfdfgNDbrZKn5xyskW+602
8d3lPsX51e3q9zO/yzPXdIhTrOM/97xnE4eYjiworHskHjl1jLelwS5uij7o
Nrbxsfj8/pdvVTZ3itPLsgrS2rrEZjev7QG2bvHEGRkrGuw94s5VAwMPdDnE
V3J3DJnn6BXvqvBodjqdYvL76dOQ8DKfVskPkx8mP0x+mPww+WHyk9/X88Pk
h8kPkx8mP0x+mPww+WHyw+SHyQ+THya/00+tkR8mP0x+mPww+WHyw+Qnv6/n
h8kPkx8mP0x+mPww+WHyw+SHyQ+THyY/bOivZuivZuivZuivZuivZuivZuiv
ZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivFjTBuWfu
gQat4fXrW0Z4txTW7ux850TeQzH54i/t7bZBR5vEOyevD525qEUcFtnh3bi4
VTxpn6XfQXObuKek6VZIWLu4pDf2lGtEhzjbr357QaRNvDLqyb9H4oDsu4FD
Y+ziZ0rDvUpiH4v/dLnTnBzXKT48zXzFx9IlXhdz41B1Qrf47ZyFSbsSe8SD
yiven5XkEP/TL2SiLblXfDzgD9ejG51i8sTkWffUGnli8sTkickTkycmT0ye
mDwxeWLyxOSJyROTJyZPTJ6YPDF5YvLE5InJE9Nn8qXPmD5j+ozpM6bPmD7L
7+t9xvQZ02dMnzF9xvQZ02dMnzF9xvQZ02dMPuRFPph8MPlg8sHkg8lHfl/P
B5MPJh9MPph8MPlg8sHkg8kHkw8mH2PfriUsc/E2qbysTy15YfLC5IXJC5MX
Ji/5fT0vTF6YvDB5YfLC5IXJC5MXJi9MXpi8MP3Dkz7Z4bnE0iD5lfy+9Zdz
iQ/FUb6b40dtaBK7XQ0ccPHNFnF579n7CbNaxQf9Xv11XFCbOD7qdFbV7Hbx
G9n+a7fN7RB7lp6cM3OeTfy3i+/YxpBH4mPTjnXnhtrFSTETKkMWPRYH5xw5
7rqkU+xVPia1wNwlrut36OOosG7xqYAR04dG9IhTV2c/XxLpEIce8qpLjuoV
j67MKPSJcYrJD5MfeYa3xg8LLFImT9y7eNXVPKsy84vJG2dfWL7BvUKZ/PHw
jBNfF8Qqcx74QdGk+Kg4Zc4H/9yd/95QizLnhbdNHj+qJEGZ88MfRh5+nJyo
zHni8ftGl/skKXO+2FaSm1+drMx54996h2/atVGZ88d7/LKWzkpRZh5wZNQQ
f9tmZeYDT8ne43E0TZl5wS6lA2oXb1NmfnCZy45z/dOVmSfJe5rH3nM7lJkv
vCZm65q4XcrMG56R4x40KkOZ+435437D3G+Y+w1zv2HuN8z9Jr+v32+Y+w1z
v2HuN8z9hrnfMPcb5n7D3G+Y+w1zv2H2M8x+htnHMPsYZh+Tfuv7GGYfk/tS
38cw+xhmH8PsY5h9DLOPYfYxzD6G2ccw+xhmH8PsY3j3+ba30i+r99N3XGNb
c7GaL2t63TehZWq+Vnb8+8GZSjVfbr5Nmzwb+7wHEbHmwmaVX97e+/6Wtj7v
QfGK58baVH6ao6a20t7nPZgSfj6tS+V3e/ntvQGOPu9B5tK4BqfKL9laFXTA
VeUVbFo4cp67yuulqRV257Mqr7ro+dd+6K/yOrPf+m2kp8ortSw4ZfAAlVeo
W9GSokEqL/qI3eOuH0trUGb+6Cv54p7dHv/1X6f2E+YTkz/O7HLfF5ek9hfm
F3M+ePoy0+yKjWq/Yb4x54frl3/RM+yi+s78y3ujn6+8F5ldldbL6jv9kPdH
P3+8xbr++41F6jv9wcyHvCcmW+orJeo7/ZL3SZ8fPG7q2rAaq/pO/zDzJe9N
dPP0jDL1nX7K+6XPH760f/ULQRXqO/3FzKe8R2X1dfZK9Z1+y/umzy+OcIu+
kF+lvtN/zHzLezWjNtN8U5n7Qd4/ff6xc1WExfO2MvcHph/ynuXeCS6sVuZ+
kfdR7w/OqTCPsdQoc/9g+iXv3TN/dY25p8z9JO+n3j8887VF1yvrlLm/5D3V
+4npo3Efk/tb7x9mH8P0Te5zff/C9Auzf2H6hNm/MP0R6/sXpi+Y/QvTD7G+
f2H6gNm/MPMv1vcvzLxj9i/MfIv1/Qszz5j9CzO/Yn3/wswrZv/CzKdY378w
8yj/H9H3L8z8ifX9CzNv+H+BjgH0
                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83Hc8Vf8fwPG7lW9pDyptSXsX8j4N7aGhpKSkkvYglaaKtAfR0FLRHjTl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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83Hc8Vf8fB/C7jBZtbQ1aKira9T5EtFFpKioq0SYNTdKgtKcmmhpSqm98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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H45 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{45}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 24->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fB/C7r2yKoshKEVGUrN5HZiTzS8jKHolsyUjZGdlUIltUMrL6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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83HVUVFsbBnBiggvYYmA3YmKhoL7HACywC7EBQUFMbMCWtAuxMEEEwQSB
fUQlDUIQke5mumf4Bmfej3/u+i1cczm1Z+/nPOcM2ea1wkVPR0fHiK2j0/Hf
0NsdPw3wpJdH6EGXIkDnn7J/Hb1En0KvlTnfDneVkvmBHnXyiAaI4J4dKRid
C+ipydlnZtvoUegbpzeJTh2Uk9bjMHVTQgNc9rw4Ysj9MkDHtcQOr+brU+iw
4WHvLPtIyK3d3U/TmQ3Q5d3nV/9tbQb0mZaJHnP7sCm0ZPi9Ucd+csncLTXZ
Q/82wKUKva2wOxvQk5wGN6d10qPQYXZk1J5qOWle/mHg2aYGyHq7bs3NBUWA
ju+V1dh9oT6FDs51Ny/ylJIb8zo2qAF27Avqc1lWDejQ/sNsH89mUuhvqfH7
358SEkq9NQuNG2Hr1Z49LE/lANrjyrZK24l6FNrsr5X1vvty0jjSwiCqfyOc
XuE3rj49C9BmzMJTIYm6FPqVcKms8pyCXOvDWNN5XCPoZHo/8LrzB9DUn84C
z8n6FNrPvrL38NtSMtvw96M9sxrhTOqZ5YoF5YB+aLG1J3RnUOjksFm/T/4V
k3p5BDfXvhHKmIppJn4FgE70K3uql61HoS+oqDjZZhm50tJxABsBvDn2jSbJ
gI477bUihqNDocMkgzc8HKgiM8uWBt/crf77RgR6z+hRAegtGeEbf8xnUGjK
M2H+dm8xqVUfPalPI0xpTEpnx5UA2japt5R6p0+h95/N7uRzVUIupQjNnC42
Aifwg8vDt8WA9un2fuybG/oUmlFy+enNXAmxepPunXy/EVbO8rhiPr4c0Ku7
3HkcYMSg0GsqMt411otJ9ZM7Xwa/aoTBKdsty1kt/zdnoEP1xeNcQF/gFHb6
MIdNh9zsOGEbYWNFwArBr0JAj3VaHnDPVJ9CR9htbErJlJLp/nPUZ2wjrJ3H
PnxuQxmgd9Xr/NzTpE+hzSeotg4cLSGVR3tG21U0gnW8pK4tpgbQS8erpPJd
TAq97ZG+sYGZkAR1XJ7cRnAc0fPxu0XFgH5x5tSvNf76FDpSJFuzokVCpnWc
rnpNsG7W4ay/PjmAfsH2OvJ3gh6FjuQM6bTwgZyUdxy+7k3gmKiX13qhENCB
a7cUDeimT6Ebl8HiLyVSEtCxOUObYPWEsJSt4RWAzjd6tueWG4NCr6mPHfhz
vJhMmdzx0wRDZg3/aBhbA+gFXTKi53owKfSeCs/wo6OEpHQ46+T1eU1gnj9T
37ikBNBPQnf4PfyoT6HfZU5sT7wgIRd6/fkhXtkEUtpVPkr3G6C7erzz7U7r
UuiKUVd1/voqyCT11eno3AQmlg/2f6orBHQV68B4SX99Cm3N6/2oS6qUFEt9
diYeUO/Pa4IRFovLAB14JXm4a4M+hW4sOvVu8jgJOdf0b0CC/tOXSFs4FYBm
d17pY32cQaF5Vev1/dliMrGkY4OaoMugEFf5lnJAfzn/6M/sPgwKfZjzYcmp
n2JSpN6aqifq/TekbeXeiVWAXpEuX9X/G4NCO3kZrEnbISJn6MyHNu/Ux2tV
aeoRQ/W4orXJ9fd7751iUeiC/Ev9P8t4ZHzc3bZnqU2w1WHrks061YC+tbJP
Xm8dJoXOXvdzfXa7kBSqRyPD302w0qI1m9VUBejVQdZvPskYFHpN3YWbxw1F
5NT1jgG4CRIjFasW3qoAdIw5rO7uyqDQ4ZEnV/+dLCZjznccwCZ4ebrAOdmo
HtBND6bebtNjUWjz5GvfB8v4JP9wg3oEbgbLEWtcyverz0utHfxX95UUsyi0
c8uq711secRXffSu9mkG/+mu7/yUdYAeGnJ73JZ2JoVOrPr2GHQFZLTTRfWI
1AyV9/XGDu9TBWjJMx2j/1IZFLrLK1VDy34RybPf1nXdjGb4O22EfEpsPaDf
22fMth/LotBXnD1PuTzjkxMdX68Lm8Fn1+Fq6cwGQJebDjwyeymLQs/J/Nzp
9FY+GdXxdePYDDVDbXsqXBoBHX+hG9P3NotCh7QWC3W/80hOx/C7sxnK4K9B
Vm0doCU/p6XESZkUuuuWK8dCjQXkWMdwdLQZouMOVvWcVQ/oKI+S6TZdWBQ6
YqRNyMEKPhnRcXkGNsO94krPM29qAG32/nC/IZ5MCh17uXNG0ggh+dlxut5p
BpHAZPzIq3WAnn3ibGBGNZNCn2UK6z2mCciRjsMX1Qwe17eqjnRrAPQGl1u+
m+azKPSiqT915h3ik2Edm5PYDGnNLJ8J72oBPenjybLAl0wKHeavoOofC8j3
bx0/zTBtn9FKj8ZqQIcUp/S8Y8Wk0DW2RwsyAoTkUPJ90wklzTDlquXoqH31
gP5ebW/4oj+LQrtOc26KSOWTIa/2uV1uaYbc1dGW3SW1gD5wvSmYkcyk0L3z
zapFpwUkS3118pXNcK604VLdo3pAhx+yqpaasSh0UtdAS+NoPjl4tWNC0QIL
bRf31DVpAPSVnO42lA2LQhc7FR30Pcgng852DEgtwDw09aRLQx2gP22037Je
xqTQPvNdwN5IQDK8OzaoBcyWWYkGZNQA2vBayAm7fUwK3fy7krG3n5DsV2/N
cWgBqevaeVfs6wCd/Cf/knMek0KfWbKqdNp6ARng6GxdtrQF8rwbwk5W1AL6
7UarHVs+MCn0jfmBFnBRQNIWW6q/YVsgePdF9+j/agH96O/20F2nmBQ6YcH0
LDO5gOyd1TGBaoFEh84txXH1gI65Os/6vfp6RIcXHva//JRP+k3oGIBbIOR7
k4fDgVpAO/Ot7vS4y6TQM/oGZBR+FZCvg/8dQBj5110ZnlIL6ExvR/L8FZNC
e3ZffDL6noB4dUyPH7bAobrrOg8jawBdemQE9Xwnk0LPN37rG2MuJH07potx
LcDbb75tcnAtoBVhAYVLHjEpNDu10cE1XkA+d0yfUlrgdv4e+cMndYB2nVrs
49bApNBTrtvpTRgnIJ4d04ncFlhtXPNo2og6QJvMkz63z2BS6IIjnaKdPQWk
d8fXa1ULzJziKH5I1wC6S3DBCbM9TApdWbOCETNISD51fN3w1Z8X389p4Mga
QNu0sm6eX8ik0N7DeDkcDyHZ1TH8Mlphe1SD6ZfRNYDuuyuBtXcRk0L/GB3I
G7BLSEw6hqOerbCg/xCDHYpqQHe3M0jpC0wKXby37di3k0JCOi7P4a1w+A1n
bNSzGkAPHDfTqMmdSaG/PDnfMHqskLh3nK5TW+Humd6npo6tAfSoirNbOi1m
Uui4WYLZNe5C0qPj8Nm0gnOXIVHeI2oA/WeewYuN6u1FOxxui5jvKSRJHZuz
phXca3QnB3nUANrxCG08bAOTQi/p5Fsbv1BIdrh2/LSCX87clQXTawC95U32
takOTApN3dxUcG27kHRbN0M9Q26FRRZ7gz8srgb0iiVOw1q7Myn0hh128cOK
hOSjerY45nwrhM5Lap61sxrQtcsmHLtoyqTQkzc9/K8iU0hcrDsWBK3w8mU8
/9LIakDv2tU68/F/TAptPnrYuffNQtJlXMeEQn08H7iIVjyrAjTL7XbSrwYG
hRZM+H5mzVgRiR/YMSC1QpeVZ/LbLKsB/aXnVqG8E5NCHy6YZWJQLSTbu3Zs
kPr8KHi0c/OuKkC/ET4v+l3EoNC3e0YvWrZIRDrpdcwoWmFcyP2P/CtVgA6s
qmtNrGZQ6MbpE4eemyYi7/nKX4cbWsFmQL2VeHkVoJezE36c+MWg0Ju4gdsY
a0Vka8fyVtoK4hmX33utqwK0j0N1S78CBoVmbLccnr5SRIw6lnuGbVDC9N9S
+boS0IfmDL0liWJQ6O4nPv7s/FRE3nYsf0zbwKbp9IYh+ysBnSMrX5MexqDQ
mwxnr/BKFZHNHcuBMW3Ar673EzZUAHrWDKstJ44yKPS54EBgGonJv+mxdRvc
yvmwcFDnSkC7Ttmde/40g0JPuTlsA0ciIv+mi4vbYPoNkann3QpAhzxJst2w
g0Ghq9+c2bfQQkz+TZ+c2uDuarbgSGYFoHfk6564t49BoSetVjA/m4rJv+mE
Rxu0vOS4TJ1dAehjY46vD17KoNCGEWz7mi1i8m/0Pd4Gi4NPho/SqQD0yu0P
6v+jGBTacQYZ3+wrJv++boLbID5TtXOqWzmgo+OIYydTBoV+HOq3qCZLTP4N
v3fbYEZg0f4QjwpA/wgXhQ3bwKDQzgndUz8sFJN/w1F0G3S61FZVcK0c0PrV
8g9TRzAotMzSIOTaWzH5d3kmt8FBg2+WNpblgB6gx7fP6cSg0Knyvs4bq8Xk
3+n6Q328VsXtXawqA/TVRdN2Z7TrU+iinVeHeepIyL/DV9YGng9TdkrV61n0
+FXrxvmq17PoJ2uXPtFVr2c1m9MG3szxxpNOlAE6hj4752mbPoUO9xEcfz1Y
QnT+/XBgwq6q3eL8EkC7eha3JCfoU+gpI+yGnwqQaOfzHFi099WQ7UtKAD26
8zTnoAh9Ch1dddWyLkpCIrm56hk1B3jhja6VtSWA3rSqZElxoj6Fnr/WxtXu
nEQ7/+fArB5+4SEDSgDtprfsV+wjfQptId+8NuyDhKyq6ggMOHDy98Dz7BvF
gOYUVXHoK/oUevCi6QN9iiTa9QIHqAnvJtHKv4Cu/7qG9cFXn0JPPLCCf1FH
SlS/OjaIA72Uk3vs3vwX0I98XVNadulT6ASdyceGm0m16wsObJ45svve5CJA
B6XNH/pjrT6Frt/j/XH7Mil5ntoxIVL//W6ptn+3FgG66/dCN+sl+hS63MVh
vP8OqXY9woEljNibv8r+ADpgsOiKzFqfQrck9ygyvCAlKzpWt8s5sNzX6Mwu
7h9AN3qd3DNutj6FHjtYOfDJaal2/cKBXf3s8y/2/ANoz0cRsstD9Sn0iPgo
w+IEKVF0xFnbOGCTM+T6lFWFgB5t9fjKOUN9Ch0T+L6I1yjVrnc46vO79LHS
thDQG77feVNmoE+hF7mk36BapeRpRxy0jwPt11V2t0J/A5rObTdYydej0H6O
Oq3r+8q06yMOTL5+MumnyW9AP530ShxfqUehX4fe7xpkJSPLOuKU0xxIdTXo
sqahANB/jCs+mZfoUWiH2lnHI21k2vUUB16lhxxzHlkA6F5/9l789kWPQv+y
71/h6i0jso444ioHrp4uP+QSlg/ofV0V0UGv9Sh0vzJ2eO0tmXb9xYH9HkXj
+vTPB3SI/Ufm6Ud6FLrK2V8g/SAjjzuW84/U549neyZV+wvQr1o2900P06PQ
D4ZT371SZdr1GgcueBpYvDL6BejYTkNY3if1KPS96iR+D6WMOHScrm/U10tT
X/OU8DxAu82aZ7PugB6Fnnj2yMGlveXa9R0HLsXkr/k2KQ/QvLdFAetd9Sh0
/2uLGpdMlhNJx+Z84cBi2759TW7mAjrDbNijyhV6FNozOj7eylGuXQ9y4IZv
kOTDkFxA8y92G2Q5X49Cm5YXf7p8SE7CO5ZjvzgwPmLDmB4PcgA98uAuF70p
ehT6jcnoqfKbcu36UT0erYw7cPO/HEC7LbrROmmIHoWesCtvaGiSnCzpWM7U
cOBFUPfPZ85lA/r68m23srvqUeh8J+ufm0rl2vWmen/oej1fNDAb0LPLO63O
0Nej0GegerWnRE5EHcsBIQfC8ib859PzJ6CtlFfK7bi6FDqIWTR7zwCFdn2q
vv56WDt6S74DenLsI5fzZboU+s7dD1O4lII86JhOs7gwfHiv6DlG3wE9d1uF
6ZtsXQp93HpW5s1NCu16lgtCk1vrz4z+BujNJ2/b3ErRpdBzlN8O/DyqIIs6
pqO9uLC7ehz/78AsQNuVTiItsboUet+80JPDwxTa9S8XGg4vOH3CKBPQF89P
KXz/QJdCV3FuLL2UrCCCjuncSC6ciX0wbE9eOqD7GFnpWQbrUujshkD55RqF
dr3MhUGzHw7mZKYBurKHoV7McV0KPbOwSf6QpST3OqZDllzIfZrWGiFJBbTn
0eZ7AV66FHqk0aiUxsFK7fqaC3ED5SstZV8B3RQLBx9t1qXQ5mF+JvGUkizo
mE7YceF2wmS3zLovgI60Pv30uIMuhX55QRrH2q7Urse5IH15cKZ9+WdAlzum
5TFm61LoOYv2rhOdVhJex9frOi58+zI86N3fFEDbL0lx+zhOl0K77jg23v+x
Urt+50KXXtHhBb8+AXprhflO+wG6FHr2rMgxLl+VJKxj+HXjQpDuIYPXeTSg
++45P9G6ky6F/jGIe8+/Rqld73Ph9NDZhjFZBNA9ucsPb1TpUOjCAU5dbPRV
xLbj8jzMBYOHK9ijSRL839etFkhbdCg0Jz/Aq9NwlTYfUB+PftUVPyI+AvrP
4C6HHEp0KLRDckW37TYqwuk4fP5cSPN8VqgTHA/o3dZfWW7fdCj0cP+DvAk7
VNo8gQsXlpa/eP7yPaCP62228UzSodAG8jkHR5xVEc39Py4U7fasS3j7FtCH
dln/fvlSh0J3H+2//PFjlTZ/UH/e3JXy1m2vAd0ztOhQ7zs6FLowa1HXnAyV
9n4iFxQFrGcLnWMB/WHadPuhgToU+tKViy4fG1TavEL9+T6zZrs2RgNaJpTc
ijimQ6GNe3b+EWXQrr3/yIXOpmM/29RGAtrtlXHv27t0KPTE+7U5383atfmG
+vcrLG+bpT8F9KIS5/DBG3QotKfNtI/JC9u19yvV++cTMajmhgOa3T70Utpi
HQrN1U0o2+PWrs1DuPA6asWUrEN3Ab3+iduNNisdCm3/dnze4IB27f1NLghG
dA7V8b0G6CX9p+iqzHQotFvaTaV+dLs2P+EC3WY5YMPmAEBzOmiqQ6EHX/q6
cE5Wu/Z+qHp/B6qWfrU9AGjb9mfbhhnqUOgDuq+s4pvatXmL+nqZ6Let1Mj1
/64nP7rKBO2ANn5wS3yKqUNr7o9yoeD353LD4DMEvezw7MaagnZAF3b8uqcO
rclfeDBYEeAivHCVoLv+cjcvjm0HtMQkq7HbKB1acz+VB3Pi7cs3DrpD0P0y
fC6cutoO6P136I+zp+nQmryGB/xJZT1m/npI0G6srYM27W0H9LfjSznL7HRo
zf1XHvy9/+la5y9PCFqXvz6wbHk7oH1ZK626rtWhNfkODy4pfrkYySIIuv+6
nMcTJrYDmrfy5rj6HTq05n4tDz5ODnHybXhJ0NtC+jHfdG0H9M/p+5RPDunQ
mjyIBz6bH7oXdIolaINGl9tD21SAVhjav959QYfW3N/lgXO/9ambWuMIetHu
0B6mOSpA/02fJNp3U4fW5Ec8eD7ZOSBs4FuCTk1cb9krWgXou0NWVgue69Ca
+8E8YDzMMKgZ8J6gOS77Y4aEqABtYG9r1vZBh9bkTTywPPdw3POB8QR9t27E
CZPdKkBPMvacI0zXoTX3j3nQ4/CDp79HfiRoX8n1s1fsVYD+pD81adofHVqT
T/Gg/PPVV+4WSQSd8lnk3DBWBehB987YBzbo0Jr7zerzw1514eMcQtCj++2x
qzZSAdqDZ1fcSaZD/4t3vHmgrE89lH6fJujyoWwuq1kJ6Eu7j59X/KdLa+5P
82DxqvvCR88+EfQhkyUnjbKUgLYRroejprr0v3jkPA+Ofr3kk/M8haCX143L
rolUAnqdcUPvYHNdWnM/mwe/yy0UXrGfCbrm8xGdXH8loDsN/Nzey1qX/hcv
3ORBYnH/H1T0F4J2c55Za7lTCehv3yuMqxfp0pr73zxY+u5y4Ze3Xwl6WkaL
s91CJaBd+vnbO23Qpf8tz5/x1PMRJ9agpFSCPnNiyiAnMyWgZ39y4eTs0qU1
98t5IHrx49ctkkbQJ81da4wNlIAmjUuCpcd06X/LvQ/q83tc4qUTdDpBU0fr
7Tl1CkCXpxj9YQfpau+/8yCh/7yGPVkZBO0e9rvycqoC0N8srnV+H6ZL/1sO
pPNg4MyZnr2zMgn6+OF13e8+VQA65XOed2yULq25H68eDybfvXorO4ugH6wP
amk+qwD0xLwZ/v8l6dL/pot/eOD6PLPcJP8bQfMja+dtdFEA+lyk8abl33Vp
zf17HjyLb5BkFn0n6Kz0ygdP5ysAHXonJCaqRJf+N51o4EGdnv/yi8U/CPpR
2Q+T3cMVgB5/qY8wvUWX1tzv50H9+Gb3gPKfBD3saEpcq74C0K0p954aqHTp
f183Uh6o7h6cHrE3m6D9blXGXq+SA5p+3XnU1M56tKYfwId2jvG+R/xsgqY/
Hx/W+7Mc0IPvzdl9YKAe/W84MuSDT2qvpO0Hcgh6i0NC17pwOaCzC8MPBY3X
ozV9Aj4YKMXlSZIcgk7WSTmffVIO6IftAxN7gx7973Q15QMxtTQdciSXoJfN
2Bf/fqsc0OuqbIcNX6pHa/oHfCgLvvjnsiyXoC/0D/PfMEcO6ESuhfWKzXr0
v80Zw4d5yV760cfyCNqr63DfnkPkgE4Xe9IHvfRoTV+Br573LIwb0J5H0BPu
el6driMHtJvFwndVvnq0Jg/lQ3iT44zJJ38RdB+bCIvXZTJAH9g4ZsfIS3q0
pt/Ah5roZP9jevkEbbfq0oCtRAboknzLvUsf6NGa/JQPlHsby+lMPkG/GjFf
VX9PBmizlhK/wFd6tKYPwYfcxYtq17IKCNrY05O100cG6KMLMxSZtB6tyVv5
kOBfQDaeLyDoKxsNL5ltkgHaMkf2vilbj9b0J9THL2TeubmGvwl6XX+vTV6z
ZID+tTd92YIKPVqTz/LhdmnPP56BvwnaMT3Bf/gAGaDz7gz96MnVozV9Cz6s
kdZP/NSpkKAjP319fVEhBfSYQQNGftDVpzV5Lh9MXQQH60IKCTqh9tRQ22Ip
oB8FJbcWd9On/y33zvLBaP/G9Gvd/hD0rEf130M/SgG9Ndro9qSh+rQm/+XD
2aDg+glX/xB0WVgxc8odKaAvx3ZTukzSp/8tB67zQY9dfHiKSRFBU6r0irij
UkCX+/W7+HSuPq3Ji/nAEPvtWHKziKAhZVDtWEcpoMsHcoIaVujT/6aLT/jA
WnFA6NX3L0H7NIXrPZ4hBfScgGjVuO36tCZfVu+PxPsLCkL/EnRu10LPRX2l
gL4p7pHhuF+f/jedeMeHkP8sq7L7FxN02KxJaVkSCaAnVbj2Dz2tT2vyaPXx
OaIn+HGvmKBvbG2fu6RQAuipS/1K/1zVp/993aTy4dvD391SB5cQdHDvgGM/
3ksAbSWwSunzWJ/W5Nd82CR8cuRseAlBPz914+GmmxJARyVPiVn2Rp/+Nxz9
5kNLyvHmQcNLCdrmZzlD4i0B9KZbF5Wnv+jTmrybD8IPWVeSnpQS9Odu9ncu
rZEAetCh9XHvf+nT/07XOj4IHMrmB40qI+h5Y9Nb+0+TALq04c4FbrU+rcnH
+bD7VZ+kxIgygq7Oi8++ZCIBdOdej25aCvVpTd+FD3O78A2zTMoJevPhc0dN
hWJAZ39OTNnHZNCaPF0AutKHORfWlBO0n/6Emx9/iQFN+bhNCTdh0Jo8XQAF
t0f/2H+znKBNJjf1sX0jBrS3awC/eASD1uTpAnCfkNd9V2E5QS9xu+GdeVUM
6KKsN19MpzFoTZ4uADHjmYNO3wqCPnMiqtB3vxjQsz9F9KBsGbQmTxdA+6d7
7jqOFQStc39iVvsKMaD9Xu0w9VvDoDV5ugDc/M+bm96pIOgl1omN+yaJAe1Y
+TAg1ZVBa/J0AQQ3WbUV/q0gaKuAbRd6dBcDuirhh7XIm0Fr8nQB3Ino3qWg
fyVBT3rhLbnGFQF6R+SX01PPM2hNni6AvDVxz35srCToG79GRvXJEQH67fXm
iP03GbQmTxcAuRtuEHqvkqAHx0bL416JAL3nmdmpp88YtCZPF8Do9gG+B8sq
CdpDZy9lc0kE6EzftM0l7xm0Jk8XQH2vmlOLB1cRdNCB4NlFXiJAJ9jEl3dP
Z9CaPF0AXl572qZurSLoBel2Bi5LRYAu7ld8zL6QQWvydAF8nLFVd0Z4FUEP
3b7Ut2q8CNBeDuuokHoGrcnTBRDjF5nfVFlF0M+JuUlAZxGgxz7YKUyQMGhN
ni4AYdqlfl+HVRM0K8xy34BWIaCVFtW2XAMmrcnTBXAytmD2M+dqgqaeXdsS
9V0I6C1Rb3+O7sukNXm6AOKO7dwW8qSaoEelZP6Y/lII6OZ7obe2j2bSmjxd
AKU+ftvdaqsJ+jINP7KChID+MKi8T+gMJq3J0wVQYpz7aOGoGoK+Iu01foOH
ENCWpwVuuQuZtCZPV18vcyzn/udWQ9CMzdWb5IuFgPbJDl6m58ikNXm6AOyN
gkdwn9cQtOPRGZ7nxwgBnTd3+8KZO5m0Jk8XAG+EcvrnhhqCZnue3D7QSAjo
4wvhx56jTFqTp6uPV9CT1y/Mawn6+YxxIyMbBYAeu72hOTKASWvydAFUvnn1
y29XLUFffPLsOmQKAD193Nip5aFMWpOnC2BvQuiXVVG1BJ0eHnc3P0IA6LDo
kRYmL5i0Jk8XQFbE4VGjW2oJ2vTFPI9d/gJA7zcvXbjoI5PW5Onq8/FPoFxv
fB1Be/WwOqVyEwB6gagy2S+LSWvydAGc+FF06OPuOoJOudV9fvgCAaDvvxaV
RP9l0po8XX28yHnb8Jg6gmYMTiwerx530Kq2h5frm5i0Jk8XgPPkrEBvTh1B
O7iaJnxhCwD95xsvfICCSWvydAEcXOFSO9uinqBT13wP2qL+XkHfXXU7fqkx
i9bk6ULostrq5ch99QR9OH9bRLP6exQ9/7rDC//+LFqTpwthz2b/7jqv6wl6
wbKPIt+nfEAXrw1n0GNZtCZPF0KyXcC8NH49QQ8pttrU/xwf0JzLldncmSxa
k6cL4RvxGXhjSgNBmz6gOW9c+IDmx9w/P8KeRWvydCGkfDCyPXKwgaDvD5M5
zbPhA3pi66nlmzayaE2eLoTz23Z+n/iugaATfyy6XTecD+jwW46TgzxZtCZP
F8KmmbVVTHEDQedUGHc+weADus9F6eFPJ1i0Jk8Xwn7Vth/Zlo0Ener341bv
ah6g75JbkwXBLFqTpwvB8rZy1sPDjQTtPFl3a8xnHqAdXH2Xmt1j0Zo8XQhx
yR4798U3EvSzBxmZto94gI6acCfUKZpFa/J0Icz1GdWXkjUSdBnlwS87xQP0
pbKFrEvJLFqTpwthxYXjys7WTQT9++Ock4e38QDdc+hm8vkHi9bk6ULoOsXr
e86xJoKWuCzo23suD9CM7xv2C0pZtCZPF4Lw7jmHZ4lNBM2KTVwXNYQH6BPP
HuaNbmPRmjxdCL3lO/XclU0EfeBUps9iXR6gU5NDKcd2Fq3J09X/P98Wt9Gz
mwnah/Jf3FTOBfSnzdaOAV3YtCZPF0JWhu83vk8zQZv2o/ueo7mA3s8bxE8c
xKY1ebr6/BjUeUQCaSboCZzDLUMfcAFdf36ef+sENq3J04WwymL7Bh+dFoJe
s8Mhl/blAnr1t8Ibgyg2rcnThfB2Xnnh0jktBD2y9GKPdZu5gG7pOl20chmb
1uTpQqjpbL2+86kWgg45vC1PMpsL6PjPDjdOb2HTmjxdfX0VPkgqSGkh6NCr
Ex5eG8gF9ORpbjFv97BpTZ4uhJelTsfD9FsJOvJSzicLFQfQLyx7D6rzY9Oa
PF3tBvrTqvmtBG0eOOh+fgkH0Lus9kw0ucymNXm6EK49M7QcdLaVoKdFHXXe
k8QBdE1Eyne7h2xak6er99eSqhtFX1sJumB9yJvudzmANsn78MQ7lk1r8nQh
zDoW+PUWq42gt821uvv6OAfQP0u3WTz9xKY1ebp6/yrN32yxayNow5ONT5Y6
cQB9jBiOK8xh05o8XQiK0vhVQy+0EfSpro/yW605gCaHxl83qGTTmjxdCEt+
Sy8WpLcRtGNP/Q/X+nEAnXdQ9Wgqj63N29Xbt73/pB2iNkCL+pz/dlvJptAm
P7iu3xgcbb4ughEfNn2797YN0P9F9369o4VNoVsfZd+eOIKjzddFsMCwJbrh
QBugr8z9uMuqhE2hi4/6mwXacMi/6VNPESgnR3edOKUN0O1BYxjG39kUWq/2
ubjOhaPN10WwPPbTmoP8VkCv8ni1uiSRTaHXjbq/yuYch/z7eh0ugsT/pO8S
41oB7TU3eVxMFJtCDz12+vHDpxxtvi6CxRX1U1V7WwG9cvrRYN8wNoV2vGhU
o5PGIf+G36kiqG3M/mpr0QroBKsDscuD2BQ6OKD3Xac6jjZfF8H5eaedQjgt
gK7MHnxz2HE2hZ65KTnnA5tL/l2eNiJI7zfKpDCmBdC81IVM0S42he6/z0PY
w4yrzddFcOSX8zJTrxZAD5za91rqBjaF/nL9++99C7jk3+FbI4J7p3tl7Brf
Auj6Bza80MVsCm2RfKBfphtXm6+L4NqNwew3Lc2AfjIiXdfTmk2h373xUozw
55J/cbqrCPJn+FxVRjUD+mBImTOMYVPoXlXUtJMRXG2+LoKf7kec7T2aAX3A
ceD6Hv3YFLrP4s/2fzK42nxdve7Ynf/9+phmQF/bcHB/jSGbQv9eYNJ3aiNX
m6+LgONFe1Y1NgFa0W/P3w8yFoU2SB+0MMSQp83XRZDVW9RzSmQToPlnZzGD
G1kU2lRwRlhjztPm6yJ47yC0Oe3eBOjolSdythSxKPTjdcyNsxfztPm6CCSG
sn45Zk2ATj6lsp2SyaLQZ2R6+27u4mnzdRFs/N7iPKy+EdBr91v/MUhgUegV
ff3tWwN52nxdBIfcr4UdfNYI6E2mI3aURLAo9PystxY2UTxtvq7evvM6Rl9d
GwGtHELPjb3NotCsRN+jd7/xtPm6+noZYLSrz8hGQK9MSzE958+i0I57j2by
m3nafF29fxqdG91rGgAdbXX7qOMRFoV+HPDdcHEnvjZfF4HVggcHyOMGQHfu
blYywZ1Foav+xtg8GMfX5usiSBnX+U1P5wZA7wnUH8dcz6LQgxokT4T2fG2+
LgK3FS/q3Yc1ADr0l/nRogUsCv1tTaTR4t18bb6u/vfv/swllfWADvV8lx0z
nUWhvw2/uulBCF+br4vg7a64/n3C6wHdEjqWfc6MRaFHZj7l8qP52nxdBD1H
H8nevbUe0DaLBr7Z0IdFob13fb654Cdfm6+LIOzMX+e0wfWAHlUx7Y+FAYtC
x826Yh/Wxtfm62KY+jz6waDyOkB3ihxTz5YwKXTti+cTOF0E2nxdDGWr9CWH
79cBenq+zuzSOiaFvrRadXreRIE2XxdDZp/ozb821QF60rmm3m9/Myn0Hb5Z
9vVlAm2+LoZA1+pO4wfWAfpR3yOnA9OYFDrhWydp/R6BNl9Xf951p2cBJbWA
XjLid8S290wKvePt8iirywJtvi6G/jrzHteG1QKaTXeNmPGMSaF5vqUvg2IF
2nxdDG8rqRc2TrWAfjk9e2e3m/j8oBiehmw2L8kRaPN1MbzecIr9sF8toFtu
lM+pP8ek0CNzZx+fwBNo83X1/nlQHdVeVAPoSWYzmog3k0LfiQke7dddqM3X
xXC+aJnL5tAaQIdPW/XnpiuTQideWWufPUmozdfFYPMu8j+yvgbQl1/uTPFa
w6TQpY/Njw1eKdTm6+rPf7Hp0ZC+NYCujPzttsCWSaFnRi4b77VfqM3XxTBn
q0H+ycJqQC/rM/fg4GlMCr3l5zETclWozdfFcOj+I071zWpAl9aZzZSOYFLo
+ROjz3d6I9Tm62LoE7/+st3aakDb7l5TnWPCpNAHhq20dPol1ObrYlg7d7jd
i17VgL7RNSMnksmk0L9KPZ0iBULt85Ji8Io0HduloArQYZGsrNNCfF5SDOmR
PHdJT5E2XxfD+yHJ/P3XqwC9+0KbwqkG+9hiGN42mGU7VaR9vlIMV+o7lxeu
qgL08AT96dPy8flK9ecFSi5eXS3S5utimD203Q96VgH6UjqUd/mK/W0xVOz2
g/KDIu3zmGLIucYveZJXCegpNccPNbzB5zHFcGsqq9u4GyJtvq7entcGqzpf
rQQ0b6ze9c+Pse+tvj6eyvMPv8PnN8Vg0vPTy4MrKgHNtNmz6+41BoUWHRw0
+muBSJuvq4/vPEW3sm6VgC7t6vvl0Bnsh6uPb6nuoa5ikfZ5TzGMFoUkL8ip
AHRA0qMJKw4wKHTzmQ8PNvTGPrkYvlg9jo67VAHo2M4RL8Y6Myj0vcqXz59a
irXPh4rh9vZxWwYsqwB07TqjdexV+Hyoen85NCzlrhVr83Ux7E21WBDQpQLQ
YXuNr1TOY1Do9P51f60Oi7XPk6q3f6TRONGPckAnZ8wNTJqMz5OK4azH0YYz
t8TafF09XiTv3Lw9pBzQkTFFv28NY1Dolw8WLfvxQUzG/tscMdhZH+Rl25cD
Otfh7swDPRgU2mnb13O9/4i1+boEem/5zIRO5YBmFe75tFSfQaEFSwee2CIV
k4J/eboENk0b7eV0uwzQ30bWBI/h61Not7ip1c/7Yr9dAn7eRRet+5QBOttB
vpddhf12CWzZ9l9/7gzst0tgvMOu3/1ulgI61b3laFUu9tslcGDsCMMZjthv
l4CqNvKA0qQU0OVO16NJCvbbJUDZ5of7HcV+uwTGGd3Iq7hWAmjXT/uswuKw
3y6BqSdMA9NCJdp8XQJj8uc8SO1RAugnVga/Dodjv10CbwPa1nb+KNHm6xLY
ADX8F1eKAd307LjP6ivYb5fA6Fcs/dV/Jdp8XQJpR+NPXO1WDOj1E957TTqF
/XYJODy8PPiOXKLN1yWQ3s1AeuzSX0DP0Bvi22Uf9tslECJP0q3oh/12CVif
Wh/j2uUvoO0mNuU3b8V+uwT23h+9auRM7LdLINR8rdGKkCJAr6zZOSdzOfbb
JeA41fzELifst0tgP70yZ1anIkB3Pmye8GwO9tslUNXlReCr49hvl4C8l1nm
mKA/gC7Tszly1gL77RKYIzvYSRiG/XYJTN8kWWxq9AfQaUa+C7cP0afQ++p1
PWckSbX5uvrzPK6/NgwoBHTYy31r5nTTp9Dpj01XniiRavN19fkS+9hNaVAI
6Jk3er4cpKtPoS/kFTyhlVJtvi6BrW5zenDO/wa08Tg3PRUH++0SqH8yQa4/
EPvt6vPhbNfMatZvQL/oOvd2cTn22yUQUXrsu+1s7LdL4HkxLPpztgDQ1+V2
oz9mY79dAgUGe176b8J+u3p/x1g55zAKAF25+vzYUBr77ertWcV9muWD/XYJ
dA2xa0g/nQ/oFK7ZgCOvsN8ugeP9o792uo/9dgmYZdu9TdHLBzRT9nzNugfY
b5eAyCh6xVIi0+brEvhrPqQp8eQvQG8Y4XzX8hL22yWw8K3l10tlMm2+LoHl
ISYD4nV+ATozNnxYbz/st0vAIyzhQ067TJuvSyDqdMTGd755gPae+DZL5IX9
dgmY3L/u1n0w9tsl0EloGfxGlQvocNXTywWbsd8ugSS9uOIVFPbbJXDQIaz8
zYlcQP/07xH2bin22yWwvbkw7coW7Lerx4PRA8+/VeQAeurXqlc3APvtErh5
cPq9XD/st0vgfHns7ffHcgDdbeY0vvcE7LdLoPT81b7dH2K/XQJesmnjPsqy
Ae1Q9tRl7SA9Cu08J27K8k9ybb4uAadfxV3pI9mADgrtpze9ix6FbshMl1+s
kGvzdSnsjpC8DOT+BPTNgLKEPu3Yb5dCbiMV8EMX++1S8Lodczq07Qegb0qt
nktbsd+u/vfGATHGQ7HfLoU53evvvGj5DujhJ5Pji0qx3y6FD8pTQYvmYr9d
Cq0xI6eTpm+Abt95iv/xB/bbpaBnLu9zYRv226UwvvOFxLyGLEBX+aVb303G
frsUrFS7L3w9hf12KXjPmjiupS4T0L/183J9orHfLoXlkvWOeo8U2nxdCqnM
Uwns2gxAOw1+fmzLPey3S8GOxBjAZ4U2X5fCaoGMDK9OB7RNTPviuSHYb5fC
wYc6bseqFNp8XQrdWFbB8yvTAL31Qd6C4T7Yb5fCbLJu93t97Ler93/apxLX
8lRAH+pf7Mnajf12KXRPsxvOH4b9dilUG6w7F1j6FdAhfi4f6jdiv139e9WU
i+PnY79dCiVTh8yPLf4C6E095vbMssd+uxTm/zn2290Z++1SWPlpK1Vc9BnQ
Jv1ZX17Own67FArS+Icen8F+uxR69HsXxv6TAujYrVlHLo3TpdD3Zroblz1W
avN19ec//N029fcnQJscVW7aP0CXQhcYMef2/arU5uvq8zlnFMs1nwZ07xPb
tqzppEuhc5nW6u80pTZfl8IPW8kTi2cE0NNSJgTPUGK/XQpXjz2oCWJiv10K
X4dxp999lATogf5pDf1bsN8uhS8te8amjsB+u/r4Px+z0fjBR0DP3diwTacE
++1SOG4zzqrdBvvt6t+/er/9ZFg8oE8lDTCq/ob9dikoznxpsHTFfrsUBm/j
N0tvvQd0tzs7fqYlYr9dCqUZE7fuOYf9dincrRjY79D1t4DuJC788CIK++1S
qO3mEPL8qUqbr0vhxBSvx7LLrwH9+Miw/Ith2G9XX7/G8avLU1XafF3t7iHB
J0NiAX1jj4fxgSDst0vh18BRdb3rVNp8XQpl3aTp/XvFANquetj+dcex3y6F
vZYf+i5lY79dCntuWUyf2eUFoLellnNmemC/XQoz988eeG4U9tulEFqSWuJm
8AzQ3v0OPRrihP129fmY0S0+0Q777VLIcvoZd1f3EaD3z8ryZi3BfrsUTM+6
d+fvwH67FNY6fW96L7wL6PjQ315N1thvl8LFzGWDR1/AfrsUDl8eP3Je/XVA
D9u45Fz2GB0KnWCzg7/pebu2zy6F/AuGbzPeBgLav4P9dCh0a+N1j2vp7dq8
XQZngw0mukw7BGg7xq1Jd4x0KPQ+8c/QjPp2bd4ug3Cvg+uLFFv/7wU2eVd0
xdhvl4HTxhvTfBnYb5fBtIPP5gfePkPQvWK9G74VYL9dBv9+3RP77TKQiO8W
Fq2/QtCDL9y9dusd9ttlwLGOfft6uA6tydNlEDHv7blC11CC5prX3HW+0Q7o
8zs7xX6fgv12GRTOMNtSM+MhQVskq35N9MZ+uwzqHvhdr5uvQ2vydBk8ayy/
v5J6QtAvJDrblavb4f8+7euguxr77TJ4aTmr8r1tBEHP69VKZU5tB3SZ4EKZ
qYsOrcnTZXAmZHFST/uXBB30yMTxpkk7oK3GC1dMOYj9dhlkrXpJXke8IujX
5swvzkLst8vg6U7lXfuzOrQmT5fBp4/nthRGxRH0/GviI5PyVYAuncr47Hod
++0yeHXVlkhi3hD01xtGB3TeYr9dBvemyL76PtGhNXm6DN4esuf2eP2OoM+a
NdE/rqkAnbwr4P6tt9hvl8HmewVzxrz7QNCmNyoX3z2A/XYZ8N90doz9iv12
GbjX38+YFZ9A0Ed0XYd5rFIBel77ktaMfB1tv119fCvXNC1KTCTo3MuLlltP
UQG693vHtZU1Otp+u3p/iC12riLJBB1U7hRv2FMF6ISLyx/JhDrafrsMPtjb
vhq7lSbohdPE7kV87LfLoNiZkdWdhf12GVwRD0yP2vaJoDsPUbhG5mG/Xb09
bSe/mffCfrv6eJH3982dUwjawOC/qKOvsd8uA8UxecTckdhvl4Gv6yDqqctn
gp7YQ2G5+Cr222XgJtJ1dpyG/XYZ3H5W9G3Qji8E3emFM6v/fuy3y+Bo5HfF
Xlvst8tg58uZwhtuXwl65c51Q1pWKAH9O3Oll/8a7LfLIGyg/K7RzlSCHhtG
BSVPUgK6MbYs/oEr9tvVf/+1bbt9dqUR9J6Xkydd6q4E9ILRtbXvvbHfLoMk
cHvf6pFO0AaS7qO38bDfrt4/p72bfpzDfrv6fDIdUeS0O4Ogw50+Ok/JxX67
DGKWh3+vuYH9dvX5Ep12N90rk6BHGto1s+Kw3y6DlqPF/oqn2G+XwdW3vc9M
2ptF0A7/nYj5cxn77TJYf2yOWY/32G+XASug5O/tfd8Imjic+RK1F/vtMnhQ
mHR3dBr229X7I8Rofvv+7wQ9KcSnt99yBaDrPlAC+K2r7bfL4W30Ida2gz8I
erShBVlpoQB009Edg9fU6Wr77XJYmvSK+dn7J0GvqV94f1Q3BaDzjTZM9BDr
avvtcqiVDH7edWY2Qad+EufLOdhvl8OAQQyTU2zst8vB9anTl+TEbPJ/F9Q7
ZGdjv10O368FFt7sjf12Ocy9ZFyxa1YOQXP+JrKfvMJ+uxwMrgw5/nIU9tvl
EDPVrq53cg5BX5s0nnX0Evbb5fCutl6RYon9djkET/h0M2V2LkEPeNPFceke
7LfLgTdCsqLQDvvtchg1Ew57kFyCFk3kVAxfJgf02Tr2xZa12G+Xw0jHSUwT
Ko+gvd1fJ8smyAFts/jpAz037LfLwTQ8PCaRziPoo2t7/8ruIgf0vFWC670P
Y79dDheee5tsn/OLoEtXh1s9a8N+uxy65UdvG3sB++1yMLPb4mmQ8ougp7U+
qz7xE/vtcqgxiOo05xb22+Wwv1/t56i5+QQ97Ajr56oY7LfLYffn47dWP8d+
uxxuhDaVL/2cT9COfb+yx17EfrscVu4foHD/gP12OeT6TRZw5xUQ9LdB/FP6
XjJAm+45N9snXU/bb5dDpVNa9ZUvBQSdbvbD9q+DDNBhTbecrhTq0Zo8XQ72
het/TbL5TdAt/g2LXo+XAdrQOtDxab2ett8uh+0jSx7nfP1N0Dvepd8I7CwD
9LfHd6YkSPRoTZ4uB70Q2OplW0jQfv1fjXJulQKa5o5q/m6A/XY5pCmnMozT
Cgk6xI+nmvkD++1yiCfn/Cr66NOaPF0Ol8eHXHtm94egnQ4Um/aKlgI69+tl
nsAM++1yeOoe3D4n/Q9B33jS368tGPvtcpj6kgsGM/RpTZ4uB8GdEJe/C4oI
Wn992MgMTymgffJiPfotxH67HHoGwpv9GUUEbT2A0/2RvRTQ27jnvcev16c1
ebr6fGX5VRou+kvQXqrNdifGSQGdrrPMaY479tvl8DPCr9fDzL8EHZS/OWFt
JymgrUyyh646ok9r8nT1deE6esC0xcUEverp28OTWiSALhj75LOrP/bb5fD6
7bmJmVnFBH11Ren+Tt+x364eHwq62h65rU9r8nQ5KK4s7bFxSQlBz+k39mN9
lATQW3ju4YER2G9Xn08XT9W1fish6NlOg2y/BGG/XQ4VyznFd+P1aU2eLofC
2JlRvvalBB2Qx+n5wEMCaOsb54UxGfrafrsCTvlOduvyo5SgBw/mjzi+RAJo
jher5dMffVqTpyugJ+VieM+hjKDlMa4n1o2VAFrv+ZJPeQ362n67Avo+G3dj
zM8ygra6ccB0qrEE0FVvvu6rkerTfv/ydAU8+ijpXDyqnKDHh5+WdGsWA7ph
fLK++D/st6v/vqzwz0PcygnaIHT8wLYs7LcrQBFXv8fAFPvtCpj/1Uvs+ryc
oDcNWHDm2wvstytgOfdvUl9z7Ler90d617AX9eUEzbkjtogMxH67+v83iVFn
boX9dgVMcXmf1GZWQdCu9sOHXNglBrT9H88260XYb1eA86d5aya7VxC0w6DS
Va6LxYBez7mUv8QR++0KOCQIcvaOqCDoL2fjv88fIwb0wFnDbm/cif12BQza
sbjpQ0MFQe9Z4hgwzEgM6PQ/uVa7j2K/XQGTEva3ykZXEnTd0NQLek3Yb1fP
I1rDPvoEYL9dAQndTdxn7qwk6EfeB7MqMrHfroDo+TamF0Ox364A4VGvtSci
Kwn63NwFqz5FYr9dAUmlf1ffj8R+uwLUM5YvSY2VBK1fHjPgYQD22xWg6mK2
NyYB++0KaCr1jVCaVxF0QFdqzMmdIkB/FG/eSTIZ2n67evtNj+vN2lVF0GG8
Tz5bF4kAHce6T/0sYmj77Qq4VXC76NiLKoJ+0/N197nmIkA/PfhUVNrI0Pbb
FcD9KRyT0FRF0AZ9mI1DDUWAVuxXBrTKGNp+uwIu3IkSisdUE/TMuNFMRiP2
29XzxJG7lEpD7LcrYF3wVeupHtUEvWrGtG01GdhvV8CaqmqHTv2w366Ajdwn
4r1R1QS9gj2OkRaB/XYFrD3ecKL/GOy3K0B5OndCdHM1Qesl96p/7o/9dgW0
PxAEjrHGfrt6XnfIvbJhbA1BH5uf1TnQXQjolI2hh60WY79dAZ56ZcYjPGsI
OtPn0hHPhUJA36Et5y3cgP129e9vzn+9+WUNQfd7s3HkstFCQPNG5DSv3YX9
dgXQIMm+3VJD0IPLT/ee/J8Q0Jwusw+4HsN+uwKCB5/flTeulqATvGYu6tWA
/XYFDEuvKDoQiP12BdzwG3faeHctQb8F92RpOvbbFTByS9bg03ew367eXxuj
etpE1xK0Tk7EwZLn2G9XgF/vMTaXX2C/XQGvx1kMOdFaS9Aj3Xd4fbqA/Xb1
/lu8ZMH9j9hvV++fhfKIN+PrCLrfBr0XT9wEgN6X62P+Moup7bcrYUVkRmTT
7jqC/m1+xzxggQDQ13bGNSb8ZWr77UqQpSvNhsbUEfTpfiebdpsJAD17HwSk
NzG1/XYlLNhhOmhdWx1BO33bx1lpIAB07u1UdoGcqe23K6HTXsPrwRPqCfpo
2tGpM+qx366EeWFzXaqMsN+uhKn2BmdTvOoJ2vXPsaSB6dhvV4J9j7kPOf2w
366EtXsauaKYeoL+lWZ4nvEc++1K6BV2NFE5BvvtSjj5O7nQnFNP0NS1B1cb
z2O/XQnlbye8M5yJ/XYl+BqvtN40sYGg6SNrKrN38AE9+POvkN5LsN+uhNFh
Vf0u72kg6GaLzvve2/EBbVgnsR3uhP12JRgNm3Lo86sGgj7a6jL/3ig+oD8b
fC+Z6IH9diU0VMcuF3IaCDqo06i1Z9l8QFsd8Vg16zj225WwgdPwZKRFI0Hn
so1eetRhv10JvY8fjVgYhP12JQzfXnFo7d5Ggt7t0GX+qjTstyshY52kZHUY
9tuVcNC4x9fzsY0EnXrEe8DMZ9hvV8KAz/O5W6Ow364Ex7WJl95zGwl65a+H
lsPPY79dCQUmE6o9E7Hfrt6fcQmFtRZNBN38NPyq8Q4eoAOixr878o2l7bcr
4dankfdM9jUR9JT7zROFtjxAu77y33G2mKXttythWOdZZfPimgi69fDWrqUj
eYD2n/dTfKmZpe23KyHmZfG9vbwmgjaLuDwxjcUDtMeY9zvCFCxtv10JeWMa
iu5NaiboXjsDr7yqxX67EoSLEt49M8Z+uxKMu/pdz9rXTNAyMUwNTcV+uxL0
GVtq4vpjv10J1osGfBPHNRN0pSO375mn2G9XwsUVbH7SWOy3KyHJpdVvGL+Z
oId+vwC7z3EB7XXbujx9JvbblWAbu+m1w+QWgt74bNnTda5cQK+I+h2VtwT7
7Uqopa86H9nfQtDBg97Zz7PlAtqKM3x9qRP229XHc6TX1UevWwg6wGPBtPEj
uYD+mPG3ut4D++3q62HXavjObyHogYtWb+nb8d4srbmO+Uv5x7Hfrh7/PhzY
KZrcStDXHn3NZNRiv10J08bfDVUGYb9dCQlpId0HHWgl6GFhH7w5X7Hfrj4/
Yh99Yd/FfrsSCiuWWtm9aSXonl0KtxU/wX67ErwlV390e4n9dvX+bzcq3y1o
JeihOrKL6Wc5gG5r1/vQL4mtfZ+MCgax5jBuTGkjaM7xMuUbFw6gL8zpenLE
d7b2fTIq8FD1eJZ4oI2gM3W8ox7acAB9p/3L6AklbG3ergL/EYbplW/aCHpm
i+xOyAgOoLf568VNb2Fr83YVuNUw3A2EbQS9JPhE1jEmB9COM+aYzlWyte+T
UUHr5/TDuZltgFZMnHTvDY9Nof+7d+fzDVPst6tg1uoZRS8D2gC9dHWI94tK
7Ler/57VVd0jrDja98eogJfzJ9F/URugjx+Y5hWey6bQ7N5Xh3x0xH67CpQ+
0YNcDdsATe43nb+dgv12FZyizTjfjnK0749RgUQSrz8vsxXQs31a6UtxbAp9
Rn+YT2koR5uvq0CUP8p9cEAroH2EC00vhGO/XQVME4+stgSO9v0xKjB2aLdX
LWwF9Ok836u+V9gUWrZO54/OX442X1fB/RebXhf/1wro+sjfYw+dwn67CiZG
LnvaTc7Rvj9G/e+ZLbc+ZrQA2m2Ode3ufWwKPfGE/+Sh/bDfroKKgmxVqH8L
oD9MfUNct2G/XQWXrt30m2TN1b4/WQXdj0RUH13YAuj5m8zjN61gU+hD814E
z92A/Xb1+ZL1fvGG/1oAncdryV0zl02hHU2HO644xtW+b1kFvx9UWMzMaAb0
NLfDxksnsSn0tQld6rbe4WrzdRU433p4c4B/M6D7uta72A1lU+gfkydM2fuR
q30/swp6Xt5/on1BM6Btqp3KoDubQntb2s7x+8vV5usq2L4/tLLCoBnQf8Ke
Hp6ux6bQDqlxnS/Kudr3OatgQJ1T2pf0JkCnzfhtYcFjUeh9QcvD7vbDfrt6
++anj3l+oQnQnbvxDM0rsd+ugpqSfo0vrHna9z+rYPSw1V2CFjQBOnNBvv6w
XBaF9ti9WhK/AfvtKtCLHrlvj0EToP1e+Pfvn4L9dhW0P29OTTvG074vWgVf
up5dtTq9EdAW84esNoljUeh7h5JW59/hafN19XjybPZbqwuNgK6MWPqyczj2
29XjS9SWJ5Ufedr3S6vgze2W64MXNALa0/XYCIMrLAo9cvJ/b9v+8rT5ugre
pj8QsAwaAT1uklmS7inst6vU68iYswo5T/s+ahWMqLTIbUlrALT/4aAD8r0s
Ct3aua7Xf/2x364+n0bcnJB/vgHQLhk1i4Vbsd+uPj6eU9xMZvK1769WQWHk
ccMkuwZAvzO/P7dtOYtCX4v8dHSIE/bb22F/YB/nJ+wGQJcMZa1vmMOi0LYJ
fPtxx/na9123Q5tuj5khafWAPk4zLlZZsCi0ga+oYnoYX5uvt8O91Oorh87X
A/q5RXx1yRAWhY4NC542P5GvfT92O7yyjNyx1a4e0M3BjesLu7EotFm1+ZKl
xXxtvt4O7vw1CYvZ9YAuSrzemqvLotBLzv0a6qjga9+n3Q7WY3cFTkurA3SX
rKLw71wmha50X5Tg3B/77e0w7+rpoiHn6wCdU/3AO70C++3tsGlacnevmQLy
379Arh2MLRyedbKrA/S8oDz3zzlMCv2/mu41pKk4DAP4pjtHLMQCS8xpphEU
iqwww9v7t9KwErOiq5orRbrJNM2SaYo5S8S8JGFp3iCDRJSoNC9T0lWmZRkp
ed3mZlmY5TkraflvyHk//j4czpf3y3l4eE76zDHPq1Gcejlu3UUh/IXs1yI7
A+ghRYGys5sh6BOuM2yOkhPydQqKwdHnRo0R0FLuaWNrM/bbKbxyLKktqODU
y3HcIQqZueOijyojoGPlvqInNQxBBwcW07J2TsjXKRTIJnu6Q42APtPvm9RU
jP12Cn4JRS5VY5x6Oa6JoxCwfi/bxBoB/S6vRNyQzRD06fnP5nozJ+TrFCZ2
vum5rzEAumVwa3N9EvbbKRTH3K1skvLq5c/5FAppbZ2iQpUB0BON3ll1coag
d9dW05YA7LdTiGeXWjNCDYAuz76WWBWJ/XYKb80ij+4oXtiPobBA2PmLrAHQ
gUVi5b1ghqBVk2ab10peyNcp2Fa31cVopgFt9WXu4R0ZQ9Bmb/fGwQpe2I+h
MOLzdyhCNQ3oywNLXOkGhqAd4q3WjrTzQr5OIafMKzs4dBrQ8vh9sUWrGYIO
8jkLk2O8sB9DYeMF50fb2GlA245qZgvEDEHPhSVvMZp5IV+3PK8ujdyk0QN6
8Efc7Zs/sd9ueZ/b9uHvUpOwH0Ph+reAVCeVHtBav4holVZC0EH58pCFAOy3
U+iydl1jF6oH9HzWnpCc99hvp+C2pEhdjDIJ+zEUIqZOycSsHtAOf47uz+qW
EPSI/YEEqjQJ+brlHrxS+vheHaBjVlYmZzRjv91yD1971zGVJmE/hsL5uLDJ
2VwdoJ2Pf3iWXiMh6L7wk0UrOkxCvk4hr/+BYipEB2j3x5ulV4qx306hvbzh
pf24SdiPsdzHKo/MT4wO0O49N6pSsyUE3ZE21+XwzyTk6xTqDcM2A71aQJ9b
5IMvJWG/nYKnnYPSyQX/r0Qh3/GgXU+uFtC63MPWSXIJQftzRxZdArHfLiL+
mq7CthAtoG/JmvSJkdhvFxFdRdUO9+jf6v+nmDk0
                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H47 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{47}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 25->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fB/C7L9nZKzOSkCiy3ofsrFJUdpII2VvGl2xFlFIkKyGkQuJz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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTX8YwPHbvQ1lU0aySUqDkBHPKSqZUUJ2ZsnK3pSZkVCyKsooSkhI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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H49 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{49}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 26->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fwPG7r8reykyyQ1ZW72MlIbIimWXLyB6JrLJHERIyyvyKFBmf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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83Hc8VX0cB/C7XGnSVGkQRaWhoZK+p5TQLkkolUraaFBEkycNpSUlStEe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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H51 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{51}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 27->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fwPG7rxCKsiIhMzvJfB8jOyNkE5LtS3YlhBSyR2REEllJIuFz
SioZUVGkvffd+95+N533zz+/x/PR91fde8Y953XefWzW/ueynsNisVoJWaym
/71+relfFRR9qrWvCMoC9LhrN8vfnudQ6ICvScP9/2rIlFNbK7QPqyB7ZkhA
4pZ0QD+JCez3VsGm0OFXap+eMNeReh8YuepNFTzoG65/P/I7oOX3YgpeCTgU
2jL2CnVOoiXB282P0mlVcGfz3TUjlF8BHdmni8OuAjaFfhz9+WLniToyya3s
e8/cKuDUL7SYePwLoAvnLDJbmMqm0NTaRXmL/9OR2vmvux+vqQJpxytZ54zf
H31ozQzTA8bvj+aM31Zmavz+VyY3vaAqeBT3aE/+zRRAh8Qvq8g7wKbQnwNm
DpvSWk8o46uZ0boarsb3cpvl8BnQcWM5se4v2BQ6KEB70eGajlT3GdbisVU1
7H3Niwp3SQL0iVms5QOc2BRavLFxxqM9enKpE8+1zaBq6OkYG/J1SCqg/dbF
/9b5sSm0zjFwtkCjIxNaZoftGF8N3UevD7kzJBnQFxbEdtasZVPov0sufmk1
Rk8qtQ/FGc7VMKlbQ9TpDimAzhK3+Tx9J5tCL7Eq3rS9m55cqGvagNUwIsvb
u0dnAui7+bncTyoWhX43abpqWxsDGVcwN+jq9mqQ6g81+txLBHRBozJ92gA2
hZ7Eaue245GelBu3ntq3GjTunSanvP8I6Hn+w3bXLmdT6DXSGx37TteTc4ny
fivOVkPCwynU0FVvAD3HluMnzmBRaPeXWq3VMgMZE5O69/3taijd/pgbUpIA
6PrkMVGju7MpdG/Pk7dPf9CT0vCQpB5R1bA2cW5bs6J4QLf39QpoUcCi0H+4
rRrqJxrImatNO2w1DHvrFUg9fgXo4p+zeGvfsSj0+IUblWOPG4hj4ETjHlsN
yxpnnwodHgto7YZlvMvPWRS65dBZyp83DKTYq8PTaUXV8HS389tr0c8BHb6l
+OulIBaFftlvrPuvUgM53XR4iquhT8Y909cbnwP6fJ9ttNMpFoXOj7Y9tLvK
QByadldODbS+1K7B0CYa0KHH9iv3nWNRaKJoY9auwEAKmzafeQ0MUfc223n4
LqDLLk5JYs9kUehROXv36bY0kpNNL6dnDXyPXRh/hH0P0LkudQLBPBaFnrnM
ViJd3UjsRzT9q4EVVwbRfpeDAT1o+WH+wGEsCh0xo1H28GYjye8tOHJ5cg1M
uD2PLzviD+h/tGRR6MRV8o66jEYSYPn7m3JBDcQtzt/dv2YboK+MWpnmJWRR
6KxzTltaihvJcOPRuczd+Hp+t1ttsn/L/31x3zztZEkjoB2SFnPyBSz6r9p3
89vdNbDSdpa5IXwHQefG1LGXNTQC+qKtSaNLCxbtX/PvhATPc9vqL2+/QNDn
6VYPnGIbAf3KWjMwrzeLHprX9IJq4G+iM3upIYSg5amaEMG5RkD7h3CidaNY
9B/jqykJrwFWapuLiTvDCZoO3FCzc2EjoHuMnd0yZRGLPkan3XGKrQFVpNxm
RN4Tgn7gIvKwNGsE9ONfJ77s3seiB0ffbIhIroH3O0y6iA9FEbRs4+p6lsoA
aP9Z3wMaj7LoHOPZqGV2DYxL2+GcHv6coFdI+7UKKzMA2sV/i9fgIJZxH2g6
AdeAzbPtOugcQ9BtLEaztr43APrAnpLGT6EseuCJpg1YA8mkPtZR9JKgeR3O
79aFGgBt2PPq45FnLPrn/irjGbgW1CNjZ2xbEkfQoTfcBx7YbAB01HPnzR/S
WPQh49a72MnofY9Wun5/S9DHp9te1ww3APr98rpov3IW3X/FWeMZqRZq3L4H
qnu/I2ixeu2GqEEGQAuPzvnSt4pFZzqvbbdkdC3Y9rTKKTpKCDp/vG9xgtAA
aLMiuo21jkUfbPp4nVEL09s79GmdlEDQV8eP9vZN0QPafs26RMqKTfdt+rhZ
Vgv3LQu6tfmUSNADu00Zl39fD+jN4ryic3Zs+kfT6XdzLfTd1Hhi86gkgs41
Zz0zP6AH9AXFoQd7J7Np76bTkVct8D2nF9t0/EjQRBz7oetKPaB7nOjd3XM+
m7ZtOjxP1cJzs36HJ/t+JOg0vebsqHl6QHc9wnEsXcym05t215Ba6KfPV8Ze
SSHo5T14Nv1N9YDOaDj435YDbPpA0+Z7XAvuoRdCq9+mELTsUd2jtS30gBYM
MIn85s2mezW9nLe1UJTu+ZIEfCJo3v35JpXfdIA22C3Wngpm01+/NP2rhe/P
Pw7tl5ZG0MkzKtRv7usA3W1566N3H7Ppfe9vdxmSVwv7vU7eFmV/JujnUW1q
2cd1gH4QoTI59I5N20R5bjxfVwuxiyWd1xi+ELTJy4S/I9x0gPa2vW1Wns6m
PxuPTqm+FsYeuqfY/uwrQXfeMdDGfKYO0LJpmxsUf9j0notNFxR18GHCmcMB
Md8Iup9jfcP2/jpA15a0CJhew6atjzedkOpg5/nkxTZ9vxP0veVtIkcptIAe
nKEaUMrj0J/2Nr2gOng8+/wl75zvBP3zcW6Xok9aQF/pf8GzbVcOvcv4anyg
DsLrbrad7/aDoK8e6/S2JkIL6JfvpDYt7Th0t2XuYwvm1kHcifPPB2f/IGjz
WyEL7E9qAa0cOvxX2RgOnTJrlPETtg4mdrRxTLyUQdBD3yh3pi/TArqyJ29a
sAuH3jm+6QKqDm6EbQ3a1jmToDtn37txb7QW0LsvPXk+aB2H7jqk6QRcB48e
9bg55EYmQVv8fNVJ1kkL6D0W96THd3Hojz3+bUCw5HPFzjmZBP1mAjlaa6IF
dJhbj/cm3hz6v6bL4zt1wKqU73a/lkX+b//E4vu/NfB/v7t1xu4ih+7cdLkY
XQeXurX1edPlJ0GHOOrc5sdpAB1dcmTu4jAO/aHp8imxDobl9tww4+dPgraf
Mer+k5MaQHssL7V7+IZDb2u6nMiog051TqRg8C+CfnNscLvpuzWADntXqcz9
yKE7Nn28ltRB9y4KhyGPfhH0/gOThtsv0gB6yof88vU/OXRC08eNtA5uxy0/
Uz4lm6CDzTatSB6sAbT9vs8/blRy6C1Np19ePWwfI3/+pTCboN2f+2V+EWoA
PSdiwpXOOg5t0XQ66lAPEdtzfXs65xC0a+8Zbq9q1YD+uS137j0TLk2aDs/e
9XAtL/Dkkawcgr4esPJmQZoa0C/Gzh92rguX3tS0u46sB5WLMHTgyd8EPWmg
oeOem2pAr65m7XYaxqXbN20+p3oIgG/b1D9/E3T3HafvHTmpBrQ4JW4QGcOl
3zW9HNd6yB6+4cmjDX8IeuaI+x0sPNSAXl7+eI98Npfe4NH0rx5OF7XzCxL/
IeibKd63b0xWA3q41aSoYau4tNmS0cYrZOPv98il6uS+XILut+iRU7eeakBv
XTRgpXg7l443Xi0OPFEPjTKd87WGXIKmEw8/7sxTAzr0FukvPcil149tuiGo
h22ztyxmHfxL0GV2ttWkUAXoM5vqWoae5dJtBzVdUNTDxt2BM0I4eQRdfvfm
oKVEBeigwcM2LQjl0nHdm05I9ZBldcHztV8eQX/ev7xk/m0VoK9PdmmzOIpL
r2vX9ILqIfr7yzf3G/MIOuuUy3zLwypAW75xzZYRLm3KabqiqIcN9h72boH5
BF3uWS6JWKkCdFDyaYHdDy79SqrP2l9VDxWOurZrOAUEnSxmvd0AKkB3O9Fo
M7uQS69pur1VG7eXfV6vy8EFBJ0X3eLVn84qQF+4733PXMqlWzXd7rVsANaQ
1eucWIUEfXjjvDl5jUpA05+zl5ixePTLptufLg3QaVYiddqpkKB3/7lVMDpP
CejkC0PbrTPj0aubbgcGNkA3p1Y6sxOFBO25UsPe91YJ6Gk/OIeSbHj0v8vj
sQ2QsvdHjG9qIUHfmHI1nA5RAjp6pf0T6+E8+t/l4qwG2KmJtJ6oKiToVL8B
OwqOKgF94331tHYTePS/y6cVDTDpCjf1JRQRdIG9oautmxLQ58pYnnVzefS/
y4mtDTAgVVIrPVhE0DUh/iaCiUpAt4wep/VZzaP/nX19GozXjcGdHrwrIujN
b19IB9ooAf3Zpo9g8388+t/HTVADtKjc7GmmKyJo3am0qUq2EtCcN9dX8A7x
6H+n35sNxu1u0Td4cjFB9xbsqR2RrwB0vc9Hk/JzPPrf6ehpA3QMsT4b61VM
0LuH73h9L1EB6OTylLAnt3j0v8PzfQPY2yeJs+higi4v63bi8m0FoE1Nd44b
GcWj/+2u3xpA1SKSsmCVEPQxbeRq+SEFoCf4DZjHp3n0v81X0ABjzbdku0IJ
QRfvnXlpoZsC0GeT/rz8mc6jm19OA7T6UDN27fESgvbq3rJ4zngFoD+INGeW
FPFo1r9/Injw0c3T/0MJQdvdTE8e110B6M3Dgm8UiXjM9bwIMrv9CDJwSwna
cmfHOJZBDug903aHNbL4dKQ4w3hFLQJqyEDadXIpQbttrL69MF8O6O+fW0b9
bMdnrv9FsDgvw/uifylBLzxvOSn2rRzQrq9k+fds+PTCkqZgIIKzgr+HAj6W
EvRrnRk99qYc0PfYSuu1w/jM/YIINIP7HPVuXUbQRyu3Tkg8IAf0+1OfCrtP
5tOGrKYXJAL/jU+7jZpVRtDvPvfb6b5MDuie17ekfHXhM/cXIujDnz238XQZ
QW/TL11yeLQc0DPZmZmwjk8/SG66IDL+92VDOOL0MoLeZlrpK+wkB/RM9SlK
t4vP3I+I4M9HxyuDzcsJuv3NkphKhQzQe4edCT91jE+7NN3dzhdB2w7l08bP
Lydolbz1ijXZMkDzjqvnz73EZ+5fRJDSKnFd1oVygrbSdP92OVYGaImfqNPL
e3xa15Sz1oqgPrwgcm92OUGbDDoXOeWSDNA+Va8i817ymfsdEZwbksKp6VpB
0I4bb/i29JQBuvTzc1qTzKfvN+UgTxFsSvz8ftnKCoL+0v16qMt8GaCvi6Kf
uWbzmfsjEUS14fusCasg6Af79RPnDpYB+vFk9uqcSj49rymnHDW+X+edPw2q
qCBop1FLu25qLQP0KvcFnp/VfOZ+SgQzEidez+pfSdB/uxdEW9RIAX1hx7k+
e1oKaE1TjrgogmHd9vhc3lFJ0Bt3fpz4MkUK6NnTuq22tRIw918iOPH9tVnI
y0qCfnu1177h4VJA97TfnuQxSEDfa7qdDxPBw5oEhyhtJUHbtbxd2tdPCuhq
ryjT2gkC5n5NBDmDRRucJ1cR9KVK4eylq6SAjm2lW5o5T0DPadpdY0Rw53BU
h6CAKoKOIhF74sZKAd2vh51Tr7UC5v5OBEWrZ+T2/1ZF0O3mLTev6SQFtGpx
xt6TuwS0qunlJIlgQnfPr/kdqgm6SDT12jm5BNDnTqx4Meq4gLkfFMGGvFRp
rFs1Qc8+39X/XroE0MtGSd4OChbQd5tux7JEcHtrqi9EVBN01KcQyu2xBND9
ukYXpD8UMPePItjaQr/2W101Qad5H/nWKVAC6K6TSPCueAE9u+l2pkwEDvHJ
F0aPrSHo9XdvOKxbKwH0t6fP3b99EzD3myKIvpgt9fGrIei+Dh38EyZIAF1b
Kh93u1BAK5puB+QiaJ0tjNycVkPQXh10kWldJID+ID8SeV0iYO5PRdAmeMm+
Fx1qCVr9YsGU+3IxoHl9fuXZ8YV0aNPltEAMFi23sC+71RK0wmvmoZfpYkAf
T1xG2XYSMvezYvA///dA2P1agh7/ymzy08diQK/tvS//QX8hPbPpctRSDOcT
/whU4lqCfn3rgo57Qgzoe1GxbN9xQub+Vww2jWevvqPqCHoHy9H+zmoxoFMb
S9YPmSekZU2Xc33EMJyK9/IIrCPoitV3E2ePFQO69fent5auFTL3y2Jw6G1y
6NTPOoIu2+ZNjbEQA7rNjMSCtXuE9K2my6FRYhg1cnBFds96gnYv29j6Ur0I
0HOCPqtfBgiZ+2sxlBQfKcnfUU/QZ9rAmXMpIkDH7S98PeqGkJ7edDkxTQyi
nWmur9/UE3SLlOtZYXdFgPa5EW3x9KmQuR8XA3uD624TYQNBH/6S5eTtIwI0
fc1iZWKCkJY0fbwuEUNe6EC/8oUNBH1hSPX704uM53HGoypPho7+KWTu38Vg
mrt0956wBoL2Ms90chosAvSHvZYr8yqF9I2m0+9GMVTvPHNxtLiBoFulODqs
E4oA7XWjxH2OTsjc74tB3+VpX15CA6CJf43JRJGQQvtJ+tUetBaRqU2H537j
fqLYtlixqwHQFw7mXtb/FVLoXN6MLN5UEdMDxGAyhESv7dMA6MTPzx4HfxJS
aJ+Nofe/bRURUdPmCzTuH9zjlXE59YD+QNl4DY4VUmgv33etwi6KmH4ghpBK
xd89J+sB3ffN+H037wopdPSpY2Yf34hI8/M/Mfie/pS2bEw9oHusi46+ckZI
oRNGh1zPKBYxvcG4Hy6a7N6lrg7Qnj/bXZvqLaTQVovyv3qaiJnniWLInpxW
3+12HaAV56K9UzYIKXSH/Ostdg4VM31CDKOrXewr5tQB+sybDl/jFggpdOnJ
X+tPLxEzzx+Nx5NZPC3g1AHaK2lw1BFKSKFb77t7W+crZnqGGIIftDycGl0L
6D6RnB7RdkIKHfNIQ0Lui5nnlWIYrOJ7BrrXArq175EVPTsLKXQVVz81/quY
6R9imFF86XOIZS2gLziWSe7zhRT675mRXaJlYub5phhycnxGKz/VANrBYfW3
gxIBhb50ceI6XlcJ00uM23P3p3e2PjWAbrnS8z+TAgGFrnXqalM3UcI8DzUe
f706b861qwF04XT/Pw6fBRSa2i6deWGThOkrxv2vz/qfmQXVgL49Y6lc9kpA
oRO3OltYnpMwz0+Nr29gcb+q89WALj3pONPrnoBCj6o+s6XVKwnTYyTwdMWk
7UVTqgFtd/XccsfzAgr98Ef+9LN5EuZ5qwTWZuWt/KCsAnSnPfuyRQcFFDrd
wmx+d56U6TcSqIye38/rURWg32ztcDJ/s4BCn+6TXTNpgJR5PiuBZBdF44tV
VYCOvqRvfLxYQKFv/uKx7s+TMr1HAosmZi8JMK+C//v7SMu7UwQU2nX1pcz4
vVLmea7x9QRF2N9OrgT05pL+XyOGCSi03ejH66NuSJk+JIF+FwsVW7wrAZ3W
+7X+T3cBhd4ae5Y3M1HKPP812prDLRxaCejcEzTLsbWAQs8U+RrOVkiZniQB
UYntktDSCkDr9ptY9lPzKXSLNnWZz0xlzPNiCbzXcr4OvF4BaNF7SnqynE+h
bfx8O1cPlzH9SQJUwLX52rkVgG631iPLkMmn0IVjRyzmLJExz5clkLAyubSl
oALQO64Oi/NL4FPoHj9uBGl8ZEyvksCgwLHzdfHlgJ5VPKdD41M+hd48dm02
+66MeR4tAQt7zjz7XeWA5gexOny9wafQijJD9vpkGfmXd/ZKwPvj7mkp/csB
vXpY3o+dJ/kUetJNpxVWNTLm+bVx++x3cBtRVAbo4bdMc2bv51PokA+lcz3a
ysm/PHJCAk8Corr4BpcBemDPx/7WHnwKHRkfIaFHyJnn3RIYMsbLVz+vDNCn
z9xaDQv5FLqyOJE6slhO/uWFq8btaX+su65FGaDB9I4QJvEptF/ZO9ERbznz
fFwCe46+G9w3sRTQeW7PPgcO5VPoqRPubKy9JSf/bs8jjPvXzI0mYq9SQL8y
XzbpbXc+hb7wZ5b3iUQ58zxdAi0FA/2H2pcC2i/hpE1rUz6F1vpUv60ok5N/
t3uvJXAvfPtus/oSQG962HXlMS2PQg9+kuqkbKFgnr8bt8/f1d+yIkoA3Ul5
dYS8ikehv5t9D7awU5B/twOpxp+3reRY37UlgD6U61gUmMOj0JwZZ8bXzlEw
z+uN7/+P+Pl/rEoAPVu2/ZJDCo9Cb+zYM/vCTgX5d7n4WwI9ox/NG5VdDOiA
2gFZX1/yKHRDn8jF7pcUzPN9CXxe8XLC8wvFgB6x+Mncx/d4FPr6/HC3iFgF
+Xc5USWBOR7/zalzLgb0pd8hC7wv8ij079mpS0x+K5h5AOP+d//3heUmxYCO
2BRb6urHo9DRdhcdXLQK8u/jRi2ByZr0WWs+FgH6vEHqsmQnj0Lnczotm9tN
ycwPSCHr54DT948UAXrPy5Zhm9x4FNrycnWcHSjJv9NRSymc/bF4remEIkC7
yy4vOTqXR6EdO2bNUbspmXkDKQzerM05rykE9Ok/E/bem8Cj0FUz/dq/8lOS
f7trFylsKzUtH/qqENBdDxwd/WUQj0KnmapPb7inZOYTpLDOrcKdu7sQ0J1z
Rv9mdeNR6G9zTzsbPirJv5czUArS7S0OTxhWCOh3XTmhc1vzKLR/qpa4VSiZ
eQYpRHcqz0v+WwBoyw9vc4O1XAqddcB/+rcWKqaPSsHt9Cyl5eICQJ/eWZVf
XM2l0JVWgyaNGaBi5h+kEHOxYMaAjHxA75WMneH0h0uh23cN2LZnlorpqcb3
/5So7TrnfEB7mhnWPP7EpdBWedxxEVtVzLyE8efVstoGpuYB+ma3QhuzOC6F
Tk6Ct3lBKqa/SuFyYyUrfnIeoKXW3dz2PeBS6K70RzB7pmLmKaQgfv3Lu478
BXT3bK9n+qtcCp00v+Ud3ncV02ulkDtyctapsX8BHe8R4LXzBJdCBw5vaNlN
rGLmL6TgcSoz9/qrXEBv2+m1XLqXS6H7dGs1o7O5mum7UjAde7/jnBG5gF6b
Ikvc5MGl0ON3WnrZjVCTf7d7x6WgHdMdZj/7A+jVKSUnqhZxKfTEnY4iu4Vq
pgcbf/6N0RO7DfwD6DMj+j5Y58Sl0GXBz5857lGTf7cDl43fb/DSKWYRvwH9
xfZUv2J7LoXeGFP1dOwVNdOPjV9v89W5sOdvQP+5E2eyojeXQju/PV077ZWa
/LtcDJfC4dKw6bG3cgB9zqfDp1/tuRS6UJC9zSVHzfRm4/5V8GCEe5ccQDd0
3eM/m8ul0D1TLaQeajX5dzkRK4UXoctqUi9nA9py4ZZucRIOhc5c3P9jUBcN
06eN+9vzZceK2mUDerzrqaFWxRwK7b+g6lbKWA3593GTbDy+hj0ZLjz9C9AO
9xeVH/7BodCXXiwcYVihYXq2FLx76hPDBb8APffe6tdZNIdCr3lFnXX11ZB/
p6NsKZwcNHCT75GfgH6+3vbrkCgOhb5l/3J96G0N07+N2/fH8GEybRagBy/r
4+97m0Ohw2e9kHISNOTf7lohBY4yscFqbxagC1epbn44w6HQ1KS2SfuLNUwv
l8IzKX/mjYZMQO99TwVKD3IodIejvnWdeFpm/kUKET5FFaqNmYC+PERnZb2N
Q6F/hQqTE2y1TF+XQeyW5Iz8ogxA7/u65M/YFRwKbb5+zqyAaVqmr8vgv4uH
AJZlAHq7pKFi2iwOhe7dtcfQHZu0TF+XAdX5+Ij1GT8A3S9sx/3ZYzgUOiqu
+wuPU1qmr8ugcvGnXMmMH4DWDziwfEJ/DoUWRJrOOPpEy/R1GXgtKzg4N+E7
oOfWxDf078Sh0Gv7B/R4nK5l+roM+lhvvWDp+B3QZUedMzhCDoV2ULkv14i1
TF+XgazEfpl+RTqgYU7Yz3Q5m0L7rYtb6NZBx/R1GbibUz0HTv8G6D7s3tF+
pWwKHaN/FaJx0DF9XQbZ5uNcxMO/AnpQQi+LIZlsCh1+8PXPO0t1TF+XQV4/
9YYzVl8AfebCofLUBDaFLv3DGrHdR8f0dRncsNkWHcr7DOguGX1azYxiU+gv
y6OrttzWMX3d+P4GOXSaW/sJ0N83HhUn3WJT6NWD1VZ7E3VMX5eBofHzwv8y
UgHNomfL+wSxqf/7sIdFdJmO6esyOF5fyZ/3KgXQlWdWsfZ4syn0kOJJjRYm
eqavy+AJWz2pV0gyoLueG2IfvYlNodMKQq+G2OmZvi4DK5+KkS19PwI6cd+q
sMLFbArt025y3IR5eqavG7encH+brauTAL37cAWtcGJT6E6NQ33Nd+uZvi6D
mjf0yXz4AOhnrR5X6kewKXRYZcRgXrCe6esy4LdZuG+bdSKgC6k92QobNoUG
X4v55m/1TF+XQf8ijzhnPQ3o9tuv5Ga1ZVPo3F6Z010L9UxfN/73DY+T98cQ
QB/YMDI5TM+i0KbDLu96zTMwfV0GGdt6rx2w9R2g/+tltmBNDYtC94rLWzq+
v4Hp6zKQkPAurXrGA5o1+OeSdr9ZFJp9b9GcAmcD09dlUJLzPM0z6zWgU84s
uhKWzKLQnsULM197Gpi+LoON1gEPM4/HAlpLzb45OIZFoVv6bvh496qB6esy
iFxxZLzWPgbQZS1rf0fcYVHokdV9Z0e9NTB93fj6Pvjsu1X0HNBdy+Olrc+y
KPSnEQGdyosMTF+Xwe9aId2y8zNAv7BmDXT3YVHoa3Tjw1HCRqavy8D1UK53
yZZIQOu3NQQ928Si0PzeNqWhdo1MX5eBd9Vpz81vwgF9f0TawypXFoWOCd7y
2M6lkenrxv2Z1+OmD/8OoNsd3i2xmMKi0AWNll2z9jUyfV0GLVqxl2VcDwa0
JSfm3shhLAqdpb0ae+lmI9PX5TAqcey9X1PPAPofu7MotE/AKxfPD41MX5fD
4H2cCJeIvYAed2TBwwWtWBQ6UL/kyZKqRqavy2GBYN3kS/T2//vgnPyXt0WN
gE7MaWcbJWQxvV0OO/o+NvsQf5Kgn0f8PRCQ1gjof1/uwmJ6uxyskt/uq6y8
QtCVrW1WrbjXCOjTBxq+/xjEYnq7HD7WbQycMTaUoC+8jnlh69sI6Fdhtn3q
KBbT2+Uw8c6hzJu8cIJWcNzNchc3Avq4wXmf+UIW09vloLzaMqX820OCph6l
fAoY1ghotwFWIWM3sJjeLodjkn6Sp9eeEvTW19sDhrdqBHRaWGq8hxeL6e1y
cBn+pv/IF88JOneF+5MvpQZAX/zh/PBaEIvp7XIYs/RT7dDOMQS9dfMIcdM8
LTptpseJpnna5p4uhxWJOYNvHool6D+7zAcJgg2Abp+8t0r3gsX0djksnDP/
cWL5a4LuWjPm58WdBkDvOrnWwiGFxfR24/6wvWoD1zmeoLtuOvJpyCwDoHfN
gq4b/7Do5p4uh5TDcfYjX7wjaNmGmMdfehsALfgS/vBaHYuZx5PDpCWeUx+2
pglaFTMse7NBD+hjthsupbHYdHNPl4N1R9ngc5BA0FYHbTSmOXpAe05s4Kjb
s5n5PePXdyckFuxMJGifHxHCpOd6QE/qaKfr1pdNN/d0OfwOXnWIde8DQZfZ
dRAdOqUH9JkquZAaw2bm/eSgfT9be/1nEkHbbLwSOnu9HtCizzHPljqz6eae
bvx53R/2/SlIJmjHvy2X24Ie0KXnvVy2ubGZ+UA5WIj9RCdGpRB03p0GdtvO
ekCbDWlxaP8uNt3c0+XgvLn7Z/8NqQQdO/xGn7ZSHaDDy59v3e/PZuYJ5WA5
xP2E4congu7m1X5Ij686QIsn7a387xqbbu7pcvDrtSEn72MaQZ/rKp0yJUIH
aEdP/7yVj9nM/KEc7Oa79suXfiboPyPlY44d0QG6/frjxeMJm27u6XK42VsS
r+7xlaC3xh9JLVyuA/TMniSkbQabmVeUQ1hKj5uBzt8IunXF8i9zHHSA9mqd
cS2nlE0393Tj+3X6oXjRgXSC9v2WNvFnOx2gE4K7rL6sZDPzjcb9d92oUo7L
d4Lm9pVMPVSjBbRvrf8KqiWHbu7pcljjY7m6RcV3gq50G1M5PlkL6NPpxa2K
rHAeUgGd5i2Yd9D7B0FrBtY86nFHC2ju5paR/w3h0M09XQEv07nuh9tmEHT7
1o3l1j5aQCsPHG4tmsih/10+dVCAt2f1VWFYBkGvWcfvMmGxFtBz5+glbgs5
dHNPV0DnF2GTzBwyCXpM+8XPvIdrAb1u78J+iR4c+t/Ha28FHNSXzXmQmknQ
dw5Prf1pqgV0FPlrYnGAQzf3dAX4czxVccuyCHrVoZIj86s0gJ5PtYHFpzj0
v9PvSAX8vLS42KU2i6A/d9k8rSZJA+gQycwVJ29y6Oaebvz/g/nY/Qd/ErTd
jrHiO6EaQFdPWyt89oxD/zs8nYy/v7DGtkWbXwRtM+G44qCPBtAit3e8hAQO
3dzTFTBU+izR9tYvgrbnLjy7d4kG0B6GRa+TMjn0v83nqoC0oUrbpEHZBP1t
hJ/ijL0G0J3L3x97Xcahm3u6Alpu87hT9jaboN+737+a3E4D6Dtf7WJuKDn0
v5zuoQDBu41Tz83KIej339fXd61TA/pOx68tPE24dHNPV8CFq+rbH3/nELTV
dXbwmU9qQEuGN75w7Mqlm3u6AroOjVpzYsNvglZLL/btfl8NaK7AoVZkx6Wb
e7rx9XUf7vdX9pugZ+/fVZDqpwb0n8lTz4VM4NLNPV0BDxvGOb898oegLZOi
as+tVgNafjMicNQ8Lt3c0xXgMzrm7/A2uQR9R5wxfdc4NaCHnriyPHkNl27u
6QpwGNWH63A9l6CHezoc8uysBnRFsjs9dReXbu7pCrhb7hFYafuXoJdMvZ93
XKECdNZfO7N3x7h0c09XwK9rIx+NeP6XoE9eG27xIlMF6LEvPPb0ucKlm3u6
Ao6d3XPHZlweQVvfuHtVGaUCtOj5YPtjEVy6uacr4MciMHmRnEfQpwdEjV9w
RgXoN9V91/x6zaWbe7oCpkL1J828fIIevOO4c8IWFaCrpo1fap3GpZt7ugI6
WnpZSP7kE7SX1x2vyTNUgP4w6dmkVblcurmnKyAjZ1z6LfcCgv7yaejsnD4q
QHcJqfh9sZZLN/d0Bch+5ZgK6gsIenJaoI8vTwXo/C7xCbSeSzf3dAUsUK3c
c2VsIUH/4s7/aF+sBLSF7+KbZW14dHNPN26fInNO28OFBL3wrMJXRZSAdn19
jOb24NHNPd14vply8O+WpEKC/rEywSztphLQneZbK7sM49HNPV0Bvl/f/4lp
UUTQE6+FXgj3VgLa7cUzh0GTeHRzT1fCr/YLzpXMLiJoi72/Rp1ZqgS0IqlD
qeMCHt3c05WwPNnsLPd8EUFnWO1z9B2lBPTVnUkllDuPbu7pSsgeRt1u97OI
oDtUrI7aZ6EE9N7W3/tO2cOjm3u6Etbte3i4fedigp4z5RHslSoA/XvlgMIp
/jy6uacrodSHL2yzspigz0w8qNv/QwHo0asTjky+yqObe7oSrO3Bjn2nmKBF
6ws3HXqmAHSLr21nUQ94dHNPVwL5e6xjfWkxQYeeHy8LCFIAeuioouNj43A+
WQnVvA2t/vYrIehTB2drzm9RAHpMwm/OqDQe3dzTlXB3Ca1N2VpC0M8yrTk3
ZigA3c9SZBiWi/PMSujznvR9HVVC0HU9etSG9VUA+mRDg8ngWh7d3NON7+/5
EG60rISgnUYNN9znKwC9qrT8sJ0e55+VEP3SaUmMYylB97XNyww3Xpegt24z
sxzUhk8393QlSFs0HE30KSVof+8W728lyAE9PlEbOtSaz8xLK2Gk871RhXQp
QXv8HlR69rYc0M7tq0wdh/KZv380/v58l/Gm/DKCdtK7rjlwUA7oVUcWzp08
kc/MVythbruLXefPKCPonH0OnouXywHdIal06kIXPvP3kkq4N/PEvIdBZQT9
dNnbxQNHywH9MMNm4eZ1fGYeWwlXbEfpOmWUEfTIbaVHpMb7TLTHJ1Pw381n
/r7SuL3O/DkTbllO0HWvLzg+kckAfTIsdt3D43xmftt43N2ZF+G8vJyg1z9b
bLc0QwboOf2yNmVe4TN/j6mEVKrCzjK0nKBvrD5dJXsmA/Tw76NP8R/wmXlv
JXBCzqhZZeUEfSja8eihIBmg6fvrJlBxfObvN5UQGXL6fZsBFQQ9MDouVLVZ
BujqPmHPjqbxmflwJZw98TET/qsgaMdx3SzdpssAXbpGLEvP5TN/76mEjjYm
Y4JjKgh693/a4he2MkBPne7Xpk8dn5knV8KLzZ7TrTQVBH0/LTlXzJEB+sl1
K/MTBj7z96FKOPdj85kUqCRox6tpjlaFUkC7x1wvEbcVMPPnSjhanHDqzvFK
gn7fxnrMkHdSQN/ZL1q70UbA/D2pEsqri49HfK4k6KCTbcbbXZcC+s2b/UVV
wwXMvLoSbr6fIvlrVkXQ0aF5/mb7pICOGHJ+3L4pAtru38sxfv9vJ7dQS6oI
Oih4TFrBAimg37wo7tLOVcDMt6vg/hrW34xbVQQ9KL3x/JWhUkBv7sR6FbNB
QP/619NVcOPOTVlwWRVBDx/y/PgIUymgN2zsO97jgICZb1fBitVJYRfsqgna
5Xu3p7FVEkBndxQ/6H1KwMy3q+DLhvCz73ZVE3SX2YMcbZIlgJYurVrXcEPA
zLer4OfbP5Gd46sJ+sqdCwN23ZUAeuSz2M3JTwXMfLsKRjzrOvcRp4agPfp5
Lon0lQD6a01yZiQtYObbVeDbzXnBjpk1BD1x59JfKcskgHabltnhRoaAmW9X
gbA4nb3xQg1B69p0avzsIAG0n2oX63qpgJlvV0H6B+GTS39qCLpTd5+HL80l
gJaJJg4MVwiY+XYVaCdcXyztWUvQfoXDF/rXiwFNzpb/fNtCyMy3q+Di6+JH
R7fUEnRsWJsBE9LEgLZ9qqou7CJk5ttVMCQ5ffO0mFqCrrQKnvk3XAzo0+IX
f8wGCZn5dhWkhs9JHKOvJWirJzm31h4RA9rz4cWoOSBk5ttV8Mhs52S3qXUE
PWDftPz0FWJAb5nyt13wfCEz366CC/P2u8acrSPoV9kfsmwdxYDu3eGWRd06
ITPfroKpocelDr/rCDpvyHh/9/ZiQJtvLHrrvFfIzLerYFRRl/CynvUE7X7W
c1BQvQjQc15P3RQXIGTm21UQmML7j2ytJ+hxNw5OD/0kAnTxsITcISFCZr5d
BUPvZkclxtYTdOXgSxG37okAfbpy5OOoJ0Jmvt14fHXs1q2O1UDQw3fv3Bl4
SAToCqdp08bSQma+3Xh8tAnYPmFWA0FLVfGpbstEgPbn3g1JzxAy8+0qsI7o
9uHF5QaC3mG3s3ufkSJAp25KEW0tEzLz7SrYNPv46VmFDQT9Zem70X/aigDd
ZYFNiblKyMy3q2B34dfHhqwGQHfbP+IRyIUUOrnttYeHLURMb1eBygnk/U82
ANr3x9yDJ4uFFJq30o1fM0bE9HYV3Apvu20sNAB6Y9Xk3G/pQgo9bND+GWvd
RExvV0HhOJ9BI2X1gHZsu3qW6TshhT5XNHFT2XER09uN28/ucP9OD+sB7djK
reXUSCGFPlsFNbseiZjeroL1ubd3VK6sB/RvRV8rr6tCCj3HPCql1Q8R09tV
0H7SpacR5vWAPt4uvObhMSGFVuS/7PdYIWJ6uwrWRbmOW5JSB+jOjy3a/top
pNDfIrKKFliJmd5u/P6NtYGN3nWA/gjexY2rhBR672GTsaxJYqa3q+Gh4/Yx
t4bWAXrAmZAzfWcLKfTjktTiqA1iprerwdv7y1uHslpAF3Qf8cx5tJBCT0q8
dsc9SMz0dTXs2Vl69cu1WkCvtFLb7uojpNBTU0xjOr8QM31dDa4fTIvXzKkF
9K8dR/cHtxdS6EXd1W3Sc8RMX1eDV6p3pIZTC+jukluR71lCCv2ha2Kkn0HM
9HU19LCfbHHtVQ2gW3yd51ReJ6DQovWr9ozoLWH6uhqy3OrsYWsNoEcuGfu1
ba6AQl+ZG7i+cIaE6etqSPV67SLqUQPo6O5PO4xLFVDoG4lhv078J2H6uhru
bs9u8/RnNaAf5L48uuWlgEI/m35J1e+yhOnranh9Z9du75PVgN5eaZV3666A
QvcekuyU+EbC9HU13N84rf0KqAb0gD8/eNlnBRT6yawVivmFEqavq4F7PDJz
rqwK0BPvVMvaHxRQaN93Ayxz+FKmr6th3clb+5c9rAL0tbt9b7luFlDob2+i
PrgMlDJ93fjzencQH1xVBeiBJk4+txcLKHRk3R5hwjwp09fVsDD2sl98+ypA
X94WXlg/RUChf/V+OaHnXinT19Xw4unT0ZafKgH95NGWM07DBRT6/oN+JbtD
pExfV8PSa2tmnvWtBLSrR3BGmLWAQi8ckb7sNS1l+roaTlXx4/raVwJ6ndfE
ehNTAYUe0+pgr9oyKdPX1WD34WL/4qoKQH8WuZ/cr+FT6M3dHWratJIxfV0N
Op77f+R2BaCB/Tu3oYJPof30ztN7DJUxfV0Nh80sLtGLKgDtNoVvu+Mnn0JT
++QvrRfJmL6uhltvY0TlrSoA3W/IoLfqRD6Ffn4n/ERrLxnT19XwdlDGyRGJ
5YD+71RM8ekoPoXuWXVlTPktGdPX1aCZZp52f385oA3nj0X3v8Wn0Ny/iuuP
P8iYvq4GNltDTRpSDmjq8IRz30/xKfThRr+CVZUypq+r4fuMTo288jJA7zZP
hiMH+BS6U+6uw/rWcqavq4F0FX0Q3SgDtEigGzpuA59C95AIb50YJmf6uhq6
pU4N5S8sA7Qw2mwjexGfQktC/g7RL5IzfV0Nh0wos8mtygDtxpmX9H0Sn0JT
2tX7VnnJmb5uPB+ZDhsZmVgK6J2TZwdFDuVT6O4HNpRF3pIzfV0NRzx4vcd4
lQI6tDM78Ex3PoWmv+jrihPlTF/XwJCiDpskw0oBPdvR6bpPaz6F3nh2z2dB
hZzp6xqoTJFSmVUlgNaIx33freFR6NZW/qstWymY+XYNXN9rr8y9UwLo+92+
6vdW8ij0i6T1PPMhCqava2DV1F42rZeVADr4x/QWR3/xKPSPFdsb1C4Kpq9r
4MYIlt9a8xJAV7Q+HBqcxKPQw8sb33/bq2D6ugYmxIpNC9KKAX1um8+HV9E8
Cl3UW3jg3HUF09c1sMn0bf2ho8WAXsZ9pi0I5VHo2eo7Laj3Cqava2CHtMjE
aVwxoP/67J9kdpZHoacL2nrnFSmYvq4BrTjf105eBOhDb19ZzzrIo9CcE+fo
TXwl09c1QHUUcB2eFgH6+/GEw0FbeBTaTeZjKO2nZPq6Brp0WbJp9YYiQPsL
XP9kL+VRaKlkwax5s5VMX9dA2IV3+ogeRYB+6P5fY//pPAr91MGG/fg/JdPX
NbDFtVBv+qcQ0CEW+w8ddeBR6LSstmz1BSXT1zUgPrpWdfZiIaB1oZ0MJb15
FLrF+29cx1gl09c10CHAZ6GdcyGg+T2tLWa151FoRXzCz02/lUxfN34/uux9
kaAQ0LAj7r/XbB6F9rMO6nFWp2T6ugZyC17+WXGkANDaeNeQgSIuhTYJcPn0
wFrF9HXj/tM6xdBDng/ogKIc63v5XAotGjeHfjVJxfR1Dagr//My3ZQPaGu9
8zObr1wKnch3v/N2vYrp6xowYxU/7ZaXB2gO9fdlWDyXQusOTbv0OkDF9HUN
tGkV+cl5fh6g104cGdc/kkuhxx28HPT4kYrp6xrokdupR8jHv4B278p1fxHM
pdCOn9Sjrn1TMX3deHwdiM1kj/kLaPv0vWOoE1wKfW2N+alDYhXT143H+7ad
1w8+zQX0i0FzXqTv4VL///q9ddfcOqiZvm78fZN6vWjZKxfQp/e7u65x51Lo
yjajFowfpWb6ugZUF/bfD7/6B9CrzdNjZC5cCj0pd80Vy2Vqpq9r4M2QiNiZ
rf8AWlmW5Ro4kUuhze1dXep81ExfN+6vG5+5Kw7/BnTnustfug/lUuhvtlke
ibfVTF/XwNboblfuyXMAPSf2w4WY7lwKvf7i/j9XEtVMX9dA4CauyfzNOYAe
tq2HzUxTLoW+ZUvebSlTM33deLxuy3qtys8G9POgLh0LtBwKfas07cfEFhqm
r2vhy/TSkcELsgHdJfCtYFc1h0J/rfOXdB6oYfq6FjYFWC0YmPoL0Kbn123m
/+ZQ6PI8x4FyZw3T17WwdKpD5tNxvwD9OdXjz+UUDoXevH34rKwdGqava8Fy
GDuu+/OfgO7Vp0d2r1gOhX7zgsx/fVHD9HUtVGfELN5v+xPQK68rWj67x6HQ
Uz+bV9+J1TB9XQtju3258+paFqAjjo6WOVzkUOjnqtMdL/zWMH1dCxnX7ep+
m2YBetnF8PHxRzgUevbvmGOBOg3T17VwIXcQyT2SCWjP+LJ9Y3dwKLRVoH27
QGst09e10L1T6yNx8gxA847aDH21ikOhVeq3t89P0jJ9XQv2pruv7NyUAej7
R74NH+zModAvdGuvh63XMn1dC4dmeQ9g5f0A9I5Nc/mhYzkUusegNXISoGX6
uhYW21Rnr533A9ADp+iXtR7AodCR+/gzKx5pmb6uhRO9fZKvfPgO6PPH0nM8
O3EodL7CbU6XdC3T17WgiU4IvubwHdCrHTqNyBRwKPSki+nXlkq0TF83bq/k
9g0ZLumAdh8nHjxIzqbQo090uxtuoWP6uhYCPlwoETh+A7Sj3ejth0vYFPps
RFCvRkcd09eNr+dzUsZXq6+Ajp9tl/flB5tCn/KIcPJYoWP6uhbaFP3a3IP9
BdBm258IzGk2hc7vFS7JPaRj+roW/kqHrTGUpgF6gnX78rlP2RT6WMLvEW5h
Oqava8Hudsi8tamfAC2NM7H1v8Gm0F1O176UJuuYvq6F2/ZXZs96lAromes+
xcScZFPoraO3XblSrWP6uhYWVu2KiA1KAfTlCfs25+5nU+hffmYDZ7TRM31d
C5IRznvu/pcMaMhc2FfjwabQfktdn7carmf6uhZeHbsR02r+R0DPSp0R324R
m0Jv+m9rYP4iPdPXtcC3bdVfOiwJ0POizw23nsym0KtD8q8nHNAzfV0LldO6
r19s/gHQvqXz99oOY1No7qgV7V/e1DN93fj9NQEzRkkSAB16Nnh3L2s2hSaF
3yzjEvRMX9fCLtPngRd/0IDObhfi2NmUTaFd8j+d+VqmZ/q68XhX+J7PdiOA
fqk89VagZVHoq+0q/SUmBqava+FSueUJv27vAD3ylWOH2koWhb56/kx238EG
pq8bj2dbjWW/328APfjHK+rTLxaFDl95znebi4Hp6zpY0ToR0i++BvS6doYD
t5JYFHpMAbf1h70Gpq/r4H7/Z4H7nWMB7XzAOWlLNItCe5iu39cvxMD0dR2E
lgnj+wpiAD0IcsYPC2VR6PtH5h67SQzk8L+eroNZc4sCSt49B7RXy2lWDUEs
Ct2qZmeKTamB6es6uLswLHRN1VNALwjy8w/3ZlHo5WUaSUyLRqav66DdkzVr
hi6KBHSM//GEhZtYFDpYIvNxHdTI9HWjf70/OZaEA3qZdkC9zpVFoWeZRPYS
uDQyfV0HE0ZZyC/3vQPovIVZi29NYVHoqa6L533Y28j0dR1M8qm8EmZ1DdDq
74OmjR7OotBtV93bGRTSyPR1HVTaFATJv54FdM8mWrMo9NuJpR3c6Uamr+vA
qcNID684L0Cf7DLi3QpTFoWuTbt2fGpZI9PXdTD+6aENXhvd/+/+1JfEz/JG
QNcWXOvehc9iersOuLGt+KOunCDoS5Xy85nfGwH978sdWUxv18HC1J28u60u
E3SBY/2+H48aAX2+pMWUjgNYTG/XwZZz89btnHOLoN+/8xyT7N8IaJs7ycU3
xrGY3m58fyJyqh99CiPohDEPQ6PXNAI6dO2jZ33mspjebvz9WrJj2297QNCR
yrlrr45rBPRAXs6cmDUsprcbj4/0lbSr2ROCPm6mn7GnYyOgJ+xjL3fazWJ6
uw62c/YdGpwbRdC/z7bo5CwxALr9a+2u3/4sprfr4F28FeENfkHQU+zbxFh/
NQA6v0xlu+Mai+ntxuOh9dSpPY+8JGi4HZJbF2EAtNvQ4eYmj1lMb9dB8tTj
1geyXhH0pUfC7a/9DIB2GKBLDXvPYnq7DgK7P9ij6/uGoDv6hjseXmkAtIx6
UgI/WExv18H0nhH3bnm/Jei/QS8tpjoaAG0+2lb+t4TFrCejA9d3v2e5pL8n
6IHuk3JbtjcAuubrqgteChaznowOWiT4zTx+nibogohnrul1ekC3s3uwsJMJ
m1lPxrg9UwLGrYxPIOhWFduXXErVA9r7dGrmy664HqkOhF2CNw4oSyRooquN
XhamB3TokcD7LoPZzHoyxvPTp9MfytskEfQPjzN9e/nqAR38xXFrPYXrl+pA
vify3CnHjwQ98Xl1UP0SPaBXR7SMC1jAZtaT0YGLc58Q87XJBO3qEPL43Qg9
oH+6R/e38cD1To3Hu5Npz32nUgh68eL3Xc+30QN6YVYPz1f72cx6MnrQRoyx
jY5JJWj2oyXxm6p0gD4cuaDnrFO4PqoeWgutgt7nfSLo7odWDJ6ehOuj6mEn
/aMy9yabWU9GD/O4LeKuCj4T9JXG/BaDbusAPfLwOe9NUbieqh5eN7qfGTXk
C0GbuI1o09l43KJ1c8v3SxPZzHy7HqpX7Dh9bfFXgl4n2/mt9SIdoNP5KcEH
frKZ+XY9iMM9LsYd+kbQkwZe/NpiqA7Qqzc7XNNWsJn5dj247ZxqfjEinaCz
hr26adpKB2jLDb2HHdCwmfl2PbS7clZybsN3gvbpsuJD13Jcr1UPiZL53SWt
Ocx8ux7uraxeMkz7naCvbvz4cESCFtAxs7oN9LDG9V31kLD2feGDM7i+q/H9
3fA9ZdENXN9VD0u+dLT6OYzDzLfrob2fmYPCJoOgvW97e/rt0wJ60tDE5AlT
cD1Y4/u1WxnX8SWuB6uHLz39zN644HqwerheP0F515XDzLfroeNqzdzW0zMJ
esxGdq1ukBbQJbMaA9mbcP1YPQyP/8PN/IPrx+rBfr6J8TMU14/Vg8dib7dl
3hxmvl0PSR9XPdy8LYugz855sCi8VAPo1zkDFz0JwvVmje/n6k3vMhqzCLrj
g/B5rWgNoGUDnyzW3OYw8+166OfS/17LCz8Jeu8juevBEA2gnQYcXzgxGten
1QNrk6DcrPcvgqbX+/pr92oA3eMrPc4vicPMt+tBeafCufLlL4L26+hfe9xF
A2iQvTV59wvXs9XD8/n5z4OmZRP0pS0BF60G43q2enBIGxsrruQw8+162NW4
uh/ndzZB92JV7iEmGkDXN7Zy6qHF9W/1MGWO2V+nzTkE/d9jbcD2MjWgU/v7
xU835TLz7cbj5UbvaUu1OQSdlOPwtH+CGtC3Lpb222LNZebb9bDqzPwP407/
JuiNNwami26oAf1l2ObgE8O4zHy7Hl7yGk3EVn8IOnPC4Xcf9qsBfbUQbG5N
5jLz7Xo4vetB7t4nfwi6W4nFjLsL1YD2bLMn9+kiLjPfroeFXLtu6eNzCXpg
Y4zj6aFqQG8+HF4St4HLzLfr4bdTVonmay5Bn6xvOe1IazWg4wO8VpADXGa+
XQ8fal0dtSv/EnT6lOphRypVgA7Oa7mBnOIy8+16+L7Z9uCPur8EPTs8NvRU
kgrQy57cG/LmJpeZb9fD4iFR3EMH8wh6gKw9hIaqAF3D31v47BmXmW83QMb5
U+v5pvkEfbrrzfvvfVSAHuP5/HFoApeZbzfAvmcb2nvcyCfonh36eJcvUQG6
Qb418XQml1kf2ADOZjMe3x1YQNBP4usWdhypAvSAnoGLdpdxmfl2A1TMvdj1
3ZsCghbYdY2bZ6YCtH6TZ9hiJa4nbPz+Lfudyu1dSNB/NFvGXKhTAvoiJ63Y
wYTHzLcb4LLlO+cZWwsJOna3zdLcT0pAhzv9t8C8K49Zf9gA4pCL9IMXhQTd
Ynjs7YH3lYDWlfceWm3HY+bbje9H5AqVRlNI0A2RP476+SkBHTCg4/v3E3jM
esUGeGByRU9NKiJoO639kYJVSkBv9lsP5+bxmPl2A+wOOprlHVhE0FNHv7eY
NFYJ6JUlPeSr1vKY9Y0NYOK68fLj70UErcua9fJhRyWg/SyW2Q7czWPm243b
51bwxqyOxQQdGfXis4VMAehHfft0kR/nMeshG2Co5ZxlslXFBF0py8k4/l0B
6NPHL1q+u8pj5tsNwO6TcsH0fjFBs7bdcFA/VgD68Kfn7kcf8pj1kw3QRXh6
iE1dMUHv0o3e+F+gAtDJ7JJZ0+N5zHy7AQxbuy4Yal9C0EdmeP6qWK8ANJWb
3KH1Vx6z3rIBhou/WI/zLiHoDSc6i9ZMUgB69jipMD2fx8y3G2D+lbAYp8QS
gs6xf2qb110B6Etl/badF/GY9ZkN8KpikMMck1KC7t26qnSJVg7o+gOnghZw
+Mx8uwF+LVqX4DqvlKAtFs25nZUtB/Ten0uiLDrwmfWcDZC6ntridrWUoK2+
rk6bGyMHtGfn711ybPnMfLsBOu7OXLY1v5SgZU5XMj6dkwNakBdjGTKKz6z/
bIARTs+DvG3LCNpjZd/Rk7bJAe08f2vJqhl8Zr7dANZn9pqd3VpG0KLXU/a9
niEHdEDYyqRey/nMetHG/StHyXnwooygH7U/ZhjYRw7oAYp3rOqtfGa+3QAj
p4SuSdGUEXR53pC5NzhyQJuabcx57stn1pc2wPKpgzrUTywn6IwVVfIWBTJA
X53f6rj3OT4z326AKd9/du4WWE7Q+R0tdu2MlwHabPeeqdPu8pn1qA0gpIPc
Fn0vJ2idddzcn1dlgObs6LXEIobPzLcbz6dH1iVe7VhB0OvgW3f73TJAzykM
FpV95DPrVxu3j3J457JVFQQtOOaxK2ieDND6d7OnxmXzmfn2Rni8V+Qw4X4F
QUcmnSgttJMB+lG3t0Fnq/jMeteNIOOP+h1WV0HQgoPu7QebyAB9MMFZsVHL
Z+bbG8H9aq93liMrCXqO/fY7u8ukgP5dNv2Zk6mAWR+7EfJ3vLx01aeSoM9P
Cx8ZkyAFtOOKQWW21gJmvr0RTg1x1fdJqiToMZULj9TelAK65NQiYvK/mu49
pKkojgO407pHDSxjhWThQqLXLCoLNfI3LUuz/pjTRbqRVErRC0oxJI0WlVgp
WJpmDzRc0cvyASnmuUVK9lZSKy3KZrRNd+/dMnosTmO7vz8//9x7/zjnwPnx
5XuXcXKfNoNrKebjXVOsFL1kSB0/p9AF6N0V1mwpkZPz7QwyLNWdh3RWih44
26xar3cBekasWRhO5/gg70COQYoxIXJ5rZWiDdptjtzlLkCnbXlT8iKX473j
1rUM1nwyLlR8tVL0yDTtnqMhLkCXF2zZyB/m5Hw7A8s309wvi2wUXXYm/kC5
zQnotrbs5AelHO8dx+k874sTD/QdtFH04Ah5WtXtBPT5EHdtyyVOzrczKJm5
QdffbqPojjyDvrLeCej6rt701rsc7x3X7PR4sDnQ5m+n6KVK89/SYiegv0+o
Te08J+fbPesnSd0yLdVO0dxHa0NBphPQRaFTop70cbz3Op/HoD//Sl7KOTtF
z+y6l5S1ygno/MvzjX0WTs63M9CsbtefH7JTdPZI/duV052AflN2d8boT473
9cUwGJb8c6TIMYqefqp4M3FIgC7o0Gx1BxI5387gcScpyt47RtFXVUceve6R
AH1PSIgICye8ry+GgVZ1o+pLyxhFvxNuRZc3SIBWBt7MiYkicr6dgS4zuCjv
3xhFD/QVPko6JgG6sioxwug5RXx9MZ79MTXsT9j6cYqO+eUyuQwSoC0BJ+NP
aomcb2eQqpjU86psnKIzWVFtdYwEaJ1fQlPzDsL7+mI8678xrbpycJyi9TcG
VqxUSoDuv6XMHc0ncr7d87yXl4L3qRwUrau5X9gjiIDWr7ieGF5CeF9fDIMI
ztCUvttB0aK715zxXAR0ieKCOuMikfPtDGLdduWmJgdFWxSlE+/NIqBDWNzk
c7cJ7+uLYaAa/t2a9tdB0WJoQIPeJAI6sKD4zttOIufbGfzLqVDsWidQtP/L
Vey5UQT00ZqdfrN6Ce/ri2EQvr/OcPqsQNHO5EZtXKwI6FNZCwa3fyVyvp1B
5I9n8zoGBIp2nJg1XqcUAR308GBQ4wSR/6/k+Z5di5O5zwKg4UNwheIX0aBN
qbYh91RRnrf7aWoOKZs6qgRAf5t9Qt04SjTo6O4Jc120SP8Dgggupg==
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83Xc8VX0cB3CuOxpSqDQlSVoq7ZLvKe2hXdJWGkIpSYuSaC9RSlEhj1Qi
0tDvJDQ0rNIie4+7L3d5Lp0v/zyv9+s+z33dc885v/v7fc7nnGeg4+5lTiwt
La3OPC2t1n/eCGn9q4a5t57/YZ+uJ+h1Y+5dPjpVAOhl2y0nTnfk0TPPulQq
/quG1HNFdje8rgC6z5tb4wRmWhT689G04P5JLaThCIzf8KIaao36KDfm17W7
k1ioveSqANCKk9yW/PE8+rqbwQn6YzWM/xy7LKNvKUFvC/nve7+9UkAvGvvg
qiCDTc/YVJ5l+rsamuNSVcbHqwja777x8T1EBGib2D1kjgmXrluabHyythre
7Fi33syljqDDM5dm138QAHp0n9VGHfvy6GDb1g2qhj9Z62fcm1hJ0FeMsjdY
bhUDeqLHtayqzxya0mzNPN0a8HjyJjH8ah1Bzx4yIPJxogDQ6132jLQYzKNr
zMd0iO1XA7ubrtisdi8j6PcnkjateCcBdL/XEV9X9uPQV3uxV+mNrAHVgiNf
OyrqAd1i8HdfqjePQrN+Te91mCUgNp3y7+2Zpnm/MbcNdV3r2t2vcrT0oGZ7
0XvPVbJtNdtbpfhPkLOoBj5LnXSD+zcCOuFo7xNO73gU+gb7c/M4dz65Ut+6
A2sgxndf4szo8nY/sJkdWTBcAu2vF60bqe/Moa3/Lj5/za0GCjccelAWWUvQ
l7NmxHQZKQR08rXCYQeruXSFZu81e9fAfdvoV1k76wBd023YKI8+PAo9ovDB
HaNMAbmUKrFYd7EGmrnP8nrwytvtdySix/4jEkC/fjNyf/p0Dj3l6XvP12E1
kBNbUq743AjocQ+8mr1FPAp97T+9LqzefFIWeTPNJK4GvsxskmtHVbc7pOAE
q2WECNDj9F97H9vJpS9caz1ga+BtAHvfCJ1qgjZ+dTRjp7cI0IKBb/plUlx6
0unpmiO2Blzdj69LmVJO0PPnkKV3HCWAXrvOZPVjOw5dcqj7oznFNfBhl+71
vTcqCLrfx+aEjHgxoIV9dKJCozj0udbTU1ADeyQ3bl67Vk/Qc09aWY0bJwD0
upSKinInHj2h9XBl1YLTfdb03ScqAP3zPyrrdziHQtvFem+c+1pMilp3n0Et
sAo3/Tr1prjdLZe+Xpk6QAboYxOvT3Dcw6bPtG6OaS3E2xfO9bevIej7uZd+
v8oVAnpE8MQrA4O59LixrX+1cGm50a2UwgqCnrTKY8ydS2JAl+XN2v74GYcu
NOMeD7KthTGnUw6HvvtL0E9vdSvupdcEaPMnBy6KmnToUz1/fpEtr4VxRx3v
d11QTdDb3tiN8HIQAXpR2I/qt8u4tJXm7HTYWguVj6d0N7cvJ2jd6BJJ3XIJ
oOUP9E52XMWh/zR7O7/yqAWLnjGRW72rCbpOPOzhZ0oE6DMnnYeGbOTS/rVt
AxK87/qo7xS7RoLu12QhLLHnA1p4otb/Qi6PHl3QukG1cOV2fmWsXx1BPxvd
/dx/KQJAR1RKJg8fyKN/abamNLIWft/6/KBifylBG4zpHaM7SwroA9tFMQcL
2LQf/fHOrKRaAO0+tsY/Kwh6U8vewj2BYkAvOZZxaU4Sh7aMv9V4P6MW+vfz
N128uJqghYJXbvb2IkDzAu68z13OpX9oRqNO+bVQHFXloFJUEfSl2LPLtH1F
gE4e+mJViw2X9g1qHYBrwVH0V2pZW0fQi7mX/HacEQD6h/JZSuYUHj08oHUH
1sKaXvpDl6fUE3TevgO7Vg0UALrn7JkfV+zm0d+8qjUjcB1sNLjS/DKxEdDX
/baq3ep5FDpLOkHHdDCf+Gj2XmCvOkjrlDNd6lbV7tvynn/93osA/cTX41JK
Xy49dN1FzYhUB5OmfummEjQA+suFsTN9XvEo9NaS6we0A/gkd5FjN/vJdbDK
1ZLt/bK03Ss/VKkoUym0v36z8/G/DWz6aOvP67w68BbF3vHSqSTo6f5DH9t6
iwFdZL3LopDm0ENaf24c6uAuu/83g7I6gn581D1Iel4AaIvpcxLZk3l0duvw
66x5vwRtvR6sOoLeZN7iJVELAJ3lcsz2pBaPPtw6HB2qA7+eRsLeLg0E/dpD
zBV94AP6TvrJI9ybPHpw6+l5tg7GXO3/e+KteoKuGu9usHWMANC6Tu+ki7bz
6K+th+vNOljUt+MT51+VBO2w9/D9jwZiQOfOnhF7Q8qhD7buvtg6ePOp4YtT
Th1Bh4ec6vU5WADo0Qkv94WM49GDWjfnVR3MmKOYG7W4nKA3rvP9PcJeAuis
bJsr1cs59OdPrX91ILrKHxP7rZKg/RN5lUN7iAE9bfAR3V0SDn3gdVifUQV1
wN36tDzWtYSgVZ8Hnx/6QQpoVm/XybtusumBcXt3XK6vA7PHw7xgfilBu0XX
2BY5SAH94UGnwos5bDpTc3aKVJrjzb1eV+HzG9BDHt3a3LJbh0LH30uz1jZp
JvsDWycU9ZDQd3rQpQn57TZ8/vjXWis5oD0HRRvkVLDoASdbB6R6sHvCWpjV
pwHQK2K1DJ/68yj0mvvqn9eEfPLBs3WD6uGJ+FZq5urydkdznhj3WSEB9Iij
9/nClRx6n2ZrjkA9HAt/liKIryZoepTZwABzEaBNqlx3v3Lh0v0dtk79u7ge
Ip2Sf38fWkLQlp8HXeleKwX0zt4NSfvPsOl3CyZqfmHrQVjxIPVnbgNBB+jG
GBsG8wH9qjlmj/Qpj3af1jqBqofD64/YOf0qJ+gZ2W/sPxtIAL3RKGx5iCeH
7juqdQCuh9MJV66UNFcStHVUUpKejhjQJbEREV5qDp1u0rYDgdtzwsum1fWA
9j352VK9kkehVeKtd3VWCMju1unxHc3nDw9dHTWlst0Bj8fkxTqKAW1tURn0
3xcO3bt1uhhfD4O2n9xtYFRB0G4Lp733FIsB/WFN8c20kxz6bev0KVXjkp87
hulXE3SoXmCm8wERoOO9JtyYP5NLu7ZOJ3I0+zepKDj9ZjVBR0dcHNffSgTo
2JHJToJtXNqo9ee1tB5+1XoaD62oBbT0xa05Z5q5FNrwTNqeWl0hedP6cyOq
h+I/0M3oWX27L+kXHfAwEwB6kqxrWrorj97VOvyyG6D2oXraM9NGgu70n9bm
CDc+oA8/8Pn68D2P7tE6HHVv0JynrCNDSD2gxyZo/f2wm0ehb4Sop7uYCAhp
PT3NGiAmaJpWxst6QDs7dT0mcONR6OHji1v6mQrIztbDdXwDfG3mk9N36tvd
6wTPZOooAaA9bJS7HXfwaMPW3TerAcbH1h++blJD0BVDO6YmNAoB3WWXwtj8
FJdOad2cVQ0weSP9qNPPEoLemhUWfShQCugvRnEPZiSx6e3bWv8aoN9695K7
vWsJeu/Sdxcs9wkBPWd1aPKODC6tbz9ZM0NugOArjkcN/tQSdGKS3RupvhDQ
URH2YWwZl36pmS0OD2iAnPL/Ejw14znaqMvwqJma8RztcbAmdr1mPHea2rog
aICil78c36SVE3S3u1fswvpLAN30KMl+tDuH7jqydULRAIpr18P2ZFcTNOvp
2Lg5RiJAtwyuGLLOg0s/N24dkBrA7sdfR9JQT9A/DS/ZhXcQALq79NmPx4d5
9JZurRvUAK4/7017u7WGoOcbWm6+/VkI6LXSHV9Hh3DpLqzWGYXm+Giqn9m9
pIagE3ROF0guCAFt7j1V/2Qyl34mUuV5VTfALs9Alyufiwn648ykDxN6ywB9
s8Ds5tZ9bHpz6/K2uQHMrvv0fTivAdAdK/7O3nWFR6EbxlJ7h/7mk86ty71O
jeAZ29Gr/mdNu9OHKmw7BgoBbbyLteFwEpdObF3+9NG8Pks6+MHBBoI2LmC7
DnvLB7T75aMfnG/z6I2ty4HhjfBs73SPAVMaAf1oXbeCgC88Ch0x++8sviOf
tE2PpzaCbfdHlRcf1LW7UGKhOylGAGj9k7XNpcN4dNt0cUEjmN08unG4awVB
u1lNX+L8QQzoD9v+5s+/yaHbpk/rGiHKwHCt9fNKgn7o6ZmzeZAY0DFpaT0X
N3DotumESyMMz/3t0hnKCNq555V5h4okgM4UT/id2pVDt42+RxpBSjYIbJ6U
EDQnfEnApvtSQKsfr361OJZNt/3cnG+El6uHKUcMKiNo07ya4zsbJIBuDOoE
mR04dNvwe6sRppqc1ckxqibokt1T1D09RIDu+r7kmHgWl24bjh41QrLzRN/f
j0sJOmJ+mY2BhRTQj36dL5LWsum20/O15vNnvBLu+1VF0CdD73AzrogA/XrM
Y2XoBC7ddrh+aYQ1ez6u7fuinKDz3vVZJjSVALpnqPC7vxuHbtt9fxthUNRG
bapnEUE3jFjS8lcsA/Tp6tValzhs+t/mNMKTO/7mOztUEbTF41cumQoRoF2i
78zrw+LSWm1/fPgt0Fm8L7mMoA143vYZ9ySAPqCkc/tZcpj5PB8GCUvFnoJC
QM/0Di20LNSh0Ad03s24a9tEYgQ5mhk1H7rFH524UV7R7ibz6VuzfMWA9nP5
+/naaw79b36veb3i2WaTCZUE7adr9rVxqxjQr5tde536zKFXlLYGBnwwuakU
PNpQQ9B74rUDorOEgH5v7vPqwTVcL2jev0cA+TGijqDZ+63DA6sFgPZOLx41
oTOPVue1bhAfihqX629LrSTobh1WyT4ZiwHdpFjhF8Ln0P/WD3xIefat0ydl
NUGbmgXJQ7RFgG50TWSN9eHS0RmtEyI+xC1dnHF2i+Z3nbFLXqCgxJ5HoS1W
/+g3xU7ArD/4kJS137r32DpAW3r0X5yhy6PQkUbpm/dVCMiy1tXtUj4cXbVk
ck1UWbtT81aXnomVADqsx4oLL4bi+oUPQ/s9Kkw/VUHQdYLobrdeigHdKeDB
gTF3ObSyNc5y1Hz+jKeuB0kpQUeHDp5nayIFdOwY17WFjWxmvcOH471HdjAa
UULQ1L7qw+JqKaA3ze6cyjnLpqNa46C9fMgz+0/X4Gs5QQe7Pmj27CUB9Ph5
w06k7eMw6yM+VE2Kf5Py9w9BZ7gHXuz2vgnQ/edMSJbd1KGXtMYpJ/jwQbz+
jIVjFUGHcrJf1H4RAdrq6DXTM724zHqKD3N6v7K69b2CoNeJ7mx7clUM6GXc
xwvvJ3JoeWscEciHwQN2l4YHlhO02565F0ZNkAD6w7vfk6q2cpj1Fx+S/35w
n5reSNBm3frOcezPB3TDgb1/7AQ8OqJ1OX9Ps7+2DJ9wdXclQbvY1ZSNnysG
9McfZ7qU/8b1Gh/e5j6aSs3E9RofjIMtSv4W4HqND4KntXrd9Hm0Xevh+pQP
S66pOjpOrSFo+3HaCrsSIaDznHx8f1zgMus7PnxSy2b5KnB9x4cbWuwCGxau
7/iQ0HL0cpE3h25q3Zw0zfnhZSl9tbqYoBvfVvkNXCEDdIfbZ6c1rmQz60HN
8XF6dPFpaTGg7U0Xet09yqbQS15u7/qSLSN3W5djeXxI67HtxepZ9e02lnwy
XbFeAGj3kyENK5fymPUjHzJLAx24Fj8Iugtv7U61pBnQB48sy9Ti6NALW5cz
5XzYbai9YNaYWkD/mUkvW/qJS6Hnevo4rN8uZNaXmv11itaaatcI6E6mo+kL
uTwKXfcyzKfEnk+krcsBieb8vXfXNElY1+4Zjx41RPgLAP03OvrUQ2sesz7V
jE9vzvzuoVknomfGlXienMOj0F5hUwwkewQkvHU6zRVAjqN/cn1OQ7uvfXk1
6LRmvYZ+en2g20vNeu3felUANweu+VbiVUTQVruXB114KwP09rmrEicZs+n5
rdPRngKILtii/6yohKBH6NsdiLgoBbSzzD5tZDKbWf8KYK2+rXOwYyOgV6dd
uhH5A9e/Alh2oPDjUzs+EbdO58wFEK481f2BTWm7446/3B+zSQpoCzBNj/nK
pv+thwXQf4r3u5fiKoIWllD97p4UATrgwl+B5TQufbt1OjRRAK6dSyL6kVqC
ni+/8NDdRAjo376Thr5r5DLrawH88PZVTL/RAOiksCLvS1E8Cn2VtmH9jeeT
ua3TiTkCmLn3iLt8/Pd2a0aLLcf3ygGtGS3sSAaLWY8LIMrm65r19QUEvWr0
uf+i/ZoA/a1y8oMHKTq0sPXn1V4Ancdff+/pWUbQh8oTbqalSQBt28U8/lZ/
DrN+F8CpuB0LlqdVAtp0xK+c7gIOhX51f4HD9/5iEto6/O4QwJURijROvzpA
m2XauGvzeBT62U7f/iqBgFnfC+D4+CTfypeNgN50/mFRcwOPQlPlETa6pnwy
u/X09BLAAkOrs6sratvtIN02JU9XCOhcv08lQc1cJh8QgKzHWZcttqUEzd7/
Yp7dBimgvdNNf//IYtP81t13WgD3thZcu/y+lKAfLdIf96yvFNBD18iczIRs
Jk/QfN8jNgb6JVcR9LedS5JS7okA3TMz32ygJZf+d/1Pc/xvc7TedKYR0DEh
vbpeL+FR6NhPX4q/TuEzeYPmeGswedx79rd2O6VNvHrwkRzQX/qXjX8bzWKu
J2r2j8cjfkRyJUE3pkcHPNTMz9Edbg23HtqAeYXmfDlc5pGqWYeiq4wn34oL
4VHo0ann029/4jPXGwWQde9kdu2usnb3spxm1OmjBNDiHZvF8j6Yb2j2x/a6
23YHGgEt6f3yfm4Bj0L3/HQ6zn4mn7k+KYDujp1WHLKpabf0i/xbapEQ0Cev
s4JuX8Q8RAChWybpGsx8B+gp/m9NpntoU+hzIq/XR41UzPVMAUScsjhR0b2o
3Y9e7np9TiID9FDTj+GTNfPnf/mI5vsQim86+FQT9Dl/TvwySgToF9aqqO8b
8XqoAP4LuB7/82wDQY94lWBu+IIP6JqBUS7Suzz6X54igHczs9y8RGUEHVpw
7b2tvwTQVvpP+xZac5jrpwLYtzfW7tOiBoLOyPjvR++ffEDf6vfAcF8g5jNC
KG1+IJ5TgvmMEPR0Yjh/9DCfEcJB9TDV5SYec71VCE+XpkRPndQAaNcVo2r0
LvAotPnqO8NLSvnkX14jhLEFvGDOm4p2b9NXjjsaJgb0Itlxp+lxHOb6rBDM
bN7dCNGcL+iGTaFWCZrzBX3665Nt5prz5V++IwTlQIF0Rb9vBH38mW1qTbIc
0JRZ4e0z91jM9VwhFKeFDw7JKSHoS7dGuSYESwE9acyOeVFP2fS/PEgIc0IS
axbKigh63djIM2v8ZIBetu3hlNxpbPrf9V3N9trN0nEKryboCvv13p9HiQB9
fnk21XsHl8mXhHBifJcGrvU3gg6LPzJTHScHdFzUm4Jj91nM9WLN+w+6tfbU
jWKC3uY2JuellQzQn+dW9ry7jc3kUULYfavFt59+BUHPHXPstbtMDOh1lcRk
jh+H/nf9WAhWHydP8B9YS9CVfUrLrHcLAX1u74Xzm99zmfxKCD0tHmrlBNYT
tGTXfy09JwgAzZ0//Jh4K4+5Hi2ENUkmvZ4VVRN0XkTjvoiuIkAHj+yQMdKL
S7fFO56azzPxYqpwUD2gP32+F6ecy6PQ27cm3+a6Cci/69NCkJpuWmJ/Ba9f
C+F1h17dg83w+rUQTjZ8zc9NEpC2eCRACMbLdRb6v6wA9Ps8rcDiRxwK7b5K
/dP6rpi5vi2E8aI7R17y/7R77Il8k+y3TYDebnN1t9FtHbotXrimOT4mpSnK
7MsB3V1PYDN5FYdC55f29z2/XEL+Xf8Wwt60miFNKxrb/e5Wp7oTK/mA7vdE
3tHmG49uW57fF8Lo7oNuWzyoB7Ru+qkhH515FLpqf0PcrmEC5vq5EBxcjGRB
Xg2A7vk7/ejg2zwKnTvPg534lk/alnvJQqD7dYo9XlvT7nCBfCicEQJ6dABr
V9ELvP4uBHmTpYyiGwBt8zpzWrc4HoU+cWKH398wPmlbDrwXgskmT152dnm7
+V9nHjEykgC6w/WC6R4eHOZ6veZ4+bE4JcMAr9drjhdD+zuhnni9XrN/pMsf
P5nJodumiz+FcMH17/NS63xAx9dPPRBayaLQoWan9N+NljPX84WQGjxko7Vp
VbvDxrlkFTeIAB1X/sHoYgcu3TadqBbCi5NbFvYb+5OgrxhX1k1KaAb0sz3n
Tm8x12H6AEJ4Uu41dz8nE9BrLwSsWB2nTaHnl/JXLQ1Tkrafm2bN+DyjY533
6dx2z3msmhneXwHodRbHC0a5s5j+gAgO940/4Da6lKBnCM3T3m+XAvqvf92t
vp/YdNtw1EkEcztf2CIrbCTodfJJdn7dNOsMxjm+pT9SZDz6X59ABJc7RCQe
TKkHtBlrp+uG3TwKnawYOdh2oIC0Ha59RPBUdibS36cG0PUpjv8Vh3EptLnf
lIfWtJDpI4hg1e/Vx1gjygH9XdojXGsBh0KvNMgj6p0S0rY5w0XAqrvdv/5j
LaC1Xm6f81LIpdAtp0e7n+4jZPoLIrg5JrZH2uhMQPd56zBdN0GbQn8+OP9o
ZYiSyUdF4Kx170OI7Ee7K+Da+d6pzYDusmncZJGxDtN/EMFCCBVcDE8BtLz4
nA+7XotCd7au0JINVjN5qggWxxje8xmT326XHlONwsfKAT1/v6N4VAWL6UuI
4PVgD4+yGd8J+pK0pGT2bjmgk/0uXFj3nsXksSIYGRE2stT/GEEn0xGThYUt
gG57uZsW068QQce3h0Zr2eURtM3iYpFPnRzQm+27cunTLCa/FcGWJo/gYy+e
EfShuOvS1X5qQL+9n8DOS9Fi+hgikOqEnw0MfQDobscs7fa6aVHoopa7W/oO
amHyXc3xGiTtcv9oTLuXLrj0zmBEC6BX/5oYKt2pRbct9zTrsuGDql8MsQwn
6Moki9QL3i2APh9RezuZ0mLyYREYjwgNLFoZQ9BhxlsUS0a2ADpuj53vas37
ty0HgkSgN77TS4lTDKDzLOq+X9upRaHtHw1ZljWihcmPRRB4krVvoUlGu+0e
h7lLp6oAvcZi9Du2ozbdNl2MFMGvgw+Sx5W8Jej0SzU7np9QAfr2szMLBtlo
M/mzCD72s3eLmZNN0F+adm7t8UgB6BCdzEUSCxbdNp1I0uyvc2OvxR0KJOgv
Y+5N6xHfAuje2y03S8y1mLxaBAMu8s6L9B4RdMDba1tOdW0BtLXxuC9TvbTo
tp+bDBFEHu9js3ZEBkFnPra+7jFFBeg+0cUJ6Zrt/Zdfi+B379ipnSVvCTr9
yJnrG46rAH37zYuEJaBNtw1H+SLoGsm6nvPrJUE//ubzfdkMNaAtetBXvxdq
MXm4CM4VSh86N2QQtKXZ9BgrUxWgq13/xlS4adNth2ulCJwKyKfzDokEPYw1
btDqGDWga9VObnkxWkx+LoIL3U8NGjf/DUG7qS4cfv5dBeh5xyfNuNddm+nD
iOC99mPBOdNUgn434OPmRy9VgO7H7/PVwlSbydvFUPpxW2jHaUkEvSxw8rZR
oWpAr55QurDqiRaTt4vhbvasygnsDwT9aZbRoIN/lYDus97DzfaSNv0vTxfD
aatOOguaPhL04+e3w6ThSkAPvTc6zu+xNpO3i2H71/OzeF3SCdpwtp3Rxg0q
QEv/2HtkLdFm8nYxOLGNrwcFpBD0iwHeUf5D1IAexKdjreu0mLxdDDu8zF/t
2fWVoEWjD1ddNlAC2n97audnUm0mbxeD/hvDIedWfiTowoD+h+0SldD+urV7
qn2kNpO3a7bH1emT9ZzPBL122b5tvVYrAZ27KuPTvjxtJm/XfN8x3tL3fT8Q
dNKw0cX+f5SAjqzZfvHVZW2m/yMGx4Hfb+j7ZhN09IH5IYfDFIAekeYwdsZo
Fv0vTxdDnWfj33KXTII21WfN3HJFCejdMvX6L0naTN4uBj2/+EiTmiyCVm4I
/H4gXQFo3yVJ3Wf2ZzF5u+b7/OkcP9jrC0HnRsTPU4xWAjr4ofla30ptJm8X
w/PjnBRRRRZBXwl73c02QwHoiXHhBwr7sZi8XQy6ZJvLAZ0sgp62pMLMtEUB
6JL8c/VuWiwmb9fs7+Wn9b2ffSXo0G9fpnXrqAS0VVCv4gMKbSZvF0OL6kFd
j/5ZBH1M65vfiyYFoGmfoJS7OiwmbxdDmVX1gicGuQQ9J4HzcPlUBaDXmR8d
usqRxeTtYkjO9evCicwiaIPM269ef1cA+sCNuDvh3VlM3i6GJxuftgxelk3Q
3asMjnk+UABaelZKZg5jMXm7GPZ4bEs9H5xN0GWO2y6uu6EA9IUvC5OzrVhM
3i4Gsx+ZnwaOyyFoWcfP52R7FYBmHw6Z7DebxeTtYs28Klcw/F0OQed2Oasz
3k4B6J4Hp3iX27OYvF0M5Ysabl54nEvQAS7sNf26KwCd8uFormA/i8nbxTB/
Vc0q/6+5BO3mPMvZWFcB6A/zCz7yD7KYvL11POo5FbbmErTz3ilj+OYKQGdm
OFYGuLDof3m6GA4O6lQj9vxG0KYHjqbPuCsH9O6Z028VPmIxebsYHA5/qplS
+o2ghxUvnDUmQA7oXRfXrN/+isXk7Zr9ufZHSpzTN4K2rj6dFRglB7Rj55dG
SbEspt+l+f4KvLaE9/pO0GffD6zMPygH9Iu+u3W7v2XR//J0MaTF6D7aG55P
0Iu/HVlRaiQHtH3Qm5V6YhaTt4thQsA066S0fIK2us3fk6MnB3RlXMC74CYW
/S9Pl4Bs6nkr9+h8gmY9WZdQ2kMOaJ/7S831JCwmb5fArwlHxxwRYn9MAvPj
w0WbdLA/JoHfUaP8F6tZTN4ugQC9qm474/MJeoMy/aWToRzQ2dr9TRdJsW8m
gQEurwq3zv5B0E1lS95va2gGtN/5/JufOujQ//J0CShTneOT3/4k6OmLnXL1
LzYDepP9op4HJukwebsEJjQNyp5b/JOghdrPMh8GNAOa52PWZ6i1DpO3S+DO
Dov5a0p/EfSP8v0Ph85pBnT3LrOG7lqnw+TtEuC8HnopcPhvgva5JOnbd3wz
oN9M5Ozd66RD/8vTJVAAAY1la38TdMfRxmncoc2AVlbybx3ZpcPk7RL4b9XN
R2X1vwh61bA1ef4zmwH9zTk36NV6zNslMLz6qZnS/Q9BJ6bnSI+VNgF68K1g
P7igw+TtElCvvjLFrNcfgtZyXiuQNjdBuxcsC2Cf0KH/5ema9/PUGrMrtICg
l5eQseXXmwCdr2ey7XyCDtOv03x+dZxr3NUCgl5FB5bl3mgC9LcBSV2C43Xo
f3m65t+ngvoc7lJI0N8fO0y+c6QJ0D2il215/EaHydsl4NSDbRLoWUjQ9+Xq
iWsdmwD90Fdra84XHSZvl8DVXbYDni/5S9B9B49Kzh7eBOi9rlWDjGp0mLxd
AveO68cssv1L0NfCDgeNGNUE6HGjZyTurNJh8nYJ9D7iMHt58l+Clm/aaVmr
3wToE4szd3SS6dD/8nQJGBiZT/9pVUTQB8QuGwMrZIBOOzlvSZIum8nbJfAu
atPQfouLCDo0dnGt+w8ZoOOH2nd6Z8hm8nYJzNu22K78bhFB/1n4w/78Ixmg
r/wMXP7cgk3/y9MlMDJ8QGKEXjFB14zaE/nQSwbozlVzRv5ny2bydglozx+w
Jm5eMUFrrd2TO2StDNDHcub0dFnGZu4PksDSuIfhUQeLCfrHkP8ej7CVAbq7
y/DonRvYTN4ugZIR6vFxD4sJ+mK1VvmQoTJATzrr08VlF95PJAGbtbMzGjKL
CXpzzp/QDn0wb5dAVvDlJ4q9mLdLoFPxgMc7OpUQ9OGue6Iz5VJAz2h6N/yG
L5vJ2yXg1fep9Tv/EoKeKYzcHPpKCuhC7sivT+6wmbxdAvp6+x1jr5cQdJNX
+pf/EqSA9rO91Wt4FJvJ2yVwpnR57wvCEoKeqrdKlOwvBXRJ0wr/e6/YTN4u
Bf+XWiOfzS8l6Gl3fXZGOEgBXWJJZT7MYTN5uxRaDv+XNXFPKUFrzXhgVDZH
Cu3eOEzc5Q+bbps+dZfCMutnlVRMKUHnbzY793eYFNDdv9ZPvlTDZvJ2KfxO
2XOlZ2UpQRvceZfkoXlf9IFRoRHpzWy67efVTAr2BgvYhRPLCDrP85eqW5kE
0MFpBsdlXfD+KSlMmW4kGLWljKC3bPTg7fgiAbRd1ixlZi8O3Tb8jpdC/G0L
0ZrnZQR9P24Xd/k9CaBjh3w8ssqSw+TtUrAZJnPxYZUTdLGz3zzaWwLoSx+n
/Q6jOHTb6TlLCqwHKw09ZpYTtM+wldL09ZrzmjHt/I3dfymHyds1n692ednE
o+UEvabT9y5bp0sAnSfv3rxoI4du232rpCCfZvEpMbucoHWKa3sPNpIA2rtr
p32uHpi3S2Hkc9Pgjiq8n0sKzvcaxh3Wxvu5pLDg0SmnGT4cui1O3yYFoWWp
+sXECoIO2HHhmGmZGNCvMpNJw3m8/0sKjqruX212VBD04uP7rxdligFtD+kJ
XW9wmLxdCobh68s6PqkgaOmo7C6H74sBzdlhdHBGLIe5X0wKCUfTTgeIKgja
/E3/qdb+YkC7DnAvKX7Fof/l6VJoDjQ36jS7kqDZSS5i+ToxoNURH076ZnPo
f3m6FIwV6y76HKskaHffpZNoEAP6vU1+6YAiDpO3SyFUtOru98hKgrbyz3vU
faQY0JWvgqL3V+P9aFLoYtNXa726kqDlm4Q+2Zp1NfrEVy51rYXD5O1SGPRG
1HBwYhVBuw3w72BbJgL0PP6rw4VduPS/PF0KncclfzM+VkXQ8vJBQXyC969p
jo8ubok8Ey79L0+XwtGdsncTnlcR9IwF7NCt90SA3vhL9WSRJebtUlh0uOvR
ZlUVQTvM8Jqucxzvd5NCbqHtRm/g0v/ydM3xdSPtet2caoLOjL+V0HGdCNA3
zMeYK5bi/XGa4z/FfPNcn2qCXnPH5etaSgToFY/n9crZyGXydilMf63ooJtW
TdBFJr6K5v4iQF9qtGHpuHOZ++k0451t/ZaFimqC7rqh45c1LMzbpdC0RNEr
1xvzdim8HXmu47x5NQRtXD358NrfQkC7d94yY9kVLpO3SyFRuTZ184kago7S
zjFe/FoI6JEtwXt+hHPpf3m65vM8T5w4/XMNQXcdNHjrxhAhoL3c6hctSeAy
ebsMIG3F30ReLUEX3VrZbfARIaC7jfl2oP4Nl8nbZSDbNTT+/ZxagmbPr43q
u04IaLXDmRHCbC6Tt8vAjKZnhZ6tJeiGsAEFY6YIAd1x9B79yhIu/S9Pl4Hq
kTx5T2YtQftG+96b00cIaPLAxvKPkMvcDyiD9HNkprVhHUHfnhxesFkqAPSY
0lH6X9k8+l+eLoMjtttPHlpTR9AzNixMmZErAPTfrDV3NvTkMfcPyuDi2Ncm
7lfqCHpSRfjud0kCQJedGzU31IxH/8vTZWA9xn/5j3zsJ8vAsdL6u+FV7CfL
YPG54u7S8Twmb5fBU2/+w5296gk6iuYNzdwnAPTDAUd29ZmNfWYZmHp13xO8
vJ6gG99K3o1bJQB0B2NOaPkKHpO3yyB/PW+jZ1A9QXdfeiRr5ngBoD3z31xb
78Rj8nYZxC8sVZzKqSfo+2v0fF/2FAB6RG6TzV0PHpO3y+CupYmVbZ8Ggn5c
1bitUMgHdHTnU58u+fOYvF0zz3R4NWrBmgaCfp8zcIdDLh/QoT0bM5cF85i8
XQZjHxXlvr3eQNAV0V173k7gA/r88Cbx6Cge06+WQbmVTXVQUQNBX6jY1Dnx
Ih/Qz88tPjQ4mcfcLymDTb+G99QywfslZZBlUCNu2Y33S2rmidIzHK33PCZv
l0FafMWWfRsbCfp2lK7d7CV8QD+Jbf7xJx/vr5QBZ59OUMStRoL2nu2dOHIM
H9Bv/lCDd1bymP62DOa4XvZjlzQS9Lp5z1JUenxAL1trNvB4E96PKdP8fmf5
zPrdCOhEG/HGbCmPQgf7GlHrDfhMvi6DEM9o/eU3GwEd1d85La+CR6Gfpg0/
sMqKz9yvqZlXH05s2bOqEdCCDfUQ+o1HoY1nDD72bgWfyddlwB8+bdWC3o2A
Vs6/+G1ZBo9Cd3AuXuGwj8/c3ymD5rtno3f+bgD06ypT519JPArtZ/li+IIr
fCZfl8FCW5fKFYENgM7t9nvytwgehXYonHduZRKfuR9Uc3686178cmUDoJVj
ZjW5BfEodIfQ/V1Nv/GZfF0GxdKcA4sNGwCdnCIuyPXjUehLfj1n2kv5zP2j
Mjjmt+S6Mrse0CYDu5v7ePAoNJ2Sn6BtJGDydRnsMNwW0v9CPaB/+a3ZFrCF
R6EXSheOFUwSkBFtmyODczlfergtqAf0vaf7Tv5exqPQL4J7SeY6CJh8vQni
vlcM1darB3Rs4sH5x2x5FDr6qu6uFi8B+d6WpzfBxyO3S60/1QHaKqxyUtex
PAp9883oC8UhAiZfb4KTA00ShpyuA/TmDu/r5pnyKLRN425zl5cCJl/XrNO/
PawYMLsO0Nv3P2gO0OdRaKse/+ny/wiYfL0J7Dndujt2qAP0Km32yV4sHoVe
oZJJvigETL7eBHYPki/bpdcCOm+YW8RyAZdCr4kZ9My+v5DJ15tgV1Df26/9
agG9ttz//qhiLoWeP14YFz5NyOTrTbB6Zsvx+zNqAd0z26fovywuhc5brwWx
G4RMvq5Zpy+kr/VsqQH0GEN+ZDrhUujbPwc89TgmZPJ1zfYvqX55NaUG0Lor
5JZOj7kUunJ157vj7wiZfL0J6pudbiR61wD6sHfItodhXArdSeezVSQtZPJ1
zf7znTOVtq4B9P2ibL3RF7kUOt5mXUlYsZDJ15vgc/7ahcdV1YAWSXou3+TD
pdB9uuesAW0Rk683wbNqz4N2z6sB7fZi/e3lblwKbXZ25lv7QSImX2+CYYce
di/2qgb0mQ3DZ03awKXQtTP+23/RVsTk603A/rXN4dLEakAfTwrpWbaIS6HV
Vz7lTNwqYvL1JvCsc188QloFaOPDfwzPTuNS6PSOc35U+4mYfL0JZDc7fhc/
rQK0epvv+GkjuRSabaW4ejJSxOTrTTBhzTcjgUcVoO1WSWZZ9+dSaKflPTwC
0kVMvt4Ey/QT0wLHVgF6xcyRgjJdLoVefSCy/4QKEZOva/YfWXE+VVgJ6NRR
K+/FKTkU+nD4yue3uWImX2+CdyYXpOOfVALa6tS9o4vqOBQ6tDGZ7TREzOTr
TVDxdrz7nt2VgJbvWdTvz28Ohe5i7PRuzlwxk683QZBp+PtrlpWAjuxgIYzM
5FDopIbHfZ/uEDP5ehM8eNtoMqOuAtC1/Kmnur3kUOhhxqcaC0+LmXy9CXqc
eFFs9KAC0Onhbk3pMRwK7fnatKtHjJjJ1zXbf7bbFVfnCkD/NfXbevMGh0LP
eCGb8OGjmMnXm2CjfvTFSRYVgLZn1wzSO8Oh0Etkw5NLa8VMvq75Ph92jCyo
LAf03l0zdsoOcih0v6GHR+rrSph8vQm2vXjaYBVVDugblg9fntvJodCf70ae
qhghYfL1JqgTj5pSuqUc0FNVZ7802XMo9BlOlaOenYTJ15ugxsnf6rdpOaAP
hdz5lDSXQ6E7f3617YqbhMnXmyHXubrBoaQM0IkOL14GT+JQ6OD5Z0/lXJAw
+XozeLot6T7iThmgb/ftzllgwaHQ6e/zJTsfS5h8vRliwrop92wsA3TNEDb8
MeJQ6OFxsuNzsiRMvt4MoaUFN/oZlwG60uuZeQCPQ6Gt9C7HC/gSJl9vhv90
+gQ6/ykFdM2xjIg+MjaFHqHem/RRX8rk683ADZ97dmpoKaBZFjklepVsCq16
vHZKyRgpk683w9aCkW5eDqWAXnPgbN/b39kU2k6/+v3bZVImX2+GE3cXF43s
XQroO1WGXgsy2BT6teWPrjv3SZl8vRkW5HVJLMkvAbThftuHTYlsCv2rx8FI
vatSJl9vho5KtcQ8uATQLOKTcjqSTaGVx7VO1j2VMvl6M4RnbdHquKoE0Bbi
Xpq5BptCxxl98VHkSZl8vRkOBPWdcqh7CaA3lPtfMD7JptAzxwtLUiVSJl/X
7N+K8p1bc4uh3QcP9vnpwabQD3S7ZC7qKWPy9WZ4OoeafuJKMaDr9ZdkhW9l
U2jzPxs3vp4gY/J1jQPpMJ2lxYD+aMavpFawKbRr0oDR3qtlTL7eDHNWjM7K
6FoMaIMeuk8FtmwK/edb5bV+XjImX9fs724zPKK/FAEa/Lr1jxnLptC+ssL0
B9dlTL7eDDcnH+xmdL4I0NvtjNNmDWJTaKstbw94PJcx+XozpP6697vTwiJA
x0mrkliGbAodZmB5Rf5TxuTrzXCo3NS5qVMRoDc8P9XnNYtNoW3PN3w8IZcx
+bpmf2y0+JIc+BfQVZ3Tex8Q6lDoUVX7P+n3bWLy9WZYsmmii4/+X0B3qvOv
H1WiQ6HrhgjNwqc2Mfl6M3yt9eZzLhYC+lBB19dF2ToUWndW0QmbdU1Mvt4M
NgdnhzrpFgLa4uuphHNvdCh03OaG6xVHmph8vRmOH7314MWZAkDHPd63cvUT
HQodHt5r5dJbTUy+3gxDsvRTPXkFgOZMmfGjIVyHQkvPHl5s+rqJydebYdam
fm8GnfwD6I7nBnlFXNKh0I2VyV2fFTYx+brm+64bntdX5w+gzx09eWjLMR0K
XcWWdJrc0sTk680w8e3CP72O/Qb09uun++rs0aHQVl/r3jcPaGbydc33vftc
QV/1L0AXn39y+O1GHQptUxba4SDVzOTrmvHLfKuO1ZFfgM7wc6H8F+tQ6P1S
cx/RpmYmX5fDKJPXiwc0/wQ0N01WPQh0KLT4QLcRycebmXxdDhY5pzZcOvAT
0LP6ZHcWWupQaM/M9VV97zYzfXY53Lp/J+KX+AegxeOurrhprEOhewfnr/qQ
2szk63JgvUiJ+Lr3B6CpZ9fEa/R0KPSxy1k9F5Y2M/m6HBwX96h+yc8HdN1/
pkeN1CwKbRH7gpOtI2fydTn8Pjfl+2m3fEDfXPpuSnY9i0J/WOd+Zr2ZnMnX
Ne+3J6PPp9rvgDb+Yn/iYAGLQqdvsWvWnSVn8nU5aJnMzni58zu0O+2918TP
LKrdXm56l53kTL4uB2eLznpdK78BuovTm+LiVywKXTH+qLW1v5zJ1+XgE5G7
b7LTN0Bf8jhkeT+WRaGLena+9yRKzuTrchh70ZVrUJoH6IonnynHUBbV/nro
Vu+p7+RMvq7Z3o5TRFc35QHaZvr22wbnWBT65NExb39Vypl8XQ77505pCizM
BXTXeTyfnMMsCl3qKtBe20HB5OtyUD86lGyyLhfQRSu7GvntYlFoakVxtsxC
weTrcvjaYfFM+c8cQPcpPj0X1rIo9KdpdW7H5ymYfF0OCg+dYydX5wA6zE0r
jj+fRaHfmLaEGTsrmHxdDtn+vgYXv2UD+teSJSVPprAo9MING6eGnlEw+brm
fCmM2DtweTagM26usNw6jEWhPd6vujfxgYLJ1+Wgkz8jxDo7C9BFDhaBQ/qw
KDTMf/wzLlPB5OtyyGqcJau2ywK0PKXKpqAji0Lr+ln6zqpTMPm6HNYfa5k9
M+QroLlNu2debdam0OKuJgfydZVMvi6HlWu+OesHfQF00MqHPZdWa1Pobysi
c9aPVDL5uhzmihz3dLz8GdDjRnGvdfupTaGv3RFlFy5SMvm65vu2n3HF7Nwn
QJ8ZbDYv9b02ha57+sz1sJuSydfloM35nlMdkAnoJZtG3vJO1qbQmyAynXVR
yeTrcpgc+W3X9hMfAb3CIcVzQrQ2hV6z4KRB4GMlk69rtj9xafUH7w+A3tg3
6HbdNW0KPePDt1TzLCWTr8shWHDP4s+h94DuDWdSHwZoU+jPx2sPRfCVTL4u
h/vzSgKDPd8B+oaZzc6dB7QpdGbSiZEj9VVMvi6HEFcLvVT3DED/8i8x6bcd
++1yWCSc8vrdGBWTr2vO14nmgouu6YD23mLQ8mOVNoXWmfxb226ZisnXFRB5
wdnw9M40QNdET7h8fbY2hR7+6ErBl70qJl9XwIRNkU/EW98CWmdVnwWLJ2hT
6OblmTs3B6qYfF0B+ilJY+s2pQI6e9fUt3rm2hR6g8XpgyUJKiZfV8Dq4/d+
BK97A+gek864fuihTaG/Xaw1c81TMfm6Ahx9bp7aa08DWvrstEUAR5tCd79U
90ggVjH5ugJC7rHNx0S/BnT/waNPT5doUeiMxLD6Iz3UTL6ugKUxDc/qw14B
evl+4tpSpkWh1/Y4bqY9Qc3k6wpwCwjeePbaC0BPfap0eJWnRaFPX+POD1il
ZvJ1BbwITFk85EIyoG/XHZ3inob9dgWkmbPP9j+A/XYF8MZv837gnwTo6DGi
teOfalHouNDec4OuqZl8XQEPfWpG6Xk/BbRquY87/54WhebYa/cfkKxm8nUF
BDir1aL98YBeIZKFPQ7UotD2vbvR4T/UTL6uAJe+hQu2ucYB+jd/g9WuE1oU
ep7xjJtDm9VMvq6A/6z9vdQfYgEt6lXSPGSfFoXu+2WqblzvFiZf1+z/le8T
cpOjAb1i4Fe7Ukfst2uOl5TNjpOnYL9d831tUfg43o8A9MX6ltO3lmlR6BIz
rbo0hxYmX1eAd8izuZnXwwG9rdB05JYZWhR6nO2LyMmHW5h8XQHJP3bseqkX
Augn2d89+1tpUehb65YZpN9sYfJ1BZiL8jNONVwCdMXj8/oFA7Uo9Njwsj+z
XmG/XQHV12QPL1w7DujrrdTXotBZ3SJKsv60MM87VIB80bzxmf6zAB20IsHF
XluLQn9fFWK+WNXC5O0K+Fwy237t16Pt7v/8fsTokhZAuw+KfVipp8U8L1EB
ude2T7g+5CJBZ40O/Br3pgXQ11tfHoD9dgWMCRzd5VDiNYJOmJZpNOwO9ts1
38fmPmLnUVrM8xUVcOXh5lNfv4UR9PyDhW+ij7UAeu3bbmEPQIvptyugW21E
aZH8HkFH/yhpstjUAujYwAsnahdrMc9jVMD+LSfPG3SOJuiyvMBd96EF0Bd6
TJg/YhP22xWa3+P8E7Z9Ywn61fTi0sEDWgBturGrnuseLeb5jQqYs2dVT9Ij
jqCV12/oRajVgPZNiG96eAz77QrY/GLV/sD+8QTtcDXmvXmhGtC5iTE36y5p
0f/ydAV8KLTe2tP8KUEbWr0KuZ2iBrS0YmDC6DtaTL9dCcdDD1cEjsR+uxIm
zb7+xvwW9tuVUPZnbJjLEy36X56uhG0qblbw+GSCHnap5UrUETWgayceS4p9
o8X025XA3ucQFj/tBUFn2Xf6brZODejrufKr9dla9LG2PF0J+eHr7kTNekXQ
ovE1QZFT1YDmlXcaP7JEi+m3K2Hu3KEHHi96TdBHdp3vMLgv9tuVMGP+88Ou
Quy3K+HjZNfeD4fRBP3OPmddjFwF6Fu5wdkxLOy3KyGsS2bX+5ZvCHrhba7x
8F8qQP+KU+6pMcB+uxL6TDpretMqlaBV1x/djH2uArRvgkX80EHYb1fC04aw
L1smvCXoYawR/mNDVICuVVdbbxuL/XYlBAW+2b1sShpBn//Mi0/0UgF6cm+l
eaStNtNvV4LJ2Y9JI2zSCTr0kfnOKfYqQMdHu2SWLMd+uxIMKjZ0tZiRQdA2
g7qrX0xUAXpzg+SY6VZtpt+uhJ3DD72umvWOoANfjK6aYaQC9LO7lWc3eGC/
XQnzIiZU/Zn3nqAPDG92TJMqAT3L+cSXW37aTL9dCYUPTLc8W/SBoP1ibhrO
+64E9OthVp6/r2oz/XYluCs+xPgs/UjQV+ioTlmJ2G/XfJ6wWLlRJPbblbDo
YFrF6pWZBP19zxCdlUFKQAfNcfFemajN9NuVUNCcbmKy5hNBp1GVit8eSkDf
3qjLupKuzfTblbCW+vlCte4zQUvyI+ZuWqEENPfqw99fv2kz/XbN8dcrjaRu
+kLQdUd40ZVjlYA+M105XLdCm+m3K2HVQ879q1u/EvTK+QN2uRoqAf3NYc/8
eVJtpt+u+ff78TLHjcsi6JpJNp+FQuy3K+Fs6aYQfy722zXfw6i+DwyTsgh6
xLjJPQ7nYL9d8987bdmf2hP77Uq4PDR5XtPEbIIOlVyu147HfrsSrDgTO7aY
Y79dcz5e5yzOe55N0F9CbOrOXMZ+uxJ6JxSdnjIR++1KeFX99ELC1ByCvpy+
rJ+hO/bbNePXre/unnOw3645/qOGr7yYkkPQXj0Th4UuUQA6zSOy5slq7Ldr
tu9eopcb5BL0+Gs5m81GKwC97WnPr/Xbsd+uhCFRE0YvepNL0J6rhAmxXRWA
Ts/jRg31wn67Eiznxpw0t80jaLFr0IYJjdhv1xwP8xKztp7Cfrtm/Lofwpek
5RH06OCfJ1K/YL9dCVXjDF/fvo79ds3x71F57NfsbwRdZpqxcd4j7Lcr4UJD
vyW/o7HfroJeOypcH73/RtByJ/+teeex364Cnc+vPvd4jv12FZzaO+bL0fnf
CXrDvX3nNrliv10FSy0zni/+gP12FUTRhlcdPn0n6O9dFQ7VC7HfroIeXr7L
zv7EfrsKphUGbBlul0/Q7h2Mh+wfIQf0e8Uel/RqFtNvV8FV6xvbm77mE/Tv
Pb0rtHXlgL4yR6Tb0sxi+u0qOH7+5s6PS38QdHi/EKfztdhvV0Gc+9hFkzth
v10FFwS0a0juD4IOfXsxoncm9ttVYGWcPHJfH+y3q2DC9Jc9tq78SdDxoy7L
o2Kw364ZR3c8840dhv12FUz3m/jRKv8nQfON9y4aewb77Zrvmz97TcUU7Ler
gOYtfim3x367CrrZjFj6Zif221XQVLRz9YAF2G9XQVBwA/vTr18EvdYhTb1w
XjOgc3NuHVuzFvvtKli4fAS5uO43QY+sHdftj0UzoJ3PlMsu78J+uwpeOWew
Vxf+JuilTl9snDs0A9r+8/Wij4ex3655fUQ33qBNfwi6TjzVRlaJ/XYVnOGU
bGKfw367Cl6cE/UoKf5D0Dn9ThwKeIf9dhVcc389wzoU++0qsJNNDorcUkDQ
I3yf3Oh5H/vtKqixuR/vEYv9dhUIO/VV7SgvIOiZ057Tkf7Yb9cc35vvDXj4
CvvtGk+ddGbY9kKCthC4rx+/DfvtKnDhzVla/gn77Zrj+YbO3tqqQoJ27+0z
KH0W9ttVMHcf5da/APvtKrj3yzIjxvkvQa+e52G3cnAToFf8TrdfWa/D9NtV
4BT7ocPOur8EXXn1c0o5uwnQ58f3HnhepcP02zXnz0LdU90mYr9dczz/bH55
oAz77Zrj2VDHNK0L9ttVcH/pyT78A0UEPWJ1ipCXhv12zfGw4g5X2R/77SrY
ezW086fkIoJ+lzhGHnIP++0q6De4kjXWEvvtKigestAvurmIoLvV/UwZfgL7
7ZrjuaPhQGcb7LdrXrcwtPabgv12zeu7pMUpjthvVwH7I7vrHTvst6vApypn
yMbD2G/XnD9ne7osmYH9dhWYvBB/yN+A/XYVnJgz9cfkV8UEbbOuxLB0oAzQ
xdl6nnq7sd+ugmBb8TIDVTFBjy88+d1TWwboim4pV2f6YL9dBbMTnmvXTcN+
uwrWmw9q6ViM/XbN8e3ipnX4IvbbVbDZYuOct97Yb1dB1q4l627T2G/XjN8f
87PjwrDfroa7Xe+b3SIlBD3KK9Z1TDj229VQ9XbovMrH2G/XzKsVBQkeWthv
VwPF0o9K98F+uxqKvGUj+tNs5vnAamjuYTB//vRSgmZLpL8cNkoB7X3S78qy
LOy3qyGl37ECE1/st2s+nwAuN9pgv13z+XibJp4qYjPPk9G4SXeaNLWUoKtO
HCz2M5YCWtfG9mIKn83029VQPpZHMnWw364GvW1HTPqosd+u+byf3jQKtTjM
82TUUJCauzdsZhlBXzEOnh1XIAH0M/7TP0P0sd+uhp7DD1XsPVlG0PtrUs/N
TsF+uxoyztx+vm4gh3mejBouPTB7NjujjKAnxbhG/AmVALps2IeHl8dgv10N
iz94s3rzsN+uBvubtPe+I9hv16xj4sOojOkc5nkyahhUo4ivnlNO0A2dfM07
r5MA+rT8tYt8Kfbb1TCuernPy1PYb1fDts6rqLtTsd+uhkXyvL+WjhzmeTJq
eLA78cLZD+UEPWxu5KQpfSWArl37sNRxL/bb1TDT5tOPtZ2w366GwqIQwxw5
9tvVcLnrWGmwL4d5frIafiXOXD98QQVBG0auX+r8Swxoz5FL8z9ewX675vOa
3RonP4v9djV8dn1SznqB/XY19Jk35Lz6Lod53rIaju/McH3/qYKgqcx+H26G
iAG96YZ7X6sE7LerYXPa9EdBXbDfroas/n8txh/Efrsaerlf2uX0lsM8n1kN
8WfjQx3tKgl6yIuoJ1/sxYCuuzvi/vVc7Ler4fz1mGbLi9hvV8OLhGEndkzC
frtmf0Y5v84sxec5q2HBDQOl/GslQf+Klx5n9RIDOjCKTdQiDtNvV4PJyReq
jG7Yb1fDnhTT46Ey7LerYe4dNzKGjc9/VsOyLUv2XV5aRdCrv6yePTFfBOi8
XnnrtnbHfrsaVsbo6zlcwX67Zp0/TNaUk4T9djUEOfudCDbjMs+L1owniQ7L
B+VWETQVuWyVW7AI0Jsefs97Pw777WrYWTS1V70h9tvV8Klryb6Onthv1+zf
Jr3Zipn4fGk1XPt6s+HpimqCHtcr/lTkShGgK0RRU0euxH67GpKiT449EoT9
djVEDp9WMX089tvVYOlcrLvRCZ9HrYbDv0S+tt+rCTrVwN+msLsI0GHSV0WX
9mO/XTMe+XiRjkbYb1fDIdrW5LAY++1qeDugcHfqSS7z/Go1LI1RzP+6uoag
fwzzdeiVJwT01ZrXOaIg7Le3QDKfJ7t6vYagI3hH/BITsN/eApbKN9MGR3Hp
f8+zboG3Vj3mrGl/3nUL3N62f93y9uddt8CThelLVyVhv70FDo082KV/H+y3
t4DtTtuDgr3Yb2+BDQs22AZk4POxW+DPm6bCIodagjYIO3Hp4jIhoA+Mfj0x
+Tv221tAf/D2sRE3awnay3VhxUgr/P/dtMDMDz91qyu4zPO0Nf99QMefTn9q
CXqm9WHDz/pCQBdunuHZW4b/fxzN+59Q7xjSH/vtmvd/fWyBiwD77S2QFg6/
5vF4dMe2QE6zPb1/TKtaX0fQS0WGxZ2zBYC253p2PWTEo9viVtsWiDKet+W/
23UE/XDPWrsHcQJAx8zJsY8Zgv32FkivW/tux986gr7dcVnogkvYb2+BMYrv
Y35N5NFtcdzyFjjinL7YwqSeoFPn9/9Ru1sA6DAHgWGnudhvbwHfL/0LKzZh
v70FSC/BpXOLsd/eAuH7Ap5NtufRbXHN1hYwveE/NfJOPUE3xv9fw92HNBHH
cRwfUdwfNSFnC4IoehBiG1MbDNfse4PIzFo2H/+wlnOoWxoJixIqKFcZ9oSl
E53ByppTK9aDGEkXVIxMrWVzlkZtMHWBdzfI0RP9uuK+f77+O+73++eONx+9
RaVOALrpdsRoq8G+nUCdfbLPEp1n0MPDst6xlASgO1cle9uPUc/+f847hPvy
a6hjzXqWQe8/7ck6zPKADm69NxNowr5duK/nzN6pSuzbCdj0BcrUMezbCYxE
wvFkOyXuyRDw+GR/XN0sg85QJCUP7/CArvnqJBt92LcL91O/pcsUYxl0S4XF
X3IR+3YC2jdGb9FjStyTIfDbvK5Lms4x6EVvD2X+qOUBTVw7qhtfYd9OIE/b
yQSqsG8nUG7NWuvehX07gXejM5z/AyXuyRBwG3NUp7wcg75fVmEDJQ9ob+Ge
/C9xStyTIdAT75fr5jgGrWz2fYsu5QFt1/WdSflJiXsyBE7mXRqQhjlAH2i5
Wfd8gaLRhqnBDQ1p2LcLz9+W+6C4Dft24f3EgrWtMezbhfenKU8PaXhxP0a4
/+fv1lwv5gBtv6HoqA5RNFr1pOd1RjH27QTUR8dXzKVxgB755Fiie4l9u3Be
2+QLzUd4cT+GwOjiTbHM9yygNxt2Nix7RNHojhMHpbOt2LcTcGVHth+/in07
gSrj4PLP3di3E9BUXp42DPDifgyBkhe36gMmFtDyetu0/xpFo0OrVbnuCV78
v07AtE9rk6WygC4K7/7odGLfTqB0rzU/meTF/Zh/5zlUZg7OA1opV0+UOiga
7R33FBasxL5dQp+d/W7sv4J9u4SOZj+VKazYt0vonAuNkz5tgvkL2H+GXw==

                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H53 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{53}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 28->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HdcTf8fwPG7r1lGIrNsKrNkxPtklBmJKDsKoYwQJWSvpGxflBEZycjI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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83HdcTX0cB/Bb3YGMhCQ0JDM7e3yPIiEinoREJLsoeyZCRUZGEYkoRGaK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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H55 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{55}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 29->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJxc3XVcVM37N/DtVewWCzuQWxSwMK5jYGJ3IxaicCsqNgaKGGCCKKKCimIi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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJxd3XVUVFsbBnBiQrELuzDwWtiF+h4Lu70mBnYnKmIrKnYrBip2d4vusQMD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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H57 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{57}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 30->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJxd3XVYVM3bB/AtFhELxRZsxQ4MVPQ+diFiECoG2KiYYIuJioqKHdgdGIhi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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJxd3XVYVNkbB/BhGECxO7DbFTvWfo9Yazdiru3qunZgd/0M7O4u7Ba9V+xA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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H59 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{59}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 31->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83HVYU20YBvBtwKYYoIKBjagIioFdz1GxWzFQFGwFMSkBAxMwwEDFbjFQ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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83HdcTX0cwPFzmySkzGREsjVFwvegQcajrKTskJXKzGggMxGJZDZEiaam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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H61 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{61}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 32->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR
5kIDdUOdigkoKEtnpE1rqDU1TC0ETyDIwkylEENQ3jkeeTmc5ny+180e/2Gf
Pdv543dfv/u+HL0sfsEKV5PJ9JWLyfTk72cdKWezsuq1hTfmDPT3by8c/NGG
1Y7cB+IfLyWOiDjcKJ7vbSm9nN8sTiw+pWVUtYjfdfgNDbrZKn5xyskW+602
8d3lPsX51e3q9zO/yzPXdIhTrOM/97xnE4eYjiworHskHjl1jLelwS5uij7o
Nrbxsfj8/pdvVTZ3itPLsgrS2rrEZjev7QG2bvHEGRkrGuw94s5VAwMPdDnE
V3J3DJnn6BXvqvBodjqdYvL76dOQ8DKfVskPkx8mP0x+mPww+WHyk9/X88Pk
h8kPkx8mP0x+mPww+WHyw+SHyQ+THya/00+tkR8mP0x+mPww+WHyw+Qnv6/n
h8kPkx8mP0x+mPww+WHyw+SHyQ+THyY/bOivZuivZuivZuivZuivZuivZuiv
ZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivFjTBuWfu
gQat4fXrW0Z4txTW7ux850TeQzH54i/t7bZBR5vEOyevD525qEUcFtnh3bi4
VTxpn6XfQXObuKek6VZIWLu4pDf2lGtEhzjbr357QaRNvDLqyb9H4oDsu4FD
Y+ziZ0rDvUpiH4v/dLnTnBzXKT48zXzFx9IlXhdz41B1Qrf47ZyFSbsSe8SD
yiven5XkEP/TL2SiLblXfDzgD9ejG51i8sTkWffUGnli8sTkickTkycmT0ye
mDwxeWLyxOSJyROTJyZPTJ6YPDF5YvLE5InJE9Nn8qXPmD5j+ozpM6bPmD7L
7+t9xvQZ02dMnzF9xvQZ02dMnzF9xvQZ02dMPuRFPph8MPlg8sHkg8lHfl/P
B5MPJh9MPph8MPlg8sHkg8kHkw8mH2PfriUsc/E2qbysTy15YfLC5IXJC5MX
Ji/5fT0vTF6YvDB5YfLC5IXJC5MXJi9MXpi8MP3Dkz7Z4bnE0iD5lfy+9Zdz
iQ/FUb6b40dtaBK7XQ0ccPHNFnF579n7CbNaxQf9Xv11XFCbOD7qdFbV7Hbx
G9n+a7fN7RB7lp6cM3OeTfy3i+/YxpBH4mPTjnXnhtrFSTETKkMWPRYH5xw5
7rqkU+xVPia1wNwlrut36OOosG7xqYAR04dG9IhTV2c/XxLpEIce8qpLjuoV
j67MKPSJcYrJD5MfeYa3xg8LLFImT9y7eNXVPKsy84vJG2dfWL7BvUKZ/PHw
jBNfF8Qqcx74QdGk+Kg4Zc4H/9yd/95QizLnhbdNHj+qJEGZ88MfRh5+nJyo
zHni8ftGl/skKXO+2FaSm1+drMx54996h2/atVGZ88d7/LKWzkpRZh5wZNQQ
f9tmZeYDT8ne43E0TZl5wS6lA2oXb1NmfnCZy45z/dOVmSfJe5rH3nM7lJkv
vCZm65q4XcrMG56R4x40KkOZ+435437D3G+Y+w1zv2HuN8z9Jr+v32+Y+w1z
v2HuN8z9hrnfMPcb5n7D3G+Y+w1zv2H2M8x+htnHMPsYZh+Tfuv7GGYfk/tS
38cw+xhmH8PsY5h9DLOPYfYxzD6G2ccw+xhmH8PsY3j3+ba30i+r99N3XGNb
c7GaL2t63TehZWq+Vnb8+8GZSjVfbr5Nmzwb+7wHEbHmwmaVX97e+/6Wtj7v
QfGK58baVH6ao6a20t7nPZgSfj6tS+V3e/ntvQGOPu9B5tK4BqfKL9laFXTA
VeUVbFo4cp67yuulqRV257Mqr7ro+dd+6K/yOrPf+m2kp8ortSw4ZfAAlVeo
W9GSokEqL/qI3eOuH0trUGb+6Cv54p7dHv/1X6f2E+YTkz/O7HLfF5ek9hfm
F3M+ePoy0+yKjWq/Yb4x54frl3/RM+yi+s78y3ujn6+8F5ldldbL6jv9kPdH
P3+8xbr++41F6jv9wcyHvCcmW+orJeo7/ZL3SZ8fPG7q2rAaq/pO/zDzJe9N
dPP0jDL1nX7K+6XPH760f/ULQRXqO/3FzKe8R2X1dfZK9Z1+y/umzy+OcIu+
kF+lvtN/zHzLezWjNtN8U5n7Qd4/ff6xc1WExfO2MvcHph/ynuXeCS6sVuZ+
kfdR7w/OqTCPsdQoc/9g+iXv3TN/dY25p8z9JO+n3j8887VF1yvrlLm/5D3V
+4npo3Efk/tb7x9mH8P0Te5zff/C9Auzf2H6hNm/MP0R6/sXpi+Y/QvTD7G+
f2H6gNm/MPMv1vcvzLxj9i/MfIv1/Qszz5j9CzO/Yn3/wswrZv/CzKdY378w
8yj/H9H3L8z8ifX9CzNv+H+BjgH0
                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M
d96X92O+O1fekZ3ZOUnK1NzMnEJmdqqbFca1GgBqfFYLKAoUA6rrGb+poWsR
oLbeFwfq6FoCqA+UAkoDKUAZoCxQV+9LAvV05Xc1NR7nWw+M19gNNAZ/v47r
1LqaAZWAykBjoDxQAWiia0Wgud5XAVYBY7S/tcA4zdkIKKffrwYytdc1wFjt
taHWzu+aamzOvQGYoH2nAW2BdsBWYLL2vQmYqL1uBiapNu2BdGAgcCYwRfNs
A7K0p+1Atva0A5iq+XcC01SDLcDpqtNG4DTVeAYwXTXoB7QEWmm+dpo/FWgN
tAEG6NpW6+L7DsAgXTsCQ4HOQBegv8bj7wfrfSdgiK78ri/QQnOfBZyheg/T
GF2BEUA3oLuF76hPVSAD6AH0BEbp2svCg9X1XcKLvKcH6Rd6o4RqQF2KSGd+
V1TveT9a4/UGRmp+zpfwMceaDczUHspp7dSotOpNHctIZ96Xl278LuFF3leW
DtSrlH5HP1SUnvyukt7zPtEb3MNw1Yk12gXMUj1bqL59gANAjjTbC8yTlvuA
+dL0IJArLQ8BC6XZ2UCe9DgG5Guuw8AiaXkEWCxN9wMLLDy0B5hr4YGjwBKt
dTcwx8IfXGs/rfUEsFxangRWSAN+11/fcaxU3XMO+pW9dQ6wTBol/JqqvaXp
/jiwVFpugpkqevRJwsfpVuDRwdrnCNWYexuqd6zFMN1zrJH6jnNn6J7+Y55U
1fUU8YRfM7S30brvqnk4Lj2RZeETejdT4/GePdJQ2rOX6UV6lrlH39KX4/WM
Hpmob+mpSXrG3zNPUvQbZh3938AiK+rr3WQ947uxWgvnm6B56MtsrZe1ylc9
qOks6UbPssb0LT0+Xc86qsaD9N0cK8iaedKNmC+dCfqqvZAj3ejzmZqTc0zV
uvgu1wpyZ5E05PqWSivqmKfaE0u0D75bJq2I5dKKOqySFhxrscbgO3q1t64r
xTn3Qs3P+q1WDVnvNaordVsrHVjX9aottd2gelPDjdKRGm6SjtRqs/SiVluk
F7XdKg3pF54f1DzLImcbSbdt0o412666UasdqiW12im9WONdSdruTtJtj7Rj
r+9N0nBfkob7kzQ8kKThwSStDiXV7LDqRi/zXK8lDY+o9tTtqHSjViekFTU8
ZgV+PC7NqeFJacWD5EaLviwMfos0KQp+m+Z08JukeSHwm6UhvcOsoUeK4Pmt
0rAY+O3SkL5gbtIbJfD8TmlYEvwuaVgK/G5pWBr8HmlYVlr9/zcRnt8rPSuA
PyitioPfIY+UA79f2pYHf0DalgW/T/oz5x6StpXAH5a2zcEfk7Y9wV+WPn3A
X5U+g8DfVu3TwN+UPv3BX5du3cBflM5twZ+WLzqAPytfdAZ/Xr4YB/6pajkF
/GuLvhkB/r60rQx+rkVujgL/UNoOBX9XNc4E/1g6J/xH733DOnn0araH3tT6
E83Nea/m2B5euY46eHjoGou/dembL6iVh3euZb09tP+MOnv4jtfP5cGvtB/u
5XrW3sNz0zz8RC99y9p7ZMEcDw/RPzM8fEaPzfLwJT35HfXxyIvvgdkeefGR
9p+vNX4pj6eDX27RP03A/7Xo4VrgP1lkSg3wHyz6Kgv8BovMquJRO9atNvjP
FrnTEPwvi7xoBP63RV40Bv/HIi/qgf9mkUF1wX+1yKbqHuvmmuuA/2KRXw3A
/7DIphTwPy2yqT747xb5Vc1j/9x7VY/asW41wX+0yMpO4Bda5E5v8Ess8qUr
+EUWGdQP/FKLrBkOfqVFfw4Bv8IiUwaAX2aRQWM8/EFv9AC/2CK/xnr4g95o
CX6eRSa2B7/AIgczwK+yyKbJHj6gB8Z7eIj+aQN+vkWGTvTwH71HTeZ66ELd
Nntox9qs9qhPnkeOMEOWeWQHc4NzjvaYl/oP9vDABxb9w955y6Kf2cvc9zCP
vb9h0dvsa9ZgoEcdWKeRHrV6x6L32HdPAi08/v5lDVp71OEpi/5n7z9n0fPs
96YeucPMeQRo5vH/x+NAK4/z5FGLPGIWUc8uHpo+Y5Ej7G3WrJ1H3V6yyCzm
Fb0w38MP1KGjhxYvWGQTc4le6O7hh/cssiZP8z9hsQb6er2Ht1d45C+zd4NH
/jJ753mcEzwj6PelHp6nR3p5+IT+Xe7hYfZcjkff0YOpHj5c55HX2eCrPPKa
Wf2KRf4ye9lbGz36i72y0qNf2ItrPfrxNYssZg6v8TgPssAXeJxJPI9yPc4M
nhf5HmcPzx324mKPfmTf9PXonUUe5xbPLPbxEo9eZh4s9MiE/wDEuW/v
                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83XdcT98fB/DP/pCdJCNCIspORN7XTlJWISvZZCUro4iUMkL2TtmUkSjO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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTW8cwPHqjhAiqfxEMrKSokTiW0ZGRkRIVlRkhEjICCFFkoaRpIEQ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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H63 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{63}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 33->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83XdcTX0cwPHqrmQVylZWdkhk5fsLJSUlCmUUSiWbohQSskJWUhmFbCJk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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XlcDP8fwPHU7iK5KoQcKUdCSSFH73HkLHRIIUeKpEKIHLkiR1JUyJUo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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H65 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{65}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 34->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83Hk8FP8fwPGdXUenTpVK90GJktKl96SESqcOpVNJUehQ0U2HDpQOutCd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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83Xk8FP8fwPHdlUInciQpOlQqpRQ63lMi9a2oREr3LV1SqaQkSqUoRJeQ
JB2IyDXu+z4iXaLLbbHY3dnd39C8f/3zezwffn1rdmdmP5/XfPaT5p7jG/dz
WCzW8GEs1sD/Pggc+NUEZsu/2v/YHAtoueYDw9+GsAh0q45eU3CimFx50/6P
MKIJNB9Fa82MKAR0xjidkLuJbALtXBSRVHeDItudQX9HYhOsvTuVqNmXBuip
NhzHdUPZBPr9OqHK/m4RGXBMwS2toAme3JjCro0oB7SlzxTWYn0Ogd7y9b3E
009Irtj1q0zrcxPkbLMKMQ8qB/S5wjU9TfM5BHrUYTuVWQFCsnVDgoZ7SxMs
P/Q6P1i1FtAyr/UNx0pJEejOMF+vGj6f9DceOKAmmGs59bX0yEpAe7x8Fvd0
N4dA97x875u6REgS9NGsHtEMHjrOK86tLwf0SXfz6aUzOARag7fr7e5XQrJ5
2jyZV+rN4Hxgc9uJjZ8AXfbq5YT1M6UI9O7nL7P2RvJJX9UhVqNmN8Ozacs3
PlmbAWg7hSm/8qewCfSsz/H69u9F5DK5mtATS5thZ9T6HaGphYAe2vJTvzmJ
TaB7Ziz01blOkX+FEdyKdc3w6XbJXAvlQkC3/x0htT+aTaCnzvnN139MkXfb
Bt7AZri8X0aH+6QK0FEjdk/9do9DoJ/+XhpnXCsgl3w397p/rBnmqqec6Eyu
ArRHqMqoJ/c5BLonoawxs0xA/qbfPb5LMygbG570uZwB6Hm+iiqy09kE+nFN
bXnbWxHpncGbbnunGRS/Ls+SGlkO6JDF152eanIIdNL1jlFkspA0is07kxpE
v376ATYdY4oBbe0WyBtVzibQm/hFYxu2U+TPsIdZk6KaYVlsgdrGTWWAvm5l
Y2wnxyHQnRvXndNpEZK37w+csM0Q7WNidi04E9Djba46qhqxCXTBuj7l0psi
0sBzOX3GNoPJ7g2eqy+VAnqssl9ATx+bQNdUVpcoj6HIhvNj36z60QwRfx8m
/7SoBLTSxXv31e04BPqj9KeyHB0heWvg8uQ2Q7Jf7TfFx2WATlD4fCFEkUOg
fepWyyTVCsmFA6crpwUUm+uWz92UC+jgNxOGzD/NJtCpIVl9gUoisn7g7VNo
gWfPI/3+2lcBusoxTuGxF4dAWyv71WX/FJA3Bg5HqwVCrhzZ3vuiHNCWJ14X
atDXO3rLxLBDGfT1vmD+wK8WyH9zf52yWTmgP/Fi8jn09YVeP/aBveC1kPw2
Zairn3ELdO4M3vQ3LAPQEiUj9x0z2QSaU3WTtyJSRF5X/lTSt6kFIqy7H22p
ygX0Bf1ST5OLbAI93G93q6O0iNSjr86t+1qgS/IqOzSgCNCS0q1LbuSzCTRn
15prLfYU+YXvYpfs2AITrO6UPa6qBXRWs3ziPTUpAn1u5pebtQV80qNl8IYE
vDmfrngPzwF0x93ZMh92sQm0Zt2zDq9lInLu14EDon//sV11h5/c/b9NXfy3
eMRJAP01LbZyyVRWWh19NI1h9P///vHldztyAe3EV57Cd2ETaPmRFfEjOSLy
alpBsMn7FrBd5OQ9e3QJoM+4DfvUVc8m0GP5nevUllHknJjHHeE5LeC8LUHu
aUopoBPcI1l1QjaB9u55If5PhiJr6buRXA39ehdEvNz3phrQ5oab/YriOAR6
t9fm6gO+AvKK38ANuAX2y3fFaoxLB7SypnmLjzybQFem7J7x5YuI1Lk28Aa2
QLNU/uujQ9IBDd5f6kzHsAm023fTNQ7fRWS1UxN9B26FyWPqwtyKKgA9ZEWS
o7cNh0D3XfBU/r5WSF6i3717qq2gmnRCAs0FgI4Z3icJfcMm0I//yrMSQihy
hu0d+o7UCsqB264XyxUA2ueDe+2rp2wC/fVWz/rnqRRZuW7PmC2GrXBwsr8l
7/4nQB/NuvtSrCdFoKedrXvJecAnLw58vK5uBUna8HRJbDmgJzlp9gct5BDo
tNEpo9PuCkntgY+bra0QcJpQ9ptUBuh3o/JCFIZwCPSDhuOJdX1Csnzg9mvX
Cs3X4vsTJxUB+pLTzbfDM9gEWmp009O/FyjywsDt6HwrnMsf8/KhUQmgA0YE
J0Y0sgl0+e+UG68MKHLqwOV5sxXqpj50+nsuE9A7YjyvPVnEJtAmD1s7M7xF
ZOnA6fqwFTY/t1W0vFoO6ELfI1duzOUQ6CMfpwubnwjJcwNv3yv676Nyq+1Y
VTygk3fZnw1NZRHo68u05T9cEZOTBw4nuRVOx5+VrakuAfTZC/dPbG9jE2h5
2XINk6kUWVw08KsVIjoXp1+SFAN6OKlI9X1nE+gW19phYwiKPJsapKb7lT4/
7OYaL9b9CGjLkQcO/cnmEGibX/N15zkKSM0oh0M+ba2Qp7F1vNwsEtC9ZXUW
u/gsAj12x5odMFJMFtJXZ7eoFW55z82KKSwHtIKCx5YzhhwC/fVz93pFLyF5
+t7AgKINJOIx2YeEFYCunxiienQnh0ATaUklU5cLyYnuAzekNiig0jbtOJ8I
6N/DnnRVVLII9PzOTLWtW8Rk/pmBA2qDT3Ebm4te1QA6yWrN40Aeh0Df2Hgk
u2isgDxFH40ztMEoJ+Dddq4BNKcj/JtPB4dAU5pRK75MEpATtu5b/N28DTyl
m82ePC8AtM3T2z8Pv2QTaHOyYeGsSIrM/W8R/QnbBnnsCumaplxAq0/afuIx
fT9E55ImE7Pp++HJpQMDqDY4Agudna/VALot1+NORyeHQE890VU/SUNAjtcd
uAG3gYLW/vk5AeWAXvHMPkeVHq+ineOnnSoJFJLZkwbfQPC+p7d05ZVsQBvO
qDSesoVNoG+/tnGKNxeRxweGx8FtsP3lmOPssApAr1VqmP3UkkOgD1cvfkZa
CclxA8PFmDbYqbjm3ZPzGYBeGLygJUKbTaB9U/xnvIoSkZkDw6eMNuiJeXMp
1zwb0LotgrOUJZtAh8yQGzPMSkQeHRhOVLTBtiuv2AV5xYCelqf29NYXNoGO
O15A/jalSJWBj9fGNvg+57lU+9YaQH/Jdkzb3sIh0GaOypdWzhCQ6QMfN91t
0Fp+SbaEKgf0MoFueiBwCLT78KcXiy4LySMDt98h7bBXvOHm+P9qAF0Edif3
NnEI9MHLOhMMZwtIpYHb0dh2EK/u5eyMzAL00326nXFr2AQ6bWHwRF87EUkO
XJ5T2mHbWOWVoc9KAG26e/mCNc1sAn166cX7R3Qo8vDA6arfDm7fFD6HDEkG
dI9/rfLUehaBVq1YXxEHYlJx4O0zaYfkjz+vZrPzAG2/bv0W9ctsAj19/17z
XAlFpgwcjlU7LJm5VX55YgWgzUx0tMysOQT65OmIpOMbhOTBAwO/2iFKBbZu
6SIBndpfnnFXwiLQ7qNsz9exxKT8FkN6hNwOi5L6edHuFYA+qEIue2/BIdB6
5a5X7u0Qkkn0aFHnWjs4xh8ym/++HNDtyiMP59CfR+jJFb9mn6I/j/YvHpgQ
tMNx1TdWd7U/AXpUZvWarilSBPrnOUu78e/55OjZAwOKdjBKjeU1+OYB+ud/
23TXe7IJtOGh1cF72yjyg8bADakdBJNb91stLwI0kbHjgFIWm0C7Xlgxv/os
Re4dM3BA7eC8UjBcwTYF0FMqdnrXN7MIdMI24vuymWJyJGdgRDHw+y+vyess
BnTCsBdXR9D3f7R359ve38spMr5bVOXU1A43vVYFhu6pAHQ0d/opy7UcAv1Y
/c0464NCcvfA9JbfDvcrzTkTPbMBbSia0ulD3x/QXtLvJ35ZLyKHD0z35DrA
19xo/G7/QkDzn72TP/CBTaBHvQ/4Mt+LIuMGpj9qHcD6sWNe6uwyQE/6opMT
L80h0GmrXpzy7hGSOwemAzodoLK2z2SNayWg3ZpSzWac4BBowawrx15PFJKD
w+PFHbDj2crprUmVgL7lK+N+8SyHQP/92M4bIi8kB4eL/3WAgZ/Cg4g/xYC2
nBEceP4bm0DbvE4pkjOmyMHhk20HfD2ar6S5OhPQ3/xt5e8uYBPolRWmXz/7
i8jB4YR9BxivsE5lpWYCeorjr+H1i9kEOkFF/y9cF5GDd1/nDkjR/jXHV7UE
0M4b21d4/mATaJltk8+3LaHIwY8brw5YOFondVRgLaD/7M6u0VSUItB6S05b
JH/ik4O338cdsNZO3BO1rQTQYb/NRyf9YhPo93q7fnguoMjB29GbDtgjz2ud
rVEIaOUNpd8a6Pk7umr77hVGjyhy8PJM7QCP+QY77t6oAvTJobn/bfThEGiN
7pOHtn0VkIOna0kHPFq7edH10nJA+0Y0D+XS4wf0p1czuybcEpKDb9/3Dpin
z9F/fqQS0M9Nn+Y4HuUQ6FgH0kF5qpD8dzgdkKr5eJWaehag1SvOPUtfzibQ
edtGxDs7i0jW4K9OCLj5bKVAVAHoUz6+ZiQ9PkGrff14zJUQMuP5Tpj/6Mv9
Jk4toD3uCfW2s6QIdHetzAMTCZ98ya2gR9Sd8L3KTrlk5wdAh1u9OyEuYBHo
mI2BGlJ2Ymb83wlhcx8cnZGTD2i50E/+ex7h+L8TWj6srTDKpUjLxoFg0Amr
vak+o6OlgJbOv/S2spdNoPuOsoK3KOB8oRPcRDHXFTRzAF2re3O6/B6cL3SC
xdOmN18Xi0hx1cABdYLfNyWtVytiAM17M2a30l0WgVYJ+ba0+rOYmV90guny
1LkXwt0BPUglFoG+6PZENrpKQr7IGRgQdUKoeOLbpWZVgK6SNMYN8+QQaGuW
gW9nm4CZj3RCRdJD++O7swGdkpTfq2zFJtAe1+0VKjaJyI0Ds9sNnfDRT+7C
N+t8QG+PiPpz0Y9NoE1eP5k7pJpi5i+d0HRi7Dq1DTh/6YQJt0NWT5bD+Usn
5DQm2n9oEZLUQM7a0wkGQZrqdpa5gO4ZlxFseppNoMcVXUh2UBIx851O4IzT
NL/1MQ3Q3vJdWYdG4nynE+q/jD8z55eIfD6Qgxw6Yd+obKflU6sAXRSsqvvi
KodAH0wuCX7bK2DmR51w+cRj0LfOAbRMDX/Tqf04P+qEzg0jtozTF5EWAznF
jT6fzq8//vJxPqDf/ul5XhfIJtChc5Vj1hThfKoTGldfT5voWwHoJbLy/W4b
OQT6WtvX0f1bhaRgIEfc64SEkmkZfrMqAF3zaWXCXRMOgd649sydOkchM//q
hJPSljsWf/X8v3nWxp4mRRJAD/54HCvt2cB0PrQTtJsdVhQpxwJ6w33FPe+f
sgj0jvLaxfdSxcx8rROmfep41OJfDOi7opIPxz6xCfTnIXtuaa2jyPUDp2ss
fb5YXQsX7qoAdFFzp+NE+vMUfXimhnI6/Xn6b/7WCfqRutHLpasBfZA3deGL
pxwCPV8p9t7bVAHZP3A4WfT5cnnrXJellYDWsBie8/Ygh0Bn7mw69XSukJkP
dsLTH9eFVeaZgFa7nWAuWoDzQfrv13h7lzT9eRQyMB2r6oRH/XtP/vxQAeix
l2bdXkKP39Cf2OGNHvT47d/8sBMWb/5y8AFUAzr8hnBtdzjOHzshulnmwLgo
Abl2YDrzi76f/EdGHS+uBfSJJpXe1+OkCPTE2WWKz4r4zHyTPj9CUl449tUC
ekOsil+7hhSB3nG/rForg0/2DkwHeJ0gn9u45bd75P+d+8OguGyyBNDqd/YG
qhxjpf2bf9Kv18HzmfKsNEA7P1+kzmaxCbTMO+9ckUREPh0YTg/lwpmrp3a6
VD/4v9vnXRn60lcCaNk/qdRLfVbav/kqF/Yrj735Wa4K0MVX9pzc5orzWS4c
FBhNWC0SkGsGhqPKXIi+vb09UC0X0C21v55EnGQT6JnrF2S8Uhcx818uVJZU
X+dapAG6zdZLdbQ0m0BPM/1V8oMnInsGhnPTuOCzyNHw3fI8QJ8zvj9//FU2
gR51rjwgv49i5stcqP/vW+J1w3JAO+dvU5mnjfNlLsgcNSt/HC0knwwMhxZx
IW5csG3sjo+AXjTZ9+bHQg6Bvveh5u/GQzi/5kL3T69Jn09lA9r8m0zMUms2
gd5j3P7w6gYRaTYwnFjFhdhz4vFXy+IAXdL9fdLVNywCvV+VSO0LETPzcS6I
V6wXOw4vA/SuvPygY2wOgSaO26dpiYRk18DH6xYurJbXfb2zqBDQStwKQXYy
m0DXTNgq5+iB83cu7H6W3OnkVwho04Lhd6w/4PydC45H/v6woMe3jwZuv4e4
8N71cN9C5ypAL5rb9s3jDodA3w2auqKrXsDM97lQblrWMcSqDNB1MoLHaXI4
3+fC2vbhWS7NQtJ04PJ04sLvG0Wx4b0VgN7uE9hbtYNDoE2/FilYrRAyfYAL
Dy8FbzCWLga0QEVN37KMTaBHlhX6We+kyM6Bt8+TC/w202Oj3UsBXX/sZ69F
P5tAL9dapLBjNMX0BC4En3jNH/ujGNByNQ/M5b9hT+BC64aCXV/p8fO/539c
qPA8fm+boADQj/sXfgh7yybQOaPuesU+pZj+wAX5DSxzr48Z8H9Ld1Ydms0m
0N94E63mhImY54lcyOt3HdW3uwDQtyb+PTHxOT5P5MKfNF2N9HcU0yu44K9R
+VuJXQ7oyr11yVqTOAR6q8F/HomkkHn+yIUbj8I7gy9nAzr/nNxEuS34/JEL
x0e0pLeYY9/gwg/xVzc+pwzQX8gLc3eyOATa7LJM0HKJkHleyYWOyvCE9oAi
QMPFGy2389kE+op0y/QGe4rpIfT14vNg0svcXECPj5ANOe+MPYQLBa9bk+SG
iZjnm1yYzyHKK8/XANqUNf381g58vsmFU5K3w//TFDD9hAsTmsuthnWUADpE
4+jpznY2gU7OmKo0UYtinodyodPJ0vGB/HdAa9y5sX5+Az4P5ULWj+Y9gYv7
md7ChRSzk+kW5pWAVp0xR7X5MPYW+vp4HVqqM0vIPD/lwoPMxkzj9jpAn3Jy
dsrbLkWg1UYPG318JZ/pM11QltfSJ/WkCNBeyS5QT7+e6N8eHFegX89/z1O7
4FawQ/KRsDJA61nePvt6LD5v7YLH1o1jwj4KmZ7TBdd/3I1d/181oOfZ3v14
OIJDoJ+s+rxx1msB83y2C0bNvBFuczsP0MEhTg9+XWcT6NTEUYUL2imm/3TB
8antiQ6nswFt3fBGx9oa+08XbFwc8mIDff/897y2C87dOrfd1DYV0PuKWvQa
ulgE2uDg9AeL1cRML+qChB/hxp515YBeRDlO37CYQ6DvDlN+u91TyDz/7YKH
Q19sWL65CNB2l9WULLPx+W8XzJYUVFufppi+1AXFc6Xe1MWTgPYYd6I6VcQi
0N1FEzdfGSJmnhd3QbnKbaFKbRmgBRknJZzxHAI94rw6W5AvZHpUF5jpHhG4
RVcCumn/uktzz2CP6oI5C/azgxSFzPPlLgjbPfGhEucVoK9dtLeSOcEi0N1D
tDd1TJQw/Yp+fTvM3Mb05gGad3uBzO47bAKt3ODfsfQHxTyP7gKZnVL9allR
gO5XS6uZ5MEi0GMKLlmkdovJwbxzpgtso+yybhVkA3popGnRC1s2ge6JcDj4
xlTEPL/ugt4nZQ73JxcAukN29lnDEHx+3QWarWHyXkkUOZhHrnVBX937IVKK
hYB+e/S/uXPp+Ts6eMrhoKDHFPO8uwsWPpDNN95fBuhV8zXPvRiBz7u7wCEw
ZeTb30JyMC/c74IzAVwdJ4MUQGfd2pme2cQi0Od+ExedZomZ5+NdYPn9r2s1
lAO6efzSKAE93kDr5LkHyUUJycHpeXgXaHEbFFZ7lAF6yg5brfwxHAKdYLwq
6eg3IfM8vQtmxl/YmDO8AtC/zpgXOC3H5+n08SnsPjLqopAcnO4ldMGDFUY6
O2alA3rms3cN2QpsAv06PsDIsU7EPH/vAv+kXMpsyV1An73D93GawiLQCj9G
fBkVLyEHpwN5XRAO8epWYemAFpwq3L1ZjU2gh6seXrK5EJ/Xd4HUpSuNlw/m
AbpT22CUkwc+r++CSVF3Gkd3U+TgcPFTF4gePtA2HBL9fxNWHkeTO8SArq9a
kq95nZX27/l9FwzbOPPPCbIY0JPCHEb1fWYTaDJOrVHejCIHhxNN9PV97e7k
7X1vAK2x5rbj1wssAp19pFHZREbCrAfogo9vpIQnN1QD+vPpXTDnJa4H6II1
Y8E1NFJADn7c8LtA4jqq4e7tbEBP+jtpThP9eYpO000Nnb1exKwf6IZdrW3B
U2YVATrnm8aajAxcP9ANjisyjlw4T5GDtyO5bhjWeTXMcGUZoNlPohZck+EQ
aHHmE39uu5BZb9ANFwyOKdXdjwd01snIstRkFoF2Uo/YccVDTA6ermrdsP9z
WEPW80RAf56jpL2wmkWg14RUR9/bLGbWJ3TD2a3n5Qs35gE6PEwlepY7m0BH
x5Y9fs6jyMHD0emGoPa+d1KnywBdJXI583QUh0BvGcJRJBtwPUM3rDyXnDfH
Lg7QBY0mZzZEsgi0vYGj4vYIMdNLu0GlpO73o+IcQP94dbTkkz2bQC99PmXv
2mkiZv1DNySxLv4J2VMI6BFlZ+fMfI/rH7qhaeeY0Mh7FNNXu0HztGbWZ6VM
QG9UWZG8fR721W6wLb9wbeVjXC9B/zzzkmHFunRA61P3J38di+slusF/WFmC
yUcR02O74ZtDSVbF8HJA25YEbjmvySHQZnuL1g9PETLrK+jj83n0ZO2yDEBr
5Dfl/5yM6yvo9/voLPuFCdhv6fOtb9UQCCwG9JlLKzvvfcJ+2w1j2Wcn1q7F
9Rjd8GypKX9EYBmgY3OnB2kqcgj0/RNv0pM/CZne2w3z5UJST/hnAzp0UvPw
gzbYe7shMVXn77x1InJwuufeDVE3bybP55YB+sxJn7PTNDgEeuyEr2PeZQqZ
PtwN/ektDm/bigE9KXlOXx09PkenXwuRX7OCIgenA37d8OvQB/mL8sWAvu0/
vlylnE2gGyvytpdtp5ie3A1+BUom6evLAL3pQ8j0WlkOgd7mlfjGvFVIDg4X
w7rh0n1YtkC2EtCdXbnXpu3mEOhJaic6Y5YKmf7cDXnEvOaH6h8BPW666cV7
mRwCXfL2lPQnJwE5OJx4T78+LkvnVDnlAbqlpnGF1zU2gZ5pYXD+Vyf26m7Q
4WzJiRiaA+jJl/c/stvFJtBJkgW5M0FEDn7c5NDX5+zSpulqRYD+3PXodkg6
m0CvUctpSHSmmL7dDfVbTYJs4rBv0+dn5N/5kQuxb9PnZ8ScgIi7QnLwdlRD
v56+8QsdnN4BOiw5zifzIYtAx3v4fnHKEzM9vBseOap4PjMrA7Rvu5bPWFns
4d3wSSvx68c2ITl4uv6h/z5n5y9fE1IBaOrYNLPVlhwCLaP17vhRa+zn3dD1
UBzh/yED0GRTkF2gDvbzbrgyK21m8QtcD9MN+e3ve+NHlwC67diRS8J6XA/T
DdpaM9iyyyimt/fAnlVvmjprygHdmqc/QWyEvb0Hph/zzZa6gb29B2L2emTr
eqQAWmP+LJd5rSwCnR0YLvVYW8z09h64rV10nGOeAuglu10UnZqxt/fAtaVS
n0brYG/vAc8FWg9mOFUC2sd05Xzp4xwC/c3hbCBPU8j09h54tbVSX/1RCaAj
9bdnpjdhb++Bl74m55xnYW/vgUDZv+Pa5bMB/eDykx8aG7C390CxOGNJxnbs
7T2QYyPcVnOvEtCGRy61nHfgEOjbM9gz5MYLmd7eAweveSe0ZxUD+oyMZ8v6
L2wCrdjRNn3PKorp7fTxsv9Ees0rBvS4E6l1qpVsAl060W1NiQ3F9PYe0Dc5
73p5aCmgNz1TkTnUib29B2ziyzp0J1JMb++Bk+VRm56LswGtMnLx/uad2Nt7
oOKXp74OIWJ6ew80QPgIs6OlgBafKrhc1csm0ENUj4itFCimt/eA0ttXizZf
KAA0t+D8prhw7O09MMFOzsYvimJ6ew8kv61ljb+aA2jqxsio5Yewt/eATPPP
IGdd7O09cIx/0k1ZqQLQc+BYWcgK7O098Mx18s7E80Kmt/dAbauDsw8b1yP1
QMmcXJVx9djbe2B/yMmyYqCY3k6f/8Kynrinb/7vqU42FgI5CaDbjStrrpxn
pf3r6fT55bVhUeiTSkDHzWs+UHUKe3sP+D3S0bNWxd7eA/NM9cO3hOYBeq/l
qRv6N9gE2sh6XItvC8X09R4Iu3XC22xTMaALZIZ5LqhmE+gj7dw2/80U+a+n
98B5Q6FFUGsaoAPejeblj2IT6PKAeiX7BhHT2+nz9eFUryznckA7vHvmE6DL
IdDqge+/lDwVMr29B3JtLLk/J5cB2vDmzCfOQ7C30/+9ppeZQ/uwt/dABCfs
lJFjPqB1LIzCje/jeir69dt5M9qpnGJ6ew+Mb7a44SJTBOiQUWF/r6WxCXRK
Q9ycThdcf9UDug/cZ/QtLQO06bu5v1KHcQi0Y+AT/SudQqa390Ah21K+cWIB
oCcQSvPEwWwCnXup+rFUMq7Xot/vsZuev5gQC+jwAD2TtqcsAh1d8uD01FQx
09t7QM9y34dzUumANjbxf7hoDJtAnz9dmef9XcT0dvr+6Avbn2/KB/RafuV+
Iz82gT44csuCm9UU09d74MLnifauRwoAnSBKV054zibQPkOcK+7EUMx6sB54
bPxrce2ER/93l92YoOt3JIC+VnA2arEBK+1fT+eBSbpro/zoIkCPVTfQ4NKv
P7om907mBPr1/9fTedC9OPzKAt0yQLv8sfT+LY29nQdS86y+6/UImd7Og6IF
jrLc4mxArzO+P+a7LfZ2Hhw4V/5tuSn2dh5EvivbtHpNFaBPK5+fudqTQ6CV
KodHHm0TML2dB4+Sj788uy4f0AXC5+drfLG388BeJkZuw0fs7TyQG/r0dcfL
dEDvZtUJ3tDzQTRI/pMLKRAxvZ0HXkLOow7NckA77LzcvXQK9nYeTFguUb0a
L2R6Ow9m5W+9VcQlAb364559tyUsAn10k9GiRpaY6e088EtdNG9ZZiKgeSme
3HEfsbfzQOVqq3rRJuztPGBn+F5+HZMN6ElrZWtnbsP1bzxIO9hm/nK1iOnt
PMiZ56RnkpMJaHU37U37lmBv50EuP8pm0TUR09t5MP1ByAJL5yJAh8xYY5yd
i72dB0mvjpw7fQJ7Ow+cVEdIe72LBXTWrumHHoWxiP//fNlb3dxYMdPbeXDh
9Gh2tksqoF9dkJne280i0C9kOt4qqoqZ3s4Dzr4kpfAH1YC+bB/fYPkOezsP
WNo+RlaBuB6PBydPJAZEmWNv58Gw8Juywirs7Tzoiv7bKmuFvZ0HNtXTq0jD
WkBHqrkLFg2TItAvC3hy3lw+09t54H9sWW+LTRqgm37vJZ9IY2/nwWw9A9eM
HhHT23lAni6o25dZAmjb8FfrFrZib+eBWfTzffe0sbfTP6dChv44lQ7oHF27
MctUsLfzwPGpzne3cuztPJg3Kc4oxrsC0EOfWa1S3sgh0D3xG09WbsP1gTz4
O5zYI5+L6wN5kMqaonxyFq4P5IGbOL5yQriI6e080I1o2kO8x97Og3sP5gzd
tw17Ow/qCkK6F63G3k6f/2OzdhdERgM6eNKoTTu8WAQ6JbXRxviXmOntPNCZ
/UZj9JVsQFc2NHMnbcHezoNtRjPVU81x/SF9/VT0eLvY5QNae93opnB/7O08
iNn/Y3ZUBcX0dh6E3ymy59dWA5rnEzh7YhL2dh4ofyl6lu6JvZ0HDZ9rXJSm
FwM69WKbtWsF9nYeXB0y1UK0FXs7D5x/3H2wS6cc0HNtNyraT+UQ6OBV2z5p
xwmZ3s4D+Ws/CP09JYA+qTrKcvJvNoHWKG20/jCfYno7D27yFU7uPVsF6Hk7
tY613sbvK/Hg8fKkydoNAqa394Kx79bbvdtyAL0y4tchcj/29l5wer1gjusC
EdPbe+E7Rzapc5bf/837rLh0baQE0EMVzvywmclKGxw+je2FkqCzPz8npANa
dG5Vqtd4NoEeOuKk2888EdPbeyGJv2G68mjs7b3waKL7Hu5l7O29kJ/GM5og
psjBj9cpvfTnR/H0rSNyAD2m8lZINj0fRNfb/E50XIa9vRciG00bHl8rBPTi
Y1O+nUvA70/1ws3J8cYj7lDk4O1XvxcSF416ZRGSB2jnxjS5qfR4DC1r6NIc
R4/H/vX0XtCs8MlZURgLaJ/bC5S3PmcR6G8N/pX/vROTg5enSS+c1fTviJ6Z
COgR0c53NpezCHTT46E/LLdjb++FTYrUGcnyCkDbXfneDmbY23tBR0hoXT4u
JAffPqteuBEaQT1VzAa04YOC0Ub0/AV9p9Cu/iY9f/nX03vh2Avj70eb8wB9
zajn6/PbbALddUNlZUwDRQ7m9AO98OWPgWdBRC2gKXXtDYZKUgRaNid6u1c1
n+ntA6/HRbUPG8sBXRFtPtl6Jn7/qxdsH+36sCFSyPR2+vybN3uTKbcU0KqV
evvHSrC390K5zQP9GjbF9PZeyPF//9BCHnt7L9gfTpJVCsbe3gvasz1bq1Ow
t/eCWdHeFq++SkB7nrNP4bpwCHT7CG13dY6Q6e298KlBoC8cWQHobbbkAXI5
9vZeWLPKVc/VGXt7LyQHcgK7OjIB/WiG9wzJMjaBznv1/RX7iojp7b0w//76
9zaifECfatr3sDoIv4/WC2qzF+ZbplFMb+8F1o9kju6UUkCPKdHpXNHFJtD1
e19MPD8ev7/WCxlgcMx8aw6gKbfG3mf09Y6W6TdQeE9f7/96ei+Adndum1Ep
oB31Ln150429nX4/HrJXhahSTG/vhbqaZr/3FvmAdnm94/BwP/y+Wy9Ih62Y
3USPV//19F5wrU4OX3mnHNBRD/p8/87jEOinBWM+znkkZHp7L7Df+JkUN+QD
un6rTdWsJ9jbe4FYs876eSb29l6Q2Me1XixNAfShyP0dF9pZBHpuxAJNmcli
5vt0vRA7/rvVhr9pgE7iHlVyH4W9nb6e1KdU8+j50b+e3gvLV8zYc3JsOaDN
ppvMuq3FIdAn3p4Ob0zE79/1QoOwJfrstHRAp5IaFw4qsAn01csZsvM+i5je
3gsxo68WigvSAC0kElrfjsDe3gtyLnemPf2Nvb0P3vv6WNn54/f1+uC/cYfD
DpzD3t4Hh4tnx+mNFDG9vQ92eeit3zk3D9AHpjf2SLuxCfSCt4bKPXyK6e19
kCJdc6jFPx/Qtie83h8LZBNos4m/7moVU0xv74M3hRudf8d+BPQZmxuljz5y
CPTYdS27cjbi9wHpn7+YNtnLMAfQ1+z0KgL2Ym/vA+7Mh9tKDERMb6eP72at
oSynEtCH5RdrL9+Fvb0PZn/1jL4I2Nv7IH/GcbuJCvmAftz1vFfTh02gc9Vi
FJK/Ukxv7wOHro16V0tJQPvev6vpLGYR6E9ldcnDpMRMb++DHIX3M/74lgB6
1u6HDuubsLf3QfjSfLW9s7G390GAMCs0UD4N0InmSx6MY2Nv7wOvXdcKi0TY
2/sg+GbWmeaWOkA7+tSuv7hdikCrfl2/R9qEz/T2Pqh9dKQmzTUM0KfebJca
ZsUi0ONCV/K5myRMb6ePL4pcGyr3HtDuov1qm6NYBLpvyILCzUFiprfT50s0
56LdgVxAK+uUhR84g729DyojdkbpKYqY3t4HzzLnZHPmZQLaqHXjrDHz2QT6
lvbW8O+BuL66D44UPFKSH1EK6PAiG/n0TuztffDuwNqvFzUo5vuSfbAp2p74
E1YO6Jn+I/8mL+AQ6MjKn7oe/tjb+8B/WNd81r0yQHcTLkN3KXAItJqLVDd8
FjLfp+yD+JdKNyZsLQZ05Nbg2uBqNoGOWJOyPtkSe3sfvN4R5jb5ThygeTMn
qJ97xSLQSi+zc0eGi8l/37fsg/pug/XeQ8sA7ayRK1vB4hBomcyTrdvE2Nv7
4JJmn06tAa73pt9/B/KK1ztc790HZeNdBT8DKOb7m31wr26M38M5xYCOGLnh
Q1MFfn+Tvl5/bveatRV7ex8s9dHR3fWzHNDTHX5J31qC68P7IHq8fs8fDyHz
fc8+0DyybE37uipA7ytelZ9Cz8fRBvtPHL3aiuvJ+8DO/di8dKVsQFv/VVa0
pccn6E26FZ9W0eOTf9//7AM3u1CVxHnlgLY42rNi0TT8fmgf7Jyqct7nHa4/
74OTXfYbtSdnAFq7dNppPS02gY7ZHaP0MEnEfJ+0D8aPMzC88ToD0Hdd74XW
zsTvk/bBV6o2Yf1LEdPb6fvXva3jpa3LAb1n45HQeno8g168bcaHZS+F5KzB
w6H/+/5vF8y1egHoLakVaVt2swi0udtWl/VLJUxv74f93gdL7gckAdptyanU
rC8sAi3wGOd2xlRMfhzs6f2walV455NNRYB2dJTrMMxmE2gVlRbNW6cpprf3
Q9eOv9rjefmA7nB3idlAjzfQWj2ch7bpFNPb+6HQJGfKBWlc394P2/etjbH2
xvXt9J+/6OBDi++4vr0fbr74LKuwpBDQnomPJ6W/w95O/3k3slIvBmBv74ee
1e/a32bg92H7IWhBi3jmK+zt/ZDhP4PzMpxiens/cHmcdccPlwB6p25Zjz89
P0KvCN6pXKGH35/th8slnZVJ+dWALhvncn7RBw6B3lUkNdzHS8D09n6I1Vtd
sCIzAdD+qzcqq+WwCHS1/bbKwlNiprfTf744N76KVQboIkm/vxoLv2/bD4dY
oyoKJEKmt/fDsOsWe79kZQD6sox+zrpZ2Nv7QdLud2pfOPb2fjh9Ljvrt30O
oO9br7UvOYC9vR/KLQ5q79UTMb29H4YPOxT3PiYe0AZEZJxfCotA37kU4Vt1
Vcz09n6YKHus23gYrm/vh7v1C8GRhb29H74su+uqIsHeTr9+6x/KtvvmALot
NrB+/WE2gZ7mX7Rsz2wR09v7wftr7elHDgmAbs150+ibySLQ2g4hBh+dxExf
74cZcRUznEyzAb1J5/GVg5a4vr0ftkVkC+Zai5j17f0QEBE96TeRDOh1XtLz
hjWwCPSBXz2PuYvFTG+n/z6vdvasO5QN6HyByferVtjb++GYnOPy3o34/WL6
/RKrG8RMTwd0fanr5JsK2Nv7AXZRCU11Iqa398PfjVf320zKAfQcky3+0nuw
t/dD6Gnzyp7F2Nv7obJ0WLpqlPf/nV4vfAQpEkA/HX1l3i5NVtq/nk77ieVD
dZ1SQDevjsuPpsf/6Fn2fvaP1Cimt/dDY0uxe21pHqBTv9leF93C3t4PV1eY
dgz5jb2dfj/2PKTGNeYBWut9ftC829jb+yHpnn3ao0bs7f2w+Ow9AxmVSkD/
OaYw7Mce7O39ME/rM3epEfb2fojIDZ6+NDIV0EtHmTTZ8FgE2r3x9Oy1SmKm
t/dDwjA3pwuvswHtPPd6fM1WNoGWDerwtlgjYnp7P5gJql56excA+pn5aznZ
COzt/RC/K6y57TXF9PZ+iGKbtr+bVwzo8bt+Lhtfib29Hwpg0ZV8G+zt9PV9
LM+wQvsjoOtGGq4SZHEI9LqfXieHnxEwfb0fJvzdWTysrhLQQ0SRfOICfv+6
H/jSL0a4yAqZ9ex82BevYD7iaQagz+hws1gzsbfzYWzEhDPiSBHT2/kw52GE
z3/OOYB+F6j2Iesgm0A/KCrwOjNXxPR2PmwKtnrUPjMF0MPjGhytm1gEusXP
SHnDbDHT2/ngJt2gJrhbBugowtZ4pwL2dj4Euaw6t5weL/3r6Xy4deFlgubm
ckA7mCstekZ/PqIn7K72iac/H//1dD7kJETscw/JAvSth2uspq/B3s6HP3l2
m94ewd7Oh/nNn+sml2YAOjT19dIu+v6JTrzy7Or45yKmt/MhMmbGk7DKIkDr
PGywMSrG9e30z/ON1t7cTzG9nQ+2U47ofjz+BtA+r1K2kOewt/Ph6/Or611H
SJjezgfDgMunX+XFAzpjyKu9JqksAu3cG25w2k3M9HY+zB7tYV+vhuvb+dC9
K2/om2js7XxQW3a8K/QRrm/nQ3iBjgrXvQzQm8/90kodwyHQViP1E92+CZne
zodH6x56s6aUArouVlaWoO8P6LX+rW2XxlNMb6ff/ybfNydcKgCt+bhCqcQc
17fzISV7a9XeXbi+nQ+lL+0TZiiVAXqr38hFYRzs7fR/v/qnT5wA17fzocRk
92L3NVWATpxuH27hid9/p9/vN9rRO9oETG/ng27uTLDpSQG0oRU/P6SDRaC9
No20T5wkZno7fb7eEpsu+lwJ6Mfl3/8eoK8vdLYtMUePvr7+9XQ+XHNeKXW5
JR/QeasWsBKeYG/nw/ET9yV3MrC388FPX2bNMhfs7XywcXv6s/H/vZ0P6/ip
Cw3KsLfzIa45Zswvfg2grbcrhyyRYG+nrz+TyiQPtoDp7XxQ5znM2/cjG9Ab
dVWMlXdgb6fPx+Dyc5XG2Nv5EL93dF7UhXJAn21ljzujyyHQCtpUsWKwkOnt
fFhi4e/pQo8f0EP2B/7NPYDf3+dDv37xnBN6uB8XH1TVu2qCHmJvp89nzUui
DzbY2/lwMZktfWst9nb6fCBPrFCzSAK02F2x4nIdi0BL9dRuE68RM72dD/43
517TOp8P6A8yp6aH3GcTaK/2cW+TynB/APr84oVMFcoVAtpKd2vM2yjs7fT1
EPzfw6dPsLfzgS035FScYjGgnxJzrReXswl0mkvQBs/tFNPb+SAvrRKy1KYA
0BtOaNbdC8PezocdE1P+q43F3k5fnxOuhw0tLQF0hesWu85WNoHeTq3XmTiN
Ynq7AO5dfm70aUEaoGUPvby3Tgp7uwDadSNr9/GxtwvggFtF366WXEAvnH5x
9HsXNoG+91b6xz2OiFnfLgBXu2k+F9tyAP3igMKnmmO4X4EAovQ+r7PQwt4u
ACurG0vY0mmA3h+Wp2jBwt4uAP24Y7U76fHev54ugM7K+7uluioA7SLQsyd2
cAj0kOEPtC8ZC5neLoAtS5ZNX7kRe7sAchrdVkyJw94ugNMG/efj/bC308cb
vlS4sqkK0G2xB4OmP+YQ6Gn+c9PfZAuY3i4A6RMtM/hULaDZx5ZODZooRaAl
k93j0tP4TG8XwJ8TV6oe7ygG9Chts69N9Pwd3Rh93GSWJe6HJoBkkem6BU7J
gG5fZBeS3sgi0FO8dZKcDcRMbxeA8uTTZw20igA9b+PZa5MzsLcL4PE2eW7C
Bdw/jX6/Tn+aaWlUCOgt91+vCHuHvV0AFuXPzscFYG8XwNvFsawbF2MA/TVY
2qL1HotAmyT37NSuFTO9XQD+M5dnpjW8B/RmWbWhyvG4vl0A1m2F3ZU+uL6d
Pr6o33r53sWAHn1kzr0Rn7C3C6BhRuin3+uwtwvA0uzL9DOOpYB2z/Las6oP
e7sAes/8NDopj71dAGa3h615PysX0D+dnu4rdMD17QJYNIpceFgN93MTwAT1
yUEvqFxAZ8zr8iy4xCbQzo/Gt9qxRExvF8Dsvr0Ti85WAfq3S6sb/zaHQOtz
tPtHNAiY3k6fv0raKfoBWYDecrJim9tq7O306z9hmxnfXsT0dgH4zdZpqAvK
A/SnGK03Ik/s7QJY9yAxdEgr9nYBxBeIs7zGFQI6stX8S0A09nYBREzbtaqE
/nz/19MFYFA+JCiFUwZo7Qf176zp+SM6pnBZgIUE95cTgIxV9zSp71WATrf7
tq/+IYdAu8w0Xgh5Aqa3069fsteyJydwfbsAij7/bZRVwfXtAjhkNsegtRzX
t9Pv76eXr/b9cAP0IBVZBHrdy+cLl9ZKmN4uAM2hiq7uu/IAvWeu/BYZDzaB
XhL01byjG/evE0C0wNpwwfoyQFtJZl7LkcX96+g/n/2S69AqZHq7APrcXM/s
OJwM6EkjYrvXNOL6dvr4/9xXtTMUM71dAAnv+pUvf8gA9JKbx9kBOtjbBeDZ
NElU+gJ7O31/49YPWZleBehlGo8uTw/gEOirmbniN6UCprcLoSExTmJrUALo
N9uEpe6N2NuF8MxMdlePAa5vF8JBO9WPP5RwfbsQ1o3MNErm4Pp2IT0/PXfj
mgDXtwvBdXT4EZXDZYDu/OHYpjUS99MTwqQlylMTfwmZ3k7//p96tu7GZYD2
svWIPCGDvV0Iv027X2h0CJneLoSoAPKx4aIsQN/kfw48ZYy9XQjNI8yKVM9h
b6ePpz/VQNopH9A3Om5uukx/XqNbJ/3dIqE/r//1dPrnGiWTL4aXALrpx5KK
s83Y24Wgu8Rj2xgd7O1CiFneBq3xVYBe+EJ0TeSP+4EIwfftkM4hFQKmtwth
yLyHeySjcgE95t2M3o4T2NuFUB/4SnGShojp7UKwvvr9fVxtLqBN+o9uu3kR
e7sQTo+esrppCPZ2IRjkLDwXWYfr24Wwz/5e/MsJuL5dCIban7xfZuH6diHs
n5RnNLKuBtAjh9iELxfi+nYh/OlbF+0sK2B6uxD6xf1H757MBnTnne/Txlnj
+nYhaNYTMcUbcH27ED7nHR5vvqwA0Lcfvef+DMXeLoRfOXfVFybg+nYhGLXN
PyK3vgjQVcvePa/Pwt4uBJsrgTHLzlBMbxdC34aJWxayqwANzVKF0y5zCPQV
nf7DMRIB09uF4Ccnxbssnw3oiLkWo1U34P6EQnj9ZOeP0u0iprcL4eW5sHXa
jpWA1n8b23T1GPZ2IfgH+8/q1cLeLoR0b0GZ1n+5gB4RMXp2jCP2diH8fV0f
9lBZxPR2IchvmOAU658AaM/mtNC4LOztQuiY6ZLgewZ7uxAKb/6+1zQrE9Ap
h5YFlujh/odCuDbHrXjPAxHT2+nzu68h7Mad94AmVXQ3O8eyCLRrWfDmYffF
TG+njyfg8WdflSRAZ7d+eZ5cyyLQZ6eZxnisFzO9XQizXPr7v8qVArrx2p3v
rztxfTv9fnbWE880cH9F+v1WDfps5ZEG6NvcD0f3y+D+ivTvV781Rb9DxPR2
+vXuq45YkhAG6K/W4V31ViwCbWoRrbZso4Tp7UK4+MHYe0V9MaADFg+ZMeQb
m0CXXe973WdMMb1dCCuVZh7Yl4Hr24XwYkX2rbWquL5dCG/Pn/59oFTI9HYh
WJr07WwqzwH0ZkeJn8ZR7O1CsFJhV2VMxd5Onz9KMtP0vfIBvc1118bKAFzf
LoT/RMu22ZRQTG8XQtAR+7XPL6YDOjEnZ18d/XmHvuXgsPC/MtxPhoLDadvn
vYotAvSwL0qZawrZBLp7VdU5u8MU09spuNNeHq7RmwXoJo2LzbvNsbdTMCdD
WmfJbhHT2ylI/hlpMr44C9BrU7fGlq/F3k7BIbc1920PiMjLgz2dgskX98cG
ZWUDusLaVLjalk2gbS1OydqvEjG9nQLe6MJtUdOwt1MgiUqWPhKDvZ0C9hOP
nhkPsbdTEDpvhPprpQpAL/BwDY1bwSHQ97upBN/zQqa3U/A2+Mqc8rA4QI9U
cvSc8xr3k6HgV7VKW0gY7idDwYM8HevIyCJA30h2iEsswPXtFLR5qPndsMP1
7RTMW+4ZHPW5CNCKvqpyScW4vp2CupqSFs99uL6dgiSbXlUjlWpALyrUMP4T
gr2dAp/DGefmJQqY3k6BFjgsdxmB69sp6Jqs8jPXAns7BeoJ5YtO7MDeTsHF
06pXf88sB3TUKLcy26m4nwwFwQ38HaZxuJ8MBRqVHqbhmaGAXjte7fEoc+zt
FBzML8xu2C1hejsF17O/jBwnKQD0lqKv3ty32NspMD+48pv6U4rp7RSs7y08
empZKaD3k18W/unG3k7BQlfTu/NUcb9NCjazVv8nGpoJaGnv2Krjc3F9O32+
fPe3mhSE+8nQTs3pVhyXA+iOI0vAZzf2dgo0p19z/boEezsFl9eoA/dNOqBf
ZHEVO9Rwf0769TqjXqtZIGJ6O33870+qJxoVAPrA+NzgyFDs7RTMzz+Z/CIB
17dT4HWv85r12Y+AdlAQdzaX4H6eFEz4LKUxc4+A6e0UDBm1IVTuXR6g68fo
v5x7E3s7BcQ3v8gnTRTT1ylo3pkySZObDWhJ9XAFhZ24nwwFUpZ/P39eLmLW
t9PnW81CY49vKYBOfT9Or6edRaCv3i16qKKF+4XS14fhNEGtJ65vp8/HvSF3
Hgdgb6fgm0FSfVYJ9nYKai1kZfQmpQF6lN/lSVIc7O0D15c4lS8UMb2dPn9V
XvE7L+H6dgrEV/Qnikdjb6dfD4FvulQ99nYKqo5Bx5Y/VYCua/szoeUR7idD
wX9T5mbNyBEwvZ2CMavSdzwwzgD0ybGtYYZTsLfT53uNduyteOztFGQOm2K2
f3oeoJ2JK5YeV7C3UyBzSWjVLcDeTkGnSvGJkYXZgL5UPqImyhZ7OwWc7b83
PDEVMb2dgk+bJlxPTMkH9LJq1xefH+L6dgrcN1NvzPJwfTsFm8a/rKrifgD0
Z4uw57dLWQT6vx1xMQ27xExvF8E0wTW3uW/yAR1yyUCm8QH2dhEkse50GBbg
+nYRnO85tPrCiDxAm93xj829jL1dBCd/VPifEFNMbxfBt10L74q1ngA6w36K
yGQJ9nYRXJwWL+14TcL0dhHsHXLpt6ZKMqAn988f/aEe91MVQeLogB9ey8RM
bxeB3F+ls2se4fp2EbjuOBmeFYjr20UgWTEh+kwRrm8XQf6W6o6kWdGAznnp
8n2/J4tAn3rJWb6gTcz0dhEsiB52Ugs+APrG0uuK/HwWgW672lE70l7M9HYR
uGdXR082Lgd0dILRmX3Tcb9WEQTdvqG46K2Q6e0iqKg+WzvseBqgt1+8drFz
KJtAm0pzh0zsEjG9nT7+Z6d3bAjA/WREcD+2REdOEfeTof97/ntetHzC/WRE
wJ/GG37GNRHQBhE7o4ZXsQi092si6K+1mOnt9O/33D12UncpoB+rmrL1JLi+
nX69Sk6JHrJxfbsIhvnem9u/qQDQhKGsG4RhbxfBJa82/uU47O0iiFw48S01
pwDQR7q5BR0hbAKtM07dblIixfR2EajoO4V2XsD9ZEQQOvT4WBdz7O3069Gl
WSO1G3s7ff4s0T9yZWM6oHM2vZs2XQnXt4vAcUtgzNtqEdPbRTCG/L4yw7oI
0FzhuinO2bifjAg0ZPbFDzuN+8mI4OfTfrflnCJAj7oBqlPScH07/fOWy6Xx
l3A/GRFsc/zx1W1sEaBNVb4tNUvH3i6C0+XGV49fxN4uApOQDrsx1SSgFS5a
u70Qswj0F+kN/Dcc/Pcp6OvpTf+7KxOCAL2De1B68TIWgTaZMJfn6SZhersI
tD1KZd+vqAR0dqdhutUh3E9GBGc0bl3cqIv7yYhAU6Pn1ILthYBuWA6rKuNw
fbsIlji7nrTxpZjeLoIX6tQC6kwqoH/Vh/+I78b17SJYuCxqibcqrm8XwbM9
Dvaqx7MAPXNargfXFHu7CF69O9ml7oC9XQRnS0sc5sYkANr5jL+bTzb2dhHI
Klb2f3HE3i6Cnu7t59e55wAavofVWB7C3i6CK8tjLax0RUxvF8Gb61Odymuw
t4vg5pYrKhdTsLeLoHm9sEzaHXu7CFLdIo+tXJIN6CUJzaZZm7C3i+D6nZkO
Z7eImN4uAotVcbk33eMAbfRy6Y5Zr1gE+mbkVePwcDHT20Vg1xE46eKlQkD3
PZGt6IvH3i4CxYzWbWO8sbeLwcDWdPPY2RmAztpvaVKuhb1dDOcWWJ/enoi9
XQyTFUX9o20LAK1XfkeSFoa9XQyPttezXGIppreLYWvKirS7DRWAjrSW2bLR
FveTEcNLiw7zbavw3/sQQ59bpsLuqwWABoNZ8qYvsLeLwfVO+NdTb3E/GTF8
5NZOjNMsAvSEO6IN4zNwPxkxZP8YYpt/gWJ6uxiMPp4vPWOTA+h9r/vs7+/H
3i4Gw7Ax08oXiJj9ZMRw1q46jKoqA7T560TfIDXcT0YMe8JufEwrwP1kxND5
dIqDzsQcQI9eoxXftRv3kxFDw5EkHzV6fPhvvxgxvJCMqF1yNg3QgtLLxaeG
4X7FYhi+S7xPlStiersYxt56XaibmwXo9NpEymEt/vsjYnBZf2Oo2kERs5+M
GCzXXMviHasF9Jom74RvI6UI9JHZ326v+MlnersYdly5OitjWTagp5nlabVu
wt4uhtjjxxO16fPz334xYtBqOhPirFIE6LvHtAvOpuN+MmL4ohV9ZMxF3E9G
DLM1PtzqHV4M6EafwkNkGZtAG305NMd1B8XsnyyGxGWK7obqxYBunb8hILOc
TaBnBGwvdbLF3k6fL8OSzhxySQa0UW2ccXcji0DfMvd1GmcgZvZbFoPsJYOS
vUaFgOZea1zy/B2bQE/sNPB4F4D7yYhB3tunUlYhA9DscYaPJ2libxeDuNgr
OzVFxOzPTJ9/fhX6lq/zAW07Y7txNT1eQq96bXJuMz1e+tfTxfD+x9fQUacy
AD3+29LmudrY28WQb3xV50m0iNnPWQwyf76r6yoWA/qEuJirV477OdN/f6l9
6g/+/++ziOHPjCCTdqkIQL9wVv4weh+LQEcPrfSqXyRh9n8Ww4HFMY+1fuL+
z/Tfb/LnGStKcP9nMdxLWP3qwl5c3y6G/4b+Z5RrWgzo/VHPTtlX4fp2MSwK
eq+qbY37RYvB8zJ3c15vKaBlVXe629PjB3RH6XLeNHr88K+ni0FO+fSE6kZc
3y6G3RtqNiz9//p2+v3fvsHWPZNi9pcWw8p7dqsMUssBfWhjm0zuIg6B1t02
tf2kt5Dp7WKoU91qdqwnH9C3g91/mgbh+nYx/EruWeiQjvtRi+G1wVOx2bJ0
QN+Uar7zU5FNoJv7deoX1oqY3k7fX+KO99o+yQS0pfBA6S9D7O1isJHV273g
lojZv1oMFVkvOTGHywD9YMtmYuFIDoEuWr/50r1f+O/RSMBQcIf1yqYQ0M8k
MmkP4rC3S+ADq/1SAf35+28/awl8Wer6NPN4LqC/KcoYUWdwv2sJrKztuDlM
Af/9Ggm4LFbT3SSXA+iEUK5e2C5c3y4B7wT1B3HLRMz+2BIw2Dve6NWtYkAv
eB+cWVDLJtCB95Kd7NZTTG+XwJzbY2Y+Ck0DdKNMcIahHPZ2CRi1p5y/1SJi
9tOWgGp5VGjqtGxAK4xc3HxkI5tAf/3lqTN9m4jp7RJwuLzX4vMk7O0SGGYw
NG5kA/Z2CXTd6fb7uZgiZQeDHP33s761Lmh3EaDPZ9f2jMthE+iRp9crF52i
yMHcaiwBnQa5q5fC0wA9+Q3Rf5b++6OTQl1Gj2nB3i4BM1Lv7bTackA3Wf+u
HrKYQ6DnWMy37PUUkoM5bpMEHk1YKG/5pAbQsZnTrhR0cwh0oFOM0E5VwPR2
CSzXOr8kQL4a0GYr7wybH4K9XQInzv7oDEwSkIO5Zh/9+/vcNb4kJwE6Rben
/vdXFoH2eKqyTG8lrm+XwK6pQ5Mi1+YD2mpPVFKBL/Z2CVguDrpu95EiB6fz
jhLI3cKLk5WUAXpcZOrCHxM5BLok4srdpWm4n4wE3EZOfVeikgboWgu9Fmc2
rm+XgMWOhzOGinA/GQm4N1qZklsqAP2/Hs4upKk4DOPbGIESLhIKikoJkiFJ
9HGRBs9hs691KANZV1pBiR+LiiEoFcxIrUkQEQxmRZiJYVbCwBjoojByB3OO
oC2WYR8guNDKoDq6twPb0+Xv7v+H9714Hx5+51PR2bWH6JMRbNrfWBZrYL9d
cKp9WS9ffA6yOxF54rTRJ2O8/4jvXsvMcs4nI/C21p+sbH0BcqBzzb5bJfTJ
COILce+7p8zbBTO2kt+3jXucnDl3eTLZTT+5wLpRP6Ea93jWFyMoWP1xe4FD
A7n4+9bPRSGzQh7d0Lt7NECfucCRthzdURUH+WpNUeMKF30ygoXKSOnPJj3n
kzHmr6/7Q/B4FGRPODn45wF9MgJ7l9q7MsR+u8GLd0fy+1+C7JxPDvjKmbcL
LhSr/Rk/fTKCsxVDS86uCZCHCzWEEvTJCG4mGnyBw/TJCAZSc/M/Nr8BWRvJ
lOET++2CpiuWnjZjH7O+GGOfvuS3DQ9Ngux4vKplvW5WyBfvT9vG85i3C97b
a/t6XFMgV4xp1dV25u0Cf3O9+9ggfTKCmrpHDzX3a5DrXgXDnnazQt7pjfq3
/FrK5e3GfnW6rAeCMZBnq66ZDhay3y7YVvstc8a4r7N1feP/6Tm1Q43hP1+6
M34jz6KQU9Yxz3Raz+XtJmXiq700/uwtyOE9p/euC9AnY1Kud+xq1qb+Rv4B
1IBwKg==
                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H67 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{67}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 35->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83Hc8Vf8fwPHLvZemBk0qGmhqaaneNyItSaVElHaJ0t6aUpGUBipCQ6WM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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83Xk8VG0bwHHMDNGm0kZJ0kratGi7SqUFKZUkhdCi0kYblSJLKCXRRiSk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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H69 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{69}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 36->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83Xc8Vl8cB3DzuQ1tlSRpl7YSEt9rVBpKSUVI0h6kpZKkRWmjpSi0S/3S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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83Xk8VOsfwHGlmdO+SPumTcrSKhF9J2lPSVKpVEoLad83ElpESIuoVFJC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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H71 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{71}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 37->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fwPE7CxWVrYFEKMoqlN4fMpLta++GkK3IKCMiI9lbFMqWECpO
lHbae++97179bjnvn3++j+cj3+rce865n/M6n/Mx0mH/yu0sBoOhpspgdP/3
wf3uP/WQ07v3hNSqXEBbjgyovi9jEfSlHz+mJqtIqLmX99RKX9XDC99z77Vd
YgFdYFs3PsCZSdCL9pm+/jFZTrV4wLQt4fXQ/vH88hN+0YAevrvXF+F0JkH/
Htd6W/OqnLq3T/tsVGI9dJmnZxoJMwFdNua4pOoki6BJqJqaOUtKzdlWnWZQ
WA8rF9//cOrFJ0A7JnrIjR8zCNpytwr35R8F1bTim753Yz3wR3vn3w4tBDT1
3Cxi5RE2QZ8N87+4ob+YumPTvUH1MCi5a+3ygjBA2ysor4wwBkED+7Rkww0F
RZRbs1C9AcbfChZlhUcB2ubYpWXv1JgEfUKjcduLOjnVMGZSr7e6DbDtmrx6
yJZcQKuHUrrRjSyCrnt4OvbYWAl1awhnTd8JDfDsg8r0rqwMQPOyGbVPNrAI
evAqxaQoOyll3Sf32YFZDTBSfmjjSkkxoJ9v3bfIjmIT9DcyatfuMyKqTvqq
PWNJA5SdyDuX8Ez5c2mL9M3tO16qELTm75uzdN53UDeau99A5d//4trn3LU0
QEceWXpGU5tF0D7ajvKSQillVbrM9+6+BriyzsrM/loqoC/+YfdXETMJusVN
lN+pIaNqlO+e+GQDzFp+4PUrYTqge/VZOo1vzSLo9kbH2wO9pNS13/yxm/wa
4GaOa//83ERA75plcd3zHZOgJ3pfL+a8kFEzP8cf+fmkAQznzn+xzCDp//aw
WKsW9lAG6DlOqySGocyoqhcPY0aENEC9VnjC8c25gJ41x2L9B+X7hT5/4vqS
AOX7dfVu9w7bAHeO9nNMcKwE9JiS6HUdeRyC/mJzdKnOUgE1/eJs5R7bAB9f
8eUhGlmANv/yc3jYGRZB37rtFXVTJqEqjg94v6Bc+f68FBeOKckD9PBppwpj
dNgE/fs2c+GReDF1pfvwbG+AI5PMI+NiswBtGntemHePRdCBrh2aS/9KKPPu
3ZXVCGcq+2Z31GQA+kBRwIaSTSyCHrEg0s5mvpQq6377tBshf+iI16ePFQHa
kj13oJkfm6Avid2zn5SLqEvdm2PQCP3zuy63VKUD2kB6Kv2xFYugI3ozNsec
l1JTp3T/aQSt9/1v3bqeDujfh71uTJ7MImiPAdKCBw+lVImhypnbNo1glfDZ
40B5MqBvLU5SHfyXSdB5zrva0h1llM+g/L/C/xqhVtOyeX1YAaD1HIJnJa1h
E3Ss5cdzu1aKqcnKo3ODUyPcOTFu0I6xCYD+ftfh4PkbTIL2TZup11kgo4rE
J10i3RohLvDioB+34wBt8mBn+sZjTIIOTpq42VZDTp1v7DkhgeqL7Wp5sbmA
Dvi8h1koYhH0zztj5Av7Siiz4u4NaoQ3q8cyjE+mAnqjNyukQsgk6EV8yZOZ
mjKqQLk1lS8a4d2jjeYKbgmg77gmxVJRbILOHrLr0OmTIupcVGLAvLBGMNzc
dcjM8A+gM/imqjYrmQS9acDT9mMb5dTE0MetwbGNIM6qDhDeTwf0k3ArnvUU
FkH/vnR+sNd9KZWnPBv1yW2E1qOxFyxc8wCtnypqc+7LJugY+776kyvFlNft
7hNwI0xZX8P13lkJ6CV3js0eWcAhaOdMdc8fiwSU8YXuN1D5+vrX2dxQbQD0
ayPJtaozKgT9NkStxFzWQWUfrVeegZtgxFl39oa9VYCOLys+vUaHS9AHrOcq
VibwqVPKd+/mkCboZ7fWYv6NMEAvDw+fdOMzg6C3Xr70qPCOghq3yU95RmqC
LvVG5/P26YB+al+cbGbCIugoq3nO/sFSKnOJg+a6GU1QkB0++vfQ34De8m6j
waORTIKe98I2Ii5STnl2f7wubIJ13gYD1pEYQK8ZO+cMdy6ToFd/OCHnucsp
o+6Pmw1NkNkV5jgmshDQktIjyefc2QStRrR3CDTFVHr36ddF+fu475n43O4P
oE/G1cx5vYpJ0NyDk4+/WSOnTnSfjo43weW1eTu9RSWAbu+j806zlE3Qeg0J
L0pmi6jR3YfnZeXPe+TY+sq9ENBnXJtm8fexCVo+xOjcQAMxldq9uz5sgm3e
Zk3tVwoB/Vbz/Cz/g2yCflnSeS5aV0wd63773jYBz655WvObx4C+U7C7YK0l
g6Cz7MYuWn6xixrVvTmRytfzx7pMs7MpgM65PE1jSh6ToFfX3aq+v0xGpSR3
/2mCXj8H3+KEVwHaq5U7+sxELkHLRvC+yAP5lPvPJ8NMi5vgVl2lSZJPFKAv
Wv8NvdKLSdAtXo4Palrk1MiQQzuvNzfB6fpPR8cG5gDazHNQv3lZLIJ+ys0s
P7xWQiUpj85OufL3K/B++OJZFqAXRRz45HaLRdC7L+rfH5QroQ7f7B5QNMP4
IL29quzg/ztV+25M7YIuQN8/8llPfRMjarh39wmpGaxnJQU8XJkN6Jc7Zrj9
95pF0CFmvoPXv5FQCUe6N6gZwubKfkodiwB916fU/dQVNkFntBBNZq2IclVu
jQc0g1feDd8Fk8oAPSLMqXKFOoegqZvmMzbVCim9DU6WpcuaYd6Tll+FtimA
5tXrR/pmMQl6sMnvC1VrZFTcIgvlJ2wz5A1bZDWbkQbojY4XjXoxWARtN6M5
pLVLSh2c1T2AagaPzWUvMoqSAZ3H3TI+JYVJ0Mt5Nm+2O8koHdPuE3AzeE8+
aJ8WdBvQ2yt+P11izCBoc8vjP51edVF/RvS8gZBUvcch/Vw+oL8/WmLywIxN
0L6xTsFJ/mJqf/fwOKAZ6v3Pz/y1OwvQxZnLjY76sgh6/rotH/tVS6ih3cPF
0Ga4fCfwXnC/REDvGnfpmOQpk6BN3zWqq/2UUdHdw6ffzWC4IWCI0d5iQM81
HlD5/B2boN1f5c4Iey6i9nYPJzKaIWqbzo67p0oAPWRPZVNHKpug04xmjBm2
TUQN7v54rWyGXjc6vo2U/wX0iHF+OhmtTIKm3pXHbxwho351f9x0NkOTfJze
t/0RgG5dVh/lWcgg6JHbJpzkLFRQu7tPv5wWsF3Xe0FgfCmgexuX2w4Qswm6
5dWsfbkaImpg9+loQAv4MB4dlwa+AjTrQEPzZWcGQcuGGxvWTe6iqO7D07AF
+Eb9apaH1wFannB2xq2JKgStskd0JTewk9rVvbtOa4ECrzmzx6TEAXri2AFO
GR5Mgn7xIddio4qc6t/99s1rgdTqqGjj4i+Anqiqv6X+PYOgn7VH20wIVFA/
ujdnTQtkjdx+eNqyCkAftl2/OeUmh6AH7V8yb3uegNrh3P2nBfrvO9J0PjYT
0L9TrhanHWUR9Amnirlb+koprXUzlCPkFiixCwsqkZQD+tuNd6++nuQQ9PWC
52+vsYRUhHK0aHyhBbJf/n75Ql4KaJ3VQ7587mITdNLq1Nt3GCJqu2X3BUEL
3NnZcjdvejqg+6fItXWMWARdsJ1TkPBRSvWb0D2gaIH/ygYnr19bCOg+Mq8Z
jS5sgm5UlVwZN15MfdfvPiG1wKaTkjuC+FxAJy8rzdAXswh617bZG35rSChH
ze4NaoHCZ+Wr30xOBrT1sC1fxkczCdo7yeb262MySoPVPaJoAdHtE0/D/2QB
mjrUb9VX5Xgb7TWsfO115Xj7a6c862h9C0iK72isM/wF6LK9+afnaTMJerbh
EoVboZyy7768FbfA8Atz0iw2pwO6ankvSZAxi6Cnb2lVC30ppdS6L/f6tML0
VyF2UxqKAW00cM2u+T/YBB2a/d8EV28R9aX78mdYK3ys1rH18kgDdJgHe+G1
fiyCvqUi3ltaJqW2dl8OGLfCsNAQzRXmKYA2UFPT2p7JJOgf9fXF09bLqJ7h
sWUrvN14bv7euARAR8zbmXXkEZOgL7mZrtWOk1E9w8VFrRD9vvWs9qgSQOfx
PZc7xLAJetkAzlZLdxHVM3za1Aojx7xx0jobDWiHULtBk6YzCdrqoUvmYz85
1TOc2NMKbb1WSicKiwCtP9ultNqfTdAxnsazp/4WUT1nX49WmHL0jTinPQ7Q
Z78+2K93iknQkmuJI/4w5VTPx41vK6SwrAWLL1cC+tNpv1mZFRyCfqAoO7d+
poDqOf0+boWCz+5GqpAM6KUn3A+1Kfc39PbeWjrDj8qontPR+1Z43PRfPfGs
AbSRdNXM5U+4BB3ae83lrb94VM/h+bMVmE9upFlICgFd9p+2ZP4pNkGTdYVq
h5hiqmd3/dsKUctuLX27ORLQJwPdHJorGATNiRhkOXqmgup5+0pbYVGi22mt
3DRAL7zf16xiGIug96ZUPLFMlFL/NqcV4nbUfGn/kwJoD+ctOluLmAStOsUm
YfYCGcXo+dMGW0Zf79vfrQLQ6xY+j+Y85hD0ir1fjwr+COjxfBv4LDi15t6k
UkC316X2mVLDJmj9idsa7k8RUa/bM5Qj6jZYmJk368v8DEDvGhYRnGPLIuiJ
SRdDVu6T0uP/Nti5q5/4Aycb0BOaR3bdfsoi6KDRkcysnxJqVWV3MGgDk3ur
k+MkqYA+u/6Px9suJkFLFh9WCWbI6OuFNrBbLOuXVP8Z0A4Vp9YtDWYQtKUl
Y5njRwWlyOreoDYIm/1LxcUnFNB9+5gvt7nFIOjqxptbj+Uq6OuLNhgx7JL3
xN5JgA4MWFd3IwSvL9ogMnKpaYG/jHoZ2z0gaoODXX6NJjvqAF3UVTkzaagK
Qdsypl/aldxJX4+0Qdvkkv6ueuWAjrwijNm0gEPQPjWaR+YfFFIru69uVyhf
D223mPKGTEAv97o6fZMni6C3SiuuLuBK6euXNii9aRyldiQb0B6HuEd/vWcR
dC8dfj/PQAkl685ZDsr9Q90+qkmrENCXRqrfm+XAJuimyNrUc5Z4vaPcvsvT
rGwGZAPa4+P5HT6BLILu/bjDrDVcQgV156BDbZBhnpmsU1kO6M8pUztjj3II
+q7TnaGH+grp66M2WBPyavGBPV8AfXbJdi/HNwyCljpNk05/paCWd+eUs20w
WOj38jmvCNCVCq3bt5TnK/RMVlF2zm+8nmoDo29ja3nOeYDmDq5+VKKO11Nt
IEifFjunRkxJunPEzTZ4qDHf/2p7CqALtlXVDyllEvQSawuTv7Nl9PVXGxRv
Ouuc8F8YoGuHTV3kH8og6MmJd3dFP1BQz7sv55+1gfPLjhWZU38C2ua234Og
dgZBH88uSwzVVdDXa23wboQq5SCOB7TaoTbjO35Mgm7QGf4ys0xGLe3eXT+3
wRx2hLrf4GpAp0VNjK6cxyXorScDj01349PXd22gOmHfWeM7eYAO+LP3wB9t
NkH/dDMcfrhATIm6NydGebz4rHczdCsCNGfS5avnrrIJWvS4vkJQIaKvB9tg
PWF5mrRWAHrQNTI8KYJD0FmlJ3/t8hFQgd2XY1lt8NHfEv57WgLoHNfaHX2y
2AS9asgks8a1Ivr6sQ1OjL484bhxJqA/OH2ct387i6ADzB+7jZwmpRZ3X85U
K19PuOe1xOA1oLu29TG/uJNB0GzrxpvNE7vo603l/q9nb+MuqQW0+4K8tMcK
LkFrH1y2JYbFowTdlwP8NnjWcMAjcHQmoFfpXV322YlF0Gv/VG67ay6lr0/b
YFzWDh8txwxAe0vUJzksxutT5f7Zp+ax5Q4p9bR7OK3SDgOn9Z88MzkO0Cum
jHwWrRw/ozff//H9qHL8/O96Vfn3ZeXcjW31gOaeOvprkIcKQQuY/TwzVDsp
u+7h6KB2cAwtKz055yWgE71OSXvbMwh6r4TRu2lWF/Xv+rYdJOQuMW9OBrSm
W2+nzL9Mgi4f3Gyx3kFG8bqHc2Pa4ZKRBj/gYSKgj2UsHx7+iknQ/TZu+XX5
rYy+Xm6H3EOa1bNy8wG9sW9gZO1MvF5uB7vKiPNml8SUf/dwyKId7tuvHGF7
pxzQzvcG9LqxnUPQU1NzWgunCunr63Y4GiYKGxSTCejUQaU5XsrxP9ohY/ZK
iXL8b9s9nFjQDlYJW0Y/+JoB6LH5b+Z2rmER9MclL48MXSmlr8fbYSLrqffZ
H4WAns/4fCDEnU3Qbl139Z9oiqmO7o/Xde1gZGgwtID1BdAjtRLSBr1kEPTP
4r1bMj4o6Ov3dmi0vHC21bYI0J61B9r0LrIJmjtJf3hMs4h61H363dkON8gg
3fleiYDu7fTL3vAlk6BbLDytvn6Q0df77SC3tN51fX81oLuuLttQtZFL0KyK
bYssbPnU/O7D86hy/+sa1XJIrxjQTadiNr9/xibocQz3uc++ieg+0A78J67D
lhh+BzTjceZOgwTsA+3AjF03MWKvgmrrfvsutsODg18qNl5LAPSwtcY/ufeZ
BJ2y4tVZXoqM7gntMNmw6KzP1WRA2/ye5VMXzyTo4yfOtU7cJ6P+3f9rh6vT
vw4zC8sHtHbtGnasOZugiyatFLvewP7QDtkq/X9cP5oJ6MJtgRba+7E/tMMi
64hrhSOl9P3EdlAJPCpeIfwJaM0/SX7hQgZBlx3eWXZJU0H3inY4GPy2eNKY
HEC33PpiGRvDImjDnFs+rkck9P3Hdqg/c3jdoIPZgJ4V0jfJQDkeQJ9/UrEr
/JmE7hvtsMbrySGzL2mAXtT2X9+gQSyCdhm+rvJThpS+X9kOIeoP+8uuJwE6
KWTGr+HfmQTt4n/FM8pXRveQdnh/pVBjcHoyoJO+FR/QSmEStMvVufrF22X0
/c12WLLIb86F3lmAdqlfUWd2hkXQEyZsMvWXS+h+0g7Cm97vO89lA/pUaNph
/xAWQbMebhkQ7S+h74e2Q9TE1/0GNhcBOm8ePyDwMd4PbYflbgMjw2NEdG9p
B1PDyI6OU4mAtvltbNoVzCTo4ydeBjBDZPT903bQ18z93OtJOKDPfAuaJ8rC
+6ftoLga6tZvDfaZDjjz9c341msZgG47srpabyWLoEdor54Ws1FK32/tgAZr
ow92HtGAbnXteB1jgfdbO2DUEJ3XR67J6Z7TAQZefVk/xeWA9nl69vT+kxyC
bv0pUoxgC+n7sx1QGqqrNmB1CaA33XE8E5jIJmjbzOnycBcR3X86gDnxZW89
+xxAR3GnBYxKZhH0ad7tH9924P3cDth4MGxE77bfgB60Q+0Gw5RJ0NmT6gsV
AXK6F3XA4pZry4u4FYC+aWk4wP0Mh6ALfL7maskF9P3fDoh7N2ncVSkF6H2+
Cw8WdTEI2rB6j94ChoLuSx1wJ0dzkUGvv4DepfHR0KuMSdATqh+HSa1l9P3i
Dph80Yg1MzsP0GPa55LgYWyC/qx35NTHRDHdozrA37X4slavckDXbRI6cOZg
j+qASfO1ZgpPCOn7yx3gVXFhppMwB9DLZcsvNJXg/eUO2Ka6pX3MHAndrzrg
oN6IHF3rEkC/Z8c8iI5jE/RzkXvi0QMi+n50BwQuf744zhfvR3dAn3mJbkUi
vB/dAU2Hdw9a0FdG9eSdIx1QvIo9TD49HdCPXMiz4UYsgk4Yf+p71Ecpff+6
A7wLmDe+8fD+dQessCTad/9//7oDtl48VZjuJaV68siFDliotfDLkH2FgB5n
8GpQ9F42Qb+PeJdxzFBM3+/ugMv70z4M52QCul1Dwj+7jUXQelVqA0TWUqon
L9xV7l8jBp8NenP+/45KF4e+zOgCdM+XBzGi/t3/7oCZW5la85sjAS3p42Pm
UssgaPWGVn/jSQqq5/I8WLk/e9z3vRJZBujBW51HjTLlEHTG7CnfvwcIqX/3
yztgrt3xXduLiwBtu9D03duHbILevzfgRVC8iOq53PvWAVPZb7Z92JsM6Ckh
fQQFsUyCfvCkob/dIRl9/70D9ONPRk34XAxoTn6/b95hbIIWLSnz490QUT2X
A/Ed4Pqi/OsG9zP/9xera3ZaxV2A7vmyFiPq3/145flp5od6YpwK6A+dD/p+
7mASdOCQxIq7w2RUz3AxvwNOzijpI1hA/d87dVc+Oa2mAHRy+5oQkDCi/t2/
74A1K5cdaR9WBeg7WTc3R6pwCTp7Td7cCx18qmc4Ud8B7rVBb5/7pAG6tejW
7QFaLII2mJ+TlVMspecDdMCFn/1qbx+uAHRga/Sx7Y85BB054qj6tD8Cqufj
RtwBjou+6i98FgfoMLfG61OPMwn61qBxRXfU5PT8gU4Y8uWJxrawIkA/E3xi
Jt9hE3S49j3ZjgwR1XM66tMJVq1dN/bLKwCdKqWqNlIcgnboddrc9oyAnm/Q
CX232c5SXI0CNPN8VmVrLyZBKzrXTB/RIqd6dtdhnXC+rloIL4oBrfVDpgj+
zCboEm8VVsgdnJ/QCQf21NgYhe8A9ENx2sUWLoOgE9W3NBnwuqiezTHuhN/X
XL7GNmcCesjK5pxvniyCTts4euVVDs5n6ISbq8bp9jOOB/TC27/bQ7yYBL0v
+7iuvwR7aSfUXFW8fuBeAOji9K2rO5eyCXr+JrJ6qIOYnv/QCS480YRHGysA
PWzWSbXaOxyCTvJm10/KENB9tRO2EV+z/M1VgB6yfNTiI4O5BJ229fuO/ul8
er5EJ6gvNXtTMATnSyi3v7fzah0bnC/RCZ5NU1YnHBPTPbYT6nbn1jKU4xm0
Z7NEd4RyPINWGd0nllKOZ/7Nn+iEKUuHDP/VqwLQvv1jF5h5cQi6Js/1wBOp
gO63nbDlfvW+0s3ZgDb5VNQc8YZF0C/vzzf0eSmh52N0gkfxhporl0sBHbIx
6dHBdjZBB9juitXVw97bCe/mzyhZaZoB6JyxcRsb5rEIevX7g7bGblKq53LP
uxP6DFx802FHLqADvHatbGpiEfRPiclGozESug93QrYWZ7SPfjagLb2ectKf
sQj6svSnYPM3CdVzOXC7E8zVVPVzBH8A/elAmf3erUyCvq8PVqNny+me3AnW
NUXrPc/8BbTT38fZg+uwJ3fCdMeYVWmmMqpnuPiiE+4xJ/5RLSgDtPPpRe1n
zDkEPbVrp57shpDuz52g3YvZe2BxGqBZI0cEBOqwCFr2g/oRHi+leoYTYZ1w
+I616/T8QkCnZuzoa3SCTdCOG8wqP/YW0726Eyarv741+PMvQEc/tTs2W4dJ
0Md/umh4Jsipno+b2E7otbbo6LMFJYAuv6SznxfPJmjrhviRg/eJ6L6tfH3P
MmavvZcO6IOaI+r6TGERtF4pZdpwX0r1nI5ylecTrrGK2v0UQK8LcQi5ls8k
6GVPZj4pWSyje3gn2Gf5d7YGZwD6SoGrQr4Ke7jy+LAbwuaskVI9u2utcn8w
/lqwoO0voH8ceuPJaWUStPewVxzhSBndz5Xvj2uDzoT4RECbB/9M93qL/Vx5
vvnotUkSJKPnwyjPt84nPyXapgDaqcbizZUsJkFPn3LtVc0a7O08WLT6mozB
qwT0fwMNgSHH3s6DDdlfz3Rxsbfz4MubNWG2T8sA3fz69gTtsRyCHvM663nh
ByHd23mwy+zpX0ltHKBV2Q1vT51kEnSn2DiIwZbTvZ0HV/d/Mz+XlgHoDo3c
85obsLfzQLdqRUfJIind23nA6avx5rhvEaCjAuxXf7jOJuhTkVarA4pEdG/n
wTCD1JVqY4oAbVO13uXXOTZBH7dYbOwpENG9nQeB82d8/ebxE9DTEr//qe7E
3s6DO7uvuE0dgr2dB4J6d5/TG3IBDfK+WssbWQTtxa0o3jpOQvd2HqTElP/p
VREN6CW6W66MsGYStHOcTe3Pszj/hwd7t83U398/A9B9F8dV7p3DIujqHQen
G56Q0r2dB+U759mMacgCtO67nfFzH2Nv50H8i4n7j/yR0L2dB/0C3tlWNhUA
2uDzwF2PNuN8IR5E3s2aEDdXTPd2HkwWBx5shhRA3zQdlqvIZBJ0wdOkFax1
Mrq38+DJw4PHJy5LB7TblKWp1eOwt/NgyH1H+6lvpXRv54Ek/AS72TAe0CER
FmlLlZ+n6ACfa1sdpDK6t/NgxCNd21WLCwB97ib74qWFOB+JB6I8UXPDHjHd
23mQa+B9t1mcBOgJK4/m+1NMgn6xsd+S36dldG/nAXf1NL7tkVRAL1/9n5+T
kEnQW1evLzfXktG9nQfjLqpc5LHLAW0XONtATjgEvSfCI4J7Ukj3dh5osvTP
nb2XCeg5UWcPaLqyCNrjlEi/dKiU7u08GM/p/0WyLwHQNmYr3rTeYRL0iSeb
X43IkNG9nQcjO6h7O9qxtyvf367Lxwb9v7cr319mnXpmOfZ25eud8/W55rtC
QOdI7gwIPMwm6FV9MnIiBojp3s4DynqxX7/9+YDOu1DfXj4Be7vy9Woz0bV6
jr2dB5sc/aPtDYsBvSfZdfqV59jbla/fjiF+tWHY25XHo6bZNG5pDqAHsIKC
ygpZBJ0n/RRqbSuhe7vyfLLAM2e0bhqgO16mhp9jswha9/22SwKRlO7tPDCd
MfX6qPhQQCcEXNSdfYdB0Hsjm2I9MxV0b+fBUHIu2tk3DNBMA13z3Z+xt/NA
ERF3c9xdBd3blT/PxWxe5TWc38WDuRpBO3UzcH4XD45Vf5oYt1FC93YeWLAG
mR3qEwvoUduYo4K3MQn6O8i/f7SW072dB1b/SbjuuvGAnvpi64G4M0yCvveF
DD8ok9G9nQ9auUN2JJknAfqg78GwPZ+wt/NBv1r35pj7Mrq380Fz9+Ddvnp5
gHZodnj3kc0maKvRM188Eonp3s6H3We587cOzAf03pCoujcGbIIe/eTkxJfh
Yrq38+F4Ym3lAvUcQC8Te8h8fuF8M+XP01BRbfGQ0L2dDxLH1isj+uUA+lTT
Y60q5d9Hs4xiiiw8cH4aH2a8T37E10kEdFVi8noqgEn+/3UX58VnImV0b+fD
6f6fZhYtLgX0AYc1Fx7Wswl6hOV/7fEmOJ+ND9M1ap6WqWNv50PwL90Bj+yx
t/Mh1CM2N84Kezsfam6v3bVpPvZ2PvzoGO+bZIu9nQ/nh72u3rkPezsffC6s
vmUflQno9pBLk9WPsgha37/hQW0/Kd3bldvTxj2050YOoFV/kqtLlPsbuuPs
yUon5f72r6cr/3+WzvNJgwoBPXfb2amxDtjb+XAUxHdcZ4rp3s6HxgDHEyuN
MwA9y23PMhfl+BntPdjI3vgwzq/jg12Z+jT95ZmA7v0oIJbtwiLolrjIQyJj
Kd3b+cBz86nZrVECaP++6R7vfmFv50N0xWaVFx7Y2/nw8Ltj8ew5hYCe4v7W
0nYnm6DvawX77DcV072dD59GXSs1TM4F9BFOx8NzYhZB9xfqxAvUJXRv54PL
vlY7u4NFgE5p3rxw3FWcv8cHZ8O5e99ViujerjxeFgZpTRalAPq607CRZ0uZ
BF1invRDTGR0b1dub+tp5yGPXf9vzVP3ax2augB9lEy58rc3I+pfT+dDwpr2
BW80cwCdP16xc+BvFkEvfc2emH0C5wfy4VaEesru47mAPnQ34NiSVuztfNBJ
j1TfPhJ7u3J/NaxKsW/IBfSdc5EzFsuxt/MhS3D+yg4u9nY+DOFNefR1JPZ2
Ppw9eb7TnIO9XXm8sjqH3BBib+fDd+eamtbQKkC/v/9dHGHCJejnyVfUfYL4
dG9X7s9jm0dud88DtOqLWc+b+uL8Q+X+/OXc1zEVYrq3K48fXh3r9awyQBvM
Cj/t0o9D0D+8LyvGlwvp3s4H9ouIhCMzSgH91M0if2Itm6CpQdeXBE4S0b2d
D05VPnNMMyoAPXRGYNrlzxyC/usbsaXujoDu7cr3v/VedPPWLEB36Ll+k19m
EbRuzFA/Tp2E7u3K8ylnq/NaYTGgfcqSmhp+sgm63XrnmPFeIrq3C+BE69ny
iqI0QLd6mm16pIO9XQAjOU8WxMVjbxeAk1b57LGT0gFtYmDVa/QYFkEHR1xo
/fJJSvUMnwYIIJX8CXeckQXoYS/XuZtcYBF08oelWsHtErq3C+BBqiyePyYf
0J33h38vMcTervz/k6N854SJqZ6PV0MBtG1Yd2T6kVJAb1FL6hvXwiboufW7
Kg4aiOjeLoBnXQ6cuF4FgOZtvVI2ZDaboAeTWuu/nmKq5/Q7TQBPy4d47gkr
BPRU3Wd+KUfYBH0v7nuZk7aY7u0CSHrFHOY66T2gg1V2Jv85ir1dAKEdpjvc
+nZRPYfnPAHYnjNZu9agFNAXr1U32FWxCbqlZOp4Fwt8PksAax+bPYvWzwH0
m/7ObnnRLIJ+nTdl8LKjEqrn7VsjgNwsk6vps8sAbT7tsqObJoegb92unz64
FHu7AMbr+mwv+lgB6D6qDkPd33IIurHdMkUrWED15HRnAfTLCdff8LcQ0L83
5NokHWMTtIfdiqO71MV0bxdA/7h1IeGjMgBdMURtjftcFkFb/q3/T8tdSvd2
AdQVXdu5qD0D0I91tPeO24K9XQCx8YWj39lgbxfA/IHZEXH5+YB+FXhcON2S
TdDvw/toXb0opnu7AKL1Ez3AqxzQHy9MLvXbxiFo/7YHs8ushXRvV74+dVt8
FUfTAc0tfpM+3BR7uwAE815uigrA3i6A/aXbtmy9lQboFp3kxsvaLII2jN8x
tq5ASj9/JoB5ScPMR5XkA3rX+mjnGOXvjzZdcmyyu4+Y7u0CWG55Wvj8XCag
XVTb/G8dYBG0Sfvw3zn6Urq3C6BQ0+bDjGM5gNZxqJtmlIrPrwkgwdL01kd7
Cd3bBTDhcKkwJ70E0EEt0pKZBWyC/mLQa86lRSK6twtAgynZsjeiDNA2p3+u
LZyIz7sJ4HiX1/KFgUK6rwtg87lxrxXDCwF9xWxedpcjm6Dr/Q+vZkwX08/H
KY+nQY+G1ZnlAzrb6z+23hg2Qa+RrBP/+SSm+7ry/OGqd52hlg7ok+9HaW8b
ySJo9rNvhfBDSj9PJ4Crk+YsV3uUCuihozhfosRMgv77XXj7pLqM7u0CyN93
wqPArhDQhXv9lm3cxSZoO8PybQsn4PN3AghPlp5bnIi9XQATO61H3gzF3q48
Pw31+pH/AHu78v0+LjviWlkA6Pl+pfv2bWITtFs5MRi1QEz3diH4aIgGpocV
A/ojkzIoCMPeLgR/2ZnwRTewtwsh9XDfg+tb0wAd/nfkxEY9FkFfcYh8Ni4G
n+8TgvUmVb0HzumA9ml8apNpwiLotrE/j64PktK9XQgJs+ccuKvcn9EzbHu1
ZFhibxfC1f2tozYo9+d/PV0Ipxcf8kvZXQzoawtbPh57xybosj2jHqm/ENG9
XQiUvmvU0ydlgA6J0zWrM+IQ9NMDsU9MQ4R0bxdCvuqQ9Eft2YCWMkY9mPIT
nx8UQh/F96R7ZyV0bxfCxsl3LIg8EdBjHI+xsz7g/GQhfJmhIV77VEb3diFM
MDeI6XX9N6AdR825ojkOnzcUwszvJ2pL3snp3i6EXtGVJn9dEgFtZvW34m0Q
k6CfXHCcGRSKzycKIaZ28+LLuWWAbj82OLNiGoeg9dXT18+8JaR7uxDmvtR0
5nPSAN1r4O+3/gzs7UJozT4R9FshpXu78u+namcO+pgP6Lr1DgUG5myCNl1s
uSj8ppju7UIY91uzYkRbCaDnDZmjyynB+dJCOJJ6Ik5oI6J7uxCaS97K+MG/
Ad2akrj11Hh8/lEIBk4uhPlGTvd2IdhyW10dFxQD+lWZ576ml2yCfm/NGWX0
XkQ/LymEhysdBt6+nAno/+zeBh46iM9LCmH97uDwYXpSurcLwSO7hRWjhfOx
hbD1SwTjYAzOxxbCnNs+Cj13Af18pRCWeg+dHmBcA+hV9ipL6y5xCXr9rE5H
0wYe3duFIFgy8fwOeT6gqYQ/bW+BTdBee9z0g06L6ecxhWBU42aU6JUCaIel
7oEmeUyCtnTUighahvO9hXAnNfvPzpF/AS3etPnKoAomQWvMn1ebYSmjn98U
QsrZL08GemUB+niI4NOcayyC1niife94qYTu7UJYHT9yZGNTOqDVZhg6PZ7F
IuhG368Wf85J6ec9hfCmdnHomWt5gOY/Wmiuqc0m6IGxe26WFuJ8ciHEOi7+
dvFGGqCPXeltsUIbe7sQ+tY2Xd9ciM+HCqG/YYVrlXopoL3melx9VI7PhyqP
5yOqlbFWIrq3C+HZxoDC3ffyAe1m7HZCYwqboAe/Gty7+j4+T6o8/soiRrR6
5QBaxWNw1eY0FkHzVNMt5m6V0L1dCC6sav9ZN4sBveRp0acdoWyCdqbm3zN7
KKJMejZHCM/r9BcejMoG9IDiUeP6fmMRdO68b+8q/SR0bxfB74T5vK1RWYCe
nu+jULvHIuhrS1pYdakSKqenp4vgnAqndUNdLqDTTpdtVlNef6G3Kqzn1iuv
v/71dBHs4/o8Xr8jE9DvGR+nNO7B+e0ieK54fG/cGJzfLoJjUwdt2zMKe7sI
/GJZV/bOxd4ugopDklpDd+ztIrA6Wbi07+F8QMfvL0wImIi9XQQHRyzcExko
pnu7CAKza2w2sr4C+p358ALtbzi/XQRBN34tKvDD+e0ieH1Ucd3SNxfQA1Ph
UHA7i6Bz7E/rfNSV0L1duT2TZvm6l1YCetfiZZXFQg5BT9xhP2OupoDu7SJ4
YWLaUH02FdCJHYFbrEXY20Wwe1j4nLP9ZHRvF8GHwCHH1hf+BbTxpet3vzTj
87bK37exKO2WoYzu7SK4uohaV7CuCNCH6gcv0rnMJmjdCWm7EupFdG8XwYGB
H9dsM8sE9HuDnD7qzji/Xbl94f811E6R0r1duT+8dPHWn5UGaM3V79KeqbII
unT1iy3f2qR0bxeBTZ8/vRy6igFtGzBkdhPFJuj9P/56Gp0W0b1dBBtv1E3S
u5UB6EXas4LOrmQR9K5C70+iDVK6t4vAwcbvgndIJKB1jluZnKvG+e3K11ft
QrBwKs5vF4H6KgnPcmEuoL3snpw0qmcRtNzlF+vjBAnd20XQFnHzslCrBNAn
3Q+1W//G+e0i4Gjp6HmdENG9Xbm/OpmP3JCXBehHyWPmqj1kEXS8c6h7fYKE
7u0i+BQ+aZvvq2xAr7FQeTvpC/Z2Efx3vTP40W0J3dtFsNg41ybAtBjQLtXH
x/JesAl6wrQ+HwZ/FtG9XXl8e7wVmedQgK5w/PP1owKfR1YeT9MPX3vEUtC9
XQSpDgGRcc/yAL3B5Jbw6ADs7cqfH5yr2TcXe7sIKPW/tR998fllESSXeegX
/v/5ZRHstFaJXrhURvd25fHNaB3TeiEX0NplxVXyNhZBF8Fcc46+hO7tIojb
YV7K+vwX0B7OnRNII5OgVacMfX5qnIzu7cqf577Q4ZB9KqCP3DUcM1jAJOj+
6WGf0vvL6N4uguivU5+mmDcDun2Cxs5PS1QJWv95tel9p3a6t4ug0Xvbf5fm
pAH6h+YeuxW9WATtXWK0e3OrlO7tIsgf3b/XNrsYQG+ZfIYRNJdJ0PMeyhWf
jsjp3i6Ce6utclzySgD96VLcBo1CNkE/aDhgV71QRPd25fFsdUg+7n4VoFX9
Np2yG8Ml6I7y+czdn/h0bxfDUE6fy4EHygCtcuZ34FhdDkHz5MfD38cJ6d4u
hr01V6KTsisB/XBGZdshPoegE6/M0B82UED3djGs6uWkWJtdBOg+Z5K7Xj/A
3i6GRrkz43WiiO7tYsiO/aF6TKUU0IXfhCNSy9gEveiq5k97axHd28XwXR4M
E9ZibxfD1y5ecHUi9nYx3GAMCpnqgr1dDKULzX4t7JcDaKveY6bX/2IRtE/z
J78JHhK6tyu33/rohNcahYAuUf0w74s99nYx2LQFuN22EtO9XQz3B+zU8Oxb
A+gx3A02T85yCfozf9GxXyIe3dvFkFI008X9UjL83++eHQmOZxK08/Nv2h/3
yejeLoZBI2pGWx3E+e1iYMdEnjPah/PbxSBxPy8IGYXz25Wv71hVbdNr2NvF
oFdNKrj/7+1i+DPtpCXv/71dDDcnFe/XNCsD9PbFQh2OOoegzXdoxQtrhXRv
F8PkzcOcnkzIBXTQorNNn6qxtyu3d6d4zL2pErq3i2G64+HT+W/+AnrqGtV7
PxrweXbl6/dfe+q58TK6tyv9Kki2Rl4K6CnZt0pfd2FvF8OD1TnkNQN7uxha
9lbd8blXB2gPne+jDcaoEHTvBN/PEZ866d4uhpHrTjpeci4GNCdp/+L0t2yC
Fu0asWNzkIju7WII97jyOuNMHaAnDn/22m2ECkE/+/X99SCqk+7tyuPJr3xk
6ekyQP92PBpvMYJD0J7T++2/Rgnpvi6GmEtrt4ZfzwD0uvaGRRYrcX67GJbp
jd95fSPObxdDYNPSOScH1wN6bMTNa6XzVAj6w8W8EuLWSfd2McxKt6iPSUkF
9ADPm0uLZPg8vhjyuPkOC1RkdG8Xw9nobHujFdWALj9wOG/hKi5BW+sPXLZn
LZ/u7cr9ZW7Eah2fakAPTd+XreLAJei/mw1Wd1jy6d4uhoyX4e8GV2QDetjq
r/w5kbgelxiSV18fcPyChO7tytczOnieZ0oRoO1Fn19+uI+9Xfn79Lvz/mmy
iO7tYrAtfepmeaEC0BkWY4v/BmBvF8Omax/mOUQK6N6u3P4vOq4THSoAfaQ5
9tHlexyCHjD6UGzdXwHd28VQzB3t7WRfDmj32QtHrl+HvV0M2p57fyxZJqR7
u3J/Ku49aD63CdAn3b28VzBVCZqjJeVtkrfTvV0MEw7OvLo8qgzQix5dHTXA
jEPQLnEV33KfCOneLoH6226Vrw0yAf3jxr5Nq52wt0vgfIHBgtUW2NslkHal
ZezUv7mAfpCu5x0rxt4ugeRNMfxD6hJ6frsE/rzuP0WcWgTo9YcdxnQpX3/0
soGWn5jK1/9fT5fAimmiEKfsckCv0rA2WX+YQ9Drqs8GLxkopHu7BATsPUap
2dWAVjAKE1wPcwmaq1i4Z8hAPt3bJZB6W+We4GMloN1eMIM8mzgEPeSL7BPH
SED3dgnsFzZcMf1YA+iiHzMrF73lErTtuUszdgbz6N4uAX3zv8/Yj2oA7ePb
WccI5hJ0e9WQiYqPPLq3S2DU/uAUFU4VoBMKd31iMrkEvc/W5L5Mzqd7uwTG
+//4M66zAtCXduw/mBjJIehGs5F6u88L6N4uAWfppndarRWALrBeuzsmAnu7
BJZ4rRjn7iOge7sE7EvMJv9xrQH0PYsri9sfcQk67Vqts14sj+7tEiBLq+Yb
xdQA+lr/7+m9P3IJuizPd1PTYx7d2yXwZP8Ia7Pz1YCu0/Hpd8WeS9Bm8a1l
tVZ8urdL4FSglUXY7jpAPx2b6ts8TIWgo97bVxkmdtK9XQJrDPQX77SsA/Qd
H9X+BX1VCDq7pS1/UUUn3dslEPi1TFAZVwXougnf5KJJXII2fe7H6fuIT/d2
CcTtfnL4hnUFoDsKdjxW/hWC1rUz+xNWJqB7uwQsddWjJy6vBXQ/1egQtSwu
QVe0H/OvW8uje7sESs4PHaW2sx7Q3+xj41kbVAj6upXrPsmiTrq3S2D13psP
Le5Wwf9dWFWTMppL0GsWmk92+syne7sEZn6fN1bfvQbQS/dpXYp7zCVox1HF
jQdieHRvVx6PTtMtL0fXAnrA0L9/K9q4BJ2X4ugwU59H93YJLDp1fcb5y7WA
ztzqdLW8gkvQG4hFpdVMHt3blecb1uaDc9KqAP2BrH2kOZVL0IEnV8SV3OXT
vV0C72G/htGzCkA3pW6MTnjJIehx22yP7XkvoHu78vwh+2/UizU1gB7YlWX7
6jaXoHOYa/a9y+LRvV0CfQzPvVhhVgNoVm/7XQOu4Px2CUibZ03IreXRvV0C
b5eV8B87VgO68aa7Z+06LkGPz9PkTlrKp3u7BHYM/zT3dkENoAviTFa8COMS
9OIDQZu/3ODRvV0CxS9efvx8qQrQ7uNcTN4ZcAla+51x8ItwPt3bpdBPOCrj
ofL7o2PkPrwg5fdHH+W0DApVfv9/PV0K/330szj/qRbQq5sqfcubuAS9xmh6
ldUYHt3bpXBzTIJgZt8qQL9YGPrjKptL0GF7Hp6rEPHp3i6F5tjZf1/MrQR0
xMFrruPSOQR9Sbd0yLvNArq3S0FPpn6jPLEK0Kpw1unbZC5Bd5wRm/s94NO9
XQqP/BR2NlUVgK59RmVofsfeLoXJ305vKPEV0L1dCudrhga0ZlYBOvDY/Dqp
cn9D/1B3Ne11h0/3dinsbny4+KVyfI4ulIzp/1o5Pkfb9QnNf6Mcn//r6VL4
maJzu7y4GtAHOudvP+rOJeiRQw9N66fFp3u7FNK/5/edMLIa0G77wmwW2eL8
dikMGXXz6K79OL9d+fqPK6/5XlkF6O123461TOcStPluP/VRV/l0b5dCTgRr
X8KCGkAL3p/e2HGdS9ADAxW2OkU8urdLQe2FztuLPjWAtqlX2W0QyCXo4xM6
xkVE8Ojerty+K6Vp735XAVq30sLtjRmXoONnXBv8yp9P93blz/u8TJDCrwI0
t/mmp+ssLkELRudxhnrz6d4uBRN3WYB8dhWgk/RO7TylySVolximKbOUT/d2
KRifn2TIXVgF6Mv26gtna3MJusGqdq9nIZ/u7VIIrp5qp/OhCtAuM3wzYo25
BG3iW73h0Es+3dulsFPb9egpRjWgH8Tolgwn2NulkHwk1ibqFJ/u7VJYKp41
+vy+SkCvOrnsYkAhh6DXs+2bI20FdG+Xgh//fe3E/6oA7fSj8XvSAC5BT/ce
e2VnDp/u7VLleETLMudhFaDd98dc5Y/B9VWkoD3SvWJAKJ/u7VJYUjemqs2n
EtD9w3vPsKrgEHTB5SbfC5YCurcrzyfvnZife1cB+pzxesZeFpegRS+XdI2W
8uneLoWsNkON4crvj55mtTBaVfn90Xcu7D3Wpvz+/3q6FAadMLymql8J6Fj9
3lVn4jgEffh3s4XsgIDu7VL43KBSZrCoEtDvwpnf4jM4BB10Sea3b4OA7u3K
47t/oaL4TiWg62LCTn2t5hC06ZEbjOtTBXRvl8Jgxt9zHwfg+o1SUDk9xd7k
D67fKAVe171ZwYcFdG+Xwv7atsp+yvEVumiGTBStHF+hba+o9j2qHF/96+lS
cD2psSpldwWgH29lr+58wCHoWCJePTRRQPd2GVwLM9TP34Pz22XwfMLFBeaF
OL9dBt+eNx+4uVBA93YZrFacWHJDrxLQt7u23HRSvp7oHMacfPODArq3y+Dk
QeMz4FEB6G1FdmX9nnAIevYCFyj7JaBO9/R0GfTjx3QOmlEO6Lmz2iPnLeUQ
9FFvvfNujkK6t8tg39O1Tg+8KwCtWzfwvrPyegqdYJqVMvmHgO7tMmh4VbVJ
vLsc0MfHz1ir2MAhaLU3vivYdkK6t8sgeUpAvZdNOaA7F+8ML1vOIehhzqaX
rbcI6d4uA981igUDCssB/ex2l9afI9jbZRCexSg6rC2ke7sMYv64b7rKLAf0
wXa9u46EQ9D6ejHp008J6d4ug7Yditmc1jJAy+6f0vxlievJyKBXMqPU0wfX
k5FBeUDNnvl5ZYA++nLGQy1zDkFrfriSUHRTSPd2GbQ+GJUxMLYM0JE1Pm7e
kzgE7TO5ZRD/kZDu7TI4FnJNkLOiDND6Js9/HB7AIeiY4K/nBuQK6d4ugzdm
Jra8sDJAG6uraf+YwCHo17X1hd7PhXRvl8GDH9oeo16VAdr5A6fUdjyuJyOD
KQGC2fve4HoyMsh74N1ydn4poDd+SvNMq8P57TKwu7+Fs3WiiO7tMni5yPJz
RW0JoA/vurBGVoTrychg0IT2larzcT0Z5fcLNKi1GIi9XQaLVlXJgv7f22Ww
a62FSuhx7O0yGLNwxeFzFSWAHj3u9dXlyu+PDnv3pmLLAhHd22XAfzpt9e0L
xYAe/jnodUcIrucpg+i7oa+H+Yvo3i4Dh98X7IZkFgJ6sWh5b8fj2NtlsLPf
luYZarj+pwwCv+VpHAsqAvSAwREjU2+xCTov/WKkfY6I7u3K95vxEjx/FQFa
i8EPNr2HvV0GJV0DQ56miujervz/75spfJcUAdqyfyz18SLOb5fBpXzX04+a
RHRvl8GWDSfrTNYXAnpxUr/Ho3fj/Hbl77+r7M/ncWK6tyvf7/u1AYoHhYAe
02mVtdWVTdCfhp5fS4aK6d4ug/0rJ0b16VUI6KWJ3HVMe1xPRgZOu3nL5LPE
dG+XwdCEEeQZKQD0qKGcnQNs2QQdniI0zd0vpnu7DH6y+ja2bygA9Loo+1lb
FrEJevkpK2+bXWK6tyv3990h3vq1+YDerhGWVmnFJuhp1Te3TD8vpnu7cvvX
/PkzRCcf0Cmvvw1xHIW9XXk8vL76d8Z3Md3bZXDL+5B15Is8QIcu/3vh6wA2
QT/c4th2LUdM93Y5+PjO3GxWkQvojyuC1ebLWATtv+ljnasqro8qhwdCTlT6
PZzfLodOf8b0Yf1xfrschv1W+CXl4/x2OUjctrmqLskF9JO+e1qe1rMI+neF
0aifJhK6t8uh9MdOniIb57fLIXKwbwlVgPPblb9vWvWc03Y4v10OHI/b1ddX
Ym+Xw+kPoVYr/9/b5dD19MH5jbuxt8vBYqvJaAf3bEDXXn4xt+k99nY5TK77
fMQoEHu7HG4N75V8VJgF6A72maGt/iyC1hHJk0f+ltC9XQ697xSfPLArC9C/
Qgv7TfTF+e1yOPnAtuxZtYTu7XK4k+4uvZCZCegpkn1dB47j/Hbl661mwNRX
w/ntcsgxUf3Q7z+c3y6Hh9VlfHsXnN8uh8Sp1gOsjHF+uxzmPdJ7M0g7E9AX
Pzlmz3HA3i6H1nvTVx+3lNK9XQ5VGvuK5yjSAR35693GeMD1YOVwweO57f7T
Urq3y2H0g9OdMDod0PP6H1AEG2Jvl4N7/nB2SBjOb5fDU+aHMe8d0wE9tSw7
5rAJzm+Xwz1YdWRAMM5vl8PynHarjsw0QCfO9F9wchiLoPdcij7ATpLSvV35
9cHjD08Q/QW0Z8DKXK9WJkGr/tiwQjJCRvd2OWwaqjg40CkV0HfKh6+dLcD1
ZOSQZRW1wrM/ricjh60lxf2EXn8BXVMsP2Bah+vJKLdnLkc/wBTXk1G+fgEZ
13o14fx2OeiO17gYVYLz2+UQ/6a6+eQcnN8uh0ZT4+sjXyYBuitUe6hXOJOg
2Q8KUqSXZHRvl4PbW+rsCZtEQMdJLL9ZPMd/n0IOh/r4+F37KqN7uxxsDrof
z2fi+rdyGOAefFfv/+vfyiFP62NaDIW9XQ4VT/Q2MHrFA1qRH8A9fRr/PQvl
8bc4ktelwPVy5crx9MC9wrA4QBttSj+y/wSToD8u2Kw9sjf++xdy4O7yjXhY
HAPoaznfIvKX4HoyyvPByqs+i53kdG9Xnk8cj1e0lkUDmgQZKfpa43oycjjz
KYRdcVZO93Y5OMMDjZMO0YAWPMsvMzJnEnT/b4utQ27K6d4uh/E/vzfGVfwG
dOXDiJMmE3E9XjlYxvuwgp/J6d4uh/qXG6Vnjv4GtF/4l+E+RkyCrrx0K6o1
RE73duXrN/Azl/KPAvS22RvbGnvjejLK7fFcOHxsk5zu7crzjcatW9P7/gT0
gafPYw624XoychhJhR3RHY7rySigkTh9Crn7A9CqBg+9fzQxCLo9IoF3bgz+
+x0KODxssknw+O+AzrpmP2N1AoOg15dY+a7eq6B7uwIYlhMtzYaHATrvYP4Z
cQiuD6yA5bpLZOr+Crq3K2BVsWda0dowQDe2nK35GcogaGMD0WSvBwp6PRkF
3HuseeVwyidAN5/b9na3P4Ogxwisg8dGK+jeroAV5sY3TtmHAvrT+usytZsM
gn64uFilLl9BryejgBFF7dv46SGALr+q+sbvPIOgrSvaXpV1KOjeroCD/Vdq
7NN/A+ilttO+HduD89sV4LT/tp+6URe9nowCNL96RG74FATooo52l5QNuF6x
AmyH6Y7fbtdF93YFvF0iMT7/JBDQFvUfhpy0YxD0zQlP/7J3d9HrySi/f8vr
rIu9HwO6aPWr/v1nMgjadtW7vPzLXXRvV8BdtvzDsXs3Aa0q2dppZsQg6A41
MtT/Yxe9nowCXi51/ZP68gygl3VTi0HQjkMPb3tf1EX3dgVsslp/nPH+GKD9
TWYxctUZBB0T5N21oqaLXj9ZAdyqdeufXzz2f+sGB208UtMF6ENvTTJi1BlR
/3q6Am6Z11WnxF+h0DdNpzrti+0CtEX3l3UZUf/WU1aAhpuj9c7q+xTa7JDK
Vpd7XYCui/VIS5zCiPrX0xXQ59jbMuvtTyi07lJPzm6vLkB3rPvlmWjNiPq3
/rLy/brA7M268YxCR3d+bd3v2AXo4SqGvWyX4noyCogquRI6buhLCt3n/u5Q
c+gC9IkpiUFO2xhR/9ZrVn59oemGUN+3FPqb98S9N3S6AG34Y2eC+SEG/e+z
KCDiaVq48f4QCs3jr5yrIVYAWsU7Z/Oxs4yof+s7K/d/lfAHxa9CKbT/1lVj
HLIVgJ6Ult209DYj6l9PV4AOL09wovdnCv3zwA2yk1IAOiAurHTRU0bUv/Wg
FWBa3re57/GvFLpZy1Rrq48C0L3dd7qnReB6MgqQrjVq46p+p9CnL8mf+u1X
ADpq5hnT6fGMqH/rRytgRsmZ++LDERRat2KH81NbBaA7+iYnfyjE9WQU4NNY
aLB72k8KbTs7Y8kr5XkHval00Po37Yyof+tNK+Bc9tW5JX4UhX6p/VWHpaoA
9Nsjhh0nZYyofz1dAUOkFSXlBr8o9OOno2KeKT9X0KGmLXoTtZlR/9anVu6P
uSe8beN+Uehh3stbB8XJAe36Y62Pmy4z6l9P74KulYH+zgW/KfTTL8Ymn57L
AW02umFX0ARm1L/1rLvgpaWd7oH0aAp9+dsRWbq3HNDhz2KYg2cxo/719C5Y
vtbGwPdtDIUedPvrxn0uckAfnmaYEW/HjPq3/nUXuBkd8vaT/6HQ2hEr+i0l
ckC7G6wV5W1lRv3r6V3Qacp4/HdtHIVmSbaaqAyUA7qLlVbvcZgZ9W+97C7Y
ELRiZM7geAo9LSnbkqu8bkE7Dxvo4HmGGfWvp3dBiErNzrLtCRR6PFR22GTK
AL1721WVLXeYUb17glwXNIx+4TzOPpFC22w0ziz4JAP01pUud7SDmFE9udWm
C77Xh192251EoRMCffZdvyED9KP3EbZfw5hR/3p6F+hNHpEs80+m0JHiE84j
9sgAbcD+ndyawIzqyXH/dQHTl+9V8zmFQm9bGmDquFAG6LR1pjuXFjKj/vV0
5ftnvXXmhxt/KfS4If/r4d5fmo7COI6371zUfopMKrxAapqCS1FLKnhMRRxi
aNRUVIJaN0jEbuAPJZQs07RJIjoviTmKimiglks7BzKrsWo63UVTMyE1h5oz
cd8pp/Dw9OPrHzhw3jx8OnY9jVoDtMutd0fOSuhGrlEzqOpal3UPfSVohTJx
4oJsDdAXR09p09cllPd0BiFVtmmTykLQr/LlqRm/vIBuHxDznXKBbnznrzJY
SSX1LfMWgk5SWHJz+ryAnpjZabUGCpT3dAYdcS+dfs0DBG1denDXWO8FdN3m
A2/aYgXK92IYqOwBpRFbBwk60pTQ2nnDC+g53dT+vUcFyns6gyNF6UShHSTo
mNCozOU8L6BnCmftsuMC5XsxDCbfJznC9lkJuvzYgnIl3gvonpwtoz5nBcp7
OoOgxYSGRJ2VoFffGZxFu72A9gkK9027IlC+F8NAP9Je/iN6iKCzP9kKPrhF
QJ9s3JEVoBEo7+kMpIGx5LR9iKBJQmxmuEkEdOuZn9kunUD5XgyDhcVq+e+C
YYLuS87vvf1EBHTQeNaet88Eyns6g1uuquZo8zBBfy9rcrjviYDW9hp8Nd0C
5XsxDGZzHheXqG0E3R9R92jynAjowLk4xX2zQHlPZ6D+styocdkI+rxZyB1P
EQFtbrhp1Y4JlO/FMPj8vGbV/7Kd/HftqKQkRAS0Ln57afK8QHlPZ3BnLNJP
L3cQdEtap1G17gG0IU/fdkIipXwv5t97NB06eO2hg6CD+69XBjs8gF5oSjHO
+0op7+kMXsS7xkxhToKuXSpLy+jyALpL05vnDJVSfq7PoCLCUvzttZOgW/5U
Tn2s8QA6Rnao2v+glPKevilx27BefVg5QtA9FbYwQ6EH0G3G2kvhSin9C9jp
lJg=
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw83XdcTf8fwPHuvWUWIiORZJSM7JHx/iTRImRWdgjZRRkJpUTJCKmokIyM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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H73 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{73}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"], 38->
            TemplateBox[{GraphicsBox[{
                GraphicsComplexBox[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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                 "], {{{
                    EdgeForm[], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    Opacity[1], 
                    GrayLevel[0.9]], 
                    GraphicsGroupBox[{
                    PolygonBox[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                    "]], 
                    PolygonBox[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                    "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJxd3XlcTV37P/DTPCGSKUm6kTmZknAdhaSijCmUaCIpaRIyJPM8D0mUWYbK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                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    AbsoluteThickness[1.6], 
                    PointSize[0.01], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJxd3XlcTc//B/DbvlJJIQohS3ZF1ndEiqJFK+0LlRYlKlEU2UopS3ZSQtay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                    "]]}, {}}}, {}}}, {
               PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
                PlotRangePadding -> {None, Automatic}, Axes -> True, 
                ImageSize -> 450, PlotLabel -> 
                FormBox[
                 "\"H75 phase, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\)\"", 
                  TraditionalForm], FrameLabel -> {
                  FormBox[
                  "\"Intensity/\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W \\!\\(\\*SuperscriptBox[\\(cm\\), \\(-2\\)]\\)\"", TraditionalForm], 
                  FormBox["\"Harmonics phase/\[Pi]\"", TraditionalForm]}, 
                DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> 
                Identity, Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, 
                FrameTicks -> {{Automatic, Automatic}, {
                  Automatic, Automatic}}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], 
                Method -> {
                 "AxesInFront" -> False, "ScalingFunctions" -> None, 
                  "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
                PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> 
                True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],
              GraphicsBox[{{{{}, {{{}, {
                    Hue[0.67, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                    "]]}, {
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Opacity[0.5]], 
                    PointBox[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                    "]]}, {
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    PointBox[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                    "]]}, {
                    Hue[0.37820393249936934`, 0.6, 0.6], 
                    Directive[
                    PointSize[0.007333333333333334], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], 
                    PointBox[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                    "]]}, {}}}, {}}}}, {
               GridLines -> {{75}, None}, DisplayFunction -> Identity, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                DisplayFunction -> Identity, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                DisplayFunction -> Identity, AspectRatio -> 
                NCache[GoldenRatio^(-1), 0.6180339887498948], 
                Axes -> {True, True}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, -92.49104228531282}, 
                CoordinatesToolOptions -> {"DisplayFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    Part[#, 1], 
                    Exp[
                    Part[#, 2]]}& )}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
                   FormBox["\"\"", TraditionalForm], None}, {
                   FormBox["\"Harmonic order\"", TraditionalForm], None}}, 
                FrameTicks -> {{
                   Charting`ScaledTicks[{Log, Exp}], 
                   Charting`ScaledFrameTicks[{Log, Exp}]}, {
                  Automatic, Automatic}}, GridLines -> {None, None}, 
                GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, 
                PlotLabel -> 
                FormBox[
                 "\"Harmonic dipole, \
\\!\\(\\*\\nStyleBox[\\\"Short\\\",\\nFontColor->RGBColor[1, 0, 0]]\\) vs \\!\
\\(\\*\\nStyleBox[\\\"Long\\\",\\nFontColor->RGBColor[0, 0, 1]]\\);\\nsolid \
at 2.\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\) pale at \
0.8\[Times]\\!\\(\\*SuperscriptBox[\\(10\\), \\(14\\)]\\) \
W/\\!\\(\\*SuperscriptBox[\\(cm\\), \\(2\\)]\\).\"", TraditionalForm], 
                PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
                PlotRangeClipping -> True, PlotRangePadding -> {{
                   Scaled[0.02], 
                   Scaled[0.02]}, {
                   Scaled[0.02], 
                   Scaled[0.05]}}, Ticks -> {Automatic, 
                  Charting`ScaledTicks[{Log, Exp}]}}]},
             "RowDefault"]}, Dynamic[Typeset`var$$],
            Alignment->Automatic,
            ImageSize->All,
            TransitionDirection->Horizontal,
            TransitionDuration->0.5,
            TransitionEffect->Automatic],
           Deployed->False,
           StripOnInput->False],
          Background->GrayLevel[1],
          Frame->True,
          FrameStyle->GrayLevel[0.8235294117647058],
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      BaselinePosition->Automatic,
      DefaultBaseStyle->"SlideView",
      FrameMargins->6,
      ImageMargins->Automatic],
     Deploy,
     DefaultBaseStyle->"Deploy"],
    SlideView[{
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw9nHdcjf3/x9tpahrZZIXsbO/snZB027ISskJW2ZuQkZEZkh2SnZGREYmG
KJXVPHuP3/t0vq+ff+7H83E/Hedc1+e6zvV5fq5zNQleNHa2mYmJiZ21iYnh
v8eOGv78o2I/l03X0soIfC/mxen5Qitf8N6cFY9bNRA9GbhrwR/1pX9ktyPd
eyv74AFnk3bNYB+8+sGxv73Zr1xLXafe/0dHRvzsNpV98O+xij0T2Ad3mViz
xJ/92DCXTanp/6jB8z43fdgHv1o8+soo9sFLG864OIv9/tN/fWz67R9Nzd96
tSb74Dp3Z5QNYB/8aX/v1hHsl49Jabil7B+FzqlP/16UEfhY3Veje7IPfvtu
yfRd7B8eYPhA/8h/kVPEc/bBWfUsfnRgHxz0Wj7gJPu+/GmG2ZdSdn7j0JPs
g326bT/Wkn3wwf1V6TfYL23RscaV+qW0tf/NFqvZB5/1v7KjIfvgR1Mvlj9j
/2Adi0DHdqVUR/bicSD74K19bl53Zx8s2Rx3Oov9vrbZ5xb3KaWFM5X9u7AP
/hb02MmBffBwv00/frH/V31JmDmqlMzPrH/uwj64X6vCGxbsgyOv00kZ+wcq
DDuwlA4Mqu8vel5G4FnO1gc1AitfcLfvwmyrhqInvQtG7zkSVkono+ooMtkH
/21k9VjCPrhjqnhTLfZ/895TRpbStkVD0m+zDy76tr9TBfvg3kPzjzVnf98z
aavJ0aW074Um6wj7YM+OJP3FPjglboN7F/Z73n694vGpUuocZ9NiLfvgUXM3
2hSwD57TUV3ej/2S88dfNL7B2/9ySvoM9sEvva4tzWEfHJ54zmM0+3uPGAYs
789j6RlD2QcnXBB1zmQffD3JI3YS+9139OMRW0rLHi/t15F9cNz1yf7v2Ae/
PD142lz2i1a7XRvys5Q268a1qcc++Iw+K/0l++DHJoGhS9nfbTg8haUkt42M
tWIf/HhjowtP2QdvVqXeWsu+j2G4mpVRr8zQGPGzMgJH384recg+uOjwcJ+t
7Bcadp9LGQX01DQvYh98yDFqRwr74K9FphV72d9p+DhNyyi//ur/MtkHd9s2
9fBt9sEHhP0/H2a/S2fDnzLqtGWfzwv2wSObxDvcZB8899Hdkjj2f3habTg0
oIzCOvil3WUfXH/3OOFV9sFv/gQ1iGd/e63cD/JxZbTMr5nDVfbBcZ+HDrjM
PvhlUNiqS+x34qNz4qwyCtpU6BbPPvhr4+6Wl9gHBzyOll5lP18ZGfownI/b
VslFJ9gHN995tftF9sHJZfF7b7K/taz6hET6d53XHmEf7Cu2LzjPPnh93d/9
brPf4bvhA5VRqmjI7xj2wTc0+5Xx7INPW+XbJ7Ofx5+m+HwZLbT1bX6AffBx
M/8dBh+crppWYfA3p6afGZRcRq6Jr3sbfPAWr07RBh8sSzz+0+B7J8VVXXxZ
RtP0Fe0Psg/OiVLbGd4/2N/E5u8d9nP4bGSbXUZX19Q3jWUfXNZwiMkF9sFe
z5bob7G/8ZDhBFxG31KaJMWxD+4Wtn2BYXuCDzSramHYnm22GXZgGd051G7g
efbBC2fbjTHsL3CLrv+mGPbXl4h/fAYup+Ttn+9eYx/sXSS5ahgP4PO9asUn
sB/Fey+mTjl9b2nvcJ99sNxmwKZr7INdylcpz7LfenI0n5HKqWeJz4BX7IMd
773/aBjP4OI9s6aeYP/zqGCnoB7lVCCv999X9sEK7eDDd9gHO1ks/XyQ/XWG
r9dh5fRwc+XIP+yD25/p9fke++Czj7b/t5v9loavm4nlVKvYr76KffDLFNdt
j9kHL9+bI9zI/ifD6Te0nJQNRr1w5PMJOHKI683n7IMtluTGRbC/xnA6Wl1O
PU7M79ecfbDjn4n+b9gHl3QcPm0h+80Nh+euctogORPdh31w43V/Z2awD061
bN99BvsZhuF6nD9v6bTECeyDr6uOlH5hH3zW9qNXAPurDLvvSjnNPrRv9zL2
wf819yzOZx/sd+duj8HsNzN8nIe8/y7FddjPPnhgaMuRJeyDV7a5Obcb++/f
Gf7w9vi7dN8N9sGN79f3LGcf/HTXy7st2V/5+JRH++/ltPvuhvOf2AcXL5w+
z/D9CO7pSe1qs9/kxtKQ/RXlFJ7xIkTCPvh7544eWvbBg2Pj3lqy/5aPTrG2
nJa5vMisw9/v4DiLm12s+Psd/FIWd1jM3+/LYwwXFBXUe13st77sg0c3+p1c
k31w8NPOBwrZb7TFcEKqoPAugtVz2Ac3cHh4si774Je/tj17x/6bFYYPVEEz
r7gkRLMPrnvZorQZ++APl2RtUthfxp9mLVVQy38l/91nHzy856rD3uyDF+xy
+HyW/QYTZ/UqGF1BJ75UbP3NPnju8gdnerAP7uS+4+Fu9l+N6MbfsBXken1i
cze+ngSnXQ60GcQ+eEXC2Irl7C/pY7iAqqC+m83bDGAf7PQzNd2fffDPPpGh
U9mv195wAq6gIWmL9ixjHzxWOKl4MvvgyQ2G9hjMflrj6h1Is4rz+p1nH5yb
ssJ/Hvtgv70u09qxv8hweXymgux03fvksA/eRH41V7APVq2f+dOV/bqGy8Wk
CjI90Svcns/DYJM/jg02sf//3KkoTVlf9OS54fLpWQWNCgv81o99cMzxLyv2
sQ/Oex3gUsD+QsPlRGYFLan3Yk4E++B8q5t1T7IPHiqKe/ec/dqGr9fiCvrt
tMv2Bvvgni/Oml1hH7xn5X3VRfafGr5uxBXU57+N9/+yDx59+LT3ffbBwZ8f
n93F/nzD6deiksrDA0ObviojcK+4Q8desw/emZaVHsa+u+F05FZJbl32Okxh
H2y5Z+aAbPbBsl/dV41h/4nh8PSspO3R0Udi2QcXFRc3/80+uHf37rc7sz/P
MFy7VlLbqHh1Fvvgt43+9ZWyDw5NbbfRnX1Xw+4bVEn13unburzm7+H/sbWY
dlmIrHzBorrr/8nqiZ48MnycwEq6mP+0oT/7YK+VN6zd2AdfcT4lyGZ/7hzD
n0p6GqF9vpd9cIep+hvN2AefHmB6MoV956AefIVcSd82P6z5gX1wtyZVmzqz
Dz7wqIkilv0HfLXYZlslpd+0kDq8KSPw0rb91g1gH1zv4jrLVezP7mWYEPD2
bZQ/x499sM767tFx7IMtBfvfBbFfs53hgqKS+klGBUWzD3Za5/p1JvvgQsvc
cd3Zv9fQcEKqpJbfwx5+ZB88/G699uHsgxfsf32mNvsznQwfqJJCts7Y6pJe
RuBjM2LPbGYf/K53xkOZh+iJg5nhiqKSNMqJlwLYB0c9DvQ6xD7YbNPYy1/Y
vyvWZkX8q6RL5RfqHGEf7PWg9cvz7IOv7Liy7Db7MwzTW2Ul/ZJcfpXLPriH
tnRJMvvgvZZe9WPYtzNM92yr6EFi1aX6b8sIfL10jdcr9sFnvWpcXsL+HcP0
x6OK+lz3uDWNfXDG5Zfl2eyDgxOWtvBnf5phOtCmimYe03w9yz74aIsnd/6y
D/6QtOGgN/vVl8e9qkj2PtrmN/vgSPHMjUr2wZZ1u6vt2a++XBxRRdFttX1b
vysjsOeIJ6NtxVa+4JR5G6aX1RU9qb58mlxFQ26dmr+AfXBm+R+PeuyDJ7fo
kP6G/erLiQVVFCS13nydfXCg1vRnG/bBAZaaPgnsV59911bR3Aj9WhH7YI8f
dKo3++B3A9Y/3cp+9dfNniq6KNg1ouv7MgJ7aYrGjmIffMW658TZ7FeffuOq
6PckUclK9sGqw72VU9gHO2RudRjIfvXp6BrvX9W9vvfZB1+PvBYdxj74rNm5
wqbsVx+ej6tI3eK6n4Z98JM3l12j2AdvXJCQY8p+9XD9UEXPrX7b9v1QRuCb
G+5tjGYffFKzW1VYR/SkevcVVNGOeo/mRbEPLhq8KO8U++DeS5uMSGXf+HGq
aMWVghmp7IMblq2sc4N9cFprp4xT7JtU/xFQot3QUpOMMgKXmh3omco+uI3q
286oOrieF9DXO/1Uvhm4nhfQioX7+n4U43peQO7NCzZOYz9RmMlX1OyPmL9j
PftgWebEpoXsg90nDn9AdXD9LyD97JToJxm4/hfw/KyyuEqM638Bmbxv1r0x
+wHFhmAgoDe+yyx17IM7fZy8Qc8++MS0wVqTOpgvCOhO/77FvT5iviCgq/sy
FI4SzBcEdOHHdMei2qInuizDBxKQ7yT3pqvYB38M3DK0Ifvg6WOlYc9rY37B
/7/n6Ad3PmJ+IaDbHz6HtZNgfiGg2OCgpufZT3hpuCAS0JOZJxOE7IMFsS1D
e7MPbvzhRptttTEfEdAwN5eStp8wHxGQyxaLHiMkmI8IKF8q2zOP/bGG2e0Y
AWXY1A6Zyz44/Jll3n/sg+uskYwYWRvzFwHNaRDR/swnzF8ENNH6x4gQCeYv
AholHBDSnn2NIWcF8/66N7VrHvvg9dcm7FnBPtjknP8vl9qY7wjocNtxy10y
Md8RUIu3AXGbJZjv8P6ZF5gmqyV6csGQg5YKaNOH3mXD2Aef6Zyx+gD74Mex
M2y/1cL8SEAJtsEx6zMxP+LxvTHH87QE8yMBXVH5JT9h39+QUzYJ6G6fkNBk
9sFhNY8du8o+2PPn2/T4WphPCajf0nELyzIxnxLQvvyAb/clmE8JqHBw4LCd
7KsMOSKGx7dyy9FGn8sIPChyxu9X7INXmPfpvLgW5l8Civ7xpHzsZ8y/BBQv
b/8gS4L5l4BSnE7vCGQ/3jCdPyegQ30azt7CPnh29JD/frIP9vm5eFSfWpiv
CahysYfp3c+Yrwmo94nBqRUSzNcEtOPV0ihP9v0Mw/W2gAqa7Xjyh32wYmhR
lZJ9sFNYr8b2tTC/4+3d/+ip2lmY3zH7//5jKcX8TkCXp3buIHEXPVEYPs4L
AZm+yzw9mH2wya0uCc7s/z8fO3w93x3zQQEN2Oz+PDwL80EBOc9I69BAivmg
gH70WX4yjf2zhulYloAW7jpidZZ98Lei8xtasQ8e3vO25po75o98vHwtnv8h
C/NHPn6limOdpZg/8vHr5pgey/5Iw3TmFx9P0TliJfvg781ka/uyDx6c4mq1
yR3zTQFNCTx/yvML5psCOjL+X8thUsw3BZQZ0O7GQvZlhumAVED7F71Z7Mc+
uGRSpxPj2Ad3H3r8VZA75qcCavfFed7KL5ifCmjE8oF5U6SYnwoo1H3liIHs
nzZcTlsJaXvnIztPsQ8uene+aC774N5zbvfs4I75rJCiMx5kv/yC+ayQSsSV
d5ZIMZ8VUvc6TQ/WZ3+44XK0lpCOBbUeV8E+uEVgesAa9sG3xs0PtHHH/FdI
6Rc+6F2+Yv4rpKRL4iebpZj/Cun4lTrrZW6iJxLD5VwLIbWZ+72wG/vgt/91
U+xhHxw6cn/NEjfMl4VUnvxKOekr5stCelCxRHdYivmykHZ61jfPZP+k4XKo
m5DuXOvjF8U++Or86M+n2AdfaPUzKNUN82shRRV4FZ35ivm1kArv7oxIkGJ+
LSTffaWO19kfaricGCIk22e37j1nH7xRsKDyBvtgdcMWzU66YT4upL4enXNL
vmI+LqR9L0f63JNiPi6kn0vnxOxhX2T4eg3i7Tu62yDL7DICV3weNeYp++AW
QbOmrHPD/J0//8Mos+bZmL8LqWnVKd83UszfeXs1SY1cyP4Jw+k3REh/xEr3
geyDVWsjLT+xD7a3MpdOccN8X0gtTZ9sDs7GfF9Iw1Pbn8mRYr4vpAVRpx/5
sT/YcHhGCMnnjFPAevbBfq0s3AvZB8++Lv9CbugDQrJcGbgjLht9QEhP48YH
/5GiDwgp8kVAr47sCwy7b4eQwnrX87rPPrh+xtadleyD38wQlTZ1Q0/g7Smw
6f01Gz1BSO3WmkVLpegJPB6s1T/d2Deu/wnptmXZC2E21geFtPBpzyUaKdYH
efuv29mAJ5T/6w9CstpzJt0+B/1BSP1nJnQyl6E/CGldj+vHlK5YTxSSy5xW
41rmYD1RSJvrpmfZyLCeKCT5u/mB5a7oFUIaHRY9q18OeoWQDn5r9p+TDL1C
SDlDU0YVuGL9UUhnbyssJuVg/VFIrdr1fVpLhvVHIV0/v2ldpiv6hpCsbx7q
GZ6DvsHvf8F5xwYy9A0hrW15pyjNFeuVQtq6Id5uTw7WK4UU3Phf/2YyrFcK
qc+TdqvvuaKHCGlGu4WR53PQQ4QUNOL4tNYy9BAh+c9743vVFeubQoqr6nv0
UQ7WN3m8Phg9p70M65tC6rR9euczrugnQrq0Y2Hwlxz0Ez5/BB8P6ipDPxFS
215v/A65Yj1USENP+RWW52A9VEiZF12795JhPVRIk2/kRO9wRW8R0pT63epa
5KK3CKn2q1FW/WToLfz3l8wSr3PF+qmQPpyPcK2Xi/VTIYW3/vFisAzrp0Kq
e3XAiqWu6DMiUrpP+9IxF31GRJFpE5aPlKHPiMhiub/7XFest4oo1dJ79tBc
rLeKaPGGEXXHyrDeKqLG2pD3k1zRc0T0K7jhm6m56Dkiuhc7JGmCDD1HRHs/
LD7u74r1WRFNd5tsvTwX67MiqmOZ3W+KDOuzIvooHbN2kCv6j4g2XDVvsSsX
/Yf/ftn6N8Ey9B8R+bbWLejpivVcEc3o0LjNmVys5/Lr278eHiLDei6//p9F
oe1d0YtENK8wof7dXPQiEXl093q1UIZeJKJ30ZeXeLpi/VdEC5pHmbzPxfqv
iCa9aeS7TIb1XxENX5gaVdcVfUlEgqgF+UW56Esi0jSqdzdChr4kohqpb/Y7
umK9WETe0Y2TFblYL+Z/v9n2dpEyrBfz+02pijd3RY8SUZ/W7WMc89CjRDQ6
/W38Jhl6lIiC54ckK1ywviyiv1scV3nmYX1ZRKvPDGi4Q4b1ZRHZP4p4XuGC
fsXbf637wp556Fe8/6cNOr5Xhn7F46Xf8jdFLliPFhF9WRXun4f1aBH5L2/Y
4KAM69G8/9yfp2WzX513Vogo4JrfwTnsgw9ddj1/lH3w14ScO+9csH4topbS
jZ/W5mH9mrf3o+ldTsmwfs37Z0vfI0/Zr84j20T0U1zQIYZ9sELT7V08+2An
q31zk12w3i2iJLH13Ut5WO8WUbnm6cJEGda7+d+3Wut5mf3qvHCEx5M4PCSV
fbCkdwOPG+yD62xNe3vKBevjIjqwfOWw7Dysj4to1vcpmXdkWB8XUbdBAycd
ZL96en5RRMendJ1ayT547oQ9Rx6wD+405tfH7S5YTxfRhNKERMtvWE8X0eGe
iaFPZVhPF1HWzste69ivnu6liOjZk1OdGrAPFlRdHPmKfXCjxjfmLHHB+ruI
ztS4r+zyDevvImq1MazvexnW30V0Q91002z2q6cDr0Vkc3We+Sj2wf3n5/l+
Zh+8tvWIyP9csF7P7/+kcOzsb1iv5/c/92FArgzr9fz+O2wLHMV+9eViroiW
dZ9dto59cAO/3NUF7INfzhxl288F6/siGpVyMePwN6zvi8i18t+tXzKs74so
r1nb2C7sV19O/BPRrlfzzW6wDy4WHjMpZx/cs366rqUL7gcQUZsGnbe++Yb7
AUQ04tXuGSIZ7gcQUeiS373rsV/9daMUkbiT35Ri9sGPdo/LVrAP3vo7aIyj
C+4fENOJmvk7tN9w/4CY/pivDNbLcP+AmDopnHuZsl99OrIVk3/zdIc6+WUE
Dtix1NxKbuULDqrwUIqdcb+BmKYMzCrtlI/7DcRU2/nOfXs57jcQU+b3Qzt/
s189XD3EVHRmc1M/9sERrc5sd2UfXPP6o8ocZ9yfICaBsHPyvHzcnyCmtZrd
Cz3kuD9BTDWsf3u+Zb/647QRU4NDNhe3sA8eMvvZvCbsg5d2XdP2kTPuZxCT
JEctPZOP+xnE1EcWua6VHPcziGmrq5nldWf0UjHph3889zgfvVRMqS6ShPZy
9FIxrc+rfe20M+5/EJNFw/o3v+Xj/gcxbbAeUu4jx/0PYtIJlrQ84Iy+Kibn
MwMbKvPRV8U0sNX+IX3l6Ku8va5/X7zJGfdLiOnfq6iyWt9xv4SYVMKC+4Pk
uF9CTPb1fXeGO6PHimnQi6w6Xb+jx/K/17Hr4FFy9Fgx/Yg7tGy2M+6vENOT
6/UvjPuO+yt4f7TZ9i9AjvsrxNQ4Qdg20Bn9VkwrBpnHLP2OfiumqZ9S4yfL
0W/5358SmTzYGfdjiGnxZeuC/d9xP4aY8kufrpwlx/0YYhrqtdapmzN6r5he
DF+34+Z39F4x3Rw7LXiBHL1XTCcn9uvVkv3q6d4WMQUm797/iX3w4XYzZ4Wz
D/4S36NbbWf0YTEtONVFJvyOPiymby33rFsrRx8W0/Abvyys2a+eDhwS0+Xs
4ckuP8oIXHbnwNXN7IO9DubFy5zQk8X0edq6j51/oCeLSTqhkWS3HD1ZTLX8
n9b+zX715eJ5MaVtHDdgPPvgm4VZ/ofYB5/sGzj1ixP6M+9PjbfDyh/ozzz+
nox4HidHfxaTYkPIqhfsV19OJIvpautRbY+yD54/3HXEBfbBXvNz591yQq8W
k9nQ1ycf/ECvFpOJS9Kfa3L0aj4+vh3vcJb96q+bl2IquBsb/IN9sKLdhdi7
7IOd4m992OeEvi2mmFGHl5sWoG+LaXbM7CmpcvRtMfnkdhkUxX716ShbTIkJ
q754sg/2Cp3a9Q374MttBhxa6IQeLqaDMd+jhhagh4vp1yx5o0w5eji/vo9z
6iT2q4frHzFdCPVduoB9cKLHvvrf2AdfTS94OcwJ/VxMb3dYJu4rQD8X07Lg
DV4lcvRzMXn00iZ2c8L9MGLqm7rC804B7ofh7XGjwbAKOe6HEdPPUy8WNndC
b5fQ3TdpP3IL0NslFLb05kqZHL1dQp714pxcndDbJTTjncNXXQF6u4TqLNt0
Ry9Hb5fQx7rKgyZO6O0SyssLsPYsRG+XULLPF1MbBXq7hGIOjNdU1ERvl1D+
qj2LhhWit0to5dTiSS4K9HYJuQzoMfRbTfR2CZ1qFWu3qBC9XUKtbH8/q6dA
b5fQjbLOq1/XRG+X0MGygTkHC9HbJfSrp7NPcwV6u4R8dn6PuVMTvV1CiTkB
mfcL0dsl5OVz6La3Ar1dQpdjvhw+WxO9nV8/fo2ssBC9XULN/53s012B3s6f
v92zzdE10dsltKjDjH7WP9HbJVR/ZNDHfgr0dgm9njt62tqa6O0Salf73PV2
P9HbJfQ27e/8EQr0dgmFhnu3mlcTvV1CLXp+7RPwE71dQjv3Lq85XoHeLqGK
Iref42uit0uoy8jtf1f/RG+XkINr0/tTFejtEvqd+2BX/5ro7fzvT+x35cxP
9HYJ3Qp0mh+iQG+X0LGxBa3b10Rvl1BkwJYtr3+it0uo8fgZTZYq0Nsl9HR8
n0f1aqK3S2jQ7i+Lq36it0vIeWbX/DUK9HYJ/ehxaEiNmujtvL17JIXWKkJv
l9CwvVeObVGgt/P4Lr6QLnFEb5fQGuHxRX2K0NslNE3ze1K0Ar1dQv2tOw39
6YjeLqHtTdzXzipCb5dQ8FDLRkcV6O0S6r1I+vS9I3q7hM6vPbd7VxF6u4Ra
F7QqPqtAb5fQtX7Xetx3RG+X0MWQT3FJRejtPN4mhl+8okBvl9CVEbVvXnBE
b5eQMLj9ldwi9HYJPcyxm5+sQG/n9+v3t3WMI3q7hFKnjr9tUozezsfHBPd2
qQr0dgmd9v9yPsoRvV1CneuXJLUsRm/n8WB9r/yNAr2dx4NwT4sFjujt/P5X
bo33K0Zvl1BpXJNLnxXo7RJq++Lh1SBH9HYJyW6ItiwvRm+XUN8ra2d8V6C3
S2jLRas+gxzR23m8JJaNO1GM3s6fr1Tl9keB3i4hgZft146O6O0SatSgv93z
YvR2CQ3d9vGZQIHeLqHFwqmrGzqit0so5PWXhH/F6O0S8ljaNVSlQG+X0Lt6
h9rYOaK3S+je/sOtnUrQ23l8xc+2tVCit/P5826XMrkDeruETE5t2elTgt7O
+2PumbMOSvR2Ca3v8Oh+iQN6u4SKZyW/nlyC3i6hHkfbdaqtRG+X0N738cc/
OaC3S+h+4uifG0vQ23l8lY5LaaxEb5fQOa+g6McO6O1SOr9p96eEEvR2Kf1r
PLOLlxK9XUrej3scueyA3i6l1b0fHf5Qgt4upYajr5/vrERvl9LzGWduxzqg
t0spqO9Qb0kJeruUDtc8YNdHid4upazCb3+3OKC3Syn+V+Khur/Q26U0717o
7MFK9HZ+P3u8ui5zQG+XUpdRq9P7/kJvl9KomJNJo5Xo7VKak/vs2HQH9HYp
7XGYlT7zF3q7lGaaHxUFKdHbpdRT+d7DzwG9XUryKu+Y7b/Q26Wke/DWM1iJ
3i4li+0hyb0c0NulNO7Qg6ZXf6G3S2n8r2tD5yvR26UU2PVsWGsH9HYpHXOy
XPnpF3q7lFoMfDolXIneLqVbK9cNrO2A3i6lnPAme6W/0Nul5DNl+8x1SvR2
KR0cVNXd0gG9XUonA/vPqfsbvV1KCYf2/bdVid4upZtZP0aK7dHbpSTwvaPt
/Ru9XUq9/RdStBK9XUrbpzXf8NMevV1KCxuUjJ3+G71dSpOs77nFKtHbpTRc
uOdrhj16u5RM942ftek3eruUTGa5555Worczd/8y6rE9eruUMgdd7XDhN3q7
lMLHtNl9SYneLqXaUy79uWKP3i6lS92uJL/+jd4upVKHy+2SlOjtUmpbcin+
uD16O4/Xgg7S0t/o7VISdhv56L4SvZ3H9765W3bao7dLyWtmtzL7P+jtUkrP
ed/zuRK9XUrz/WbtXGWP3s7H17XcI95/0Nv5/c2XnX+rRG+X0rVWrrdD7NHb
pTR122jV6D/o7by/f8boPivR26U0pneOWZA9eruU/ouudF7yB71dSl/PrRmY
r0Rvl1JASo2VQ+zR26X0t4/Xj/1/0Nv5eI7eubJEid4uJfufpU7d7NHbpdTt
XczUpD/o7VJyFMcfKVeit0uppG7yxxb26O1SalMr70DmH/R2Ke3akhwvUaK3
8/6QHEiuZY/eLqW7i96sFv1Bb5dS5aSkkxoleruUPIcef2Zlj97O56ewEbVc
/qK3S+n+twNbLFTo7VLaPTRPIrNDb5dSceKc2R3/ordL6V7if//Zq9DbpbQ3
ceSoP3bo7VISL+ob4v8XvV1K2uM1PdxU6O1Ssnpd+DbbDr1dSo3nuTRa9Be9
XUpDj714VU+F3i6lxW9XLH5th97O+4/67tzzF72dz3/R0cHNVOjtfL4sLOx5
zw69XUoR3j0SL/9Fb+fjecTeUi8VeruUXoQUeyXaobfLSLzvUNSbv+jtMuoz
69e0Tir0dhlt7dbV97gderuMwmeY2P35i94uoyl1Up/1UKG3y2hwRtTq3exX
Xz65ySjtlu8oi39lBBa29Xftxz644YVpuevs0Ntl9Nyz25Am/9DbZdTxzfsx
Q1Xo7TI6uXDW5EXsV3+9esrofb/vyj7sg5f5r4wczT7YY5qz+Qw79HYZ1f87
cM7Ef+jtMrLuuf9ooAq9XUaiXd/fjWW/+vTbVUYDTxzZs4J9sPOf2eemsA/+
0bHLvYF26O0yGp7nvuTAP/R2GR1YMejELBV6u4y+uSx/5cN+9eE5SEZJU2u5
XGMffOXIls3z2Qdf/CiRtbJDb5fRqxDLpW/+obfLqNPEDZOXqtDbZXRihHZw
Pfard1+gjC7IZh4oYR+cqI31XMU++KrFh2QHO/R2GY1WvwzX/0Nvl1HW447f
o1To7TIK2nhikAn71Tl9jozaRH/18CgtI/Dbc3e2bmUfHJpyUCSyRW+X0aJ6
o7Z2KUVvl1H+4Jgme1To7TIaujT34S9b9HYZ3VsvS/ErRW+XkffpPtdiVOjt
Mop/svlcji16u4wm9rh+O6QUvV1GgR/atDumQm+X0biZCeff2qK3y+jgyplr
Npait8vo1/eck6dV6O0y8hno9+yxLXq7jGb6OtY8UYreLqO6+56bX1Sht8vo
Q0GE4qYtejuPr00pS+6UorfL6FnjsMlXVejtMlr7uNmQ87bo7TLKbRdx/kMp
eruMVthNvXRLhd4uI7d/A67G2qK3y+iO76Irf0rR22XU7mO9snsq9Hbe/9Ne
t95ti94uo/Xf07eblKG3y2j63U5NU1Xo7TLy3X/sQZQteruMLCY86123DL1d
Rk8PdRj9UoXeLqPIrJMzltmit/P76Xs4vWMZejuPr+jzS9+p0Nv5/RTe9phr
i94uo9gl0V2Gl6G3y2hOfrM9mSr0dhl1GZLya6IteruMPnrq1gaXobfz/99B
p3JU6O38ehXrn/rZorfLqImo+4XVZejtMtree++lHyr0dhkJthZf6W+L3i6j
dyXHkw6UobfLqLPywpUSFXq7jI45JF3wsUVvl1GjbdviE8vQ22X0+meTS6Uq
9HYZLe798KqXLXq7jJoKp0U+K0Nv5/GuOXJKoEJv5+PD+mNqQ1v0dhml5Ozq
n1eG3s7jX3Z2n0yF3s7j3/X+Dxdb9HY5RZ5bJhaWobfLqfBv/lqNCr1dTv28
B1tZ26K3yyl39foYm3L0djklNyycZaZGb5fTwWfko7ZBb5fTsuB6zZuUo7fL
KS5n8LAaavR2Ob30W7qwyga9XU5HxlxJ7F6O3i6nOW6XvRzV6O1y6pJ9KbHY
Br1dTrtHH23hX47eLqficRds3NTo7XLqGXSrPNsGvV1Oa2IGHZ9bjt4up4JZ
n37XVaO3y6m/z5RO72zQ2+Wku+hkF1WO3i4nE68Xzxqp0dvlZHpl5epUG/R2
Od0/MD7icDl6u5yuzXI/2VyN3i6ncz5fnt+2QW+Xk69J6K+r5ejtcnJaP3FV
GzV6O+8P/XCHSzbo7by/wuMC0srR2+XUeErL8R3V6O1yejro5vg4G/R2OTmv
7/46vxy9XU4WjR07dVOjt8tJ8aT4+H4b9HY5HVat6S8pR2+X0wXdSac+avR2
Od0xe/Zjiw16u5wm9j+dZleB3s5/3ylE2F+N3i6nzz/aN1htg97O+2tD1rhm
FejtcprZWJo1VI3ezvvriXtgmA16u5y8lX2qelagt8tpZGTGAz81eruc5pnP
2B5sg94uJ7ux8qNjK9Db5bQpa92FADV6u5xUgRa3Am3we0k5pYhrBoZW4PeS
cqrUbDo0UY3fS8rJ00qRNdwGvV1O5sG7mm+sQG+X04ac4B3T1ejtPF78elb0
tcHvK+WUcXq67bEK/L6Sx2+r2I1z1Ph9pZxir2eoOtmgt8vp9MlVVkkV6O1y
Sph7csMCNXq7nG50eK5pYYPfY8pJdD6pXnoFfo8pp7WXyrcuVeP3mHKyvtpC
5GGD3i6niC+5I4oq0NvlNHW57ECEGr1dTgPdXfMcbfD7TTmFnroWq6rA7zfl
lHexzYVINX6/KacRNxJumdmgt/Px4f/T3LUSvZ05QJG6WY3ezhxUM1JWA7/3
lFOz4y7RbSrxe085vbnwoninGr/3lFNY0orupTXQ2+W0uuPnXgMr0dv5/b+T
OO5Xo7fLacDcWkXfa+D3oXL6Pvmc3ZRK/D5UTt2y//Y/osbvQ+V0YIz36k81
0Nt5/MWL9Msr0dvl5HhJExWnRm/n88tVK5O0Gvg9KW/flY08oivxe1I5Pfu+
7eU5NX5PyvtjoGBpSg30djl1LFwxKaESvV1O9infayWq0dvl9Dd6YOZl9ttW
fxw5Jfp2SXvKPtjLadSSG+yDLxfMbnCqBnq7giKdNwR9q0RvV9D0gY2/JqvR
2xXUb+WTcQfY/1rd0xW072p4LSn74Flt4gY9Yh/c/VJa+JYa6O0K+tLUzaRm
FXq7gu7UsEx9rkZvV9DhSmlURA30dgU1sxtbq3UVeruC3mw8OChdjd6uoDDV
1/D5NdDbFbRlgePEAVXo7QpqcnzT149q9HYFPX6jGDu1Bnq7ghzP1Ho3pQq9
XUEDEyyXZavR2xW06rqk7pga6O0K0g5qvjCiCr1dQVFjhtX7oUZvV5DZlIVv
BtRAb+ft0amoT0wVeruCju6OyChRo7cr6MNvxxk+NdDbFfQ3vKjvtSr0dgX1
jEuJLlOjtytod9rewlY10NsVlBOUsPhNFXq7gnxqeU0WqdHbFXTw8+Uh9Wqg
tyto2NJzn0uq0NsVdCD/bxelGr1dwdfH3ocdaqC3K6jNzQ4hJgL0dgWNaGvv
YaJBb1dQ6MU/b/XW6O0KmrjmmHd9AXq7gr6evGBnrUFvV9C4Z0l/hdbo7Qoa
/r5Oy+4C9HYFje380sZRg96uoElHl5UXW6O38/ic8WlMgAC9ncdnULibuwa9
ncfn6NrZX6zR2/n1fmRfWyxAb+ftIb/Tpr4GvV1B2U4HE15Zo7cryNfWu+8e
AXo7j++Nu0Y306C3K6hQ9Xf6PWv0dgWR1Qv9JQF6O/umwigvDXo7+5oGJpet
0dsV1G5vhPilAL1dQbua/XjYUYPerqDSlAFbT1ijtyuoLtWtWyJAb1fQy9GD
rXpo0NsVFD59mXiPNXo77//i4MWmQvR2Hl8pdSb7atDbFTR774chUdbo7Qoa
89xU2VCI3q6grMW+j4do0NsVFNQwatNia/R2BcVo9yf1FqK38+tFxbcdrUFv
53/f9O6FGdbo7QoK/nnqxEQheju/nqLlxUANeruCRte8cXOsNXq7gjr4JyRH
CNHbFWTvlthuqga9nY+P7MvxA6zR2xWkblrX5IgQvV1BT4Zapc7WoLcraGOY
OKqLNXq7ggIOjom4I0RvV5D7bLepCzXo7Txeu2YPaG6N3q6gS9fONswSorcr
KPFygvVyDXq7gq4kXBO4W6O3Kyjh8WiRSIjezn5VzMO1GvR29hvnbLWyRm/n
89WbvSJnEXq7gmYknVu7WYPerqC+x1Os5Fbo7Qp6a7WjYUcReruCbvU7O2S3
Br1dQcfWPlj8xwq9XUFnp0xa7i9Cb1dQSHZgg4Ma9HYFtR8zNi3bCr1dSf6/
askWidDblRRwb4v2uAa9XUlBeyQWr63Q25W0M+TpqWgReruSmk4U/DmnQW9X
0oMRjTqkWKG3K+lo2fgl10Xo7Ur6vXp8/mUNeruSutiOH5Jghd6uJFGXtHkZ
IvR2JfUetSTvlga9XUnbZjcYEWuF3q4k+QTZtioReruSdIe0Px9o0NuVZJFl
0Xu7FXq7kn70e5VeU4zerqSIjzdFzzXo7UpynnbCI8IKvV1JvYY6dOwgRm9X
Us2xA+zfadDblVQ0adWfuVbo7Upqd+/QPX8xeruSRoTN9s7SoLcrKbRZ13MT
rNDbeXstaDFziRi9XUntj78Jytegtyvp7JsFfkOs0NuVNHNCZNsDYvR2JeUe
arSrRIPeriS/rNR/Plbo7Uqa1CDQ7ZYYvV1JE7a5p5Vr0NuVNFaYtbyFFXo7
b98L0+tmidHb+d9vHWQl1aC3K+nhldFidyv0diXdTRrRUypGb1fStfIDfloN
eruS4lvkBVtaobcrySUsdXktCXq7kjbXWxxnqUVv5/35ulGaxBK9nbeX5az0
bhL0diVNND0qctCit/P21b73KLFEb+fx0jPH5z8JeruSoh2TR9XSorfz/iqK
mfXZEr1dSc1lD+6tlqC3K2mHNuxaQy16u5IqLZqee2aJ3q6kE98vjzkhQW9X
0lx5qFtLLXq7kjo5e2XftERvV9LNn/21jyTo7UpakOIf1V6L3q6kVtFTTc9Y
orcr6fhHjwcFEvR2JbW8/bKymxa9XUlJR5Y23WeJ3q6kqpJ3O0yl6O38+Xss
C/bVorcrafueur2iLNHbleQ9TjS3mRS9XUnvDmpyh2rR25U076vVyDBL9HYl
nf7iGTBIit6upJCuNuPHaNHbldThUMX4KZbo7fx+ffQj50rR2/l88Z4+/6dF
b1dS+az1/420RG/n9/+lwZgdUvR2Ja1dPiQgWIverqQa7ksm9LJEb1dSaqdG
0y5L0duVdOPdq+xQLXo7v985i/29LNHblZQ1L375eyl6u5KWe8ybskyL3q6k
Wm/bDaprid7O4+/umJgqKXo7n08WZpWs0aK38/nEc4JPDUv0diVlyj4kO8vQ
25V0+9GthZu16O1KOrI51lNugd6upMa1X//oLENvV9JryyT5bi16u5IWS447
/bZAb+fj+0iFTaAMvV1JstlrNh7Sorcrya2LjTrLAr1dRQqlxCdCht6uosi+
jxxOatHbVWSxaUvJcwv0dhV96nB01jEZeruKuoxscfSCFr1dRbFzb71PssD9
7SrKdjy+/6EM97erKPn5HM/rWtzfrqKDEZ3unrFAb1fRrWtPH/6Qober6Or8
DtfvatHbVXSh1akz+yzQ21W0LievxESO3q6iRsk+PVK16O0qehZzYE+UBXq7
imrPfFCjmRy9XUUvc7yfvdait6so3O/smjAL9HYVzd9PLQfJ0dtVNKkkY9gn
LXq7ioZ3m75gigV6u4rOzR/Bxzh6u4r+5WVm5GrR21XkPXzi9JEW6O0qsnF7
O3qHHL1dRWZponFFWvR2FWmWewT1skBvV9GT2rcmXJajt6tIkFb+pVSL3q6i
xuEtArws0NtVpL5vEvhejt7Of997/XixFr1dRRvP6gPqWqC3q+iH7/1hVXL0
dhV13xeWqdait6tof0HTSTUs0NtVlOVd1dFZgd6uojtv14y00KG3q+hwSI25
cnP0dt5+u1IcOivQ23l8NA17bq9Db1fR2PvNVv02R29X0YA6PfIDFOjtKnIe
7NjNXYfezu93WfH+L+bo7Srquz3uxAoFeruKnIJbXmygQ29X0c9eN2++MEdv
V9HX6/X9YhXo7SqStdnm2kKH3q4i9wRhzi1z9HYVPbgpr7qnQG9X0aJy7Rpv
HXq7ipq2tKhxzhy9XUV+LVZv+KZAb+fxvmNqoY8OvV1FueX96YA5eruKDvRV
mWoV6O0qio+O9CUderuK7haaRW0wR29X0eyinMUNlejtKjra3efEEB16u4o+
7I15tdgcvV1F9ukb3pMSvV1Fm5ZOF4/WoberSOVBdaebo7fz9ouZX3uGEr1d
RS9K8gYF6dDbVRThMzx8tDl6u4q2fqztt1GJ3s7bQ7IlZroOvV1Fj2pLcvqa
o7er6Hot1yXnlOjtKrqSNjA/RIferqKE8BVDvM3R21XkaiaNeqFEb1fRFl9t
oyU69Hbef5GWqQ3M0dv5eOo5ffUvJXq7itY7xk5dpUNvV5G+KKO/gzl6u4pu
hJlNt1Kht/P7OW4Su0GH3s7v57UuQ2OG3q6i4rEHO7RUober6J5b83c7dOjt
Ktr79c7ccjP0dhX13J9bNkSF3s7jY5ZMtV+H3q6imd1cbfPN0NtV1P7R6f0h
KvR2FY1sH+J5TIferqKQM+3vvjVDb1eTiJ432aFCb1eTJmPx0LM69HY1WU9v
uOiBGXq7mpz7NT9xSYXerqaB/jZzE3Xo7WqKmFbR8bIZeruaPHbdMUlXober
6WVwu/VJOvR2NS3reV5/zAy9XU1+CxaOLlWht6vJbdK3mPs69HY15Q4blrPT
DL1dTSti/LfbqtHb1fTD0+3sMx16u5oGJWc/WG2G3q6mqr8LLnup0dvVfD33
LTFdh96upu27hiWGmqG3q8lzVl7KcDV6u5psjvpcy9Sht6up8v2BcxPN0NvV
NOf7/RuhavR2NU28630lT4ferqZR+89eHG6G3q6m+fk9Ynaq0dvVVG/lh/gi
HXq7mtKdZyb3NENvV9OimbunJ6rR29WUX6dZbKkOvV1NQz/cy/AyQ29XU/e7
gjrpavR2NX1o13urSIferqZZ8dvEHmbo7bz/m117+E+N3q4m/fY2i1Q69HY1
mVUmNLEzQ29X08wnbiNtNOjtvH/aW44z06O38/48Lf1PbYrerqZbLde9aqVB
b1dTxbCCjrZ69HY1tVjQ70SZKXq7moJ9h7YfqkFvV1Mdp0w7Fz16u5oyCib9
/WaK3s7jrfzHprka9HY1WT2QF9bVo7erSbzDqe87U/R2NY19cTNtqwa9ncfb
kgU3m+jR29WU3aBl3ENT9HY1PfzQXXpeg96upuud/da11qO3q+ls7EzLq6bo
7TyeOohd0jTo7Wpq+u7hwI569HZ+vblbV8SZorerKa1gTqMSDXq7moR3c617
6NHb1dRw30jBHlP0djUVjW1cz1yL3q6mFLfXL3316O1qiv66aGmkKXq7mvZ6
J1k11aK3qyl+15UNQ/Xo7Wq69/eCJswUvV1N9UW3i3y16O1q2tb7and/PXo7
nz+2nt87zRS9XU0bzr68Pk2L3q6m0wnCsgl69HY1pV6r38rfFL2dXz98Z1ik
Fr2dzzdxZ49P06O38+un3X/ta4rerqZVyxIaxWnR2/l4r186ZK4evZ3PRy/b
LO5oit7O46Xd++cPtOjtaho8QiwI06O3qyl8Xt2GTU3R29W0KeDSpDwterua
mowvPbxCj96upsfj22S6mKK3qyk5VPhHoUVvV9O1iZoekXr0djWdH26929wU
vZ3H96wp82rr0NvVZPvfhLwtevR2Ph5GjRkhMUFvV9Nov4TCrjr0djUddPWK
2KNHb1dTTs7lmr9M0Ns1RNJovwAderuG/LXnXA/p0ds1NN0yJeeLCXq7htTb
s24t1aG3899vKr1yQo/erqGND9wvvDRBb9eQ04Duzvt16O0aeuHkNzBej96u
oYgfM1feZX99dU/X0ET7qLnX2QfXel6Qe5l98OdVviMTTNDbNdSpWdjd9zr0
dg292/5t4S09eruG5lYO9Txqgt6uoSbP3pqW69DbNbRdsNTkgR69XUOChh76
HSbo7Rrq82rqEFs9eruGMm5m73+mR2/XUPAJ//zVJujtGho2uXJ7Kz16u4Zc
jvRqmq5Hb9dQ/qftD+aboLfz+z3V79VgPXq7hsRzP978pEdv15BHh2knJpug
t2uo8ehG5rP16O0aev35lW+uHr1dQ4uDFkeOMkFv19C9JaP6bNKjt2sobPK4
jEI9eruGPIf8N6OvCXq7hq5b7l9xRo/erqEF/eKn/NWjt2uo1bq7A9uboLdr
6NrVq9ef6NHb2Z9fVlalR2/XUOvWrVs1NkFv19DU6bP/fdejt2uoTtB/q+V6
9HYNfRo9ys7ZBL1dQ1F1Izw1evR2Ho9WDW30evR2DfmKn1eYmqC3a+j87nMz
PEzKCdy6OCTWysTaF3yth3eGSC/8X2/XUGbu2TPd2QeHJ4e0cmQfXDvG+3ox
+8aeriHtAO9fgeyD9ftG3HNnH2z2I2RPFvvGnq6hmH+qtsvZB8++33dEA/bB
Prs2zktj39jTNeQedX9VDPvgtFNhPzzZB69IbTogmX1jT9fQL7t6726yD1Y+
s1rWln2w42pR3YvsG3u6hsZeeun5kX1wQGJHmy7sgydcPlFxhH1jT+fPM3Dm
5kr2wSaf6pzpxT5YP+XDo+3sG3u6hpKmHSizNy0ncPmRkp4D2Ae3/OizcxX7
xp7Ox993wcQ27IODuz38Opx9cO/928aGsm/s6RrKflHr8zD2wT4308LHsg8+
GBdeaxL7xp6uoQ2ORwJC2Aefft7cfSL74NSI219GsG/s6RqyWaYv2Mo++Fm+
/u4M9sFrB5vs682+safz++uVs/w8++AMxxVT5rEPDi5yHdSOfWNP19Ad1/ha
L9gHV1hcslzCPriF7KqkAfvGnq4hq+KCZ0Xsg58p7t6IYB+8znHfSUf2jT1d
Q+lnzdaYmpUTOCkhdep69sHHr0X21+uE/+vtWlreax01Zh/83a+g5nb2wYOD
+xVWsW/s6VpynXnfidgHp8V6v4hmH7ziw9mVhewbezq/XmTDqinsg++eerXm
CPvgA6mLa3xi39jTtZSwzfrbWvbBpT+f+pxiH9y299oDT9k39nQtjRG+yzrO
Pjigd2fpBfbBQduOuiexb+zpWtIdfJJ/n32w76/2d6+xD97Q9fT+s+wbe7qW
/E62FueyDz44N31tMvvg3A7zrWLYN/Z0LS1Z41dHyT44/6Tr4Mfsg4c+y1m2
iX1jT9dSw4+hI+uYlxO4xm0P15fsg4VH0nOXsW/s6VoKn387uhv74O8eFcXv
2QcPTm/efRb7xp6updu+E4sC2Qe323c45Qv74AsFmXsD2Df2dC1lBm8euIJ9
8O06TfZ/Zx985MOj7wPZN/Z0LX0xC0g+xD74jsmhhb/YBx/WffHsyr6xp2up
5pLibnfYBw/MV4yqYB8cMcRxVnP2jT1dSyZNBr/JYh/su31MJyn74PVVk4+7
s2/s6Vqyu7E9VMI+2LztWQ8t+2DVxQfpluwbe7qWXlbeqOdmUU7gpF7lVpam
1r7guO0tRVKt8H+9XUuC8kf5ndkH917TXm7PPni7zRnn3+wbezrvzxoJV8ex
DzYzCy1zYx+sUbdp/ZV9Y0/XUrBm+t5l7IPrUGxxffbBGRsyur9k39jTtXRP
8Tkyhn2wt+52gSf74Hjzw77J7Bt7upY63f4VeYt9sP3CewVt2Qf/ab7H9wL7
xp6upWdbw/d+Zh98o0lccRf2wacepnU/zL6xp/P5YFPQVTH7YGHjwLLe7IMb
Ph7Xeiv7xp6uJenhmd9cLcsJ/OhXjmwg++CtXfxcVrBv7Ol8vjo3o04X9sHf
Q+pYjWIfPNg7QzybfWNP15Isvs6sAPbBfVtb1R3PPnjLVfH78ewbe7qWijKH
Pg5nH5zS5UD7KeyDow9/Oz2IfWNP19KatCstDrEPntbx8rDZ7IP7x11a0JV9
Y0/n88UJ5Yk77IN95vadu5B98MGOmzo2Z9/Y07V0snVB46/sg0PSu21fzj64
4/x9VW7sG3u6jlbUrpEkYx/8w3LjlXXsgwdJ1Bcs2Df2dB21rOvhX9uqnMDD
t1plbWEfvEAsmiDRCP/X23XUrFayqhv74B1brur2sA+ulMSblbBv7Ok6Ovhf
xM0g9sGza01te5h9sM/nARc/s298XoyOXj9TLFvFPjipg27ySfbBJ06aD37O
vrGn6yhDlt7vGPvg24+W7rvAPjh2s0dBEvvG58XoaEJMpMcD9sFf40+9vMY+
OCA5delZ9o09XUfbgk9pv7EPPpszV5/MPvihXwfTA+wbnxejI1X0nVIN+2Dd
zKs9n7APNu9+fucG9o09XUcrfwz62cC6nMAnV46JeMU++IXTlJpL2Dc+L0ZH
h358KuzLPvj8yi4pGeyDk52ORE9n39jTdWTTIufvNPbBG218VNnsgzXlMXb+
7BufF6Oj/duyFOvZB5c06dq3kH1w94eHNhH7xp6uo5ARvk5n2QfnuTht/ss+
eGRegdybfePzkXXULuSA93P2wXbH4t8K2AeXvk0Oaci+safryOUhjSthH2xR
leGmZB8sbzL9qwP7xucp62j64AfrLGuUEzj2U9g0UzNrX/DHyU37adXC//V2
HVnPWHG1Bfvg/rFTLtuwD16bMfBSOfvG5y/z66sKfw5hHxzbN0LhzD7448aa
NfPZN/Z0Hb36MM9jHvvgpGXHBnuwDz5R5+3St+wbn9esI++zkYE72QfvTjh1
qCn74H/XUrPus2/s6Tpatmr3ocvsg6c0nPnLi33w4Oc9uiayb3y+s45CP+u/
vmMfnCd50rUz++ARtdYfPMq+safr6MDPgR6V7INndd+/tRf74G7R30Xb2Tc+
D1pHQ1JfTa1pU05gF8HN7AHsg/MbnfCPYN/Y03UUfk1yrgP74Lg22lYj2Qe/
TLC8Npd94/Oj+f8P7P5vDPvgls5+qwPYByd9n2k3gX1jT9cRXda3W8Y++GNp
1NvJ7IOne5nMG8y+8XnTfH76mLLkIPvgul3C6s9mH/zhSLNXXdk39nQdzTiR
eesO++A6FyULFrIP/nizVovm7BufT83Hd/NH4q/sg0OGVT1czj6448ImW93Y
N/Z0Pc0r/tdBwT44L6KnfST74JGOu/6Ys298nrWeUgvehta1LSewQJ40cSv7
4MZOx4aLVcL/9XY9Ff3JPt2TfbBC2TVhL/vgmvYHrxexb3z+tZ7SH2zOnMQ+
WOR9RnKYfXC9s49qZbJv7Ol6mth7hH4t++BaGZl0in3w5xkT1z9l3/i8bD31
jL3Q4iT7YMcLl3ZcZB9cfOtK+Q32jT1dTxNWug19wj74awPLzOvsgwNeSCed
Zt+mOsjpyaq5+8xC9sH9h6XVSWEfvG7h8g/R7Ffn1gF6ik1ps9LUrpzALSrT
p6SyD77dLHRgFPvGnq6niN4/NjVlH9wwWn76NfvgFz+dHoexX53jxunp0ec7
2wewD64Kb1f0kX1w01rne01l39jT9VTnR98ts9gHb707ukku+2DJvumPRrFf
nWtm6am5h82qLeyDdwzuP/Un++DKpWsG9GHf2NP1ZP/y4swL7IM3Cf/F/mMf
rKrf9kNb9qun8+F6Wvb45sBX7IPjFrX9JGQf/LLxxSn12Tf2dD3FH39a7y/7
4H9zBFYq9sHenRqJ7Ng3Pi9GTzXeL/9bw76cwP2XNehpZm7tC15bN22XWin8
X2/X09OkxYmt2QffaHsi1JZ98OkLr7zK2Dc+L0ZP6+8EzRjOPnh6u8BYF/bB
vufHZeSxb+zpeto1Ocd+PvvgZrV9nnuwD77/KWZVOvvG58XoqXDGySu72AdH
xLYsa8o+2CnjRuv77Bt7up6iX0zxvcI+2HNJbac27INTGnwquMS+8XkxPB5z
3796xz54+Apxx87sgxe61j1xlH1jT9fTqKDE/hXsg10PJ/r3Yh+c9zlx6g72
jc+L0dPq+bduODiUE/hHXtsFA9gHDxh+oeUq9o09nY+/u1edvdkHyxbO3zyC
fbC7Z2t5CPvG58XoyWtu8Gw/9sHpR4OOjmMfPP+d3/sg9o09XU8O7U9dDmMf
/Pztn8RJ7INXh3RIHMq+8Xkxemob6FOyl33wrkMO92ayDy7NKtnTnX1jT+ft
e1fneJ19cOXVJ8/nsw/2jF8f0Yp94+36erJM+9wmg31wP6EkfRn74MgGtULr
sG/s6Sa+07Yc6lnFPjhoxvkPa9gH+/e5E1yD/f8DQlFdlA==
               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw9nHVYFd3ah+nuUsFARex8bdEHAwO7xUDAwsBABQO7UVFU7MbuBlHBDmxB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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H1 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{1}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw9nHVcU28bhxEVuxFQMRBMysKWGxW7sVsxCBFQUAkJkVBEQBAsxMLujp+K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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw9nHVYFGsbhzlYCIoKit2goijYmA9ioIitCHYSCiooKQYhJSgCFnYXdmBj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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H3 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{3}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M
d96X92O+O1fekZ3ZOUnK1NzMnEJmdqqbFca1GgBqfFYLKAoUA6rrGb+poWsR
oLbeFwfq6FoCqA+UAkoDKUAZoCxQV+9LAvV05Xc1NR7nWw+M19gNNAZ/v47r
1LqaAZWAykBjoDxQAWiia0Wgud5XAVYBY7S/tcA4zdkIKKffrwYytdc1wFjt
taHWzu+aamzOvQGYoH2nAW2BdsBWYLL2vQmYqL1uBiapNu2BdGAgcCYwRfNs
A7K0p+1Atva0A5iq+XcC01SDLcDpqtNG4DTVeAYwXTXoB7QEWmm+dpo/FWgN
tAEG6NpW6+L7DsAgXTsCQ4HOQBegv8bj7wfrfSdgiK78ri/QQnOfBZyheg/T
GF2BEUA3oLuF76hPVSAD6AH0BEbp2svCg9X1XcKLvKcH6Rd6o4RqQF2KSGd+
V1TveT9a4/UGRmp+zpfwMceaDczUHspp7dSotOpNHctIZ96Xl278LuFF3leW
DtSrlH5HP1SUnvyukt7zPtEb3MNw1Yk12gXMUj1bqL59gANAjjTbC8yTlvuA
+dL0IJArLQ8BC6XZ2UCe9DgG5Guuw8AiaXkEWCxN9wMLLDy0B5hr4YGjwBKt
dTcwx8IfXGs/rfUEsFxangRWSAN+11/fcaxU3XMO+pW9dQ6wTBol/JqqvaXp
/jiwVFpugpkqevRJwsfpVuDRwdrnCNWYexuqd6zFMN1zrJH6jnNn6J7+Y55U
1fUU8YRfM7S30brvqnk4Lj2RZeETejdT4/GePdJQ2rOX6UV6lrlH39KX4/WM
Hpmob+mpSXrG3zNPUvQbZh3938AiK+rr3WQ947uxWgvnm6B56MtsrZe1ylc9
qOks6UbPssb0LT0+Xc86qsaD9N0cK8iaedKNmC+dCfqqvZAj3ejzmZqTc0zV
uvgu1wpyZ5E05PqWSivqmKfaE0u0D75bJq2I5dKKOqySFhxrscbgO3q1t64r
xTn3Qs3P+q1WDVnvNaordVsrHVjX9aottd2gelPDjdKRGm6SjtRqs/SiVluk
F7XdKg3pF54f1DzLImcbSbdt0o412666UasdqiW12im9WONdSdruTtJtj7Rj
r+9N0nBfkob7kzQ8kKThwSStDiXV7LDqRi/zXK8lDY+o9tTtqHSjViekFTU8
ZgV+PC7NqeFJacWD5EaLviwMfos0KQp+m+Z08JukeSHwm6UhvcOsoUeK4Pmt
0rAY+O3SkL5gbtIbJfD8TmlYEvwuaVgK/G5pWBr8HmlYVlr9/zcRnt8rPSuA
PyitioPfIY+UA79f2pYHf0DalgW/T/oz5x6StpXAH5a2zcEfk7Y9wV+WPn3A
X5U+g8DfVu3TwN+UPv3BX5du3cBflM5twZ+WLzqAPytfdAZ/Xr4YB/6pajkF
/GuLvhkB/r60rQx+rkVujgL/UNoOBX9XNc4E/1g6J/xH733DOnn0araH3tT6
E83Nea/m2B5euY46eHjoGou/dembL6iVh3euZb09tP+MOnv4jtfP5cGvtB/u
5XrW3sNz0zz8RC99y9p7ZMEcDw/RPzM8fEaPzfLwJT35HfXxyIvvgdkeefGR
9p+vNX4pj6eDX27RP03A/7Xo4VrgP1lkSg3wHyz6Kgv8BovMquJRO9atNvjP
FrnTEPwvi7xoBP63RV40Bv/HIi/qgf9mkUF1wX+1yKbqHuvmmuuA/2KRXw3A
/7DIphTwPy2yqT747xb5Vc1j/9x7VY/asW41wX+0yMpO4Bda5E5v8Ess8qUr
+EUWGdQP/FKLrBkOfqVFfw4Bv8IiUwaAX2aRQWM8/EFv9AC/2CK/xnr4g95o
CX6eRSa2B7/AIgczwK+yyKbJHj6gB8Z7eIj+aQN+vkWGTvTwH71HTeZ66ELd
Nntox9qs9qhPnkeOMEOWeWQHc4NzjvaYl/oP9vDABxb9w955y6Kf2cvc9zCP
vb9h0dvsa9ZgoEcdWKeRHrV6x6L32HdPAi08/v5lDVp71OEpi/5n7z9n0fPs
96YeucPMeQRo5vH/x+NAK4/z5FGLPGIWUc8uHpo+Y5Ej7G3WrJ1H3V6yyCzm
Fb0w38MP1KGjhxYvWGQTc4le6O7hh/cssiZP8z9hsQb6er2Ht1d45C+zd4NH
/jJ753mcEzwj6PelHp6nR3p5+IT+Xe7hYfZcjkff0YOpHj5c55HX2eCrPPKa
Wf2KRf4ye9lbGz36i72y0qNf2ItrPfrxNYssZg6v8TgPssAXeJxJPI9yPc4M
nhf5HmcPzx324mKPfmTf9PXonUUe5xbPLPbxEo9eZh4s9MiE/wDEuW/v
                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw93HVYFHsbxnEWRQELFQts7EJRDMJndJG2GxuVklaUsMVjd2NhKygqKha6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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83Hk8VPsfx3GjXZsWrdpsqVTatPcZJJQkbUIqlKJViFKUsrRvt420ao9K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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H5 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{5}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M
d96X92O+O1fekZ3ZOUnK1NzMnEJmdqqbFca1GgBqfFYLKAoUA6rrGb+poWsR
oLbeFwfq6FoCqA+UAkoDKUAZoCxQV+9LAvV05Xc1NR7nWw+M19gNNAZ/v47r
1LqaAZWAykBjoDxQAWiia0Wgud5XAVYBY7S/tcA4zdkIKKffrwYytdc1wFjt
taHWzu+aamzOvQGYoH2nAW2BdsBWYLL2vQmYqL1uBiapNu2BdGAgcCYwRfNs
A7K0p+1Atva0A5iq+XcC01SDLcDpqtNG4DTVeAYwXTXoB7QEWmm+dpo/FWgN
tAEG6NpW6+L7DsAgXTsCQ4HOQBegv8bj7wfrfSdgiK78ri/QQnOfBZyheg/T
GF2BEUA3oLuF76hPVSAD6AH0BEbp2svCg9X1XcKLvKcH6Rd6o4RqQF2KSGd+
V1TveT9a4/UGRmp+zpfwMceaDczUHspp7dSotOpNHctIZ96Xl278LuFF3leW
DtSrlH5HP1SUnvyukt7zPtEb3MNw1Yk12gXMUj1bqL59gANAjjTbC8yTlvuA
+dL0IJArLQ8BC6XZ2UCe9DgG5Guuw8AiaXkEWCxN9wMLLDy0B5hr4YGjwBKt
dTcwx8IfXGs/rfUEsFxangRWSAN+11/fcaxU3XMO+pW9dQ6wTBol/JqqvaXp
/jiwVFpugpkqevRJwsfpVuDRwdrnCNWYexuqd6zFMN1zrJH6jnNn6J7+Y55U
1fUU8YRfM7S30brvqnk4Lj2RZeETejdT4/GePdJQ2rOX6UV6lrlH39KX4/WM
Hpmob+mpSXrG3zNPUvQbZh3938AiK+rr3WQ947uxWgvnm6B56MtsrZe1ylc9
qOks6UbPssb0LT0+Xc86qsaD9N0cK8iaedKNmC+dCfqqvZAj3ejzmZqTc0zV
uvgu1wpyZ5E05PqWSivqmKfaE0u0D75bJq2I5dKKOqySFhxrscbgO3q1t64r
xTn3Qs3P+q1WDVnvNaordVsrHVjX9aottd2gelPDjdKRGm6SjtRqs/SiVluk
F7XdKg3pF54f1DzLImcbSbdt0o412666UasdqiW12im9WONdSdruTtJtj7Rj
r+9N0nBfkob7kzQ8kKThwSStDiXV7LDqRi/zXK8lDY+o9tTtqHSjViekFTU8
ZgV+PC7NqeFJacWD5EaLviwMfos0KQp+m+Z08JukeSHwm6UhvcOsoUeK4Pmt
0rAY+O3SkL5gbtIbJfD8TmlYEvwuaVgK/G5pWBr8HmlYVlr9/zcRnt8rPSuA
PyitioPfIY+UA79f2pYHf0DalgW/T/oz5x6StpXAH5a2zcEfk7Y9wV+WPn3A
X5U+g8DfVu3TwN+UPv3BX5du3cBflM5twZ+WLzqAPytfdAZ/Xr4YB/6pajkF
/GuLvhkB/r60rQx+rkVujgL/UNoOBX9XNc4E/1g6J/xH733DOnn0araH3tT6
E83Nea/m2B5euY46eHjoGou/dembL6iVh3euZb09tP+MOnv4jtfP5cGvtB/u
5XrW3sNz0zz8RC99y9p7ZMEcDw/RPzM8fEaPzfLwJT35HfXxyIvvgdkeefGR
9p+vNX4pj6eDX27RP03A/7Xo4VrgP1lkSg3wHyz6Kgv8BovMquJRO9atNvjP
FrnTEPwvi7xoBP63RV40Bv/HIi/qgf9mkUF1wX+1yKbqHuvmmuuA/2KRXw3A
/7DIphTwPy2yqT747xb5Vc1j/9x7VY/asW41wX+0yMpO4Bda5E5v8Ess8qUr
+EUWGdQP/FKLrBkOfqVFfw4Bv8IiUwaAX2aRQWM8/EFv9AC/2CK/xnr4g95o
CX6eRSa2B7/AIgczwK+yyKbJHj6gB8Z7eIj+aQN+vkWGTvTwH71HTeZ66ELd
Nntox9qs9qhPnkeOMEOWeWQHc4NzjvaYl/oP9vDABxb9w955y6Kf2cvc9zCP
vb9h0dvsa9ZgoEcdWKeRHrV6x6L32HdPAi08/v5lDVp71OEpi/5n7z9n0fPs
96YeucPMeQRo5vH/x+NAK4/z5FGLPGIWUc8uHpo+Y5Ej7G3WrJ1H3V6yyCzm
Fb0w38MP1KGjhxYvWGQTc4le6O7hh/cssiZP8z9hsQb6er2Ht1d45C+zd4NH
/jJ753mcEzwj6PelHp6nR3p5+IT+Xe7hYfZcjkff0YOpHj5c55HX2eCrPPKa
Wf2KRf4ye9lbGz36i72y0qNf2ItrPfrxNYssZg6v8TgPssAXeJxJPI9yPc4M
nhf5HmcPzx324mKPfmTf9PXonUUe5xbPLPbxEo9eZh4s9MiE/wDEuW/v
                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HlcDP8fwPHdhIQUlauQqyglV6K8R0LIWaKUo9wkObrklg46FHKU3BWJ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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTf8fwPFzb2SlCJUkI4mKZEe8T4qvnUgiUrYQkozMrAhNGSlFg0p7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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H7 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{7}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83Hk8VN8bB/DKmFvapE1pL/Jt1aJFy3NbtZdIKrSh0r6XNtGuPVokSQtt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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83HlcDP8fwPGwu0OuKEmiJBWh5D7fI3dCQhLf3EWR+8gtpBxFydUhIYQk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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H9 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{9}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR
5kIDdUOdigkoKEtnpE1rqDU1TC0ETyDIwkylEENQ3jkeeTmc5ny+180e/2Gf
Pdv543dfv/u+HL0sfsEKV5PJ9JWLyfTk72cdKWezsuq1hTfmDPT3by8c/NGG
1Y7cB+IfLyWOiDjcKJ7vbSm9nN8sTiw+pWVUtYjfdfgNDbrZKn5xyskW+602
8d3lPsX51e3q9zO/yzPXdIhTrOM/97xnE4eYjiworHskHjl1jLelwS5uij7o
Nrbxsfj8/pdvVTZ3itPLsgrS2rrEZjev7QG2bvHEGRkrGuw94s5VAwMPdDnE
V3J3DJnn6BXvqvBodjqdYvL76dOQ8DKfVskPkx8mP0x+mPww+WHyk9/X88Pk
h8kPkx8mP0x+mPww+WHyw+SHyQ+THya/00+tkR8mP0x+mPww+WHyw+Qnv6/n
h8kPkx8mP0x+mPww+WHyw+SHyQ+THyY/bOivZuivZuivZuivZuivZuivZuiv
ZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivFjTBuWfu
gQat4fXrW0Z4txTW7ux850TeQzH54i/t7bZBR5vEOyevD525qEUcFtnh3bi4
VTxpn6XfQXObuKek6VZIWLu4pDf2lGtEhzjbr357QaRNvDLqyb9H4oDsu4FD
Y+ziZ0rDvUpiH4v/dLnTnBzXKT48zXzFx9IlXhdz41B1Qrf47ZyFSbsSe8SD
yiven5XkEP/TL2SiLblXfDzgD9ejG51i8sTkWffUGnli8sTkickTkycmT0ye
mDwxeWLyxOSJyROTJyZPTJ6YPDF5YvLE5InJE9Nn8qXPmD5j+ozpM6bPmD7L
7+t9xvQZ02dMnzF9xvQZ02dMnzF9xvQZ02dMPuRFPph8MPlg8sHkg8lHfl/P
B5MPJh9MPph8MPlg8sHkg8kHkw8mH2PfriUsc/E2qbysTy15YfLC5IXJC5MX
Ji/5fT0vTF6YvDB5YfLC5IXJC5MXJi9MXpi8MP3Dkz7Z4bnE0iD5lfy+9Zdz
iQ/FUb6b40dtaBK7XQ0ccPHNFnF579n7CbNaxQf9Xv11XFCbOD7qdFbV7Hbx
G9n+a7fN7RB7lp6cM3OeTfy3i+/YxpBH4mPTjnXnhtrFSTETKkMWPRYH5xw5
7rqkU+xVPia1wNwlrut36OOosG7xqYAR04dG9IhTV2c/XxLpEIce8qpLjuoV
j67MKPSJcYrJD5MfeYa3xg8LLFImT9y7eNXVPKsy84vJG2dfWL7BvUKZ/PHw
jBNfF8Qqcx74QdGk+Kg4Zc4H/9yd/95QizLnhbdNHj+qJEGZ88MfRh5+nJyo
zHni8ftGl/skKXO+2FaSm1+drMx54996h2/atVGZ88d7/LKWzkpRZh5wZNQQ
f9tmZeYDT8ne43E0TZl5wS6lA2oXb1NmfnCZy45z/dOVmSfJe5rH3nM7lJkv
vCZm65q4XcrMG56R4x40KkOZ+435437D3G+Y+w1zv2HuN8z9Jr+v32+Y+w1z
v2HuN8z9hrnfMPcb5n7D3G+Y+w1zv2H2M8x+htnHMPsYZh+Tfuv7GGYfk/tS
38cw+xhmH8PsY5h9DLOPYfYxzD6G2ccw+xhmH8PsY3j3+ba30i+r99N3XGNb
c7GaL2t63TehZWq+Vnb8+8GZSjVfbr5Nmzwb+7wHEbHmwmaVX97e+/6Wtj7v
QfGK58baVH6ao6a20t7nPZgSfj6tS+V3e/ntvQGOPu9B5tK4BqfKL9laFXTA
VeUVbFo4cp67yuulqRV257Mqr7ro+dd+6K/yOrPf+m2kp8ortSw4ZfAAlVeo
W9GSokEqL/qI3eOuH0trUGb+6Cv54p7dHv/1X6f2E+YTkz/O7HLfF5ek9hfm
F3M+ePoy0+yKjWq/Yb4x54frl3/RM+yi+s78y3ujn6+8F5ldldbL6jv9kPdH
P3+8xbr++41F6jv9wcyHvCcmW+orJeo7/ZL3SZ8fPG7q2rAaq/pO/zDzJe9N
dPP0jDL1nX7K+6XPH760f/ULQRXqO/3FzKe8R2X1dfZK9Z1+y/umzy+OcIu+
kF+lvtN/zHzLezWjNtN8U5n7Qd4/ff6xc1WExfO2MvcHph/ynuXeCS6sVuZ+
kfdR7w/OqTCPsdQoc/9g+iXv3TN/dY25p8z9JO+n3j8887VF1yvrlLm/5D3V
+4npo3Efk/tb7x9mH8P0Te5zff/C9Auzf2H6hNm/MP0R6/sXpi+Y/QvTD7G+
f2H6gNm/MPMv1vcvzLxj9i/MfIv1/Qszz5j9CzO/Yn3/wswrZv/CzKdY378w
8yj/H9H3L8z8ifX9CzNv+H+BjgH0
           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HlcDP8fwPF2t0uUXBEVX+RIcivCe9xF5eigQoQQUkKuJFIKiRy5qdAh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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83HdcTf8fwPE7GmYSIZIkOyQlRO+PTZG9EhmVkSQjWRkZIUSSiiiSkTJC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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H11 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{11}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83Hc8Vf8fB/BzjUoqVCrtoZTSHop6a1BSIlEphZIGbfmWprJaIjIiMjKS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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83Xc8Vf8fwPF7r1U0UVqK1lfRVBrofUolSUaSdtpbVJKGklHaiZSmKNoJ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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H13 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{13}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR
5kIDdUOdigkoKEtnpE1rqDU1TC0ETyDIwkylEENQ3jkeeTmc5ny+180e/2Gf
Pdv543dfv/u+HL0sfsEKV5PJ9JWLyfTk72cdKWezsuq1hTfmDPT3by8c/NGG
1Y7cB+IfLyWOiDjcKJ7vbSm9nN8sTiw+pWVUtYjfdfgNDbrZKn5xyskW+602
8d3lPsX51e3q9zO/yzPXdIhTrOM/97xnE4eYjiworHskHjl1jLelwS5uij7o
Nrbxsfj8/pdvVTZ3itPLsgrS2rrEZjev7QG2bvHEGRkrGuw94s5VAwMPdDnE
V3J3DJnn6BXvqvBodjqdYvL76dOQ8DKfVskPkx8mP0x+mPww+WHyk9/X88Pk
h8kPkx8mP0x+mPww+WHyw+SHyQ+THya/00+tkR8mP0x+mPww+WHyw+Qnv6/n
h8kPkx8mP0x+mPww+WHyw+SHyQ+THyY/bOivZuivZuivZuivZuivZuivZuiv
ZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivFjTBuWfu
gQat4fXrW0Z4txTW7ux850TeQzH54i/t7bZBR5vEOyevD525qEUcFtnh3bi4
VTxpn6XfQXObuKek6VZIWLu4pDf2lGtEhzjbr357QaRNvDLqyb9H4oDsu4FD
Y+ziZ0rDvUpiH4v/dLnTnBzXKT48zXzFx9IlXhdz41B1Qrf47ZyFSbsSe8SD
yiven5XkEP/TL2SiLblXfDzgD9ejG51i8sTkWffUGnli8sTkickTkycmT0ye
mDwxeWLyxOSJyROTJyZPTJ6YPDF5YvLE5InJE9Nn8qXPmD5j+ozpM6bPmD7L
7+t9xvQZ02dMnzF9xvQZ02dMnzF9xvQZ02dMPuRFPph8MPlg8sHkg8lHfl/P
B5MPJh9MPph8MPlg8sHkg8kHkw8mH2PfriUsc/E2qbysTy15YfLC5IXJC5MX
Ji/5fT0vTF6YvDB5YfLC5IXJC5MXJi9MXpi8MP3Dkz7Z4bnE0iD5lfy+9Zdz
iQ/FUb6b40dtaBK7XQ0ccPHNFnF579n7CbNaxQf9Xv11XFCbOD7qdFbV7Hbx
G9n+a7fN7RB7lp6cM3OeTfy3i+/YxpBH4mPTjnXnhtrFSTETKkMWPRYH5xw5
7rqkU+xVPia1wNwlrut36OOosG7xqYAR04dG9IhTV2c/XxLpEIce8qpLjuoV
j67MKPSJcYrJD5MfeYa3xg8LLFImT9y7eNXVPKsy84vJG2dfWL7BvUKZ/PHw
jBNfF8Qqcx74QdGk+Kg4Zc4H/9yd/95QizLnhbdNHj+qJEGZ88MfRh5+nJyo
zHni8ftGl/skKXO+2FaSm1+drMx54996h2/atVGZ88d7/LKWzkpRZh5wZNQQ
f9tmZeYDT8ne43E0TZl5wS6lA2oXb1NmfnCZy45z/dOVmSfJe5rH3nM7lJkv
vCZm65q4XcrMG56R4x40KkOZ+435437D3G+Y+w1zv2HuN8z9Jr+v32+Y+w1z
v2HuN8z9hrnfMPcb5n7D3G+Y+w1zv2H2M8x+htnHMPsYZh+Tfuv7GGYfk/tS
38cw+xhmH8PsY5h9DLOPYfYxzD6G2ccw+xhmH8PsY3j3+ba30i+r99N3XGNb
c7GaL2t63TehZWq+Vnb8+8GZSjVfbr5Nmzwb+7wHEbHmwmaVX97e+/6Wtj7v
QfGK58baVH6ao6a20t7nPZgSfj6tS+V3e/ntvQGOPu9B5tK4BqfKL9laFXTA
VeUVbFo4cp67yuulqRV257Mqr7ro+dd+6K/yOrPf+m2kp8ortSw4ZfAAlVeo
W9GSokEqL/qI3eOuH0trUGb+6Cv54p7dHv/1X6f2E+YTkz/O7HLfF5ek9hfm
F3M+ePoy0+yKjWq/Yb4x54frl3/RM+yi+s78y3ujn6+8F5ldldbL6jv9kPdH
P3+8xbr++41F6jv9wcyHvCcmW+orJeo7/ZL3SZ8fPG7q2rAaq/pO/zDzJe9N
dPP0jDL1nX7K+6XPH760f/ULQRXqO/3FzKe8R2X1dfZK9Z1+y/umzy+OcIu+
kF+lvtN/zHzLezWjNtN8U5n7Qd4/ff6xc1WExfO2MvcHph/ynuXeCS6sVuZ+
kfdR7w/OqTCPsdQoc/9g+iXv3TN/dY25p8z9JO+n3j8887VF1yvrlLm/5D3V
+4npo3Efk/tb7x9mH8P0Te5zff/C9Auzf2H6hNm/MP0R6/sXpi+Y/QvTD7G+
f2H6gNm/MPMv1vcvzLxj9i/MfIv1/Qszz5j9CzO/Yn3/wswrZv/CzKdY378w
8yj/H9H3L8z8ifX9CzNv+H+BjgH0
           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83Hk8VG0bwHFmRPsiW1IqFSVKKRV1TdpFi0S0UKK0SlS0Ekmp9FRooSLa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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83Xc8Vf8fwPG7jEJUWhSFULSn1vs2Vdr6SkpDQ0rSElJKW3sXqaRERaiM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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H15 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{15}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83Hk8FP8fwPG90EW3StJ9qKRTd+/tUpGSSkpJp9CB7luUlL5ISkqRUjpE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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTf8fwPF7b0uSESWr+maEIqIU8b6yR6KMbEkIZZRQUUZmlJFQFBKS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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H17 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{17}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HdcTf8fwPG7KiMrWSEr2ZlpoPc1QmQ2EFmFskeICBWRlZWZjFS+QkUy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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83HdcTf8fwPF7b8OWvfcqUjKyove1CdlJxFcSyoyQkYRUFEVDlERDQtKg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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H19 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{19}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR
5kIDdUOdigkoKEtnpE1rqDU1TC0ETyDIwkylEENQ3jkeeTmc5ny+180e/2Gf
Pdv543dfv/u+HL0sfsEKV5PJ9JWLyfTk72cdKWezsuq1hTfmDPT3by8c/NGG
1Y7cB+IfLyWOiDjcKJ7vbSm9nN8sTiw+pWVUtYjfdfgNDbrZKn5xyskW+602
8d3lPsX51e3q9zO/yzPXdIhTrOM/97xnE4eYjiworHskHjl1jLelwS5uij7o
Nrbxsfj8/pdvVTZ3itPLsgrS2rrEZjev7QG2bvHEGRkrGuw94s5VAwMPdDnE
V3J3DJnn6BXvqvBodjqdYvL76dOQ8DKfVskPkx8mP0x+mPww+WHyk9/X88Pk
h8kPkx8mP0x+mPww+WHyw+SHyQ+THya/00+tkR8mP0x+mPww+WHyw+Qnv6/n
h8kPkx8mP0x+mPww+WHyw+SHyQ+THyY/bOivZuivZuivZuivZuivZuivZuiv
ZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivFjTBuWfu
gQat4fXrW0Z4txTW7ux850TeQzH54i/t7bZBR5vEOyevD525qEUcFtnh3bi4
VTxpn6XfQXObuKek6VZIWLu4pDf2lGtEhzjbr357QaRNvDLqyb9H4oDsu4FD
Y+ziZ0rDvUpiH4v/dLnTnBzXKT48zXzFx9IlXhdz41B1Qrf47ZyFSbsSe8SD
yiven5XkEP/TL2SiLblXfDzgD9ejG51i8sTkWffUGnli8sTkickTkycmT0ye
mDwxeWLyxOSJyROTJyZPTJ6YPDF5YvLE5InJE9Nn8qXPmD5j+ozpM6bPmD7L
7+t9xvQZ02dMnzF9xvQZ02dMnzF9xvQZ02dMPuRFPph8MPlg8sHkg8lHfl/P
B5MPJh9MPph8MPlg8sHkg8kHkw8mH2PfriUsc/E2qbysTy15YfLC5IXJC5MX
Ji/5fT0vTF6YvDB5YfLC5IXJC5MXJi9MXpi8MP3Dkz7Z4bnE0iD5lfy+9Zdz
iQ/FUb6b40dtaBK7XQ0ccPHNFnF579n7CbNaxQf9Xv11XFCbOD7qdFbV7Hbx
G9n+a7fN7RB7lp6cM3OeTfy3i+/YxpBH4mPTjnXnhtrFSTETKkMWPRYH5xw5
7rqkU+xVPia1wNwlrut36OOosG7xqYAR04dG9IhTV2c/XxLpEIce8qpLjuoV
j67MKPSJcYrJD5MfeYa3xg8LLFImT9y7eNXVPKsy84vJG2dfWL7BvUKZ/PHw
jBNfF8Qqcx74QdGk+Kg4Zc4H/9yd/95QizLnhbdNHj+qJEGZ88MfRh5+nJyo
zHni8ftGl/skKXO+2FaSm1+drMx54996h2/atVGZ88d7/LKWzkpRZh5wZNQQ
f9tmZeYDT8ne43E0TZl5wS6lA2oXb1NmfnCZy45z/dOVmSfJe5rH3nM7lJkv
vCZm65q4XcrMG56R4x40KkOZ+435437D3G+Y+w1zv2HuN8z9Jr+v32+Y+w1z
v2HuN8z9hrnfMPcb5n7D3G+Y+w1zv2H2M8x+htnHMPsYZh+Tfuv7GGYfk/tS
38cw+xhmH8PsY5h9DLOPYfYxzD6G2ccw+xhmH8PsY3j3+ba30i+r99N3XGNb
c7GaL2t63TehZWq+Vnb8+8GZSjVfbr5Nmzwb+7wHEbHmwmaVX97e+/6Wtj7v
QfGK58baVH6ao6a20t7nPZgSfj6tS+V3e/ntvQGOPu9B5tK4BqfKL9laFXTA
VeUVbFo4cp67yuulqRV257Mqr7ro+dd+6K/yOrPf+m2kp8ortSw4ZfAAlVeo
W9GSokEqL/qI3eOuH0trUGb+6Cv54p7dHv/1X6f2E+YTkz/O7HLfF5ek9hfm
F3M+ePoy0+yKjWq/Yb4x54frl3/RM+yi+s78y3ujn6+8F5ldldbL6jv9kPdH
P3+8xbr++41F6jv9wcyHvCcmW+orJeo7/ZL3SZ8fPG7q2rAaq/pO/zDzJe9N
dPP0jDL1nX7K+6XPH760f/ULQRXqO/3FzKe8R2X1dfZK9Z1+y/umzy+OcIu+
kF+lvtN/zHzLezWjNtN8U5n7Qd4/ff6xc1WExfO2MvcHph/ynuXeCS6sVuZ+
kfdR7w/OqTCPsdQoc/9g+iXv3TN/dY25p8z9JO+n3j8887VF1yvrlLm/5D3V
+4npo3Efk/tb7x9mH8P0Te5zff/C9Auzf2H6hNm/MP0R6/sXpi+Y/QvTD7G+
f2H6gNm/MPMv1vcvzLxj9i/MfIv1/Qszz5j9CzO/Yn3/wswrZv/CzKdY378w
8yj/H9H3L8z8ifX9CzNv+H+BjgH0
           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M
d96X92O+O1fekZ3ZOUnK1NzMnEJmdqqbFca1GgBqfFYLKAoUA6rrGb+poWsR
oLbeFwfq6FoCqA+UAkoDKUAZoCxQV+9LAvV05Xc1NR7nWw+M19gNNAZ/v47r
1LqaAZWAykBjoDxQAWiia0Wgud5XAVYBY7S/tcA4zdkIKKffrwYytdc1wFjt
taHWzu+aamzOvQGYoH2nAW2BdsBWYLL2vQmYqL1uBiapNu2BdGAgcCYwRfNs
A7K0p+1Atva0A5iq+XcC01SDLcDpqtNG4DTVeAYwXTXoB7QEWmm+dpo/FWgN
tAEG6NpW6+L7DsAgXTsCQ4HOQBegv8bj7wfrfSdgiK78ri/QQnOfBZyheg/T
GF2BEUA3oLuF76hPVSAD6AH0BEbp2svCg9X1XcKLvKcH6Rd6o4RqQF2KSGd+
V1TveT9a4/UGRmp+zpfwMceaDczUHspp7dSotOpNHctIZ96Xl278LuFF3leW
DtSrlH5HP1SUnvyukt7zPtEb3MNw1Yk12gXMUj1bqL59gANAjjTbC8yTlvuA
+dL0IJArLQ8BC6XZ2UCe9DgG5Guuw8AiaXkEWCxN9wMLLDy0B5hr4YGjwBKt
dTcwx8IfXGs/rfUEsFxangRWSAN+11/fcaxU3XMO+pW9dQ6wTBol/JqqvaXp
/jiwVFpugpkqevRJwsfpVuDRwdrnCNWYexuqd6zFMN1zrJH6jnNn6J7+Y55U
1fUU8YRfM7S30brvqnk4Lj2RZeETejdT4/GePdJQ2rOX6UV6lrlH39KX4/WM
Hpmob+mpSXrG3zNPUvQbZh3938AiK+rr3WQ947uxWgvnm6B56MtsrZe1ylc9
qOks6UbPssb0LT0+Xc86qsaD9N0cK8iaedKNmC+dCfqqvZAj3ejzmZqTc0zV
uvgu1wpyZ5E05PqWSivqmKfaE0u0D75bJq2I5dKKOqySFhxrscbgO3q1t64r
xTn3Qs3P+q1WDVnvNaordVsrHVjX9aottd2gelPDjdKRGm6SjtRqs/SiVluk
F7XdKg3pF54f1DzLImcbSbdt0o412666UasdqiW12im9WONdSdruTtJtj7Rj
r+9N0nBfkob7kzQ8kKThwSStDiXV7LDqRi/zXK8lDY+o9tTtqHSjViekFTU8
ZgV+PC7NqeFJacWD5EaLviwMfos0KQp+m+Z08JukeSHwm6UhvcOsoUeK4Pmt
0rAY+O3SkL5gbtIbJfD8TmlYEvwuaVgK/G5pWBr8HmlYVlr9/zcRnt8rPSuA
PyitioPfIY+UA79f2pYHf0DalgW/T/oz5x6StpXAH5a2zcEfk7Y9wV+WPn3A
X5U+g8DfVu3TwN+UPv3BX5du3cBflM5twZ+WLzqAPytfdAZ/Xr4YB/6pajkF
/GuLvhkB/r60rQx+rkVujgL/UNoOBX9XNc4E/1g6J/xH733DOnn0araH3tT6
E83Nea/m2B5euY46eHjoGou/dembL6iVh3euZb09tP+MOnv4jtfP5cGvtB/u
5XrW3sNz0zz8RC99y9p7ZMEcDw/RPzM8fEaPzfLwJT35HfXxyIvvgdkeefGR
9p+vNX4pj6eDX27RP03A/7Xo4VrgP1lkSg3wHyz6Kgv8BovMquJRO9atNvjP
FrnTEPwvi7xoBP63RV40Bv/HIi/qgf9mkUF1wX+1yKbqHuvmmuuA/2KRXw3A
/7DIphTwPy2yqT747xb5Vc1j/9x7VY/asW41wX+0yMpO4Bda5E5v8Ess8qUr
+EUWGdQP/FKLrBkOfqVFfw4Bv8IiUwaAX2aRQWM8/EFv9AC/2CK/xnr4g95o
CX6eRSa2B7/AIgczwK+yyKbJHj6gB8Z7eIj+aQN+vkWGTvTwH71HTeZ66ELd
Nntox9qs9qhPnkeOMEOWeWQHc4NzjvaYl/oP9vDABxb9w955y6Kf2cvc9zCP
vb9h0dvsa9ZgoEcdWKeRHrV6x6L32HdPAi08/v5lDVp71OEpi/5n7z9n0fPs
96YeucPMeQRo5vH/x+NAK4/z5FGLPGIWUc8uHpo+Y5Ej7G3WrJ1H3V6yyCzm
Fb0w38MP1KGjhxYvWGQTc4le6O7hh/cssiZP8z9hsQb6er2Ht1d45C+zd4NH
/jJ753mcEzwj6PelHp6nR3p5+IT+Xe7hYfZcjkff0YOpHj5c55HX2eCrPPKa
Wf2KRf4ye9lbGz36i72y0qNf2ItrPfrxNYssZg6v8TgPssAXeJxJPI9yPc4M
nhf5HmcPzx324mKPfmTf9PXonUUe5xbPLPbxEo9eZh4s9MiE/wDEuW/v
                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83Hc8Vf8fwPG7UCptoaGp0h5SVO/T3ntS34ZKKqW0l/ZCgyiVStGSlCQ0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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJxE3Xc8le//wPFzjuOQZBQaUhEampRUH73vhpL23mlRGak0tbQnTVK0F2mI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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H21 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{21}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83XdcTf8fwPE7WjahFLIjFFJCeB+i7E34JkTJJsrOioykElE22TNJWZ+j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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTf8fwPG7GmSEMkPG1ypJZor3icomW2ayNw1CKCtEkShRCEmFSvb4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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H23 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{23}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HlcTN8bB/BZWij7EorsWcsSCfFca2SLEiUJ8RVClmTfIlRIirKTFrJV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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83HdcTf8fwPG7KiV7Z4WGlR0h3scoK1lJKqKShKLiS2SHjEKyEqFkhEpG
kc+RSiVppyFNtPfd43er8/75x+P5uI8H99wz7vm8zud+xti7rd/BYbFYPdVY
rM6/79zu/FMDwgYr6m5sOaCPzR/cd6crj0LzfHN+Tx8nIEsv7vkreVoDzy08
3vU7Wg7oSXkle3l2PAr9bKOpjmCRgDQeBcOtcTXQIRo559zCckB7H/v6/cEa
HoVW5e53/LhNQG659j9Np9XA6oThtJRVDuiAZtVpQPEodNGo1vsnjwvI4m3V
mWOLayB47LQN7l/KAB3eI/16yTQehY5u3Jlvek9A6te9H+VTVwO1/Ua2/PUp
A7TX0mXSw2N4FLrnf/vVNOMF5MaSzg2qgWE2oXe2LC8DdPLgp05D+vMotGf2
ixlZxQJCKbdmhWYtjKTPrs3RKAO0WuSY3BgOj0K33v+46YZYQGr1pveIGFEL
PAt1/Wt3fgP6xMTypevbuBRa8WzBQZthQnJ9KM+yt0EtrDL6mOI9+jeg1c8N
iW2q5FLohpbMy9pGQrJQo+DRvgW14HUp9Nyu0FJA+19tn3Y5l0uhK0oG36u2
FJJ/kqct2atrIesUtWPjhFJAW/d9EjExiUuhzX6/evzsgJBca+jcgbWgvU7T
YdHLX4DWubB9csobLoV+X2cc7nZdSIx/r7l801X5+pPTpwxm/gI078DayB2P
uRRaMMju/qzXQvJHufdEx2rBpWNM0rD3JYB+sTDUiHuTS6Efn3rnJ8oSkisJ
HeNt/WvhVM22yaoLSgA9beSlpJBzXAodkvTX81OzkMyLSTn46X4t3D4ZF9v6
uRjQM9fO2bTwEJdC37G7uu50HxGpCgtK1I5UWvTY9bdpMaBn/s5tKHbmUv9/
fZGlzvIpIuJ3s/OArYWzk+6bpX8rAvT+6gDfw5u5FHqU4c96zdUiYuS7SHnE
1kIcaG2MXVsEaMGyRxOHrORS6P77Yp9l7RaRCq+BL5eV10LAKX/fx3mFgF7f
PD0rZh6XQtuMvrvlxgURudR5erbUwtchB+sCrAsBLUpw9V4/iUuhe3uNVbF5
KiKzOw9XTh0sKl9y9OTvn4Aef/T81ObhXAodqdYUMjpFRMo6d1//OuhZ7brA
zfEnoB+UvPh7WZNLoeNNQ6dV/RGRC52bM7YORszfO21LTQGgHcN7PZ4k41Do
uVFVr5+oiMmsmZ1/6uDDyRjLVa4FgJ5zJd8ltYFDoa/+Xj9xr46YlOqongxc
UgeqDbFRc9vyAf1gwZzZO0s5FPrTmasB05eIyfnBhRmCDXXwX1zr4vGH8gG9
ZtPWHio/OBTaft2Spo7tYjJDeXZaO9ZBTkZuzyGyPEAX3fYqf0g4FHpVusaC
uBNiUiI65vLRsw6KC3N7qZ7KA/T8oLjPVCSHQvumXjh67L6YnK3ruiBBbzXn
lR2qeYCuYK1+WhrCodDG8h0vFn8Sk2m/OjeoDlxVeV+qLuYCOuPEtltHr3Io
tKN84Q/VX2JSpNyayrA6iHIcdTi3by6gb6SP89c6xaHQuU7vy9MkYnKGTntg
8rYOthVOdk0MzAH05KCky+/dORT6SapnlZ+WhEyJDm4KT1a+X++wRzFaOYD+
+MrzuqUDh0KfDxlcsH6uhPxUXo00CuqgZrBcK+x+NqB/Jdg9at/AodCmXlTs
YCsJORXYeQGug2s+L/ICdbIBHR35Ju7aUg6Fvnvv+oWigxIy6VznDqwD6urE
vLNPswA9fn1Y0TRDDoWOtHmz8l6ghOQdqlFegetBuq5e69CULEBTF7Zwf+hy
KPTJuqWi7TEScly59wKG1oNtucuTXa8zAT3Ztpfh3sEcCv10WXWgbo6ETLD1
V16R6iG1/6jjNkaZgN6cUOnWU41Doc2PGGnXtEhIzmr7vlZz66GsTEYFef0A
dO/SPjFPBWwKXbWk7GZEXynx7vx6XVEP8+b3GnHiTAagY3Jo9vJ/bAp92+qY
1G2qlOh3ft1Y10P9py3Xdvh9B3RTse7mPz/ZFHrs8pjVM82lJKvz8utSDzu4
1Y9X3UoH9Oy1rnFnUtkUOsBu3EX+Hik50nk58qqHyya3bWc8/AbozddTdcfF
sSm0ecGemNiLUqLbeXpeVH4++u5vh0WkAdp77M6gz8/YFFrtw/TUo8+k5Efn
4RpUD4Oe7nrHfpsK6Kt3Dg7fFsSm0L/S+qdCqpQc7tx9EfUwuO2wfS1JAfT0
+/qP5RfZFDr4c+Rrzj8pGde5OR+V+789JC4n9Sugl/Z5Nj/4KJtCHyp/fj5J
VUa+p3f+qYfSjpKE+JxkQG/9YVAyfy+bQi/dHrrsvK6M/PfpvtbUX/UgXDfl
2JNfSYDWrq44V7SFTaE/G85rXrlURsZEujtfbagHx5c3mwL+JgL6j5do4WFz
NoWepdHrVC8HGfmmPDvbZPVQYTtK60TLF0BnVD9gDwU2hXac9VH646SMHAjo
vKFogB6aqay9kgRA01c0M99OZVPo46V/7K6FyMhon84LUgOMKwx5bK2SAOhr
vVyebdRmU+iSqknPLYiMpB7s3KAGmOkW3XtFn8+AbtOru9Lel02htaInlA4u
lREP5dYchQaY6NzT2GgYDejTb+nTAWw2hZZcOyb8KZWRkdaO83+vaYD1nkcd
1pp+AvSjyuGnZ7SyKPQHoxTRneFy8nXVHOU3bAPsMflYPd36I6AnVRj4Z1Ww
KPTT+aHltvPkZP+CzhuoBhh9QkVlkGscoNmTxz/Zl8Oi0PLwV69GbZaT4VM7
L8ANECu99FV08j2g/+w0zuiTyKLQs6adcyj7T06StLt2IKRP959ZFvgW0H6H
77JfxbAodKXmV+mDG3Li1nl7/KABNE6br0l5GgPooZ5ei83DWBT6x5CeRxze
yMmwztvF6AYYsXXgmOj4aEC3POxxtSGQRaFHxTX+0smVky+dt08Jyu3pN+tV
cFYkoK+EHG64dJZFocs+aer+aZWTvZ23E9kNkFDeizX42wtAn5vDspr8H4tC
t15RrAnvpyBDOr9eKxvgxdeyme2tTwE9+vSPzG87WRT6i2jbVudpCvK58+um
TXl8bn2nmq/1GNCHfmlZ7bZiUei+JmlrJqxRkN2dl19eI4xL8fb5sPghoMcI
BjVqrGBRaNIvd1ztXgUZ1Hk5GtgInqxtXivy7gKaTbdfezaXRaHlxwcXPbuk
IKTz9NRphEvWyQfG6QYC+s2lOtOVE1kU+saf8e67nyvIrs7D1bAR/GYKp2jU
XgD0rE5qsSj07T4P6yalKciAzt1n0gipCSr/Ygf8B+hyTnuJb08WhV4gHmJa
/09B4js3x7IRQq9HHOdFb/2/iweWHdsgVAA6oMOfyuey6J1OnX8aYabtPH3z
2acJevnFKIeAQgWgu14ewKL7Wc1V3iE3go9n1nfdVVcJekpcinNOnALQNQ+D
Vt0Yy6I/KO8WJ51Tvp+55jYjJLcIetjXa34D7ioA7XH3rRF/OoveMb9zQNAI
ee9XrvXZGELQc595523wVgC6cuKiQZaLWHQfg84bCuX7mcmnDhmEErSjuXDB
9a0KQGf85Ja/WcuiY0d1XpCU+8frZYuTyhOCnnjJPSUXFICui00OGrSNRTv0
7dygRtiy3dJi3a/nBN1htuXAoDEKQPtsXmdywI1F9+J03lE0wgarGOs5b14R
9IItE00sOQpAb89y+ZV7jEW/a5PlHqpphF8Fs45cSo4i6FPRZkY3K+WAJo8L
HWb5sejtncNbUSPMTvTSPBL9mqDjNxit+ZkoB/TYfIefAcEsumfncE+jCarS
f27eee8NQc/wsL8w7LEc0DuTM+a1RbDoN53DH60meHqrxmbdhXcEfcBpUa31
OTmgk8x+X1j/kUXbdQ4HJjXBx8CZPecejCXo0GQzt7vOckC/vLs5Jeobi+66
PZ6v/Pd1x28bZf+BoMO8ZcNKV8gBbbCI3da3mEV33S6uagIT0N3ANo8naM2I
77WjJ8kBLZ5wW2NfLYvuun2ybYIcR/eS8rmEoF8XGlVs15QDWj+gsvcPEYvu
up3Y0wQXdbXFv6/RBL1G8oEV2iAD9GbOQ4WBOpvuuvoebQKLcIvU7+c/E/Tg
3XmmfzJkgD6wMrDk0lA23fV1c7kJ4h4VbIo7lkDQvj1V3oyPlAHa2Ms7rE6f
TXddfoObIPF18IMwzy8EfX5F+qrdV2WANi4eZr1yDpvuuhy9bALdHf4P/V0S
CdpmwMueL91lgF7PHy9+Ysqmu07PT03w6vU5y0Pbkgj6gvrUjuYNMkDPP+Ls
o2bJprsO14wmmKZlEWtnmUzQcUfzeswylAH60aJAyY4dbLpr9/1W7o+/Mckm
Zl8Jmu0wYdl/g2WAPmG+2zbRk013b04TbMmy8Zq4OIWgc31iIuMEUkAPjg8L
H3uGTbO6/jTDGff6H72MUgk6cj/HVP5TCujxX+UlJwLYdPf9ejOIKsQJTQZp
BP3gUYja4jgpoKe9nCotfcimn7VkK++om+Get+aazHHfCNps3yi+T5AU0EVf
m3kLotl09/19MxyZetPt1bB0gu6n1at/2lEpoIXuIv6dz2zaorIzGDTD+y0s
7ct9vhP0inaFTe+tUkCXqLCyhZlsuns80AznzYJtdqlkELSb5aXc9SAFdEpu
bKBlGZuW53ZuUDMo+kWPXCrJIGg6fsXRm9pSQGuPKV4U08Smu8cPys+Tct8+
suUHQTe/y9pQwpYCuofOkPx+Cjb9JLnzhqgZ3GMVV7w8Mgk6tB9tM6ZSAugp
gtHr3Xpz6O7xRjOs/DjrxY7GTIJuzIy+7pQoAbTvzcdv0kdy6PWdo9t1zXDu
Wz5n7a4sgh61eqXieZgE0PsLrVkTDTh09/ikGXausvGfW5VF0HoGE+62nJUA
eu+uuunnjDm0tDNn2TfDcLnB2rF22QR9+ET77jnOEkB/ISorq1Zx6O7xTDO0
q0Yt1ijKJuglnza4ea+QALpU23L5IhsO/bgzB7k3wwtXY8cWixyC3ljV/PjL
RAmg8y+fm3zPhUN3j3+aYXv/UdEFP3II2vnIoQEamhJAmyUs4YsPc+i1nTnl
dDOsOXt7QvzKXILec+/2m7UNYkCnTZsZtsmXQ3ePl5ohoeXv1wdJuQR9havq
dzNDDGgjudQo5haHFnfmiIBmILfmXPCh8gg6c5h7cOkrMaCHtplG9X3CobvH
V82gf+/5XucPeQR9cGhgle5VMaCTPN702vuOQ4d2DucfNUOAua3bytn5BG1T
P95xr7sY0Nm+datTkzl093isGcY5WF6aFJVP0HN21o54s0EMaMf0C/t18zm0
eefhGqM8XgcHfe45uYCgj8273Uc2Swzoz/YzD52s5tDd47dmKEwcrVn3uICg
03oLjU0GiwEdJDy9/Vc7hxZ2bk6i8njM+e6cOuYnQRtdTA+7LBAB2jFumMFc
HpfuHu81w78dp3If3/1J0Gedfq/M/ykCdLzZlaLrA7j0w87hWG4z3DHqbXZ6
SCFBF+2XTh4dJwL0gK8ndzWP5dLd48NmuHXAMH3rtUKCvvOw1cw5SATo1y/P
Fq6awaXNOocz1c0gn/1q3dxeRQRNzbj+POqoCNBlfwwnhi/i0t3jyWYICdQt
7H++iKBv3Xm7QrJFBOiYaB0bzjouze8cDnQ0w+mlhnZ1nGKC/v1yxngTEAH6
ypM/u7ds49Ld489mGHFxb1mCdzFBzw2uWuavLQK0Y1Qv2/duXDqk83ZatQWW
hq/ZfFtYTNBTB0c8LWSLAP2vfcKkAce5dPd4tQWe8NYku3qUEHT+wj3mOpVC
QAeWpf7c68elV3bejg5uga8PM8ctaSwhaPOCnnPcEoWA3jzQyzElmEt3j29b
oFV1kuvgXb8IeunCA45xYUJAl25L+j72BZdu77yd02uB+U1hD/5V/iLo6Wdu
FKicEwL6b/ysgd4fuXT3eLgFdvX2iovdWkrQTke3X13nLAT090Vr5hR849L3
Om+H5rTA4u+ZMb6FpQQdmf7tWvAKIaCfDLsze3oxl+4eP7dAUP/ES1YWvwl6
sySjpGaiENAbTt3qd7GWSy/vvJ1Y1gLTGrYs1Pvxm6Bjzjjvm60pBPTj+G9f
q0Rcunu83QIX9dLtRTplBB1Xf9v8dIMA0I/UX1stVOfRrZ1fr1YtELZzSh87
+zKCnpLufCgzQwDomtvfvtwcyqO7x+ctMGbh4rGJ98sIurmstHFkpADQ5/2v
9GjR59F3Oy+/zi2g/bTu9vhfZQS9b5LG691XBYBeXuult3IOj+4ez7fA5UGq
npe0ygl6Xoc0KdZdAGgHH/bIR6Y82rTz9Dyk3P8Gji+bNpUT9Naa7+N7WAgA
va7n7TrJRh7dPf5vAavYH6brA8sJ2mLcrRJLQwGgLRtfX7XYwaObO3efbwuc
3aU+Pya7nKAXrDpSETZYAGh764TeLzx5dHcvaIHjySnnB/WtIGj6btD8DgEf
0CHTZ9irnOHR3c//WmDQ3w8GB1dXEPRBzbE1Swv5gE4SuV7cEsCju/uC8vj9
75x+/oUKgnZealx/PY4P6PRf5b5vHvLo7ueFLWBgk+xhmFJB0C7ZI0yrg/iA
/najxbZXNI/u7hEtkBis3ve6SiVBj5ouERh68wG9fyeHt+Mzj+5+vqh8/+t/
iloWVxI0P38A99xWPqB9Bh489jGTR3f3C+X5Zv5qypoTlQR9yeqJ80/gAzou
5/m3AWU8uvt5pHJ/qbMjnsdXErTFEcWEiWP4gLZczKpzaeLR3b2jBR66Grqp
SSoJ+tXyHcuPcviAfmLzvfiznEd3P79sgRExTw/YG1URdKvupKSMyg5Aq+11
CR7aW4Xu7iMtkDEo8uPHA1UEPawj/MGYpA5Ae6pMnuo2UoXuft7ZAo0p/osG
v64iaN/hRr89H3cA2rjV4UrSZBW6u6e0QMezM2y35iqCPvtswfGUcx2Ajp+4
nR5urEJ3Px9Vfn7DiSjZoJqg57lrnx6xqwPQlclun/avUqG7+0sr7PzmoD9q
dzVBm2mZ1+9b2QHootafvl+tVeju56mtYOl38Zznk2qCzjOa9zFpUgegb1RW
jBnpokJ395pWWKC1ZEhadTVBV7hvbdfq1QFo/+RMH/fDKnT389dWaPxyIWfU
uD8ErX5v3o19je2AlkZWxHw9r0J3951WEHhZxrpv+0PQZxIsHiX/aAf0p3sb
X464pUJ3P69tBfutl5OSgv8Q9I+1c0eOjGoH9K1NDvv3h6vQ3T1I+f781TuG
FP8haCOjIyqe19oBXeWwWJb0VoXufr6r3P5Bt5buGvqXoA07Xm/55tEOaCcV
vXVaySp0dz9qhRgPYWTsxr8ErZd8Wn/cxnZAN4xYuMc1T4Xufh7cCt6BJbPV
A/4S9OI3Vx2PzG4HtJ3uu9UJVSp0d29qhdkH/mVvyvxL0DuSLg7OHdIOaPOR
ce2D2lXo7ufHrfC+PupkWK9/BB2qrg8GojZATzmyZ9surirTr1qhbh8NrSv/
EfSFr6PLzha1AXr+iGb/j/1V6e7nza1g8/mS+sLz/wh6/f25krIPbYDeNM3h
VJ+xqnRX3jnYCjlfThSfT/pH0IPvwbX5wW2A7phWNtt+uird/Xy6FRJ1BVHZ
nBqCHrWXF37jWBug96d6R8RQqnRXHjnXCiuHzvcdTtUQdLGH/fxWuzZA9082
r1Bdq0p3P89uBeh3fouDdw1BbxPMX2e+qA3Qa3n2BVZ2qnRXXrjZChuOqE96
FldD0JaLj9Q+G9sG6LytCReeuarS3c+/W0HLtaihSVBD0G0p/dV78NoAfTbo
oETirUp3Dc/DlfvXVuXhLMNagq5eJ3u5o7oV0L03nRy/+rIq3f28vBX2kdNL
DrnXEvRy7YWlX5JbAV3SVNb33l1Vumu49175+RQuyIh7VUvQNgPKb419ojxO
GK8/6P+68bkq3f18XXk8rNZYKK2vJWiNQnHZSd9WQB8JONUHPqjSXcOBlFZY
l/7Cz3hiHUH/HPb0fbmL8jxlPNDj+Tj/NFW6+3l8K2yliz4c2VlH0Fn3+49d
bNYK6KGR/MbSQlW663axsBWCW6d9jg2tI+josztHP1Ke5+hwY7N9U2pU6e7n
98rz12jBHX55HUG/cSiP5vVpBbSeuf9jb6Eq3XU7UdMK7LZDi2eMrifoE2e/
lDo1twCaNr53JV1Nje5+3t8Kqhkr3uyxrSdo2VCbsNSsFkCf8lhvMHyIGt31
dSNqhdRl7Maw2/UEPcJW0cPgdQugW9edOLJLT43unh/QBu8tS/7+yq8n6NDc
fppXr7cA+uUgweF3hmp01+VIow1Uqjj3Bg5sIGj5ZXlkx4EWQLNjT+irmKjR
3fMJlK97n+u5cl0DQbMXGYutN7UA+sTv8lPrLdTorsNVqw1qUp0mHfNrIGjN
ILNa2kh538rYK7rwwn0HNbp7/kEbWI48J4z81kDQG/d/PK2v1QL/f/3rmIX1
7mp01+ZMaoOl4nd7K3o0EnQpRyfVT9IM6KvyvUFGp9To7vkKbfDqbpRPf9NG
gn4yXT+eX9IM6Mk79zw4c1WN6aVt4L9n4PxFpxsJ+n3qAXu7T82A1hmeZJ4Z
okZ3z29oAzjjfN6VbiTosvhvH1LuNwO67xith8Mj1Zi+2gYbRo10viNrJOj8
fS3fZpxsBnTgMrU7TkSN7p4P0QYs1fO5ifOayP8t+xAYbN8M6BPssYZRGWpM
j1V+XqrVXxv+ayLovKO9RqgvbQb0jUWi/ZJfanT3/Ik2CLfaaDzoTRNBR2zI
235AtxnQEy0HrTFpUGP6bRsEtJZOmt/aRNBvz/Z1qVBtBnTYR0Gan1SN7p5v
0QbW3OtuIZlNgM5nVQ8f365GoTfIDVNeDWlm+m4bvKswvOsd0ATol4d67fxd
pUahQ3tXT180u5l0Dfd82qAcLLfZWjYBWug/aOjNPDUK3bcs90eWRTPTg5Xb
f8Y+wXhYE6D1HtyatiZZjUK/ic+4t92jmXQNBwKV7/fjn5RRJY2Anv1qbrTa
OzUKHfjgUlDz1WamH7eB704/L879RkBX3H50jw5Xo9DG6e8TjkU2k67bxbA2
GKiuW/p3eyOgTRb7Cg7fUqPQB4809NX80cz05jY4PeOmOEOnEdAP0sM+zfRV
o9CfnGJO3WpoJl23E2/b4PiStvx3fxsAXZb5saPhsBqFpraeHaij2cL06TYQ
zXLxevisAdALL9+598RFjUKfqU5LeDmxhXR93SQr33/w2nq/vQ2ANtEf+MHB
Ro1CH4wq8DVa0cL07DbIujh6lve0BkC3V6itHm2mRqGHzmve8XlnC+m6HBW0
waoTBzbvbasH9IBtWyyLjdUodBGYbFhxtoXp320w8sgQR7u39YD+WqpSeNNA
jUK7L25fnRnaQroO17/K86e2xWbD4XpAh3hJ8y1GqVFoWkNtveWXFqaXt8GB
wmErVhjXA3rLQdP1/fuoUWjTAR42xeUtzHyYNpjU9n3mIkUdoL8dbTPLVKhS
aBfVYU52rFamr7fDwLT/dOYn1AHap3Vkql+zKoXmayXurRjVyvT1dhhRGTFu
jk8doL8a1aWsLlel0O5+E1wdF7Qyfb0dzvSZNs9weR2gy7mXzHtlq1LohcK/
9tU2rUxfbwf7t637DHvWAfrWC2Pb7wmqFPpH6NllO7xamb7eDtNHDM6ak1EL
aM1zJu2XX6tS6H8tnkOqbrUyfb0dRmXVOxhfrQX08lmSoWtCVSn0/pvqGdvf
tTJ9vR1OaktnLLGoBbR2D5LeN1CVQtNNJ51K81qZvt4OLZdly8yG1AL6qIOi
X46PKoXuMZddsrm9lenr7XDCsSxiU1ENoLWHGdUFHlSl0PR3/wm5/duYvt4O
CVbfdu8IrgH0tPxW6807VSn0/Q1aK1dPb2P6ejusmDbK/8C2GkD3v/TVYaSV
KoUu+bvPKGlNG9PX2+HYGY8x58fVAFq73LZHxXJVCv15gWnTfNc2pq8r7/Nv
PDQI/vMP0K/CnFeFz1Wl0A9jpuyKutTG9PV2eKv3+VPM03+AfrkicureiaoU
OmzP/RDd521MX2+HQwd1yzL2/AP0vS3q72cOV6XQiUsb/G+ltjF9vR3MzZyD
66b+A/TAAdZ/xT1VKXRh4arpGv/amL7eDgLtnZyebX8BvTDlNp0gVaHQZ9zS
j3mptjN9vR1aTUyHG7z9C+ijV7NMLzaoUGi1X7buNTrtTF9vh14zPNrXHf4L
6NPpI7wtSlUotNgpWWXTknamr7dDo+TxncPGfwEt/fTUadQPFQqtfipixpft
7Uxfb4cI8k8rVPEH0HVT41RriAqFnhhysdXgRDvT19tBb9WVU1kJfwCd1j90
W0ykCoXeW/Ru4c177UxfbweL7OW/2Wf/ADpwVvZ/Jx6oUOj8GzZ9FR/bmb7e
DpdeDwDDFX8AXVmfuGb1NRUKPU/v4LYdxe1MX2+HWO9Vkbs1/wDa9Xf/eq3T
KhRaZ1GRfpqonenryvcvebwo7Ec1oNM+7Vpb46FCofeemmxnMLSD6evK65e9
MafiWjWgPw31P/HeUYVC+2SUy/1mdzB9vR1+vz3DHmtZDej3BttPnN+oQqGv
hC5QNFp0MH29HXIpuzU7hlUD2jCzYMNmUxUKfcNurdVqjw6mryuP/zmDpM9L
qgDduFpFMXGOCoXWdexgP7vawfT1dmi+uGUo/34VoKX2Q87K9FUodI95WW28
yA6mr7dD77/b3ixxqAJ04lyrhsyhKhT68KU1ulszOpi+3gHSjPiq63pVgCYe
U+eGqatQ6FNDH1x+U9/B9PUOCFG7/L6mphLQ/xaNc/US8yj0tKOx43r25DN9
vQPW93dasvhFJaCvnym8sraOR6EL+GalWyfwmb7eATUih1v39lUC2ks+9LF+
CY9Ca3IzXkcu4zN9vQN6LZn4TT6zEtBfrqRFK9J5FNqr1OUOy4nP9PUOSBlf
22QvqAD0jAviDz/jeRT6bp3GefMzfKavd8ATVefh3+IqAP2MXZQc/ZJHoSOk
q9zvPOQzfb0D5gxhO8w5VgHoDBP65+X7PArt6HncvIrmM329AybtjCoJX1QB
6G+bJwt2XeFRaBez8H6Tf/OZvt4BZUO07o9QqQC00CdZf9lJHoXu2+4euV/G
Z/p6B6RLzn0OTCkHdJt8+z5ddx6F1uIYj34zXMD09Q546ya2GXCpHNCNQfJ8
ngOPQuumcNbz5wqYvt4B9VcnngtcUw7oI6Fp26s38Ci0xjsXY0MrAdPXOyC6
8JrtiAHlgN7zVmfI16U8Cq0f8DZr/0EB09c7YED///jh+WWA9kkMlj015FFo
/sFEXsR1AdPXOyA+vN7N6E4ZoJsmSIb76fEo9NgI9ZTKaAHT1ztgoGdl1fct
ZYBW+WV02GMIj0LzTfx6DcsSMH29A1jsqe7OY8oATdEXR1j34FHoE8f/Ja9q
EjB9Xfn5r9be3TftN6Dj1B17LRZxKfTl+jnVR3oJmb7eAUNuHQuyXvcb0Nwc
tw2TarkUWrxZe/PTSUKmr3eAp35jzKufpYBuTAzmDyrmUuhxBxP7564QMn1d
uT2OCmGfbaWAvl8/WsFO51LoBD2aLd0pZPp6B7SfPvD8yN9fgD4W6Xqg6SOX
QnPvjx005qyQ6esd0OeqXf8211+AHtu6yr70BZdCfxzuPH9JqJDp68r9XTnj
4EF+CaB32CZnZNzjUujZyzzs7ROETF/vgEOFf8aoHisB9NRi40Tan0uhH644
+9+xMiHT1zsgldff4aFKCaBvU/ZmMSe4FDrj2PydN+VCpq8rPz9n9QurLhcD
epTBov1P93MpdGKY98gXI0RMX++AG5msWvagYkAP0KIWhNhzKXTRt+M+ZJ6I
6esdoO5mUJh0twjQ5S90P9zawKXQC0NjfDOsRExf74BVi2ojb+oUAXrC8pH8
a0u5FPqFW9KAooMipq/zQXyq9Pt/EYWAtsv8IPIz5FLoxXbnNSuui5i+zoeZ
+/WuOM0qBLReBi/7kh6XQr924Nv8iRaRrtungXw4s/6YjePHn4Bem+Z28dIQ
LoW2261d8ydTxPR1PjT32Xdz/9KfgJazG2f49cDfQ/GBJx13p7JRRLq+XnX4
sOjg6Vd+6QWATnFtzrsq4lDofWNHW5Roipm+zocZDvsHfLQoALTTZNdTN2s5
FHpW+DhJ5kQx6br8GvJhTl/rOeKSfECrLa4zvV/ModCtRya4f14uZvo6H9ad
lges2JEPaJfM4zOepnMo9GQ7VtALJzHpOj1N+CCIkj1+1pAHaHj72+JNPIdC
nwqgLAPPiJm+zodnLoPaRh7MA/TGF/afvrzkUGjLsHmnDz0Uk67dZ6n8PPR2
skLluYAurNI8kXufQ6HNZ/9RWNJipq/z4efOz7YLzuUCWjL51vO/VzgUWuPx
jyfTSsWkK6c78eFreENQbZ9cQItivDfITnIodO8bvM0qUjHT1/nwz5prFXEr
B9BbdrMuDvLgUGjTCYqa3GESpq8rj68D9PTTY3IAHdbbyGmaI4dCv63wn3l/
joTp68r/3+9vptuzbED/bhkhXr2RQ6EXj0ju6bhRwvR1PpALoVXuM7MBbXX1
uq2rKYdCr/2VbzrOQ8L0dT4caRCMu/wxC9CvZMdCr87hUOgHPM67kisSpq/z
4dL+CebEJAvQM6Yk1bwbz6HQwY8OTL7yUsL0dT5w4hdP0viRCeiQTc4m5cM4
FJpeO/XAgnQJ09f5cM762iVXq0xAr1t1LatXTw6F3rqr2LaqRsL0dT6w3ffd
KfryA9DaauFPF0jZFJpuiYo4oyZl+rry+qB2KKx3QQagT5zYVLuvgU2h2Yq1
k0bpSpm+zoeRcbbDj9R+B/TDb2+iwkvZFPqj8/W7kYulTF/ng7tGRPsYeTqg
w+mVoyt+sCl09DGXz/O3SZm+zofbOjmLVfqnA3rlDAML7c9sCr03KGwT8ZYy
fZ0P2Z9fTtfX+wbokfVaHvbRbAqdrJ82bH6QlOnrfPh+3Uj9wrw0QK/2DQh5
8ohNoZ0afn56+V7K9HU+3IqynDptTSqgtXZ3cNqusyn09wmDxMPypUxf58PQ
+u8TRjimADqh9G7CorNsCu29ONnraJuU6evK89/BNmTt4a+ANkpW0Qj8j02h
r3i01+X1lTF9XQB39sq3ZvolA7roT5NKgzObQq+eod2uO0XG9HUBvJLYW90L
TQL0h6lnq1dYsyn0hZC2WXtWyZi+LoATxdeexMclAvq9gW/R81VsCn0ltGHl
E2cZ09cFoLcg6+b0rC+Azh7gPWzAAjaFtvmp8r3QR8b0dQFoRMQGy/4mAPrz
neLC41PYFPp42nIz1iMZ09cF4Ln5oaOu4jOgb+qutGwdzabQ2TG7NwynZUxf
F4DB0xXfIwZ/BnTAndx0l35sCl2UZuk08ZeM6esCODwxv/XmFBrQT+wNjtdw
2BQ6al4Y20AsY/q68vWrjlvzL38C9GWdtmjXdhaF/vN22J2xQ+RMXxeAYutt
sCQfAS1Mk0aJq1kUuq+L6l2NWXKmrwvga9qVjbEtcYC2PBuRdrmARaEt2h67
VK2VM31dAOOj16tr6MYC+mrgyrXjU1kUujTXxe7VXjnT1wVQ8Lf/3g2b3wEa
bjoHpcWxKPTprCmpLhfkTF8XwO7mHyse+L0B9Onj5hoHIlgUWsRyqBsULmd+
/yiA0MlLp7CSXgN6xxh39vh7LAo9O3647NUXOdPbBXCsj8Vxb2kUoI+GiOsq
/VkUugfRGG9UJmd+LymAqse6F/QNIwE9x2Cd8dOTLAp9LWzLuRdSOdPbBTA6
RWfa8NIIQGsH0HsOebAoNCk8ptdnmIL5faUAfC5uVT9h8RTQU7x0Wet3sCh0
aM83ChtDBdPbBRAcYRkR8j0M0NHWUadmb2JR6KCVweJr6xTM7zGV59/Fh5EP
VzwE9NQLCRf0VrAo9MM6r9rovQqmtwtg/jNOre3VYEBbqOTGjp3PotCbOjZd
ivNVML/fVB4P1X0SSwNvADpt9Pn4SQYsCr2bbjrzJEzB9Hbl53/hYdbaxf6A
7uJoFoWui7PdeuSzgvm9pwDGyXfAgp0nAd3FfiwKzZt10mf6LwXT2wVw1/+I
V2WRLaDd17jZBnFZFHrE9jHLUoUK5vehyv2fIH2UTnn+3wu5tjNJnQLQ2+Xr
nLQ1WMz8cwGc5OnM1vx2jqAF7wL+7spUAFql8+UhLLr796ICyKiOcaOjrhH0
rsmL5EZvFIBO3/X7hIMui5mvrjzeLuWomXneJuj0qLIfU+4oAK0V3ufWvxks
enLX5gjg36vtCYsHhxD0ydb6mtXHFYCmz6r33EyxmPntQuinouL0a88jgi4o
+DHwtqMC0AMH3jrwejWLzu/q6UKIoAOeX49/TNCS7Y+sB6xUAJq75uV6vjWL
md8uBNWz3uPkas8IOnNAVW96qgLQQ/mXhaOdWcz8diHsjnUYGrbqBUEbVhgX
PBykAPQfv+3XpxxgMfPbhXBirNFj3tJIgv7pffcNkcgBPfDzdF3tUyxmfrty
ex9P+2JeGkXQ9zvSBwyvkAN6us+wg61+LGZ+uxB2ORW32nu+JujbK7IzY1Pk
gJ5ZfGPIoyAWM79d+f9tLxDVqrwh6CZf+7UPXskBrf4hY9PUJyxmfrsQ+o5Y
OuPctbcEDZ+KLxXckAO6TPva3OsxLGZ+uxCOVtUZfx/2nqDfL5o+2eGYHNA6
dn93ZdAsZn67EBz8Iw6bBsUStMacHbdWOckBfcTx+8yidBYzv10Ie+fFzHcd
/IGgN39cOuK2uRzQOQ9+7X/9k8XMbxdC0Suf568ufCRoTtgylY1z5IA+bmDr
vbGKxcxvV34+f6xMHATxBH1//7NvvtpyQE//OlHrQxOLmd8uBN6k0aXfbAhB
r+01avESDTmgrUTNW0vFLGZ+uxBCBqhd8LWhCfrSSJLh1y4D9Lz9Ibfeq7CZ
+e1COLR1/pmxvM8EPf36oVdHfssA/e/NkvGL+7KZ+e3K7bHLCdIN/0zQfa/7
mA3/JgO00DB+s7sWm5nfLoTv/mXD25YkELRq4+m7J9/JAC3r8Wk66LCZ+e3K
/8+EpZlTmEDQSwTH7yWFygC9lUdPCzZgM/PbhRB7OuVU884vBO3b9LiJHSAD
tPH5yT2Oz2Yz89uFoC/SK9vQ8IWgi7UlpzeekgH6mhtnYd5CNjO/XQg7NvR6
VOycSNABG+9drHKXAXp23rS4y6ZsZn67EBJeSQ/MLEwk6B4u1NVCRxmgpWl2
cwJWs5n57UJYM2xFY4pxEkHnl8yucLKSATrwapVf+gY2M79dCC2mjmviryYR
9Nj/BlimrJYB2m0pP3f4ZjYzv115PLYnu+TkJRH0iTHh10xMZICm3CJmb9nC
Zua3C2G0fswuK9Vkgh5xJLV1FsgA7b446OyObWxmfrsQXN88r1PRTibo9b4X
FivmywC96UPcVpY9m5nfLoRp65buLB6VTNBFB4YE6BjLAD3AxPNtw3Y2M79d
CEZjDHTrZUkEXWhjfWQxJQP0wOz1CaV2bGZ+u/L6ahjtN+pdEkGbxk6YMmKF
DNBbxtX922/DZua3i0BxcPjQwsVJBK19VVoSukkG6H3vTl41sGAz89tFILbN
sLp9M5Ggt8/6k6u5VwbozOpLgYdXsJn57SIIsYmY7fn0C0Ff8px4OOuCDNBx
SS5Lbs5jM/PbRSCdsGq9z64EgqbvvN34I1oG6JBonY239NjM/HYRWNifNnBK
ogn6bcCaeRv+ygCtO/unvaUmm5nfrnSp3K5kdTxBj+rPmjd2khzQLXxFhWst
i5nfLoKBT22Tbte8I2g3w2cOTiflgF5RPTHDjLCY+e0iOLUh5aHexCiCTvHK
CdzSIAf03cWDDdf5spj57SLYecq4ctr3BwTdMPzPoRv7FYDWaL30ZdYyFjO/
XQS7dDcV5o7dC+jUjbPfLFfD35uLYK9FQKBri4Lp7SJ4VVd6887oJ/B/H7Fz
ObaNRaEf9Vg0iQsKpreLIMym4+A59feA/vXs3XwzGn+fLgLTZ1fO7zwuZ3q7
CDYETnpuppEA6I2x0Wmh2mwKbXn5jsvbTzKmt4sgNNC97l/MV0BbT3jnZ36E
TaHNXlytsFeXMb1dBFrPNavhYzqgo9PWyr98Y1PoYJet3EPOUqa3i4Bdmxb0
6XgmoKkth3MEfTgU+oRJr819yyRMbxcpx3cqwUshG9BTnocE/FvGodCPnn76
OWWfhOntIrARjU9kPc4B9KTRPkNpTw6Ffvq5I+P4YAnT20UwYNvRkA90LqA5
l/p4DrnFodCSv2VDsn6Imd4ugtvC7Nsr7+YBeoDdvA2+rzkUumjRxc0Nt8RM
bxeBr90UnT5L8wHd8s2n6mQKh0KPcm6fLXUVM71dBP99/Dfm0ud8QPsPWXBm
+k8Oha7I9BHcXSNmersIMiwPzvEaUQDoorRGU/9KDoU2cxnrXm4kZnq78vO6
Omamuk0BoGfNcNTbXseh0DeD5rxeMEHM9HYRlGgcqB1/qgDQtg/MR5o0cyj0
inj7pAOjxUxvF0HZRfiXFlgA6KMtaltiWzkUusfIZpPLWmKmtyuP5x4Pvw+9
XQDoQYtiho1r41DoAu+b6bHDxExvF8En8e9r9/0KAG2lsGnNaeFQ6LXs5cOt
RoiZ3q4834MWmu4/VADofTlfx/du4lBo7c37XlaOETO9XfnvTew7HqwKAL1K
hVOtpvx80C4dEsNm5efT3dOV+59sy9k7tQDQFUP2xDVUcyj0/Ez9izqzxExv
F4Pj/Le5Oop8QO/5euNO1W8Ohdbfn502mxIzvV0Mv7e/+2Kdkg9o4/qDVj0L
ORT6vH7/NTWrxcx8djEoYr69Lr2YD+iQg4fzj2RxKDTdv9eGHlvETG8Xw5Gd
TnftVuYDuin9UtuqVA6FHuP0Z6jzXjHT28WQw18yw52XD+iiY8tN/Wjs7WJY
xXHzqDyGvV0MR8UjLwfG5QF6LXkUtf4d9nYxbD/5/q71VeztYri8Tf337L15
gO4/ubz48Qvs7WL4Fb5geXQo9nYxuGeou8eMyAN0xtxFfjceYW9Xft6XvCuz
32NvF4PLlMYB21JzAf09yZsz+Tb2djE4efIk4d+xt4uhNnFan5MeuYAOHvpn
zD4/7O1iSM6Y+XF0JfZ2MfSJ9kvZOBx7uxgW5/eLdTmNvV35eWwouTxRhL1d
DCLP2AGDPucA+v6U/x6OPYS9XQwJD/t9iOsjYXq7GP7b5bW6yTEH0FNXv6oJ
3oO9XQwPdzyYnKgnYXq7GO599DXto4a9XQzX52T9K9+GvV0MP69smWK8EHu7
GKbdlagFhWcD+qyHYlubBfZ2MbQPZS8cZom9XQzjj687FGOKvV0M1VM1/POX
Y28Xw+yQuvL1rtjbxZDl/OPP4aosQGs1FBr7G2NvF0O6rtnZ8rPY28Wg/vHO
SdWT2NvFcHLTzEztadjbxSBfe9vu033s7WL4Zr40zn0E9nYxFPou3+Q3Dnu7
GFbXu66rfI+9XQwfvWKCct9ibxeDlf/BgKLB2NvFsK68f+HKbOztYnDY/WsA
tRZ7u/L8fXGE00MDe7vy/A3rIWmqw94uhuffNjv5ZWFvF8OHuzv+DJVhbxfD
xeRZMzNUsLeLwdsjJrmd9QPQRst2m/Vpxt4uhiv7J+wsH429XQwTxOkGWVMy
AP3oR0n/hgrs7cr/b5tpke487O1iKHDJqlpo8x3QLwavbnydh71dDGHZO8bd
ssDeLoZTP3TKLc9ibxeD0Ky/644U7O1i6OtUPM7QDXu78nh/t507LRJ7uxg8
h89mcT9gbxfD0NQAhcgXe7vyfHC4Z/77J/Z25fb+qWm//AJ7u3J7Z04eXBWK
vV15PgeqDzvESgO05e0rJ9VCsLeLweJ7qbSZYG8Xw7WvKbM19VMBffjSni/7
rmFvF0Pvv3qHRxVjbxfD9L6/R0eYpQCa2yL7nHYGe7sYxCN5R134Uqa3S2DP
2y/9du7/Cuid80fsH/wf9nYJzPD9OjKnH/Z2CZwtnWuwKjAZ0P+Cc6ItdmFv
l8DURKs7lgbY2yWw2qPiyo73SYA21O+9+awN9nYJ3IiqXN22HHu78t/Tbt2X
UJQI6N5j++hHrMbeLoHKD+VR4Y7Y2yVQYuc0ea/0C6DlO5KzkwF7uwR4szys
3U9gb5dAtpnqtn0jvwD6uyNLtWA69nYJOM1WtK27i71dAutWewryFiQAOm/p
f3a/xmFvl4DlwX6LTN5jb5fAcz9f4/AtnwFddyvFo2gQ9nYJTMpwHboqF3u7
BNZsnlJdf5QGdGD1+owMNTaFzp9l7WDfLGN6uwSaf8fC1jkE0KwfspY4EfZ2
CbDteSMuaGJvl8C5lOoFdR7xgF46pWnz/Trs7RI49GiM2efx2NslMFOz1sT/
1QdA26+d6nX0F/Z2CSywe9BTzQR7uwQKShPVrGpjAS3QW0iv/4G9XQIDok8f
t96OvV35+oZtHut13gM6hBMUMPYz9nYJfBan/ozzxt4ugQnSnikXtrwFdLkd
ZVkfjb1d+X6o4xv072BvV75fr+CHmjdiAJ1TN3BHZCj2dglYj883vP8We7sE
+km3aFR+jwZ0edP6oW43sLdLALStf4zJwd4ugbDyyqNDVaIA3Wv03y/jz2Nv
l8Cfz9MPvWySM71dAiM317Ts/e8loB3Dvr77dRh7uwTmvNl3Zakm9nYJnPHu
0+9K5TNA8xcspfx2Y2+XwMAz/x2vHI+9XQKv7ioCnpqHA9pDvubxvC3Y2yUw
nLvt9QUT7O3K86HSvuXb+0eAvnQxaWqlOfZ25fn3zzNkrj32dgmYinxr1MaG
ALpa//Ho8xT2dgnMjnxNNx3D3i4B75ghE4sH3gb0rqkWbyfMwN4ugSkPNgVE
BGFvV27f67iqoVVXAe18IHV6yjjs7RKYNmjvXbf32NslsJkqSf3u4APoLg7C
3i6B48v2OBrlYW9XHj/+M1b2bdsN6NBL/ROlqiwK/f5P0X+qrQqmryv3v/Pa
v9+j9/7f6Zs0b+u1YG+XgFbu4dd71LC3S8Dt/Nun9j99CLrpWsS8NbnY2yXQ
9fIg7O0S2Po7z0Vj3DWCPv3EIt/jHfZ2CZDneQNNdbC3S2D5p8wt36xvE7Ra
/Pns63ewtys/7wcfbryZgb1dCkJbjZsvVoQQ9NAXywKivbG3S8Fzgu1bvUXY
26WwM8Hu7do/jwi6gb3a6/s27O1S0DheuPj2GuztUihnaQ5ecjqcoEX31/yt
XoK9XQq8aVaavbay6BNdPV0KisYVwkPazwn6fOQCI6meAtAf9csrT+7B3i6F
l4OorD/xLwl6g+JAal8NBaA3sUyCBF7Y26VwLbJXCG2AvV0KAh1Fx7gG7O1S
8NnLUnH1xd4uhQ/8GWfuSaMJ+nrmxyGzM7G3S+HtzTHtVText0vBuyTV59y3
GII2sn90btlr7O1SqDKfYmz7GHu7FN75bhlz8A72dins0K8Ntvp/b5eCeb1G
VM7/e7sUTHoalTjuwt4uBbPjxtG7DmNvl4I1Xa636gv2dilYWdktMjeKI2gv
jdrhR2yxt0vhi1jDPSELe7sUtIPvlk5W+0jQU2YPnnEZsLdLoaaq3WluGfZ2
5fY0XlgkyYsn6P7r/q4KGYu9XQr/bdIsetWIvV25v4qftL8OJQRt4v6GjlHB
3i6FX6Zh93Vl2NulcLvJ8NOTWJqgey2e+y/tnwzQ4q2VF+/0ZDO9XQpRlvoT
/4Z8JuiJgz5oVX7D3i6F3QceuvfWwt6u/PeNGw70P59A0HutFkfJXmJvl0Ja
zlb9k+Oxt0shaEl2lr7bF4K+/C5JZfg17O1SmKcz0rt1NvZ2KcyIHb1DxzKR
oIt62HrMP4C9XQoBknWm9ibY25X7U/2ymcqCJILO3+pqaWeFvV0KgZkpFpkb
sLcrP6+00FtfxyUTdKhTnea5+djblZ+32YXDxvbY25XH2+CRZs4aXwl6wpaj
/OhR2NuVn0/W5zOP92Fvl8KeLWOsq5q/EvT63A+elWzs7VIoGPTQpPdx7O1S
6DfmYqhRQQpBlwa51g2tlsL/X49efsHjMvZ2KdhXqYm3x6cStCeX0BtSpIA2
PRYyOj8Ie7sUjuhOGLjlURpBryv22nL9uRTQVtcWZxk+w96uvN5stw3U8/1G
0J89LAyK/aSA1k7euOvae+ztUujj8FX1g2s6Qd8boH9/vPI4Q08/uCeyLhl7
uxTWLFXLH2zxnaAPDgFd741SQJt4btu7KA97uxQ2Dvq+fvbcDPJ/b3lsWGgk
hf87a/KOgErs7VIY678xYtCoHwQ9wvzAygUjpIButUqyLm/B3i4FssD2Pyt2
JkFfaR5f8VQhAfT7c3W9J7E4TG+XgfpXHuuURyZBL8yQHx9dKQF0+S0Wta83
h+ntMkgreWTuU51J0Bk9NkXcU37vom8fyX0aOYLD9HYZyF9fmLRtUxZBszaM
7NB/JgH0Ccv9KvUTOUxvl0H8nWHL+qZmEfS623MbPyjvk9BWMyt7jJ3LYXq7
DGyai+cEzMsm6Bqu+gyb/RJA9zwmcVq/jMP0dhncv3Hs0J/n2QRtZV22XXWj
BNC52X1+HN3IYXq7DF7lB+9QG5lD0BYXbul9MpIAOj/udX2IA4fp7TKQBe2Y
33Y5h6DZt/Wmnx4hAfSJ13t2ftrPYXq7DDLDFf3D5TkErTmYmm/JkgBa3G5X
kXucw/R2GYjOpP0e7ZZL0Albe/UwqhID+v5akaTyModZT0YGDeXr91j/ziVo
n2V1jhOU4170QtsLq+uCOMx6MjKYMkB904Y1eQQ968OCiZMixIB2GlvuUvuU
w6wnI4OhvZ/3ViN5BO1lvNF44RUxoL9szysve8dh1pORwSEP64z9U/IJeqzD
rksOnmJAu5l/m5uRxGHWk5FBjM/G2/7B+QQdcO/ZsLtWYkC/jZzYFpXDYdaT
kUGQcNlsW80Cgi5ku7b+MxYDeoAi5ezFcg6znowMTBeMn5jjVUDQL5sPGK4a
Iwb0UzWTHdZNHGY9GRlMq7kW3fSvgKBjTGwGJKqIAa23ZT1/pIzDrCcjgz1f
A0mE5U+C1vXTyrSoFQG68X3rzTwNLrOejAyc4Wc9L/EnQes1pybKM0SAblAL
Cj4xlMusJyODJSq9vVqnFRL0q2NHt395LQL0E3rRmlF6XGY9GRm0u99d7BZc
SNBLKq2mht4SAXqr34Z/L2ZymfVklOfzr80xnupFBH3nfE32Q28RoF/Pv3hj
yiIus56MDLTGLE+SeBYRdJzgRe/P9iJAj+M9PXTfnMusJyMD2+bx/6S/iwi6
5ktHEmu5CNCao1SCFTZcZj0Z5fFRlahwW1lM0FXJvVmOBiJA+90VKlbv4jLr
ySjPD8d3a81iigk6Uy+7rr6/CNC36gdf8D3IZdaTkcGn/Zf2nx9ZQtBXKu9W
BguFgDbym9476jSXWU9GBnMDWo20zpYQ9AybL/sPlwoBvXP9qGVfrnCZ9WRk
sObQh6f8hhKCrh9zdeOpRCGgNdzm5H0K5jLryciALN1c0m/jL4LOfFlz/sMz
IaBvjb84/+EzLrOejPI+Vudw9dYPvwia//aB6firQkD76Lwq2f2Oy6wnI4cF
j1fG/tAuJej9li/6pf8nBHSKxQTBsEQus56MXHk/26Kx0aeUoN3Dl8Q/2yoE
9LLJWx88y+Qy68nI4ZPijH7pv1KC7kuPOphiIgS08H5z4vBfXGY9GTn8vV3z
zWrVb4I+e1vl+wQDIaAXzPQetruGy6wnI4ewmeHtkRG/CXrIzPyEnIFCQB/4
c33UjQ4us56MHCTT7DY4q5YR9Kmda/O/SQWAhvSCgXfYPGY9GTloOYz7+cOw
jKA9zBsHDK0WADr5Zw++Ry8es56MHLT9X7866VhG0PuM9MaT7wJAp1TW79Ye
xmPWk5HDyhP8wW7Xygi6mJzxTHkrAHT/kPikIB0es56M0s7vXp0jZQQtWKUz
3jhEAGheUUNd+VQes56MHHZy4pbF1pURdLp8rO24CwJA3znRuK5xHo9ZT0YO
4o0rbzQNLidobl7RrPOeAkAfC7xW/cGEx6wnIwe1fbsbBywqJ2jpsrQeB+0E
gOaU3JEsXctj1k+WAzHdWqnpUk7QISVr/UQrBYCOvFpgdNqax6wnI4cjd2JK
4q+WE3RCdFi/MXMEgL6vZ/CfmyOPWW9ZDh3ux2+ovi8n6LOmdIx0nADQ8SX3
w9iuPGY9GeXx6GLpm1BSTtDCNIsP9/oJAH3mzsaH0/7jMeszyyH3UMusFEU5
Qd9Ycq56OEsAaMOtxr1aj/OY9WTkMEA/0fSfdgVBH6wPLrnYxAd0knpUv3nn
ecx6znKYccblej1UEPTf+LQ36mV8QGs+0NKV+POY9WTkEN0U8fuGbQVB65+f
cCUmiw/o+vl173Rv8pj1n+WQKVq76f7BCoIeenqTRWQiH9CeC3PzwoN5zHoy
ynHuqLjE6MsVBH2y+WGwXiwf0PS5KVF7HvGY9aLlcHTP7vX7HlQQdMKKtPxl
r/iAHl18Z6DtEx6znowcns6IznaKqiDoiD+Pb5iF8wH97FJEzOYIHrO+tBze
bxzr3C++gqB18hpX/feAD2jXwB7WS1/xmPVk5DDt8KrdOV8qCNp5ifXKwff4
gDYrzS5qj+Qx61Erz/fjBfZtiRUE7UFdNz8bzAd08u83P42jeMx6MnJoXPa8
9DqpIGh122dXDEP4gJZmPZtTrXw/3etTKz+voL5qUdEVBK0d/d/R8Md8QDfr
JS6KUG5vd09XQNz3WfG9gisIetztHWMOR/EB7TpztduScB6z3rUCzo85vWam
dwVBG7sttHL6zAe0fUpZjtl9HrOejAJeWJdpbV9XQdDPsv3d1xTwAf188HtT
q+s8Zn1sBcTov9U5NaSCoPXqQxsWtvMB3eBr4Fvmw2PWk1FA/vqmvjrfywk6
0PK8YO8wAaDf5s7nrfDgMetpK6DxMm/hAbdyglaPlW0zWS4A9NFxJ9f8suEx
68koYJRPdvJ6SRlB74+/cdfylADQyx/EROUu5NHqXUFOAVvWBpZ77i0j6OxN
hv4m/6vhzkOaDsMAjs+tYxmWuLzJzOwgSxJsXtlTSae1TIMsnVlpGiUImiOv
6E5DsbQLl8WSbgQv+jnR951NxbDULMtMzBxmlmhTpznd23B7/vz88/Ly/vW+
Dy/fpglA2x+M9ZU6z6Gz49YgBr1dZSXyKz0ELdwd9vGeyySg0yM6bpePCMw9
GQYF3dI9p7XdBF14PX597KVJQJdVB5/aVyugs+O4MOP6afZS6vqNoIXLlQMt
E5OATh9WLHS4LDD3ZBg4upFykd1Xgk71sRalpf4DdJBGllK3TUBnxzUxDFqt
K1Ke93wm6GZ9qMJWOAVop4sdnuN6vrknYzx/9+TB6FufCFqtO14fVzgF6KLL
kqV7y/h09jmfzMDud63Hy53tBO2/3Xqjrace0Ce6ZbHj8XxzP5yBzybdhwSH
NoLWJm67oanSA/paY5TSagWfmnoxDHaslvSHbHhP0PYB4r5xv2lAJ/+IWTS3
D3vjDJyH/LZOF78laGndF1n0y2lAfygSqfe/sKCmXgwDybOJoHl3GwlaZ3nB
Z5nVDKCvpEJM4jnskxv37xcojhPUE3RnuK9j/lHskzPIbz+RJA6xoKZeDIO4
xSWi9O91BC3anJ0x8ngG0Lrv/qr5ntgzZ3BH+PRs5XIVQQ+5BB9o6sKeOYOs
xCOHnG0sqKkXw6DxzTGxLokQtLrvvpwKDYB2WVRe+lDPM/fPGYxFjt3R+tUQ
tJcyryN6nQHQA4rXBS2/eNTUizGeX0vw2vjz1QRtGRSRsWCXAdBpUaFb9V08
cy+dwVXvhjypl5KgOfnoqsFIA6CLva7+yW7jUVMvhsEaZ9EEB1UELXmfmzjn
jAHQnfe4xpkm/N/OwE1eWfpXzhH05icazQbjvQHd+yon56eaR029GAbiin38
ikCOoGvcu4h7ugHQigSbR0MqnLczeHB4yelrDhxBn1RKsmTGewb6nSI8QE15
1PRdn0HDdFhm5kqOoL2pk8OzDAOg+x9qRz1UOG/nbUlxtPfXSjmCPpUb9c01
1QDoZq715nAdj/4HurIPVQ==
               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H25 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{25}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HlcTOsfwPFZm5DseyqyE6ns8j227FtClmsnZEllqci+U0KELKEQUkhZ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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83HlcTG0bwPGZqZlRdkKUPdkSylbSdRSRNVuFhJCtLBGebCEVQiSUsmQp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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H27 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{27}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M
d96X92O+O1fekZ3ZOUnK1NzMnEJmdqqbFca1GgBqfFYLKAoUA6rrGb+poWsR
oLbeFwfq6FoCqA+UAkoDKUAZoCxQV+9LAvV05Xc1NR7nWw+M19gNNAZ/v47r
1LqaAZWAykBjoDxQAWiia0Wgud5XAVYBY7S/tcA4zdkIKKffrwYytdc1wFjt
taHWzu+aamzOvQGYoH2nAW2BdsBWYLL2vQmYqL1uBiapNu2BdGAgcCYwRfNs
A7K0p+1Atva0A5iq+XcC01SDLcDpqtNG4DTVeAYwXTXoB7QEWmm+dpo/FWgN
tAEG6NpW6+L7DsAgXTsCQ4HOQBegv8bj7wfrfSdgiK78ri/QQnOfBZyheg/T
GF2BEUA3oLuF76hPVSAD6AH0BEbp2svCg9X1XcKLvKcH6Rd6o4RqQF2KSGd+
V1TveT9a4/UGRmp+zpfwMceaDczUHspp7dSotOpNHctIZ96Xl278LuFF3leW
DtSrlH5HP1SUnvyukt7zPtEb3MNw1Yk12gXMUj1bqL59gANAjjTbC8yTlvuA
+dL0IJArLQ8BC6XZ2UCe9DgG5Guuw8AiaXkEWCxN9wMLLDy0B5hr4YGjwBKt
dTcwx8IfXGs/rfUEsFxangRWSAN+11/fcaxU3XMO+pW9dQ6wTBol/JqqvaXp
/jiwVFpugpkqevRJwsfpVuDRwdrnCNWYexuqd6zFMN1zrJH6jnNn6J7+Y55U
1fUU8YRfM7S30brvqnk4Lj2RZeETejdT4/GePdJQ2rOX6UV6lrlH39KX4/WM
Hpmob+mpSXrG3zNPUvQbZh3938AiK+rr3WQ947uxWgvnm6B56MtsrZe1ylc9
qOks6UbPssb0LT0+Xc86qsaD9N0cK8iaedKNmC+dCfqqvZAj3ejzmZqTc0zV
uvgu1wpyZ5E05PqWSivqmKfaE0u0D75bJq2I5dKKOqySFhxrscbgO3q1t64r
xTn3Qs3P+q1WDVnvNaordVsrHVjX9aottd2gelPDjdKRGm6SjtRqs/SiVluk
F7XdKg3pF54f1DzLImcbSbdt0o412666UasdqiW12im9WONdSdruTtJtj7Rj
r+9N0nBfkob7kzQ8kKThwSStDiXV7LDqRi/zXK8lDY+o9tTtqHSjViekFTU8
ZgV+PC7NqeFJacWD5EaLviwMfos0KQp+m+Z08JukeSHwm6UhvcOsoUeK4Pmt
0rAY+O3SkL5gbtIbJfD8TmlYEvwuaVgK/G5pWBr8HmlYVlr9/zcRnt8rPSuA
PyitioPfIY+UA79f2pYHf0DalgW/T/oz5x6StpXAH5a2zcEfk7Y9wV+WPn3A
X5U+g8DfVu3TwN+UPv3BX5du3cBflM5twZ+WLzqAPytfdAZ/Xr4YB/6pajkF
/GuLvhkB/r60rQx+rkVujgL/UNoOBX9XNc4E/1g6J/xH733DOnn0araH3tT6
E83Nea/m2B5euY46eHjoGou/dembL6iVh3euZb09tP+MOnv4jtfP5cGvtB/u
5XrW3sNz0zz8RC99y9p7ZMEcDw/RPzM8fEaPzfLwJT35HfXxyIvvgdkeefGR
9p+vNX4pj6eDX27RP03A/7Xo4VrgP1lkSg3wHyz6Kgv8BovMquJRO9atNvjP
FrnTEPwvi7xoBP63RV40Bv/HIi/qgf9mkUF1wX+1yKbqHuvmmuuA/2KRXw3A
/7DIphTwPy2yqT747xb5Vc1j/9x7VY/asW41wX+0yMpO4Bda5E5v8Ess8qUr
+EUWGdQP/FKLrBkOfqVFfw4Bv8IiUwaAX2aRQWM8/EFv9AC/2CK/xnr4g95o
CX6eRSa2B7/AIgczwK+yyKbJHj6gB8Z7eIj+aQN+vkWGTvTwH71HTeZ66ELd
Nntox9qs9qhPnkeOMEOWeWQHc4NzjvaYl/oP9vDABxb9w955y6Kf2cvc9zCP
vb9h0dvsa9ZgoEcdWKeRHrV6x6L32HdPAi08/v5lDVp71OEpi/5n7z9n0fPs
96YeucPMeQRo5vH/x+NAK4/z5FGLPGIWUc8uHpo+Y5Ej7G3WrJ1H3V6yyCzm
Fb0w38MP1KGjhxYvWGQTc4le6O7hh/cssiZP8z9hsQb6er2Ht1d45C+zd4NH
/jJ753mcEzwj6PelHp6nR3p5+IT+Xe7hYfZcjkff0YOpHj5c55HX2eCrPPKa
Wf2KRf4ye9lbGz36i72y0qNf2ItrPfrxNYssZg6v8TgPssAXeJxJPI9yPc4M
nhf5HmcPzx324mKPfmTf9PXonUUe5xbPLPbxEo9eZh4s9MiE/wDEuW/v
                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HdcTf8fwPG7L5GR7IyUFZVN1vsYKSPZe4ZkKyR7lZG9srNKoYwUUjlH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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTf8fwPG7rxH6qoxkl51N9vvYFJHMyEhGyoxkS0bZGnZmJDtSmeeI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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H29 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{29}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M
d96X92O+O1fekZ3ZOUnK1NzMnEJmdqqbFca1GgBqfFYLKAoUA6rrGb+poWsR
oLbeFwfq6FoCqA+UAkoDKUAZoCxQV+9LAvV05Xc1NR7nWw+M19gNNAZ/v47r
1LqaAZWAykBjoDxQAWiia0Wgud5XAVYBY7S/tcA4zdkIKKffrwYytdc1wFjt
taHWzu+aamzOvQGYoH2nAW2BdsBWYLL2vQmYqL1uBiapNu2BdGAgcCYwRfNs
A7K0p+1Atva0A5iq+XcC01SDLcDpqtNG4DTVeAYwXTXoB7QEWmm+dpo/FWgN
tAEG6NpW6+L7DsAgXTsCQ4HOQBegv8bj7wfrfSdgiK78ri/QQnOfBZyheg/T
GF2BEUA3oLuF76hPVSAD6AH0BEbp2svCg9X1XcKLvKcH6Rd6o4RqQF2KSGd+
V1TveT9a4/UGRmp+zpfwMceaDczUHspp7dSotOpNHctIZ96Xl278LuFF3leW
DtSrlH5HP1SUnvyukt7zPtEb3MNw1Yk12gXMUj1bqL59gANAjjTbC8yTlvuA
+dL0IJArLQ8BC6XZ2UCe9DgG5Guuw8AiaXkEWCxN9wMLLDy0B5hr4YGjwBKt
dTcwx8IfXGs/rfUEsFxangRWSAN+11/fcaxU3XMO+pW9dQ6wTBol/JqqvaXp
/jiwVFpugpkqevRJwsfpVuDRwdrnCNWYexuqd6zFMN1zrJH6jnNn6J7+Y55U
1fUU8YRfM7S30brvqnk4Lj2RZeETejdT4/GePdJQ2rOX6UV6lrlH39KX4/WM
Hpmob+mpSXrG3zNPUvQbZh3938AiK+rr3WQ947uxWgvnm6B56MtsrZe1ylc9
qOks6UbPssb0LT0+Xc86qsaD9N0cK8iaedKNmC+dCfqqvZAj3ejzmZqTc0zV
uvgu1wpyZ5E05PqWSivqmKfaE0u0D75bJq2I5dKKOqySFhxrscbgO3q1t64r
xTn3Qs3P+q1WDVnvNaordVsrHVjX9aottd2gelPDjdKRGm6SjtRqs/SiVluk
F7XdKg3pF54f1DzLImcbSbdt0o412666UasdqiW12im9WONdSdruTtJtj7Rj
r+9N0nBfkob7kzQ8kKThwSStDiXV7LDqRi/zXK8lDY+o9tTtqHSjViekFTU8
ZgV+PC7NqeFJacWD5EaLviwMfos0KQp+m+Z08JukeSHwm6UhvcOsoUeK4Pmt
0rAY+O3SkL5gbtIbJfD8TmlYEvwuaVgK/G5pWBr8HmlYVlr9/zcRnt8rPSuA
PyitioPfIY+UA79f2pYHf0DalgW/T/oz5x6StpXAH5a2zcEfk7Y9wV+WPn3A
X5U+g8DfVu3TwN+UPv3BX5du3cBflM5twZ+WLzqAPytfdAZ/Xr4YB/6pajkF
/GuLvhkB/r60rQx+rkVujgL/UNoOBX9XNc4E/1g6J/xH733DOnn0araH3tT6
E83Nea/m2B5euY46eHjoGou/dembL6iVh3euZb09tP+MOnv4jtfP5cGvtB/u
5XrW3sNz0zz8RC99y9p7ZMEcDw/RPzM8fEaPzfLwJT35HfXxyIvvgdkeefGR
9p+vNX4pj6eDX27RP03A/7Xo4VrgP1lkSg3wHyz6Kgv8BovMquJRO9atNvjP
FrnTEPwvi7xoBP63RV40Bv/HIi/qgf9mkUF1wX+1yKbqHuvmmuuA/2KRXw3A
/7DIphTwPy2yqT747xb5Vc1j/9x7VY/asW41wX+0yMpO4Bda5E5v8Ess8qUr
+EUWGdQP/FKLrBkOfqVFfw4Bv8IiUwaAX2aRQWM8/EFv9AC/2CK/xnr4g95o
CX6eRSa2B7/AIgczwK+yyKbJHj6gB8Z7eIj+aQN+vkWGTvTwH71HTeZ66ELd
Nntox9qs9qhPnkeOMEOWeWQHc4NzjvaYl/oP9vDABxb9w955y6Kf2cvc9zCP
vb9h0dvsa9ZgoEcdWKeRHrV6x6L32HdPAi08/v5lDVp71OEpi/5n7z9n0fPs
96YeucPMeQRo5vH/x+NAK4/z5FGLPGIWUc8uHpo+Y5Ej7G3WrJ1H3V6yyCzm
Fb0w38MP1KGjhxYvWGQTc4le6O7hh/cssiZP8z9hsQb6er2Ht1d45C+zd4NH
/jJ753mcEzwj6PelHp6nR3p5+IT+Xe7hYfZcjkff0YOpHj5c55HX2eCrPPKa
Wf2KRf4ye9lbGz36i72y0qNf2ItrPfrxNYssZg6v8TgPssAXeJxJPI9yPc4M
nhf5HmcPzx324mKPfmTf9PXonUUe5xbPLPbxEo9eZh4s9MiE/wDEuW/v
                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HdcTf8fwPG7L1kZX7JXVqKMkPU+ZY8ie2Ykkk1WJFtkZJWVEJUkK4ni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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTf8fB/DbnUo26UuyskchI8n7EIqyMiM7SWZmIVsqJKuyhezMVIjP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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H31 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{31}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR
5kIDdUOdigkoKEtnpE1rqDU1TC0ETyDIwkylEENQ3jkeeTmc5ny+180e/2Gf
Pdv543dfv/u+HL0sfsEKV5PJ9JWLyfTk72cdKWezsuq1hTfmDPT3by8c/NGG
1Y7cB+IfLyWOiDjcKJ7vbSm9nN8sTiw+pWVUtYjfdfgNDbrZKn5xyskW+602
8d3lPsX51e3q9zO/yzPXdIhTrOM/97xnE4eYjiworHskHjl1jLelwS5uij7o
Nrbxsfj8/pdvVTZ3itPLsgrS2rrEZjev7QG2bvHEGRkrGuw94s5VAwMPdDnE
V3J3DJnn6BXvqvBodjqdYvL76dOQ8DKfVskPkx8mP0x+mPww+WHyk9/X88Pk
h8kPkx8mP0x+mPww+WHyw+SHyQ+THya/00+tkR8mP0x+mPww+WHyw+Qnv6/n
h8kPkx8mP0x+mPww+WHyw+SHyQ+THyY/bOivZuivZuivZuivZuivZuivZuiv
ZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivFjTBuWfu
gQat4fXrW0Z4txTW7ux850TeQzH54i/t7bZBR5vEOyevD525qEUcFtnh3bi4
VTxpn6XfQXObuKek6VZIWLu4pDf2lGtEhzjbr357QaRNvDLqyb9H4oDsu4FD
Y+ziZ0rDvUpiH4v/dLnTnBzXKT48zXzFx9IlXhdz41B1Qrf47ZyFSbsSe8SD
yiven5XkEP/TL2SiLblXfDzgD9ejG51i8sTkWffUGnli8sTkickTkycmT0ye
mDwxeWLyxOSJyROTJyZPTJ6YPDF5YvLE5InJE9Nn8qXPmD5j+ozpM6bPmD7L
7+t9xvQZ02dMnzF9xvQZ02dMnzF9xvQZ02dMPuRFPph8MPlg8sHkg8lHfl/P
B5MPJh9MPph8MPlg8sHkg8kHkw8mH2PfriUsc/E2qbysTy15YfLC5IXJC5MX
Ji/5fT0vTF6YvDB5YfLC5IXJC5MXJi9MXpi8MP3Dkz7Z4bnE0iD5lfy+9Zdz
iQ/FUb6b40dtaBK7XQ0ccPHNFnF579n7CbNaxQf9Xv11XFCbOD7qdFbV7Hbx
G9n+a7fN7RB7lp6cM3OeTfy3i+/YxpBH4mPTjnXnhtrFSTETKkMWPRYH5xw5
7rqkU+xVPia1wNwlrut36OOosG7xqYAR04dG9IhTV2c/XxLpEIce8qpLjuoV
j67MKPSJcYrJD5MfeYa3xg8LLFImT9y7eNXVPKsy84vJG2dfWL7BvUKZ/PHw
jBNfF8Qqcx74QdGk+Kg4Zc4H/9yd/95QizLnhbdNHj+qJEGZ88MfRh5+nJyo
zHni8ftGl/skKXO+2FaSm1+drMx54996h2/atVGZ88d7/LKWzkpRZh5wZNQQ
f9tmZeYDT8ne43E0TZl5wS6lA2oXb1NmfnCZy45z/dOVmSfJe5rH3nM7lJkv
vCZm65q4XcrMG56R4x40KkOZ+435437D3G+Y+w1zv2HuN8z9Jr+v32+Y+w1z
v2HuN8z9hrnfMPcb5n7D3G+Y+w1zv2H2M8x+htnHMPsYZh+Tfuv7GGYfk/tS
38cw+xhmH8PsY5h9DLOPYfYxzD6G2ccw+xhmH8PsY3j3+ba30i+r99N3XGNb
c7GaL2t63TehZWq+Vnb8+8GZSjVfbr5Nmzwb+7wHEbHmwmaVX97e+/6Wtj7v
QfGK58baVH6ao6a20t7nPZgSfj6tS+V3e/ntvQGOPu9B5tK4BqfKL9laFXTA
VeUVbFo4cp67yuulqRV257Mqr7ro+dd+6K/yOrPf+m2kp8ortSw4ZfAAlVeo
W9GSokEqL/qI3eOuH0trUGb+6Cv54p7dHv/1X6f2E+YTkz/O7HLfF5ek9hfm
F3M+ePoy0+yKjWq/Yb4x54frl3/RM+yi+s78y3ujn6+8F5ldldbL6jv9kPdH
P3+8xbr++41F6jv9wcyHvCcmW+orJeo7/ZL3SZ8fPG7q2rAaq/pO/zDzJe9N
dPP0jDL1nX7K+6XPH760f/ULQRXqO/3FzKe8R2X1dfZK9Z1+y/umzy+OcIu+
kF+lvtN/zHzLezWjNtN8U5n7Qd4/ff6xc1WExfO2MvcHph/ynuXeCS6sVuZ+
kfdR7w/OqTCPsdQoc/9g+iXv3TN/dY25p8z9JO+n3j8887VF1yvrlLm/5D3V
+4npo3Efk/tb7x9mH8P0Te5zff/C9Auzf2H6hNm/MP0R6/sXpi+Y/QvTD7G+
f2H6gNm/MPMv1vcvzLxj9i/MfIv1/Qszz5j9CzO/Yn3/wswrZv/CzKdY378w
8yj/H9H3L8z8ifX9CzNv+H+BjgH0
           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83XdcTf8fB/C7ry2zrJCQkZmZvA+hrBAS+dp7lMiIhCLZhIyyZyEJLfQ5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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTf8fB/C7L1nZlT2TmYS+1vvI3iPK3oTsTcgoIooyQqKQvUJG6nNQ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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H33 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{33}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJxE3Xdcjf/7wPGzDxkpMyMlRCSbUNeNZI+sRJQd+WQnWVFR9ohQNlGyEpLx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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTf8fB/C7upGdipKsZFZWvgjvQ/bKCFnZRFZKSGYSkllkK0JllxD1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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H35 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{35}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR
5kIDdUOdigkoKEtnpE1rqDU1TC0ETyDIwkylEENQ3jkeeTmc5ny+180e/2Gf
Pdv543dfv/u+HL0sfsEKV5PJ9JWLyfTk72cdKWezsuq1hTfmDPT3by8c/NGG
1Y7cB+IfLyWOiDjcKJ7vbSm9nN8sTiw+pWVUtYjfdfgNDbrZKn5xyskW+602
8d3lPsX51e3q9zO/yzPXdIhTrOM/97xnE4eYjiworHskHjl1jLelwS5uij7o
Nrbxsfj8/pdvVTZ3itPLsgrS2rrEZjev7QG2bvHEGRkrGuw94s5VAwMPdDnE
V3J3DJnn6BXvqvBodjqdYvL76dOQ8DKfVskPkx8mP0x+mPww+WHyk9/X88Pk
h8kPkx8mP0x+mPww+WHyw+SHyQ+THya/00+tkR8mP0x+mPww+WHyw+Qnv6/n
h8kPkx8mP0x+mPww+WHyw+SHyQ+THyY/bOivZuivZuivZuivZuivZuivZuiv
ZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivFjTBuWfu
gQat4fXrW0Z4txTW7ux850TeQzH54i/t7bZBR5vEOyevD525qEUcFtnh3bi4
VTxpn6XfQXObuKek6VZIWLu4pDf2lGtEhzjbr357QaRNvDLqyb9H4oDsu4FD
Y+ziZ0rDvUpiH4v/dLnTnBzXKT48zXzFx9IlXhdz41B1Qrf47ZyFSbsSe8SD
yiven5XkEP/TL2SiLblXfDzgD9ejG51i8sTkWffUGnli8sTkickTkycmT0ye
mDwxeWLyxOSJyROTJyZPTJ6YPDF5YvLE5InJE9Nn8qXPmD5j+ozpM6bPmD7L
7+t9xvQZ02dMnzF9xvQZ02dMnzF9xvQZ02dMPuRFPph8MPlg8sHkg8lHfl/P
B5MPJh9MPph8MPlg8sHkg8kHkw8mH2PfriUsc/E2qbysTy15YfLC5IXJC5MX
Ji/5fT0vTF6YvDB5YfLC5IXJC5MXJi9MXpi8MP3Dkz7Z4bnE0iD5lfy+9Zdz
iQ/FUb6b40dtaBK7XQ0ccPHNFnF579n7CbNaxQf9Xv11XFCbOD7qdFbV7Hbx
G9n+a7fN7RB7lp6cM3OeTfy3i+/YxpBH4mPTjnXnhtrFSTETKkMWPRYH5xw5
7rqkU+xVPia1wNwlrut36OOosG7xqYAR04dG9IhTV2c/XxLpEIce8qpLjuoV
j67MKPSJcYrJD5MfeYa3xg8LLFImT9y7eNXVPKsy84vJG2dfWL7BvUKZ/PHw
jBNfF8Qqcx74QdGk+Kg4Zc4H/9yd/95QizLnhbdNHj+qJEGZ88MfRh5+nJyo
zHni8ftGl/skKXO+2FaSm1+drMx54996h2/atVGZ88d7/LKWzkpRZh5wZNQQ
f9tmZeYDT8ne43E0TZl5wS6lA2oXb1NmfnCZy45z/dOVmSfJe5rH3nM7lJkv
vCZm65q4XcrMG56R4x40KkOZ+435437D3G+Y+w1zv2HuN8z9Jr+v32+Y+w1z
v2HuN8z9hrnfMPcb5n7D3G+Y+w1zv2H2M8x+htnHMPsYZh+Tfuv7GGYfk/tS
38cw+xhmH8PsY5h9DLOPYfYxzD6G2ccw+xhmH8PsY3j3+ba30i+r99N3XGNb
c7GaL2t63TehZWq+Vnb8+8GZSjVfbr5Nmzwb+7wHEbHmwmaVX97e+/6Wtj7v
QfGK58baVH6ao6a20t7nPZgSfj6tS+V3e/ntvQGOPu9B5tK4BqfKL9laFXTA
VeUVbFo4cp67yuulqRV257Mqr7ro+dd+6K/yOrPf+m2kp8ortSw4ZfAAlVeo
W9GSokEqL/qI3eOuH0trUGb+6Cv54p7dHv/1X6f2E+YTkz/O7HLfF5ek9hfm
F3M+ePoy0+yKjWq/Yb4x54frl3/RM+yi+s78y3ujn6+8F5ldldbL6jv9kPdH
P3+8xbr++41F6jv9wcyHvCcmW+orJeo7/ZL3SZ8fPG7q2rAaq/pO/zDzJe9N
dPP0jDL1nX7K+6XPH760f/ULQRXqO/3FzKe8R2X1dfZK9Z1+y/umzy+OcIu+
kF+lvtN/zHzLezWjNtN8U5n7Qd4/ff6xc1WExfO2MvcHph/ynuXeCS6sVuZ+
kfdR7w/OqTCPsdQoc/9g+iXv3TN/dY25p8z9JO+n3j8887VF1yvrlLm/5D3V
+4npo3Efk/tb7x9mH8P0Te5zff/C9Auzf2H6hNm/MP0R6/sXpi+Y/QvTD7G+
f2H6gNm/MPMv1vcvzLxj9i/MfIv1/Qszz5j9CzO/Yn3/wswrZv/CzKdY378w
8yj/H9H3L8z8ifX9CzNv+H+BjgH0
           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83Hc8Vf8fB3DclZGGqGgvRUNpkbyPhopvkYbSICntoVKhvXe0JxqSCu3d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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTf8fB/DbnbaQEKJklhAZGe9jVrZsQmZWEVFWsmdEQpIyiy8JyfY5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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H37 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{37}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR
5kIDdUOdigkoKEtnpE1rqDU1TC0ETyDIwkylEENQ3jkeeTmc5ny+180e/2Gf
Pdv543dfv/u+HL0sfsEKV5PJ9JWLyfTk72cdKWezsuq1hTfmDPT3by8c/NGG
1Y7cB+IfLyWOiDjcKJ7vbSm9nN8sTiw+pWVUtYjfdfgNDbrZKn5xyskW+602
8d3lPsX51e3q9zO/yzPXdIhTrOM/97xnE4eYjiworHskHjl1jLelwS5uij7o
Nrbxsfj8/pdvVTZ3itPLsgrS2rrEZjev7QG2bvHEGRkrGuw94s5VAwMPdDnE
V3J3DJnn6BXvqvBodjqdYvL76dOQ8DKfVskPkx8mP0x+mPww+WHyk9/X88Pk
h8kPkx8mP0x+mPww+WHyw+SHyQ+THya/00+tkR8mP0x+mPww+WHyw+Qnv6/n
h8kPkx8mP0x+mPww+WHyw+SHyQ+THyY/bOivZuivZuivZuivZuivZuivZuiv
ZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivZuivFjTBuWfu
gQat4fXrW0Z4txTW7ux850TeQzH54i/t7bZBR5vEOyevD525qEUcFtnh3bi4
VTxpn6XfQXObuKek6VZIWLu4pDf2lGtEhzjbr357QaRNvDLqyb9H4oDsu4FD
Y+ziZ0rDvUpiH4v/dLnTnBzXKT48zXzFx9IlXhdz41B1Qrf47ZyFSbsSe8SD
yiven5XkEP/TL2SiLblXfDzgD9ejG51i8sTkWffUGnli8sTkickTkycmT0ye
mDwxeWLyxOSJyROTJyZPTJ6YPDF5YvLE5InJE9Nn8qXPmD5j+ozpM6bPmD7L
7+t9xvQZ02dMnzF9xvQZ02dMnzF9xvQZ02dMPuRFPph8MPlg8sHkg8lHfl/P
B5MPJh9MPph8MPlg8sHkg8kHkw8mH2PfriUsc/E2qbysTy15YfLC5IXJC5MX
Ji/5fT0vTF6YvDB5YfLC5IXJC5MXJi9MXpi8MP3Dkz7Z4bnE0iD5lfy+9Zdz
iQ/FUb6b40dtaBK7XQ0ccPHNFnF579n7CbNaxQf9Xv11XFCbOD7qdFbV7Hbx
G9n+a7fN7RB7lp6cM3OeTfy3i+/YxpBH4mPTjnXnhtrFSTETKkMWPRYH5xw5
7rqkU+xVPia1wNwlrut36OOosG7xqYAR04dG9IhTV2c/XxLpEIce8qpLjuoV
j67MKPSJcYrJD5MfeYa3xg8LLFImT9y7eNXVPKsy84vJG2dfWL7BvUKZ/PHw
jBNfF8Qqcx74QdGk+Kg4Zc4H/9yd/95QizLnhbdNHj+qJEGZ88MfRh5+nJyo
zHni8ftGl/skKXO+2FaSm1+drMx54996h2/atVGZ88d7/LKWzkpRZh5wZNQQ
f9tmZeYDT8ne43E0TZl5wS6lA2oXb1NmfnCZy45z/dOVmSfJe5rH3nM7lJkv
vCZm65q4XcrMG56R4x40KkOZ+435437D3G+Y+w1zv2HuN8z9Jr+v32+Y+w1z
v2HuN8z9hrnfMPcb5n7D3G+Y+w1zv2H2M8x+htnHMPsYZh+Tfuv7GGYfk/tS
38cw+xhmH8PsY5h9DLOPYfYxzD6G2ccw+xhmH8PsY3j3+ba30i+r99N3XGNb
c7GaL2t63TehZWq+Vnb8+8GZSjVfbr5Nmzwb+7wHEbHmwmaVX97e+/6Wtj7v
QfGK58baVH6ao6a20t7nPZgSfj6tS+V3e/ntvQGOPu9B5tK4BqfKL9laFXTA
VeUVbFo4cp67yuulqRV257Mqr7ro+dd+6K/yOrPf+m2kp8ortSw4ZfAAlVeo
W9GSokEqL/qI3eOuH0trUGb+6Cv54p7dHv/1X6f2E+YTkz/O7HLfF5ek9hfm
F3M+ePoy0+yKjWq/Yb4x54frl3/RM+yi+s78y3ujn6+8F5ldldbL6jv9kPdH
P3+8xbr++41F6jv9wcyHvCcmW+orJeo7/ZL3SZ8fPG7q2rAaq/pO/zDzJe9N
dPP0jDL1nX7K+6XPH760f/ULQRXqO/3FzKe8R2X1dfZK9Z1+y/umzy+OcIu+
kF+lvtN/zHzLezWjNtN8U5n7Qd4/ff6xc1WExfO2MvcHph/ynuXeCS6sVuZ+
kfdR7w/OqTCPsdQoc/9g+iXv3TN/dY25p8z9JO+n3j8887VF1yvrlLm/5D3V
+4npo3Efk/tb7x9mH8P0Te5zff/C9Auzf2H6hNm/MP0R6/sXpi+Y/QvTD7G+
f2H6gNm/MPMv1vcvzLxj9i/MfIv1/Qszz5j9CzO/Yn3/wswrZv/CzKdY378w
8yj/H9H3L8z8ifX9CzNv+H+BjgH0
           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HdcTf8fB/C7uikiCcmsb2SvyPY+ZW+VGWVHZCeRXRTJHmWGiBTK1vic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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83HdcTf8fB/A76mYL2YSQnRkqvE+SLWQnocjmK0VUlJ2UlRWijAgVJUr6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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H39 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{39}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJxE3HVYFN/bBvDtNRHsBEVF7EBFRXlGLAQ7sANBDBAwsbEVA0zEDhQb/aIi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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XVYFF0bBvDtfW0F7BbBQLEDEZ9BRUxAsBvFxsAOwsBuxQBRUbELEVEU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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H41 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{41}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HdcTf8fB/C7ry0kRPbKTEb2+6BsCVH2+NoyMsoMkR0pO1JCRooykvI5
KCVR2qW097p739vvxnn/+sfj+biVezrnfO7n8zrvz7vPht2LN3FYLFZrIYvV
/O+d281f1WA2Oans0pdIgoZVkaMSvhgAXbxo4JYeASza9qJLpfZpNSxz2r/l
gOQNQV+MPvc0J9AA6A8PJj33C2fRDUdh7Jroaggrndm+VZ8ogo6/2npt4zED
oC1sDju0+MSib+3qeIpOqoa1tY7ZLg7RBD331QVr9QoDoFeGRG8+lcaip68r
T+37uxpKYsw2rDwRQ9DW1/7M0dgYAF35xuQ3p4xF1y2K6ulVWw3nVuYNX/jq
I0HPXtG3ba2pAdD5absOXZCz6Bszmg+oGiwdqPS9rjRBa+U3H/0S6wHN5Y8Z
3kXIpinj0cxpUwNLvnlNSrjwiaCzZl7pGvJTD+jrq6L2hXZl0zUDR7UI7VED
xfzHPgsffiZoW6ht6/ZcD+g161qpbYew6WtdecvaDTfa4kYbXewXgnacvNOD
OqcHdNb6b3ThJDY9tVV28J4pNfAsfajVtpw4gr7opcmVbNQDelIsx+/MAjZd
pX0qTltgfP8TvIunSuMJOsv5Z79b0/SAvp7etWH0WjbtW998AmuAVzOsxdB2
CQRNb9AETOypB3TgT8+XJXvY9OTChd43d9WA0E0njbVMJGhwPTEtUaMD9LoE
KPT3ZNMVxrOn9qgBjwKvrIt23wjawXakl322DtA5q7fGOl9j0z6f5YNXXamB
MfdTYkrXJxG0eZvN575E6gAtVSdP6vmYTU98nej28X4NjNINIR4e3wn6cKD5
YCsfHaC/hEtqK9+x6bJH/nG9X9ZAssnmJXv9kwm6Yorfm6suOkC3XT9uwLtv
bPryzeYLtgY2pFsIM6N+EPQ1ux5ry2frAD2uwNXB+zebHn9+mvGKrYHC8z/2
3cj6SdBx9mdGDR+gA3RAzuQt2+rZdMlh07BZxcbrxSd09C1ZCkGrdl5Qu7B1
gOZ9m3hqThObvtR8e4proH7yyfxr51MJOv5lYeKdAi2gAwb5+Ft34NDjmi9X
Ti3MuNPLqlW3XwS9u5tqX+x7LaBnS7kz+/Tj0EXNp69jLcw7u/DEkye/CHp4
z7rCzOtaQFeLWpp0HsuhLzQfTt9aeLJ9XO8t49MIetkmiU2FqxbQS38IytrM
4tBjRjd/1cIsl6px2xLTCLqhzC6ifIEW0OfbFgxsu5xD/+kvOHl9Ri3s418I
OeScTtDBHhY3ii21gA6jxGPa7+DQ58xyfyqX1MIg2yOVSVXpBK0Y0WfmD74W
0F5bG1d1O8ahrY1354qNtVDOWsyZdCiDoBOO74BXxRpAW1Bz1w26wqHz1R7b
Y/bXgnl3VVVmy0yCnqj+5HUhVgPo/7i9YicGcegztX8HJFh5rC7M704mQT8t
sjVdeVsD6OdXCg4sjuTQVgXNB1QLkj32DV5Dswg67j+X0z0PaADd8+e32D3x
HDrPeDSlj2rhHjd7vV9MFkF3gwuDfjtoAL2/aKKLbzaHPk0nBdm9rYUyu5fn
UxdkE/TZBr+Ci8M0gI5pMa5DdDWHHhFxrzHkq/H4jm/42Kswm6Ct120xGd9C
A+jKhcnKUi2HzjGORq2yjeejIbil754cgnbk3Tz2u1QN6KxjY6Z1bMelPa83
D8C1kB5RmWvJySXoeZ3OnD9A1IBeoZg8ya43lx56tvkE1kKLYt1/ZX65BP0x
gVUp8FcDus/d45eOWnPpzIPVxhG4DqKmj4+LGpBH0IsbxT+vuqkB7dTibNd3
tlz6uPHs+XWtg8PjqdyH7/IIukQc/s1ssRrQ7YWD/WXLuLTlqivGEakO9mV7
fQqd85ug+10ISLk2XA3ohmirW2O3cen0BRtMnCfUQReLIKeU378JOjqqy5A2
LdWADu4nqzl0hEsfa/54nVMHL7+UmLfYlU/QpgtnqY+VqQDt5ryK+8mbSw9q
/rhZUQc3e+8PW8MqIOg85QbHKqICdKfTPzNbB3LpX83D7/Y6WPg8Y0y8bwFB
D8tMirD3VwF6+/U7j50juPSR5uHocB0cayTnpw34Q9B9eD73wt1UgBbpbUY9
iePSA5pvz4t18DD0ddeUd38IOjsjbUKbxSpAX7tuVqrO4tIpzZerfx082Rzn
4Ta3kKCXVdiv2zBcBejMSzkp9tVc+lDz6Qs1ns/ajY1DCwoJelj8QN6bFipA
b79Xd+yRlkv3az6cmDp4bj5mlNymiKCfSTZt4Zcp4f+vCxbM17fl0T+Sm7/q
YOLRGKs1J4sIuvRTUKUDUQK6Xa+Rl5x682j3j/fNRxbUwapX53akJBUR9OKQ
SXNv3VEC2mlYSV6kNY/u83Lv1qv1xvMxsuthMC0maLcq6fSiA0pAx7c+86e9
HY/+brw7pfo6gBni8Heriwl63Rrh4P6LlIBOddDV7nTi0Qf8micU9ZCYu37i
6JBigu7RKWXD5mFKQO91u/UzeRuP7uXVPCDVg1Q/7lmEqJigBSfLnj0WKgF9
jHg/G3aUR39zaz6gehi49PjhcRNLCHrnUvpzWYkC0HMz7wd4X+bR+4xHcxTq
YUv3h5oPp0oIer7kBafvRwWg8wRPDQ2BPNpixcZJhQvrYega2ajpP0oIuiaV
X7nmtgLQF7scu+QQyaMT5tkYP2Hr4WZIyZBks1KCHhN6ueb2fgWgK55GtYqM
59GuU5onUPUgX/65zbJ1pQQtSA9QZyxUAPrYDatTnXN4dPeRzQNwPewpOZOZ
/7SUoBMvT77eYagC0Hej1o91r+HR8b3/nkCodEwu2SwtJehLmbcvzxcoAD2x
c2RUro5H726eHgfVQxyrh/EzvoygA5pc150vlgN6FCth4aT2fLpb83Qxoh48
2KV395wpI+hpxy+/SoiRA3odPX7Q3T58+kvz9OlzPXT1cz4qTykj6P1v06fx
b8kB/bW/2Vr9aD69s3k6kVYPGV0pal+3coK+IS1cO3OfHNBjBSapq2by6S7N
H6+lxvevGhon2lBO0AHcmntn7eWAHmVoNSrGmU9/av64kdZDGfQq2RJaTtDt
1onaJVvKAa1OOavqtoNP72gefnkNMPBkfZ/f8nKC3gktd3fkywE9d92RRLdj
fLpz83Bk2gCTd2R9nwMVBL0hydR8ZZEM0Cl35HvTrvBp0nx79m+A4RqWX8S5
CoKu8Tz+9vEHGaAvTqUfDnvAp7c1X65jG2BsC/8gs7QKgq44Yh0uuyEDdNvP
m594vebTnZpPn10DnK/oG7yneyVBx1zaFTZrrwzQD94nDs7/yqdjmw9nWQO8
fzNu+NeNlQTd/9HG6rsLZIDe9WLBxVG5fHrL5uavBhhZ3za9Y1glQW9teeiG
YrAM0POPfHl9upZPd3CeYJwhN0AL2crnzspKgtbxFz9bwpMBmqPPGpKl59Mf
jLPFoWcb4HGHU7OvUVUEPdz94+83hVJAb4/r3XGAiYDeNKl5QdAAnz86hiec
ryLo+4FLB/f4IAX0y5GZta59BXT74c0TigaIjiv5IE6rIujge+36nr0hBfSI
V6pdMWME9PuezQNSAyT93BffoUc1Qft3nWmhdJUCOkK6ypU3S0D/Z9J8QA1g
26bP10Gbqgn6z6HGHi4LpIDuMOOceM5yAd2W0zyjaACZ17YL1mHVBC2Y8j26
YrAU0MfW33lwaYeAfifVZxysbgC/Qne2tbKaoMeZ2DZt5kkBXa5cfSL5mIBe
37y8VTdAQ19tyiCqhqDP7+J0rSuUADom0SBt6SOgWzcv91o1QvWawI4m52sI
+lJquML9gwTQ0V2e8GwfCOg3zcsf80bj/TUsqu5XDUG3K6oObnlTAmh1+9Yj
jrwW0GublwNDG4Gz5uupWPNagm5K7TE1aK8E0CduiteFfxXQf6fHk4y+c/3z
yf9qCZq2ftMT7CWADtz8aE9RjoD+O12c1wiWIZK340NrCdol9MzDUksJoJOe
xgxvVyug/06fVjVC4efTsSWyWoL2CZgSdJkvAXSU1frw8XoB/Xc64dIIdva9
aI8pdQT9x1l0nyoWA/pquvDl2vZC+u/oe7QRZmeNKm17po6g8023tFPHiAHt
eyD54Kk+Qvrvx413I4yfUjXG52cdQW8svlj+7pYY0PbtJ7Z9OFpI/x1+7zVC
wZzRIdwu9QTdceXmYR77xYB2T0uupu2E9N/hKKwROvUyD922tp6g3UQSy3kO
YkDHnxXsyHMS0n9vz4+NEGJmM5sOqSfo0P1lv3sNEwP6WXzbjqJtQvrv5fqz
Ebb/lz6upaieoOfZ39ioFYoBnZfzegHnqJD+e/oKG+FQxy3dbcc3EHSc23xJ
QakI0AFxuYIOl4X0v8NphD2RtTtdTzQQ9OyBreYkEBGg8+sOr+wRKKRZf79E
cHHuzLrLiQ0EHZ2Xfz7KXwToYN8OH/pFCJn5vAhKXc9tu2/SSNDtEibNe+ku
AvShHhvyBsUJ6WfiNOOMWgSJogLLIOdGgr4r7LAjfIkI0NZH3ecOzhIy838R
HNg9fdv1wEaCnpm4Zt6bkSJAF/g7rBhQJaQdS5sDAxE0TXCJPFzVSNCs0jmP
P7cWAfpEu9+hPTVCZr0ggpgO4R9DUxoBvTvu+chaqZBC93V/EmjZVUQMGc0H
JAIud9SA0rONgP5Ezf+mKhZSaA+PLTvbTRYx6wkR5FGjfgygGgE9zmH+vpap
Qgrtt3ZLt/q1IvLka/OESARyg3Cdm6oB0LFN7FsWH4UU+gxLlxJ3SsSsP0Rg
/1K8Lv1lA6BNXSbnjAkVUujcQWcX3ggRkcXNq9tFIhi24IdmyrYGQM9bEumx
8I6QQm9ffpuz/ruIWa+I4Gb5WLvXfRoAvfnQgg47zwkp9Ji2mwoGNIqIrjnO
2iCCAXZTMsfl1QN6zqKFb7zdhBR61+r118s6ipn1jQjWu/S6HOdbD+iuv8/2
e7VRSKFT54ii7o0Tk8fNcdBe4/Vj2ghr5tUD2jpeeyV7sZBC3z3QoshhhZhZ
D4mg/bnkuRxePaB5fSN9WdOEFFr14Xae4ZiYODTHKadEcDvTSf3SuO5Ab5Yv
nTpspJBCj+nseCokSMysn0QQnpHZY9uBOkAPOzB21goLIYV+0vm667x4MdE0
xxF+xr/nYvX9ISPqAP3Y0RByobWQQr9exn1ZUyVm1lsiSAr22iavqAW0ZOv6
FbFqAYXuPmLKPK82EvKweTkfLAJq/rOzifdrAW3iV9NHUimg0EW5Q2K6W0mY
9ZkI3g/0twh2rgV02LfNCYOzBBT6oYu1a9gSCbFvvlxfi8BfO/XN6Q61gK78
uHD4+jgBhbb2XPdoiruEWc+JIOD8khMuSTWA3lpi2ts/QkChR03KIt/uSIiq
+XDiRFCTfrL7ilM1gNbsLzqTFSig0K3NQLL4o4RZ/xn/v09aiwWTawA9X+Qx
q9MVAYXe0ovjmlssIQ+al2MZxvu3dSc7W3k1oD99tu2w6JiAQnscditYzZcy
60Xj9aQOWABh1YDe8nFL+pUdAgptfcpqedFgKZnfvJwpF8GEnJMmU7ZUA7qd
W2/blOUCCl3Wibivny9l1pfG8XPZbM6U3tWAft/Zl2o/W0ChL2f89ijeLSWK
5uWA3Pj7LwZ/nppbBeifJU9eLhwnoNAbJ4YFrPOTMutREXQ+eNGH8q0CNP9P
3/4+/QUUWjEj+l3hWykJbJ5OC8Tw6dqet9PnVQHaasDdF6kdBRQ68E3CwzV5
Umb9KgbHsq6tbXlVgO484SunA1tAobO892kK9FIyt3k6aiY2zls6npsRWwno
W2G8EodGPoVOfaCYtKaPjFnviiH0++Q0yq0S0LXWV8b4FPAp9JA7xTcKbWVE
1jydGyiG++a/d00cWQnoJ1/f+v/8zqfQL/f6Jm7YKmPWx2L4HqWTj6yqAPTo
Ecf1raP5FPpOMJtfdVFGApqnQzZiOFTw1qxPUAWg17x7YTf7CZ9C2159uH93
uIxZT4shd60dp82KCkArnK6yTt3gU2hThwKDOk1GZjdPJ2aJwe4uuSvqWAHo
DpUjB8Wc5lPoP6MCX51VyJj1txiEh1ub/fxeDmjPP55e0r18Cq2brpF1NZcT
SfPHq7MYqNa9TgWfLgd06ueEosHr+RR63eE9U8OmyJn1uhiit/+4s3tKOaDD
VkRWrFzIp9DBc29bz14vJ3ebh9+txutnv5ertaIM0Far19+9NIVPoQPtpiRU
nJYz63sxJBU+KqoJKwO0xN0yKnoon0J3N3lx5cITOZnZfHseFMP4tduX3dpS
BuifN+90rujGp9AbU5MyRifLmTxADENn3CETepcB+rtPxe52LfgUevsf696l
jXIiaj59543H61wa/TOnFNAjsqLCRit4FDp4yeUHtzopmPxADJd2+0Yuu1oK
6FL/stClZTwKPTFx3GNHGwXzPFAMh1Oevk+dUwroP/u2j9ifxqPQM7oODe6y
UsHkDWI42tVp9WROKaB7fV3a5QrNo9Cf9zn+KvZQMM8Pje8/lCq7FV0C6BFD
TSY8DuNR6OCnhd6RDxRMPiEG0tu+onxvCaCtzvkden+XR6EDG3PaeH9VMM8b
xRB3896dvkNLAC3eFPI48QKPQvcc8ypiV42CyTPEwH3lmWVfWgzoaaGBb9IP
8ii0R8jHa87tlMzzSTHM3TGbs92/GNBp5r4n8jbzKPTKpN+GudZKJv8Qw7h4
35v7lhQD2v5VWXm+I49Cb7o3bszMZUrmeabxfiusnbajdTGg45WHU/Om8yi0
m0mrtXMPK5m8RAw5FsUKhy9FgHabFTUlw4pHoU1dr5x2ClAyzz/FcGK4Krnf
kSJAr2s9VZrYk0ehqepT3XZ9VjL5ihjOJdpalFkXAbqv9SLh+zY8Ch3jv1rs
XaFknpeKYXryuKd9MwsBfS534NKHGi6FFs2PWPqulYrJYyQwMM/pyDLbQkDb
abenXKjiUmi3lkPW14xQMc9XJXCvV+vZGyP/AFr2H/u8SxaXQncbr68fuETF
5DcSyD62w3pe3z+A/rB7weY5cVwKfaH3ptE73VXM81gJDG8s3dL6agGgK47p
XPpEcCn0WJ5wYKy/isl7JLDkQeOcR035gJ4rm/JUdp9LoXd0Of3CjFYxz28l
MM032KPrrnxAz96b0f6LN5dC7+nuVHSoTMXkQxK4MrbOblP+b0BHnIl9cukI
l0LflZwOq2ihZp73Gt3J7v6lub8Bvf9Bld+ibVwK3e3DiJxVw9VMniSB9jN+
eV+OygP0hsHRvzo4cSn05PCLq/IXqZnnwxIImkq+7hiYB+iMyuyDP2y5FNrZ
yqHdJjc1kz9JoB13KmvAtVxAb6CFgaetuRR68nERUdxRM8+TJRCb3b86mp0L
aNWd/qttenMpdIekt3ZXiZrJqyQwa+eEsBG7cwD9dHhCZnlbLoUOe+jqOKZM
zTx/loBD0NvuJ/OzAT0kw62fj5ZDoUOdOr4vbKEhf+MdNwmMP7i8Y+ScbEAL
R87bMK6aQ6ElQdsm+Q3XMM+rJVCerJ399W0WoO8d6vUtJ4tDoRPafNppv1hD
/sYjZ43H223h+w/9sgA9vtTS3T2OQ6GvTgjt0MFdwzzflsChqJiP13wyAd3+
ZvbNjhEcCl3yyyE1z19D/sYLNyVQuND982J9BqB11fbOz+5zKHSLYRsWPqc1
zPNwCdxvY39euS0D0Nc+WYqnenModM7RUAvPcg35uzwPkUDugsJbp7PSAf2h
urtf6mEOhb4wLDF3TSst8/xcAo/c5Cu009MBnRm2ZsfarRwK7fRguuW0kVry
d7kXJYF1+b2XrAlPA/Sl7huTapdyKHRVos2OwY5a5nm78fpWbt4Q1j0N0KV/
5icfmMGh0BOnb95iekhL/i4HEiXwxnuqXcPZX4B+9yskUW/FodB+q17u4gVo
mefzEriprrjRS5YK6NGF+ZJTPTkU+s60meaqz1ryd7qYK4He9y91sl2XCugy
P1fPFm04FHp8Tg9tQ6WWeZ4vge68glMxt1IAPT11SuJFNZtCH1t7endVGx35
O52oNh5PxquSwj0/AW1rMdTQtpJNoQ/FP+WWjdIxz/8lEPDr2UzF7B+ANn+x
feOVDDaFTn40xKZ4mY78/bhRS+D5XM4nXp9k+L/7m8w3+cym/u+3hVsKj+iY
egEpFIcV7G6nTgJ0Q56+wiecTaH7z+VZ/wnUkb/DUSsptLZ4FNz11zdA/1o0
8UKHe2wKvXbVxdr8eB1TXyAFau2nHYOeJgJa1jnGzfcCm0J3zTjb8XeNjvy9
XM2lsPWOYBCcTAD04217JJ0Osil05LBe3XPa65l6BOP7ue2d99/yr4C+mvtk
yo1NbApdOD/sdPoYPfl7OEOl4D7v3Mfbo+IB/e50lX+3JWwKfVUxIjF5uZ6p
X5DCjGlvqPKWcYA2dWztGECxKXSOU7XTFw89k49K4fbqJyfmlnwGdJ5Xqyf9
R7Ap9AJZTfjbYD1T7yCFSquNcT+iPwG63YyZ+aHd2RS69NC+WY8T9UyeKoWj
fidX7/WjAT2+W84Am5ZsCu3zY+Hrq/V6pj5CClN2ndpxKOcjoPd2X/X9i4JF
oXt8m7XtYEcDk79KYXOHOXPXX4gB9MXZi1stKWNR6JpdK2uX2xiYegopJD1o
lfhgcjSgzZZSZuW/WBQ6fenx9LGrDExea3w/z6+L7RrfAXrFi0sjDxMWhZ7/
qCKw9UkDU39hPN+LO4kXPngD6Bt3zh3v+IJFoTOTGli/HxmYfFcKWwoj5yUu
jQS0NmD19LA7LArd6rPtkeAkA/m73PMy/n/vgmtet3wF6GiLpSELzrEo9MW4
pa82NhqYPFgKuvOtl9gcfQHowSPmF4gOsCj0y+Atdj1Nm8jf5cB1KdiF74/g
VDwBdGzat1a3/mNR6DMrXGpSxjcx+bEUXHR9srMcHgJacnbVyhmLWBTaQjRz
zqHVTeTvdPGRFMSxqazDh+4D+mgQWyaZyqLQLWJ1Xcw9m5i8WQpv1wxZ7r7k
BqBjHSMaHg9jUWivZf59Ix43kb/TibdS8ObozPasvQBobjPNWRRaK0zrNe17
E5NPS8Hm5fbDvSfsAbTz2Ck+PVqwKLTDda/Cr41N5O/HzVcpfJDwNw+esf//
bqu5nR1T2wRoNWf0tT6tWEy+LYXL0s2vZCsuEXQ363tmcxOaAC1rfrkHi/47
HGVLIaaht0PMrJsEbXeUtCt+0ATogmmBB6+MYDF5uBTcPKvWx48MJOi6D6KM
kx5NgG714GxnQrHov5drpRROHQvnukY/JGjT0yXuw1Y0AVoR2y6uejGLyc+l
UPIxJqZwxlOCbmluzike2wRonUTi0X4Ti6mHkcLJ/ptSTJJfEHR+1ulD9zs0
Adr32pQZVu4sJm+XwcZR7js9LV8RdM2lwblb6g2Avvh+R6f551lM3i4DD0NV
1RqXSILuuse1w8RvBkDLZs1SbvBnMXm7DEZ92b02IOwNQf/gtjQ3e2QAtLmH
VrL/BYvJ22XQWf8oZbroHUGPDOSna08YAF098piZJ2ExebsMujnkTrAfFU3Q
hu0betSuMgD6ZNJP1wu/WEzeLgP7Pdbw2TWGoLU5bfJLxxsA7emn7nC5lEX/
y9NlwAq8V/7g1Ufyfw98/Kvc1AD/d/2wLt5yFlPPI4O1Nlfh0EGaoE1z2+aI
RHpAu3VS+50Vsul/eboMqpSFS/NufiJoLtv2De+HHtAeTasfHevGZup/ZOCS
tqlE8fYzQUfYRfbr81QP6EGrB+7aPZRN/8vTZaDfSd6mZn4haKrj4Go7Lz2g
ixQ7Wq+ewmbqhWSguzFw+nZZHEH3Hv7h3d71ekDv2db34cyFbPpfni6Dlx6n
u33t+JWgh+xJmRwyRQ/o2lm31g9bz2bqi2Rw3qHpSoVVAkE3dmaNKO2mB3RL
edPWdvvY9L88XQbvzE28f9onEvRT3eoRAxU6QD9n/6qqO81m6pFkEHbySYuT
Lt8IOqmx5s/uNB2gu5+7YJJ4g03/y9Nl8HDK1wrWhSSCnj9+UCkJ0wE67z+X
doFP2Ez9kgyWaSeuWBTynaCvB0ZldL6oA/Sb8ODOB6LZ9L883Xj8OXrvA3HJ
BF1qS9m7btEB+kpBofOsZDZT7ySDL6whRXuKfxB0FdGU/pqhA3SbQE67Ln/Y
9L88XQaXj097M9Pwk6DbpTpZ2vTWAVrdxXFHWSObqY+SwSPKZv6xtqkEnT1S
Ehqo0wK6c9WZp+FsDv0vTzf+/c6nGRL8Uwn68up5rHa5WkBPWJTXdLATh6mn
ksHEvebL+UN+EfTe/94/9XijBfQs+37PqQEc+l+eLgO/+O7dbKJ+EbR/u/cT
JFe1gI442K9UYMNh6q9ksHDm3H5rZ6YRtMuu4TZbd2kBnTR7W9n32Rz6X54u
gw2NOxYdz0gj6MG8R0OL5moBXXdseM2VFRymXst4PtPOnbm9IZ2gV35fHbB8
kBbQS8x/WS1x4dD/8nTj+axYHhAuSifoWWe2dc3gagGdP/m7tLMHh6nvMv59
TvIPfPHIIOiI+x/7LizSAHrQy8BdOVc49L88XQZbL9tIs9pkEvTmHtYzkmI0
gP4h3vznThCHqQeTwYsFKypr72QS9HUXS4HdbQ2g386pPbo6kkP/y9PlUJKS
M5RnmUXQLZJbyj8e0ABa1+2IV+94DlM/JgeHaZJLfd5lEXTo7i93bRZrAD1k
dsCosiwO/S9Pl8OrGSd/2dllE7Rp+P2LYSM0gHYbbBX9pIrD1JvJoQfZ8Hlv
ejZBT3DYsrBfaw2gy5zmO+/ScOh/ebocngX/bvlsfQ5Bm3U5f+x6pRrQB/ZP
mja2DZepT5ND3P745fWNOQSd8uDyU16cGtC3wsY/11tw6X95uhxyo88vnOqR
S9Bzr1q47AlUA3qljfhbwkguU88mh/E2yYcD2uQRtLVk/vqco2pAV55ZnuI3
jUv/y9PlcNzv64r2/nkE3XulveXk5WpA70lzrl2/hMvUvxl//pDXFl/L3wR9
JqjnZv+xakBPCRfNt97Epf/l6XL4ecVSYBn1m6Db3D3wUd5BDWjNqPjefHcu
Uy9n/Pncu2cyZuYT9Ktvzn/mNqgAPdg/3SfvHJf+l6fLoZwq6X8jM5+gE3Yn
uN1JUgHaYvbduIg7XKa+Tg5+M3a33r2xgKC7j+w/peyxCtB7q3YWe4dy6X95
uhxo72vz10kLCNonP69u0CkVoKOu+rZ0+chl6vHk0Ll1gGS75x+CnnTMecam
tSpA//dpyZoFqVz6X54uh+rtDYVXOhQS9MxNvBZ3J6kAvfqHXjuqhMvU7xnv
h3ZXy1MCCwl6Woy/ILmLCtBFfSJ03WRc+l+ebry+41LKOnctIuh4i1tt5VIl
oHuKRx/iC7DeTw7n/1Cd09YWEXSMz1q5WaoS0A9sHLxkXXjM/h3j+XFdEn83
pIigB89adm9UqBLQLvmOoyoteUx9oBzslv0Z7dZYRNB/MkwqbM8pAX31uvJS
wSQes99HDvPr1p5ZY1NM0HktU2McNioB3Ul7Myh7AY+pJ5RD6eGxRUuPFxP0
5enl7ZdSSkC/X9P2YOZaHrM/SA6uUQ8cViUUE3RicFj2oh5KQPcIG2ya7cpj
6g/l8JUoc13blxC0RW9ep1kqBaAljcfc8k/xmP1EcphsUuV+w6mEoEuUrePG
ZCgA3Z6nuVd+ncfUK8qh3ZnHrZLulxC0OiZUY/5SAejTQU89JSE8Zv+R8fpo
ozzQpqqEoNMO8eLVFxWA7vLlmAU3msfUN8qheOmVU6utSgnaZOn4qb+2KAB9
MLN0XZdkHrNfSQ53u12UxxwsJWjrfRO9gmYoAL3l64YpI//wmHpIBRQP0x0f
8qmUoH2q2fT2XgpAj2/ddH+uiMfsb1LAht5tvz1qWUbQKbsPdR9u/L3orrNn
7N3G4dN/p0+mCiD9vbePWFxG0IE73ydVZRnHdcZWc4LvXDTlM/uhFLApu0b6
5U4ZQdtfayUIMF5n6Nw3Gt3LgXz678drfwXwXsaWbSotI2jDoKC2Cy7LAc12
GXkodzyf2T9lPL7vw990GlZO0OPNtw1QbJMDumzvvHrePD79d/gdqwDbsy2T
k/eXE/Saydrbt+3kgP61njN69Go+s99KASrp+0s+seUEzRMEv7fpIwe04eiI
fht38+m/t6edAtLGPpq7RlBB0F02vchL1ckAvX/BU9+bJ/nM/iwFVOzaunDs
wgqC9k6c57wpRwbo6O55S3748em/p2+ZAhzGCAtMb1UQdM6mo1flkTJAm/6Y
ZsN/zGf2cykgPkI3XFdUQdABj9nVJ6/IAP1q2PHWEMWn/8bpmxXwpPWCfTWW
lQQ97PDyr612GOcdjGump989nMRn9n8pQGxikvVnbyVBn1Mqr/nMlAF6Mu/0
m3f5fPpfnq4Alz0b3XM+VBJ0UsKCuE59ZYDu3iPXQtHAZ/aLKaCjQbQ/i1dF
0MoTZ+Ov6aWAPg2T741lC+h/eboCnj3rUJ69oIqgnw9xb2uaK4X/v77dVn2g
k4DZX6aAhZGGnN83qgja+fGJTr6vpYDOCAXF2wEC+l+eroBtdibrigurCHp+
gXJhex8poFd04DmrbATMfjQFvHdJO105uJqgH367MeXSDimgR/iPKZ4wV0D/
y9MVcI3YL6p3rSbocYHOTi1nSQFdHr7E8cgqAbN/TQFvf7CSxNHVBD3gdpP5
2b5SQO8afWJvzC4B/S9PN16vY3crpdwagmZvms0TGCSAPvHjt153QsDsd1NA
S5ODhZL5NQStU87wOZMrATSH9+fdZD8B/S9PN75uCD5ff72GoD1ZIya1fCMB
NGnauuHIIwGzP854Paz/T1/yp4ag5y60P3nZRwLolTnOJOqdgP6XpxvH7Sv7
Z6UNqiXotVF2+WYuEkCn9iu4KvsmYPbTKYAevvdA9J5agu5dPTP+wSwJoPdc
XHVvRL6A/penK+D3poc377yvJeiOP4a/tu4nAbR7t+pHmxsEzP47BcQeME1w
5dQRdN/4Az0SDGJA77aId73LEtL/8nTj+NrPwQLm1RF01wYn13V5YkDLWjgm
pHQUMvv1lDDx0uSP7Gt1BF36vrh30xsxoNv1u7KbNUBI/8vTldA61Dw1Kr+O
oDVPJTeDr4oBzX0uGDPCRsjs71PCoICznv8NqCfoOquYqfY7xYC+UBlU5DxH
SP/L05Vg08GzLXtXPUFvVE491DRbDGj70+tmnFgpZPYDGl8vHvvS5209Qdu3
Lw95118M6OUH2w57uFNI/8vTlbBIPjqiQ1M9QTvzKwa6s8SAdtRfcok7LmT2
DyrhmkvY5lOzGgj67bcn86fmiwA9wP95btFVIVOfrATTodMGll9pIGi37YUu
baNEgI6f6zNHHSxk9hsqwaX9a+dxOQ0EPVf1KL3MTwTo39zhN9q+FTL1zEqQ
+vvudOvdSNCCiHHf4naLAK1/vNHfIlHI7E9UwrEtPQsebm0k6OnJe66+mCcC
dOHtWTaWeUKm/lkJ/idvjvz0spGgrWHM1vuDRIDeUlQ+z6pOyOxnVMIevbM8
SdVI0LNPLvG6wxUBehUsi7U2CJl6aSWsb5gzbippBPStI77eKY1CCp3a4nfZ
ut4iJm9XQkpywrMV7o2AHiN99SyrQEihb3W7+2yxrYjJ25VwdsbNyAsjGwFd
kloeWvJdSKEnrxnzeOJWEbM/UglX64/7/qxsAPRG7f2H0vdCCj2+Jf226yUR
k7croefHlkcGBjYA+tzuzwEtnwgptLj3kc914SJmP6Xx9RFnb/o6NwD6wffi
R/1vCCl0zNbJr9+mi5i8XQn5B+K5nTo0ANp9tZi2PS2k0B3tLDzclCJm/6US
ul+xTwv5Vg/ohGA/2ba9Qgq9NyrHbFh3MZO3K+GE4pdwkWc9oAOPyaZdWyek
0DSvy9HsqWJmv6YSkhOPBbabVA/o0Xt7PfliL6TQd7p/Cj+4Qczk7Uro1fXC
xSJpHaBbnCnpq5ospNAi6cTo9mfEzP5OJYwacDf0a2gdoOe3HPR81FAhhd5a
/+rp3adiJl83Xr9peX/oTXWA9nn91mZPNyGFLrzh69Prh5jZD6qE2LUDRT97
1gG68WbLmEihkEL3Ta07e0skZvJ147rDIypElF0L6JheDZY6uYBCn6f7hQpN
Jcz+USXoaueSAVdrAd0UnbZ7TpmAQnMurOi900bC5OtKeB4mqN05txb+7+ef
DvunCSj0sydHW31bISHD/h6OEq7c2JmWyK0F9MNN/mMktIBCR435dqO7h4TJ
11XQsU+T2bjYGkDbJhKvBeECCu2++4RsY5CEZP3N043r3OGpDm/cagC9uPUY
xxf3BBR6dfVNp0dxEiZfV8GXVfdMZlrVAHqU06DTHS4JKHTAolfK/EoJk6+r
4IrFq8LK6mpAb5xVpzx0WEChx7sOMmnTWsrk6yq4vjEE7gRXA3pAbvWViq0C
Cv12wbAi6xFSJl9XgaXVnxerVlcDutUl96FOTgIKXVdp8nTRIimTr6ugYvmb
gBFdqgF9eNmLkO92Agrddsmjl1v3S5l83Xg8PReebv+rCtBPEjoVzxgjoNCv
9uRMOXhTyuTrKnDeJf9muFAF6Bsrj0WQvgIKnTGb738iWsrk6yr42tUiS2tb
BWjrmWflUzsIKPS9fWJTzwIpk6+rQLQhs42gqRLQMc5jT31q4lPoc/bX1UdZ
MiZfV4HT3mE/e7yvBPSNHhdHz2rgU+iMr9W3XPvJmHxdBX/Mnd1gXyWgowQ3
ClLy+RT6qiTddt1MGZOvq2DZhA7rdw6vhP/b3tZ55Xc+hV76n/vCOdtkTL6u
Aq73sIpHlRWAntbv4qHq93wK7fG+us3wSzImX1dBzvaHq6uCKgD91nxbl8NP
+BT6WtLwX63DZUy+bvz+124WY1ZVAHrci9XCtjf5FPraI1tx+S8Zk68bz2eW
1dFzZhWAfja2Ta8HXnwKHXqt8tMHmYzJ11WwycoptSy1HNDdkjuPmbCfT6F/
bsm46d1FzuTrKlAHfNoz+2I5oD9useqRtoFPoU9b3U9YOVHO5Osq6Jcf8TrC
rhzQLd8Ne+GyiE+hG64+fjRwtZzJ11XQ+ECu6MsqB3TM1tjYFhSfQp8b4XW6
4bicyddVsPucs++t6DJA9+h7o//jEXwKnfgh/W3kAzmTr6vAc8Pz8o4HygAd
mLP9va0Fn0IT+yHebvFyJl9XwQb7bYuujiwD9K0lKxzLWvMpdIrzPCebKjmT
r6uA6lQ2sVNNKaBTee9/ntbwKPQ6hfcGRSsFk6+r4DZ7UKtbD0sBvZk+zxlY
zaPQY47XaSKHK5h8XQUTjvsN7bW2FNA/C8uSErJ5FHojNW77HgcFk6+rIO/O
N5Mn3UoB/XazNW/7Vx6F9rP2Vw7dp2DydRVM3j57pHVGCaCvmKddbPOGR6FL
klZWVVxXMPm6cfw8v50be7kE0K4P8qjwYB6F7vlhrkdQlILJ11VwMr6h7ew5
JYBe9+oId7Evj0JT91qoV/5WMPm6Gjo2umWlcUsAHffh3hvZCR6Fdj8Xd83M
oGDydTVMbzG5ZtXHYkCbcK5MvLmbR6ELtcUXfvVWMvm6GgK4aQXlB4sBXXVi
v/uENTwKPcpg1sF7hpLJ19VgVukwf+foYkB/nWC65Pd8HoU+cCl7+ZzNSiZf
V8MHoUuOpL4I0I3s7m+PTuJR6L66b36C80omXzf+vv6jh7o9KQK09bfkCxZD
eBT63s7NNXHPlUy+roYJ5yoVig1FgG5X8j42tiuPQpdNunT69E8lk6+rYfno
TrL9FkWAzkrmTVkt5FFox80KLzuxksnX1SCw8UwoDC8EdPFMkUor51LoqXt7
tWthqmLydTX0CDDvndK/ENBxS7hlt8u4FPqQs9omeZyKydfVMKa23u/d7T+A
3hx7TDIunUuhR3vxuvsuVzH5uvH9LHuRdavdH0B/epZpnv6JS6E9njkmLT+q
YvJ149/3/eEXe08VALq/U/jSXS+5FDpqUZBjv/sqJl9Xg23LdfW2qnxAD2aH
3mtxn0uhw/UhcQ2fVEy+robgaPNj7XfmA9rRKbgxyJtLoZ0Wve8dU6Zi8nU1
dLc55JhW/BvQpQOvzJ14lEuhJ0QUb78oVDP5uhr8j4Ue8V72G9CRVw6E/9rO
pdC3i0yDVg1RM/m68f0o7rWZ9j0P0Bkf/fpsXc6l0E6eOTEjF6iZfF0NCYoM
K+NsG9C5AeaP9bO4FNr+c1Ikb4+aydfV0HCwdz/f17mA7tl+o63vOC6Fjiu2
cf/tq2bydTWkSxJHWFnmAnpFz1z+wAFcCj3vywJZ5Bs1k6+r4dSek2EJ93IA
bTIiVR7ViUuhC4PXml7OUTP5uhriy63aLu+YA+j3PR73mcfhUugrXyNjtmnV
TL6uhj4TuseVnckGdP8tp27lizgUOmqU+ufMnhomX1eDr0PZqh3aLEB3vHB3
x85CDoXOr/06eMA0DZOvq+Goj3hn/e4sQJtYf3yh/8Gh0MX+px7yNmqYfF0N
B8sm3ttRlgnoK6tC9nnHcCh0ycxXXcvPaJh83eh6z7sVzpmAjlntk97jOYdC
n7MtdP76VMPk68b7s9PAoWt/ZAB66+eN5c9vcyi01ZFxY58ka5h83fh+loV3
ypqWAeiUmgOfJ57jUOgNQ0yPXGjUMPm6Gnhj7g6f/zYd0CfORHp9c+NQ6CbJ
LZlLRy2Tr2ugxKfvis9D0gHdY7HtPOdNHAqduNJ928KxWiZf18CyIY6nJ9xP
A/Q8rwtWlUs4FHq7vCZglLOWqW/XwPML/YIiOqUBeqlrf0e36Rzq/7Z459Tp
iJbJ1zXw7uDIFyPO/QJ0l8ZHmfxRHAqd1ue1o+yelsnXNVCUODgsTJcK6B7d
4jOv9+JQ6MQfBxwzaC2Tr2vgXt3rsNGuqYC+di/rwMB2HAqdG7fYNLJUy+Tr
Gthw2Ovkse8pgH7s1DXnnY5NoV87pCz0EeiYfF0DtyP2K4Je/wT0kHlbes2t
ZVPoF9tGfdphqWPydQ2kxMpFWfd+ALpgZfvdBblsCj1zdnEfu/k6Jl/XwNUL
qWE9zyYD+mmL+hrXRDaFDmsYMKTHbh2Tr2vgzf6trkf2fAf0vLNm74Tv2BR6
mzjtquiqjsnXjb9vWQePxuVJgN7RuVgZ8IhNoYdmTjH5/FrH5OsaWNDyaPdj
M74B+jr97pfNNTaFzvLwWeWTrWPydQ3ExC+/MnB4IqBX3ZVvTfNkU+jZCaYj
Vmp0TL6ugfgLf3o2mCUAOrSqvniXK5tCh4zoP7mvhZ7J1zUQtam4ZRbrK6BX
mQWsa7uOTaHnpH+ZWg56Jl/XwCh2F++imjhAd9rzq0WYPZtC5/Va3RC8Qc/k
6xrYPX5xfvvML4A+2y9e7zCFTaElUQd4a7z0TL6uAbouot9m8hnQySMmbVAM
ZVPorQ/OT+r0RM/k68bf1/O+V/nTT4CuEi93DjBnU+iRPeYv/JKkZ/J1DdS/
ndbV5xoN6N3dT7PntGRT6L7flLqd9XomX9fAoETfbymGj4CedmO+h0LJotAe
6Zu5nUwMTL6ugbie578XZMQAWjF7VcPjChaFNt01q1+EtYHJ1zXQ4ejI9vbP
owFdfOTQnhWZLAoNLdr2mrfUwOTrGqgO+WnX3zMK0HBgRN8OcSwKfbJz8IcC
dwOTrxvvD95b9sblbwE96GXb3t8jWBQ64n4Z2XbHwOTrGviR9iDUZNRrQN8w
2+R1LohFodPTxsobYgxMvm4834Neeg1vGQFoODncZY4Pi0J76h8O2lloYPJ1
Dfgn8Ocd+RIO6J5dhtW3Pc6i0F9+hQwoYzcx+brxfg/fWnP2wHNAkwdPe2Xt
ZFFoz+hQekn/JiZf14DvkD3/nRkcAuhntHe3B6tYFPq5R1nyh5lNTL6uBacH
1T+O5D8A9PnHNo2u81gUuj7Cp0+PbU1Mvq6Fk7UJKbl97wE6+8r9SLuJLAq9
uIi+tf9iE5Ova2H4SQkv5vI1QHPKWx60sGRRaO3YuvbxL5qYfF0Lu/7bv3S+
+iyg/7ILi0JP6LJ0S9vUJiZf10KTtNRXs3EHoPVRD6fmClgUWnD5recCSROT
r2th7H9eitle+//ve4dbvjtc2wToiOlHHk5vxWLydi28SxppunjFRYLeEZi9
ct63JkB/b365O4vJ27XwLch+a9G4GwR9KH6NR/+QJkDb3kuldw5jMXm7Fga4
2V7Y/zGAoAc1ZA0XeDUBuu6cafXRKSwmb9dCWv8sK3FQMEHn2h9yE21oArSf
85e4s/YsJm/XwrbpK4v9SkMIun6AfF0p1QToVju9Fl5ey2Lydi04z316v0//
UIJ+8YYj/dOzCdCWjzzO+OxhMXm7FlgRViY/Rr0k6CKZbkSpzgBoH6+TWy+f
ZDF5uxaOkn0xBocIgm4RN95UlGcAtO5eqfysL4vpN6iFeYevdHy8+zVBr2yR
HcB/bwB02pFrVseCWUw/Ey0YRsiOf/F+S9AmsazEfjcNgD4Y1NR912sW059Q
C9P8HIKcnkcRdLKixmvuAQOg75xuFbsinsX0PzF+//RL0/9LjCbo/EnZ3w8t
MQC64wZT8xlZLKafofF4fRasqiyLIWjVwEkXXo0yAPq0S8nEQZUspl+KFkIP
u3csZxGCXnouJ0zc3gDozA9+g4UqFtP/UAsTfXfmjrhME/T7BWn9JzboAd0/
90Z9SQs2019FC9u3d1vx1P8TQUemxWRcSNYDOuRG0PXobmymX6Lx/nt1M7fk
yWeCzmj542HpMz2gzY7cHn55CJvpx6KFDZu9J+S/+ULQY5b8PGh7Xg/ozVm3
vqyexGb6KxrPl/Swy43PcQR9ImiP9YstekBT4QmbLeezmfp2Lewd28WtY0o8
QS/uNuWVxUw9oJ32rR8kXsVm+jFqIfDXtm2Lfn8l6OT4tLTr/fWANr93w+zN
TjZT366FoEndtzpWJhD0pVu6vZ25ekBHR56cecCDzfRv1ELW5o4PekgTCXpA
ZOyOu8U6QO8c2Cdp1BU2U9+uhWuLJix5bvhG0D8zb10fQusA3e366Dc199n0
vzzdeP9zp31ht/pO0J6FNxNIgA7QYDKmR+BLNlPfroM2OUK7Pp2TCdrAW5u9
8pgO0CePOZgu/sSm/+XpOnBYETu6de8fBP3W8dxtw0odoB9lTopkpbGZ+nYd
+G7wkNJDfhJ02Gif4pCJOkBbVti0Dy1h0yf+5uk6gKAvjTPGphB0zkWhp1M3
HaBNJ+qmOkrZTH27DhqCW/9I6pVK0LwusfPbqrSA9tgftFzN5TD17TpoP+jG
698PUwl6sltex29ZWkCXxPm6+ZtymPp2HVzbVLYj0/IXQftXCB5deKMFdMSl
oy8mDuAw9e068Hue+Coq7BdBd8/0Tl90TQvovZ0nmGWP5TD17Towiai1OzM6
jaCPdvLa1XOfFtDT3WIT98zkMPXtOkix+Fg1NSqNoC8dTLUTLdICOvpLlwKh
E4epb9eB4yneitLJ6QQ9tNDDMsFKC+jtPtSOu1s4TH278e/Tzn/5/k/pBH10
8u3qB+21gP68fvTFEQc5TH27DqxOhzyS2GUQtKznjWWnGjSAPiN67fjxHIep
bzeev9ZdtWuSMgh6kn7CtK0/NIDewP6vcN5tDlPfroPeZr6m0faZBH3w8O/D
i0I1gI6b7js9+ymHqW/XwQv5qGe89EyCvu65L3PqRQ2g306deX1dNIepb9dB
3bUFruCURdDxd0L7WW3XADogwrKhMonD1Lfr4Gbx3u47fmcR9J1Z/SYMmKMB
9OhVu/7b+ZvD1Lcbr+/1X5adW5tN0G8HLayxGKwB9ACXnFbiWg5T366Dwa4n
km+WZhP029LCNuZCDaAHtPNR79VxmPp2HYTe+NXnzpYcgl5656J7two1oLOs
J9pK22D/Tx38uueruFKbQ9CXnFdyesSrAR29JM3gasFl6tt18FoytfzQ7lyC
XjLj5Zk+D9WAXvYnZHLjcOwXqoNDW655OktzCbpvxYpCy1NqQDdeWmyyYyqX
qW/XwYOk+auHuecRtPOP0KoxG9SAdrz99GK5PZepb9eB+dJXerkmj6Cjn/md
mD5NDejgIW/JmrVcpr7deL09XV/+xuM3QX+4HnJmcW81oPuODY3J2s1l6tt1
sPj78CsunHyCHuY9Jn9jkwrQ29+XX11wgsvUt+tg2veYXeZn8gna6ofDxkN/
VIDeejt7wRcfLlPfbhxfes4TkZYFBD17fD3XJ1YF6Pz/WhpsgrhMfbsOqMUn
Dq72LiDoPbWFQU/uqgA9u5VJ+PNXXKa+3Xj9CBdulJr8IehxU+sGfjmiAnR5
0XmXnp+5TH27HtJyclp4XvtD0Mnfvh0rXKECtHn37tN80rhMfbseJhUJI1t2
LSRosXCqn36CCtBC3bpx7FIuU9+uh7E/foVc8C8k6MhLrZdZdFMBOmSCxtFV
ymXq2/Ww4JDoqmf7IoJe8UX4bqoK+6nqYUnPow+LuDymvt34fh8nvZi8qIig
74SaP12frQR05NO9QxeaYv9VPfBjTsdKfYsI2hA0pc+Zt0pAs0eub4zpz2Pq
2/VAhajTQjKKCHrdsFNmodeVgE7d9lFmORb7terhp2W21tmsmKC77TD1TN+v
BPT+JPnUG3Y8pr5dD8u0odOEzsUEvdTTcq1uiRLQWVN3pLKXYX9XPTyZn/s0
4nYxQYcu7/R84GgloIcscXvmspnH1LfrIXP/u7ErfxcT9A27/psWd1QCemzB
zh9ZbtgPVg91Z8+XsCxKCLrV5A+Xj4uxH6wetOsfjKfO8pj6dj1Yyi8+DV5T
QtAu/IlDw1IVgJ6r31Dz5Cb2j9VDUs/eJ2YElhC0v6gR/oRj/1g9RAhbFJk8
4TH17ca/x/dYp6LiEoJeZt4no/0VBaAz9zZ2PhiF/Wb1sPzooJ6H+2G/WT1k
TKsTTd+F/Wb1YFZ4/uyfRB5T366HC/5bY002lRL0pIh5Qe4LFIAuGbhipG0u
9qfVg1OmoMfDx9ifVg+O13XiF8OwP63x/b1hC59W85j6dj1cXmlqMaaqlKAn
pB0Ql7dWALrMzE7YVoP17XrY+n56IG2J/Wz1MD/4T3ivWuxna7wfwkwG72nF
Z+rbjfPY2hGec3aUEfTxC1VTVybJAU1HX1yXZo79b/Xw4aP93Z+h2P9WDw8C
c17deor9b/UQHt4pZPRQPlPfbjx/O+3iFzaUEfTKOastcs7JAb145SKx3yTs
l6uHm6m5qckjywn6dRe/m922Yr9cPQzcP26MdB6fqW/XQyzM97FzLSfovkW5
NqtnyQHd2L7TxkWrsL+uHka1O5T2PgL76+qh6uAXs+CB2F9XD5dmBOwPc+Ez
9e16OGdT8Z+lrJygJ5e1sa/lywFd4q12bnUM+/HqYVb3Vu2vja0g6FWSw6qx
5TJAp535zN3kzWfq2/Xwe9zeu2q3CoL2Lfs66lScDNDvvHts+XgP+/cax48K
bdryqAqCTm3jaZYeLAP0LfXH/WZhfKa+3Xh8Kb/dX6srCLpN145xA07JAK2R
Kix2fsR+vwbo52O2sOWkSoJueLff+cgGGaBbPoxf8vknn6lvN0DV2q3dnY9W
EnSb1HmS9GkyQGu65AnMCrE/sAEqt9wOCIytJOg28yNfjuyD/YGN37/88aCt
jVjfbgC/L5G3SwyVBD2u58DIy837aBmXi1weRzVhP2EDvJhr/sOCqiLoZ3l7
u4kLpYB+7jtzn9BEwNS3G2Bw/HfVopNVBO1icYfrRKSAniu29nDsLWD6DxtA
aheY7/G5iqAFBeFX6QApoI91GPzuvpWAqW83gPCnw/iH3GqC1t3KLh3uIQW0
52jTdtWUgOlXbAD/I+nfP9lWE7T1dDPz+6ulgK78I9trtUjA1Lcb4OnLnU7Z
XtUEHTpojqPpFCmgh7j8zjywXsD0Nzb+/OgS/7Kv1QTdpqJdhHcPKaA1l1QD
37sKmPp2A9iue7miWlhD0H9SQha31kkA3aFr6DLNSQHTD9kA27qOX1Y+u4ag
k6Wljt6/JYA2F1xeOsFXwNS3G+BmTtainPM1BP3azzS70wcJoAe+PWDq9kDA
9E82wILefTp+Tqoh6LzdjYqAOxJAd5p97vTLCAFT3248vyfarH7Qupag68ih
XyMOSwDdqveMm1WfBUy/ZeP74/I0B+fXEvQ+g97zy3IJoL+yTk7tmY717QaA
qT0i7LxrCbqoSDxw9QQJoH3an3VZVIr9mQ2wK9/aocXPWoL+drUiW9tVAuge
79qYekqxvt0AakuTILpdHUHzat3D76vEgPZoZTv4JVfI9HM2wBuh575dC+sI
eqBu6tfZOWJA158suvu7k5CpbzdA/CKPWx186gi6ZzY9WvlODGjXa7028/oL
mf7Pxvvh1ITSp6l1BL1y6n/tnt8UAzpt3c+DQ8YImfp2A8whsy1tOtQT9KrA
lTs2uosBnTZycdICWyHTL9oAM2c+n/5+UT1BF6x6tqafkxjQvr+eOexyFDL1
7Qbo+1rV0sq3nqAbH3G1lePEgG4x3INzaaOQ6S9tAJv3Dqv80+oJemNw9qII
MzGg7UeYZj/eL2Tq2w2QmXKpm7ZjA0Gb3Zqwz1MhArR89H9fP54WMv2oDZC4
2qb/wiUNBN1jUdlO5ywRoPdmt/2Wfk3I1Lcb74/KF+tv+jUQtHkby4Vj3ooA
LT20I6f8oZDpX208/14dotPTGwjaY4qyr9kNEaCnrT/dIHuN9e1N0D/PpSvP
tJGgG3y/SfUHRIA+P667gB0vZPpdN4GX7MH2wY6NBP3RKyypdqkI0H1in5i3
ysT69iZQfXIPoq41EjSvl2144VgRoD1EqweblAuZ/tjG3+f88OX8jEaCDkp/
EZLbWQRoKzPLYZ3kWN/eBPuPTHeNrG0EdEGAQ36dRkihZ35eM2tgKxHTP7sJ
tPovSeR5I6CP/6+Hew1pKg7jOL5ZnGMXtft1hZqMLjMStGKpz7+FaSuKLCKy
C6HRxbW0ssyFvqgtl5qF0cWYUZkVaRcXCzVZoHbFMLpgYqZW5O47Z64Llf/G
+D+9/Lzdznlxvjz86D3RY+cJOkRaNS1yrpf1dQozfh7d1pntATSf/Gny9y6e
oMVjSzvGqwOfXMEgR8GyMHnB33keQN8pi1hFX/AEff1L707pHq81mFuXUbgc
Nqic73QDetew5lOjmniCXvBL3z9g9LK+TmGsp70gu9YN6FaduWfabZ6g80Mv
ql7c8lqDOW4dhYGDyoEHGjeglaZwZewlnqBL2/pLrj/3sr5OQRHiyx8Z6wZ0
yePEKlUJT9D2QkNLgc1rDeaaLAp52jGRGpcL0Kbpw0MzdDxBP3n2w7NihMD6
OoUbHbJXH+pcgJ4bf+LAoWy8b6dQe16YMn6OYA1+zh+kMKk+Oned1gVoQ21a
99kMnqD9NdrU92kC6+sUxrwxD3bOdwG6dVCRZFmJ9+2B32dSjb5il8D2ZCik
lk5Q7fE4AT1ulv501xKeoLsb/D3qYoH1dQqLPiYR/p4T0KsPR3RIFXjfTiFr
bN+2PzcEtidDoeXC8Ld3c5yAjpNL/fNkPEFXmf9OvPlUYH2dQpklqjczzgno
a3tDf24cjfftFBpjPBGrvwlsT4bCyqL0lFmiA9BvLq9/XfyHI+hNjzdscXMi
6+uB91Oa1++qdwA6jZjym5wcQecUtYUb5SLbk6GwwVJ5tuWAA9Dn6uRfvd0c
Qb+rrk+YuVxkfZ3CS4NiUXW8A9DmqJdhc9o5gq58tPtL3Q6R7cdQ0CSEVJf7
7YDOKJPYMps5glZ/HYpdrBdZX6fQkKAz6y12QGvbezRX6jiCjtmhkjdXi2w/
hgJ9eiXRcNgOaMn+2eV9Jo78t+xuX2KryPp64HmYqp54ZrEd0OmG9JSYU3jf
TmGzb1Pew88i24+hMNooH1fzywboZVeNx3cXcgRd0OT8rhjmY3098L4Nebi2
Rhugr9Gmpfe1eN8e+H8lxUdN0T62H0NhQuqRJy6dDdBta6tyf2/lCPrQ5hbZ
CJWP9XUJcR7vjI5MsgF6SZQlNG0N3rdLyMnmCve+7T7rP1+JT3o=
               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83Hdcje0fB/A6024gVEiyZ0JUfG+yV2WPirJlhoSQWUIKqSiyV49EFNJ1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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H43 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{43}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83Hc8Vf8fwPG7lW9pDyptSXsX8j4N7aGhpKSkkvYglaaKtAfR0FLRHjTl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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83Hc8Vf8fB/C7jBZtbQ1aKira9T5EtFFpKioq0SYNTdKgtKcmmhpSqm98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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H45 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{45}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HdcTf8fB/C7r2yKoshKEVGUrN5HZiTzS8jKHolsyUjZGdlUIltUMrL6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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83HVUVFsbBnBiggvYYmA3YmKhoL7HACywC7EBQUFMbMCWtAuxMEEEwQSB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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H47 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{47}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HdcTf8fB/C7L9nZKzOSkCiy3ofsrFJUdpII2VvGl2xFlFIkKyGkQuJz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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTX8YwPHbvQ1lU0aySUqDkBHPKSqZUUJ2ZsnK3pSZkVCyKsooSkhI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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H49 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{49}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HdcTf8fwPG7r8reykyyQ1ZW72MlIbIimWXLyB6JrLJHERIyyvyKFBmf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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83Hc8VX0cB/C7XGnSVGkQRaWhoZK+p5TQLkkolUraaFBEkycNpSUlStEe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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H51 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{51}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HdcTf8fwPG7rxCKsiIhMzvJfB8jOyNkE5LtS3YlhBSyR2REEllJIuFz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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83Xc8VX0cB3CuOxpSqDQlSVoq7ZLvKe2hXdJWGkIpSYuSaC9RSlEhj1Qi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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H53 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{53}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HdcTf8fwPG7r1lGIrNsKrNkxPtklBmJKDsKoYwQJWSvpGxflBEZycjI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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83HdcTX0cB/Bb3YGMhCQ0JDM7e3yPIiEinoREJLsoeyZCRUZGEYkoRGaK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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H55 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{55}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJxc3XVcVM37N/DtVewWCzuQWxSwMK5jYGJ3IxaicCsqNgaKGGCCKKKCimIi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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJxd3XVUVFsbBnBiQrELuzDwWtiF+h4Lu70mBnYnKmIrKnYrBip2d4vusQMD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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H57 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{57}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJxd3XVYVM3bB/AtFhELxRZsxQ4MVPQ+diFiECoG2KiYYIuJioqKHdgdGIhi
zkFFBEEQkRKQ7ljY7ndh5+a9nh//eH0u1uXEnDkz33PvbGfP9bOX8zgcjrkp
h1P77+VLtT8lwKn7SYD/msf81xoy4djaIvVDdDb81wLmv1aQyl0wdNG7/3/9
fy1g/msFuejd/AAbUwKeHW7eiRJ8q/eWjDXmK0EL6G8W03Y4LOGy45YUJHT5
WwINxMFWJvmfCfr6WAd3v9taQA/8lzaL6c9ly2eFWx8qK4H3i450SGzJArr8
0PfOC7lcBt1L4v1holZLzo+v3aESUOg2Hc3ZkVLvcczt4MmdVYD+t7j/IPcq
HssY9mZqo1K6PxzO/5j5H7OlPQY1eNKhFO4kvK9uJY0CdMOP7dfP8uMyaOP2
acnZNgKXJv1KocVPOwtPx9h6jylM/WjrqwF0zvEWnQu/ctkxDVNubxhdCn2O
2l4LePoa0FOvVs9dG8Zh0OuiOrj0PKcjxeqH1Ykz6ren3vTvA5puHxtUUXsC
S2G171anyRPuEPSMCbsiMxfqAZ2eOdbKYhaHtf8388QF71IYHOiUuJT3l6CN
51cJaOP55bOFhrOn3FOK5xfQ9HwyaHq+yanPUhv3k6VwSPkzkLcpDdCD6l7P
Z9DG1yvJyFfffT9dL4XRUR9fb5CF1vt417OSi6wO0CMrww6FXuew+XevfO30
vBSq2n79Kh3+jqA9PoXe3uuuA3R8px4h5BeHDbxQ22AN5+fAxXDdpDJAJ9T9
Xsigjf+/htgdHWtosfXbA2j69xk03T6Su8MyZHJOKQSWr31i6pIB6KDgE1I2
gM+gM77mW+4pVZDjtZdndSnYDL3xZs6YG4D+szfLUclwGLSrbpxn4z16Mqy2
ufLKYI611b243T/qPczdfvqkUxpAF/zySM94w2Wza09f8zLYJRy0UXsiGdDG
/eUxaOP+qkhA7e50KcP2DGjafhk0bd9kiG3tT1n9+ULj+ULj+crqJtx3bnwZ
9j/kv1bAfy1gj7RK+ymfUwbvFzdfwmPfAFoXxGnB+cRh0IJ0XZr+gI4MNlyd
85eV0fZWAmjj/gkZtPH8i0mGco/Xhy312w9oPL9oPL/+ZXUdEsRGN+nXKDAH
0Jtfjjc/sFTAoNtd2VaitJOTgZm1O1QGYSMHTBlp/xHQydvHJuaUcBi0c6Pd
C+z76ki6YW/y7pbBO/9jK6Mb3Kp3zO0vr96u1wO6ff9r3btO4bAH2ZibE1+X
4fUOaHp9M2h6/ZP+L4Or7n8rq++f0dg/o7F/TjX0Rg1T/v/1aHw9Gl+//1xt
B4znTwT/dQPmf35P+hyuPYFl9f3z/5j5H7N/tpUYeuByWDFt3EVZqyCCTpZd
637njR7Q5w4OrOjXjcP6Gc7emTblcHBMD5d2ud8BXbzU827nQC6DHmg3KuxD
nob0cj9p6JHK688XGs8XGs/X7xmezdxGlNf3h2jsD9HYH+6uvb1OrX//etP3
AzT9e2zP2tvN/HJYnRWfuH5iNKCLtH21Lme5DNpWcM9kdoqG/Krtfr0M25P+
tu9H8XtAJ/xcXhL8j8Ogl3gO6feV0ZGdtd3Rjv/ffjRuPxq3v3vt5Xms/vX1
xvaAxvYQX9tcr/z/+6Px/dH4/ttrT9+T8vrxyX8tYP5rBelauzsfyqHbhEl3
Z3b5Aehxy+aqur3kMuhdw13NX1/RkLjY2p9ycDMZ7/AlNAHQj5ccWb2tFY9B
PxpT1bfpbzXZ+ul6uwGZ5fXt83/M/I/Zzs83rTpdUY73I0DT+w+Dpvcn8sNw
dYq15fXjvf+ax/zXGuJzpnZAUVF/PNF4PNF4PDsequ2QKur7TzT2n2jsP6N9
a3eoon5//8fM/5jdbNibXVABZ1x0zU7bviDoC+1Eld/KdYAOqzl85OpRDms1
f9mofzMrIGHjs35XtUmANva3PAZt7G9VJGr6cMMdtgI8/NlXTOmjesep56me
2ugB3Y73m/dwDYfdOLp2AFUBH+rGk88BLRuXfypkL4dBW+4YnnVLpyPtB9R2
wBVgun3b075+LKBPHU6JqTHlMuh/IievdiItiexUdwIhyXrPwUu/XgBaLuoa
ezyQw6BbWIevLMzVkfW1w+ObFVAwptevi3EsoCvPND+R1ojLoLumphc4FGpJ
29rh4ks8vgn/Yw381zz2S+3w6XNF/f0ajfdrNN6v19UOJxIrIDnniWng2j+A
HnVVyp5+ymPQAVGWezLuqEjr2ttrXgWkLpsx/WZOCqCvPFnda4iGx6Bj7vV9
esFURSJqbzfiCjCra5+JgDa2dx6DNt5/1WRNbfcrqMTxDKDp+IVB0/ENaVnb
HVlW1rd/NLZ/NLZ/Unt5dvv/16Px9Wh8/era5jq0sv5+gcb7BRrvFy1qT9/E
yvrxAxrHD2gcP3ys3R2XSoh922ykfkgIoIvGFWt+b+Mw6ME7BgjdmujJyhW1
P5WgKZ8pCJlyCtDp1xu4n+7EYdAObOXkzE96YuE2wjBCroTAFtMV8b//AHqT
p5l++zseg+4wqoLb6JiKvDeMFvscroQPL76PfDw1DtAdjj0JvZzEZdDfS+5d
jHHRkOWjaicElRA68tO0c/sjAP047/HcXm24DPqR3QOXp/Fa0rRf7YCisn58
jsbxORrH52+tazukyvr7HRrvd2i83y1tVrtDldCmi2PCsHZvAW2xcf/rX985
DDrLSh3k7q0jjXm1I4rK+v7tf8z8j9k3Ym3StpL/bz9obD9obD8etdNbZSV0
nn/iXk9FAqAnPP4lEXTkMehtD91bySLUxLx2utewCob82vXg+9c0QPe43LTl
JTs+gw79kf0nLlBJwmqnP+2qsD8ENO3/GDTtH8ni2ulAnyq4n6zZNvpfLKC9
4k6miOO4DLrP8mynNss0pG54PKqqfvyAxvEDGscPdcPF6VVwpnWywMbyNaA/
Pu/B3HzOYdCHr730+3hNR+qGT+5V9ccTjccTjcezbjixtormA88Bjf05Gvvz
ut53VxXcovN3NM7f0Th/r7vdnKiCaK/epOurWEA/vVczatwPLoO+/7LdkZ2r
NaSu+w2uggkXq8ptOt2vt7E/0wPa2L45bF13FGI4XvT+hcb7FxrvX3WX56eq
+vb5P2b+x2xdc/1ZBTaTTrXcs/AgQW/5l8SfmKIHdN2vLTls3en7VwUbEs9d
OBn7hKDXzhp/4EpbPaCnuS4aM3gzhzXuThU0s8prkz/0JUEP+Lnx080MHaCL
20R1enaaw9Jxff3+onF/0bi/xvG6CILXThh5pOlRQK+rZVsOg+659VhVdpye
PKpONIyoRTCb429+Wfyt3jI4+el4Zy2gTZaE3xixnkvH/yIoDzRzXhUSTtAW
K5/taOujA/RWhwfjNkdy2Ll5tYGBCDatK90RYfaVoGe/vJUQtUcL6JR7Ia2v
MlzWOB8QQXNeuwr7hhEE/Ym4e4ZnaQHd+cavn7ebcVldUu0OiUCvc/i6deML
gm428P2B4mIdoBUru3w6dozDGucPIrjnWfw31yOCoB+L99/58lsL6N7+n/pZ
t+KyD77VDohE9eNzNI7P0Tg+N843RGAX3dTjYwVL0GnCrDlTcrWAPqtplvy3
CZedXTu7nSUC/40Hg6xbhBN0cXhKq597dIA23u9w/iLC/oSgaf8BaNq/sJra
OMtTBNEJFcHBEYSgxV069yjk6wDt711V3kjHYY3zGUN7atXi3e/VPwl6dPDH
I5GDNYD2HHRzVHAhl71XGwdtMvz/gQuLewyOIuiqeZIu79tqAd3g9yHvLpu5
rHH+Y/j/lXIuc+ALQQ/hRegvnNQCunBPR84QOy7rVBunHBDBq4Km6++ejyfo
aXzr2X0aawC9QCdy8VJyWeN8ybC/zcQLdnyJI+ii4H2vTk3WALrxIHJ3eAaX
VdXGEWdEEHGrcsFSzwSCdnIV9FpZpAa0W9LuNQ6NeHT+JYI7Tl/cL45MIOiU
PvHF86rVgLb0umg+x5TH3qmdzt8W4XyKoOn8CdB0fsUa52OG67vZxVZTFv4m
9a673tWANl7vPNaxtrm+EkF48KnDQud4gp5a3njA4pYaQGeYbV/lJOWyxvmb
CN6pG3fr0z+RoJvv0wzz2aIG9Fayb1nkRB6rqN2dr4b3k2zY7OmWQNCVn7su
LSpRA/qotbdjI3Mea5zviaBkh0WpdvQfgp50c+ehvc9VgF44YNxHcp/H3qqd
jiUZ+qOYgL1tV/4iaN8ZmddH3FMDeuI8i4F5fXmscX4ogq73r3j2XvCLoIe3
mrdy6EM1oPO3zHFY3ofHOtROZwoM18+kg7drUhIJemGltSt/mhrQiUc2zNXN
59H5pqE/69WLf+1cEkF/CBvqdzFdBegu3ZezoUE8VlY7HZCKcHxI0HQ8CGg6
XmSN80/D76fc69xen0LQynXnh4/gqAAtiB6yLE/PY2/UDqeF1XDittviqBXJ
BG2V0svGcYUK0Jssy8pSY3mscb5aDeF9ujGOuUkE3VwqW782SgXorYcE36de
5bHTaoejraphTUhnnXhAOkEvP7uVw9+iBHTc0K9+uol81ji/rYY3o1/e95+f
TNBBG1q4LFqtgvrfT5YlOf3gsZLa4VyPauh8dUNYTno6QStSbwdNnqoE9MEW
IcPcF/BZ43y4GkanTx8ZlJBK0BvN1m38+0MJ6Ck7p05u3o7PXqsdDg2vhuSI
pnsGRaQRdEDTXTdCTyoBPUoRMaCHHZ/Or6sh893l181+pBH01FnzEkedUALa
3fV3K88RfHZK7XBicjUc7zJs3Osnfwl64dZN6xMtlYCe/XXS9/M+fDofr4a3
x/1+eQ/6S9CJHW5Mv2OrBPSF6gHp/Vbw2Zra26tbNfj7u2fNvZVO0IuyVn33
clUC+tepH1emzeWzxvl5NSQknN3uyP4l6Ngflz3KmyoB3e7y4HizbXz2am33
u6oaWD+rqs0tswi62Q07we0dCkArnuXtDvnMp/P9amgzKGvU+/xMgn63ucGg
X/4KQHf9tnPlhQ98dlLt5bmtGuaErDk4eHQmQa+xLFgU+lwB6BifE0737vNZ
4/y/GkD+QLLxQyZBD/z8Z3/eKQWgi63PjQl8w2dFtafvaDWodlkMunk9i6A/
33gf2tpNAejrA7r0kPzms8a8wLA9687te2P+j6Af37ncsfloBaAfPR0s8s3h
s8bnf9UwoNERD4lDNkEXK0fFH0qTA7oR37PN6BYC1pgvVMO5M6Uxft+zCLr9
gomNs2coAL159kJl0zQ+a3xeWA3SYx33+dhmE7Rw5AaYWCgHtDZ38pLMRgLW
mEcY2pdgTS+bCdkEnbh7WllZphzQrSPmN2xoIWCNzxcNxzfy5Bf9/WyCbm9l
Z815Igf0puo8kb6XgOYb1WCi73d/WnQ2Qe/hrH4y/4oc0BF+Px7OHixgjc8j
q2GJ6T7z/Ck5BO20C1QnFsgBnTo2mzditoA15h2G9uMczB9gnUPQW5wH7Sne
IAf0JOci9thkAX2+WY35P0HTvB/Q9HkAa8xHqqFg2jf7IbdzCDow/WrO8v5y
QL8NGtQ0bpWAPg+thvfr71kf98kl6C7fn4hGRMoAXXXloenSYAFrzFOqYUdZ
/4N/FuYS9PiA4tEtf8kAnfXO3MPngoA1Ph+tBtd9PpX8A7kEPRciG+z5JAO0
y5JgNXtDwBrzlxpY5R17X1mdS9Cx39v25R+WAfpye/HqPR8E9HlrDYyNrpoX
os0l6CXtG/y22ScDtFPNzvNriIA15jU1sMe0w8who/MIeqxmY+pyDxmgs7lR
LWbEC+jz2RrY3GjyrejxeQT9bXtG//aLZIC2+nJ6VU2CgDXmOzVw3etv6JKj
eQT9fFrzezNHyQD9IF3W1y1XwBqf19bAoF9DHjRh8wh61YWCx4qOMkA7DGn8
iC8SsMY8qAaOf30f+Gl6PkG/s7oV3ildCuiu1SG3q5qb0Oe/NWAS26ayhWs+
QesuiRv4JkkBzbX1V39tacIa8yPD8b6x1wuu5BP05Wdk2pKXUkDb2txIj+9h
whqfB9fAfY/mTT6k5RN033iZovMZKaC9Lh7krx9mwhrzphrwmB37xqc6n6AT
ktt2m3hYCuiLluJ1C+1N6PPlGniVdbHBoHUFBH3vVOjOlVOlgH46vMc4hwUm
rDGfqgHT8Mk7Rx4vIGhNV/fPuSOkgOZV/rrWZKkJfR5dA/zhX0xWfy8g6D3L
rHf/aC8FdETchrHtNpmwdfGObw2wdjVkm0UhQd/IE94YL5cAemCgZsCigyb0
+XUNuP4J9gD3QoKe23LQzOxfEkC7+KxMbXrBhK2LRw7XQIc3Q/TXAgsJetOd
5Xufh0sAHdUvjty/bcIan2fXQOLrNk4tPhUS9IU7YlfZDQmgX/UTJh18ZsLW
xQsXamDfVS38bV5E0Owg7pIgXwmgO63Ux7/+asIan3/XgP2eu7FLRxURdC7z
tK2jpwTQJxf3Eqf+NGHrpuf3a2DI5Q8+zV8VEXThy86Rsu4SQJ/osT5YUGFC
n6fXwNKoBm6lNUUE7XhV/TtAKAF02iDe+XcaE7ZuuhdeAyJFh7g304sJ+siB
jW27pYsBbT9msriiuZA+fzdcryerPfUPignayu6w497HYkDXLP2QCr2FbN10
4HsNXNsrX/j1SjFBvwDBL6uXYkDbZO9uXd1DyBqfx9eAW7BlVHBiMUHPfeHT
4cV5MaBdekZuvD9EyNYNF9NqIH58qpuvUwlBt8k68/urqxjQkmbDzlvNFbLG
5/c1UL5m0oPnJ0sIumFMxuOedmJAqy9b9C5fKmTrhhMlNeD75fkZ3tESgp54
refrPaPEgM4aWH6H8RSyxuf9hv6i/covY/uUErT3JgfrxaU1gI7+lrYhIUDI
1t1ulDWw7tW+xQsGlxJ0THdwSiw09LvU7ddlp5w/LmSN9QFicIgtjISzpQSd
fqmRVXZYDaBbhG6vbnpXyNZ1Rw3FENeq38/FulKCvrylpE3CXsN+U4dOPCa+
QIS03kAMKZtuDPzZpoygz357VnRxcw2gX3ewOW77TcjWNdd2YpCm220ZMqeM
oP2D8iKXG/od9MdhTazikoSssf5ADNVPLqYO+VpG0Ecehp4psKoBtH2fHsMa
VwvZut3pI4a3/ZrOLWlSTtDdViucjykM41Zq7x9853d8U9ZYryCGcWevX5zs
Uk7Q/4Y+t81IqgZ0s4KehadbmrLGPFQMsgEphWfelBO0yaqzjYbdqQa07keY
Mr+fKa1/EINfYaLZcUU5QbPHW6nfHqgG9I23W3hdx5iyxvxUDFOf9IaeSysI
OuOh15K1jtWAbv44Jj7azZTWSxiO54vtO5OOVRC0sOf4zy1HVgN699osa6mn
KWvMWw3HMx8uFRRWEPSRxktsTzSqBrS9cuaKt9tNWWP9hBiO5obsNx1eSdAf
Ah+M2ZUvAvSt8MfZESdMWWM+K4YurV41a3K1kqCrJHflihciQB8x6XeQf9+U
NdZbiOHQhXYnyz5XEvSYV5vsAq6JAJ1z91veu+emrDHPFUNIsMmjQX2rCLrX
IG3votUiQK9duc+r0Q9Ttm66d0gM2y8e+2J9oIqgv9qOvLZhjAjQ1oW5z6Oy
TVlj/isGTbMudk0zqwh6v7xy6TYLEaDhYIOf4+WmbN104JwYWoc2OzY6tQrQ
3/p+9WwqM2XQW+5tHZnTQkTzY8P2Tu58bVpAFaBjZh25H5RryqDXulc9Tx8p
InXDxbtisJoWtHh+/ypAHw7Kv3D+hymDrkkflpC4SkTzZjG0bR7Ue8y/SkD7
H7wTEP/GlEFLZK9Ll5wSkbrhxGsxtGy47Xn60UpAH+JZP/G9ZcqgZaov95u/
FxFjHi0GM1GDO/LBlYDm2fNKPh43ZdCaw+p+BwtFpO52800MpTY217uXVwB6
ZMOYlWY7TRn0sbI1AyvMqmmebTg/pU4nbQ9VAPrFyKQ8Bw9TBn0twNVuxehq
UtcdpYjBadOkT9EOFYA+e/X0+sFzTBl06reMTlfmVdP829AfLPLM+VRaDuij
F9zCn400ZdCVCY4nbwRUk7rmWiSGmfb7lY9PlwPa8uQSnVc3UwadmjOG3/tN
Nc3LDe13e/NVwwaVA9rpmuDyjEamDNrji+zHsqJqWg8jhvaKrx3W55UB2nTM
oKi/CiGDrjkQvHFKkxqar0tAx/PRTA3EOhkJsIyVX1CekEHv2xPJ/WsYIxnz
dAkI/qpjD88sA3SEbIw457eQQe9pvr+tvVsNzdclkBTQKtysohTQYbdMvMe9
FzLo8+8kXXceraH5ugS+zuvkE3irFNAbW00Jvv1AyKCtf6+PDA+pofm6BHKc
e4qyp5QCetsfM3u7ICGDbuZcfvjk3xqar0sgqtDlzhhBKaBfvm35sOk+IYO+
ejzpaba2hubrEgg6fGH1w7ASQOfnLJ/vtU7IoIfbD5nep7uY5uuG7f+oHTzU
swTQG9cThxNuQgZt3XnfigJHMc3XJdC28m8zZ4sSQPurh01wniBk0JIGQVud
t4ppvi6BpwvazDocVQzoslaTknIGCRl078TNrvZXxTRfl8CsqcG3/HcUA3ru
7PsPbloLGbTbghchHz6Lab5u2J+PI+RbexYD2nH9T22mmZBBL+u8VDChXEzz
dQm0aNyD1y21CNATDxzlmMlMGLSvslxX0UJC83UJ2M/Lz0g4XgToma1GDB+S
Z8KgPX+fOH1hhITm6xJweDC8ZtyEIkC3KD3xodkvEwad3iffP2uhhObrhvdL
8/C8oCgE9Fzfi6ndP5kwaLcW8Y6vDkhovi6BVaOSetg9LQR0epMwM8fHJgza
Ifdc+dKHEpqvS2D8hCNHBywrBLSFhWeu+SUTBp2VOWpUcZyE5uuGcXKhk/M2
y0JAHxwxt6X1IRMGrTzu+ueLVELzdQlkKHaYW/wqAPTwT1njJmwxYdBBB8bt
2NpaSvN1CYw+abL4bkABoOOXRrg+9DRh0J52u52ejpTSfF0C3vszn4lHFwD6
6hJ52a6ZJgw6eoyFjdBDSvN1w/UbLvR+o8gH9NCQfX/7jTFh0Odva6bcOSCl
+brh/b7tup31Ih/Q9wf9e7C1rwmDfnl1bEiz+1Kar0tg1LVk4dMN+YA+eT9s
bJ8OJgw69/nZXQ+jpDRfN2xfxIbOqX3yAb1poHsDWUMTBt3h+uSqFqVSmq9L
4O2Z3tNGl+QBuvJOwOyZKgGD7va6dL6HuYzm6xLgf11tff12HqC5Gy9HFRUL
GLTO6seGgf1lNF83HM/e2ilWnnmAvjoNZh9OFTDoaK99C6odZTRfl0DkoWUD
u7XPA/TGzm0bRX8TMGjrj3FF6zbJaL4ugQDwCz6SmQvo3PjFPT3fCBj0qCXM
i1GnZTRfN7TnHj0tTl/KBfTl6KkTlt0TMOjYtWu3Dg+V0XxdCh5/1wfluOUC
OlV2ZZndeQGDdmr+fdjJ3zKar0vBK/G9tH+bXEBflnh/NPcXMOgfrbocKhbL
aL4uBaX5Qn+zpBxA68Zd8OD5CBi0YMcve3VLOc3XpZDkuHnyhvM5gA77nWFx
dbmAQZ93m5QRNURO83Up/Jw9/tJS5xxAv0pyKnRzFjDoSy6LbB2d5TRfl8Is
/c19fyxzAJ3kt2rJ0IkCBu3GGQDnfOQ0X5dC+Nm3nf8lZQO6/3Lv78OHChj0
naFd1586J6f5uhTsQJC75kI2oH823adI7y5g0MuytU2mvZLTfF0KzjHhJ2+4
ZgP63ODKrsUtBQw6+XLX8AFJcpqvS8E9sh+ftMwGtOvGH+x6EwGDnm21ek8n
qZzm61IIutf2/IvQf4BOHPJlsK+Mz6Ddz2+/3KKFgubrUujp16H52hH/AF1w
cvz+fkV8Bj0se5v6ziAFzdelECyYGX33Qxagz2b3ens2hc+g08Y8OZHspKD5
uhSeDP83zXtMFqBlhQui46L4DLrl4Cnrlm1Q0HxdClviUl9kRGUCOqTtqPPq
cD6Dvh179HeDQAXN1w3tddGmAymTMwEdM91bpHrAZ9BrV3Xt2DBEQfN1w/E6
Mm7eougMQDecZfOjzyU+gy5f+Gz1gzgFzdelkOVoM+XT7AxAZ5iZRLsG8Bn0
lHLpOqcyBc3XpXB35xHrP0l/Ae3T9Nftyzv4DLp1zsLwmIZKmq9LoY2H9liB
y19Ad33i9yLDi8+g393nBE/qraT5uuF6vZ37Lyg1HdA752oWNF/AZ9ANXU2n
/J2qpPm6FG65T179YFE6oM+W2TT+M53PoFNtQgqcVylpvm44vvaPNy7MTwP0
2ZVDQ47Z8xl0ysBzt4v9lTRfl8LiYo5D01VpgG5ktbeE24/PoIsj9X01d5U0
X5fC2GtLj48rSwX0983HZ62y4jPoDW2K3AdEKmm+LoWbplPL965JBbSk01Gr
DY35DLrNp4qvHQuUNF+Xwt9na7bGVaYAWu1TEZKm5TFoM8vutxwEWK8ohdUn
O3GyvbFeUQoVFgJORgXWK0qhR4ZcP7mbiubrUlAdVrmfkSYDWu90fc3LLB6D
5i2KsLkyDusbpXBdusDm2ZZkQL/aY15w7ifWN0rhIq9kaJKniubrUggsD3Kw
lfwBdNDCoNX+n3gMOmPC377i/Sqar8vA+szIa4ZBMKCXzY4Smz7jMWi7BRvb
iG6qaL4ug/ebtHnRiiRAu4b42be9zmPQs25zDsdFqEjd8MlSBisGhu0ctjUJ
0I3v+cYXBvIYdGFoc4/BuSqar8vAynzmwDzZb0AvyzFbkbGHx6BHjC63ncxT
k7rbazcZzOia2jxv829AewkWeO7y5jHofvKpo0y7qmm+LoMbdvo+kZWJgLYs
8rubupDHoFMHccIcJ6hJXfc7VAYhW509fq9LBLQspPfadzN4DNry1qOex5ap
ab4ugyHh75LlJb8ALXRNUY0ZzWPQ4lmzGu4/pCZ1l+dEGUyMMNv1bvkvQPey
2zfzTV8eg352Urvk9D01zddl0O3q5fGWWQmAPjhn85HP7XkMWu7WtmrHdzWp
O30uhuMxYNX1lvMSAF1hUhHaxZzHoHtIul98V6Km+boMilcP7nT5Zjygr/Xg
32qr4jLoLy+V72PNNaQuTl8hg6lOZT/tgn4C2iSs8njXEi6Dlp/rUhjeT0Pz
dcPr8459ztgXB+ihn2xirVK5DPrCgZCVX2dqaL4ugxSvql6i9bGAfiq7xtN/
4zLou80/q7ibNDRfl0GWmY11tPsPQF/bm3s6Ngw/LyaDr7qRGSvOami+LoNG
3AfD5k6LAbTFXq/xd+9wGXSWvvf2sNcamq/L4IrvNvHTvtGA9jo8/F9MEJdB
96s+NdYrXUPzdRn8LX74uGGb74AOvPbu0d59XAZd8DngkU6jofm6DBaNdRvg
Iv0G6FYHpZ7O67kMOkluOdK5s5bm64brN0GsvJkcCWje6OsdvRZyGbTmUATb
Z6KW5usyGHvh9c/bb78CesvqMvvL07kMuk2/Xv4/Vmlpvi4D8zhJ1rIzXwD9
y6FqxrARXAa9eEXnZWdOaGm+LoN7GclhSzZ/BnTMuoXmw3pyGfSabhNLzrzQ
0nxdBjaPVy16Nj0C0C8DCqXvLLkM+krpYMuAZC3N1w3tT/8n40V3FtCaxXFW
C3hcBt2AWf51qlpL83XD38/Y+rq58iOgCz+FnvtexWHQtvsvJnl3ws/TGc7X
3tHFfnfeA9q0fKy+ayaHQdf03MUNn6ij+boMeke1jnB0fAvoEZ8a+G6K4TDo
EwcqW7Rfo6P5ugz8MhLW9qh4Deh8/xW2q9/g5+8M/W3N4Ev9Tutovm7Yv4zR
swOCXgG6uPL07LN3OAx6YJeM+SmvdTRfl8OMud8tYga9BPStcYFOgac5DPr9
jrxFeRk6mq/L4Xwjq7te558BevCWs4/m7eEw6CutUx458PU0X5dDYGxowfuo
R4AeHH++ynoNh0Ff9Ujs9LmXnubrchgSFuX3reouoP9Y69sSVw6DdvnMjd3n
pKf5uhwqrg5PXW15E9BbspbcnzWBw6Dbjh/zwn2rnubrclg7sEB03ecioD1i
cqBsIIdBj1ljv7fXNT3N1+WQuu7Ts+3eJwDtXUsrDoPuduBGo66Repqvy2H5
EWureS6bAT3hZGDfx2ZYnyyHbTm59x6W62m+LoeFce+6fDuzud62EzNHrC3X
A3rlQou8aDMOzdvlwLFNVe09f4KgL89sqEv8qgd03a+tODRvl0ODmSP7O1+9
SNBfW01+HBisB/S1Le6P7AZxaN4uB16lS2bw1JsEfWpKS4tQHz2gwxf4bO0x
kUPzdjmcEI0ZaT70HkHvatD/nqujHtCf1cV9k9w4NG+Xw3qh29oefR4TdBwE
x97roQd0uyUvLj1Zy6F5uxy6i/IP9jR7TtC65y8Or9PrAL2vZ0/7qXs5NG+X
w57G05w9/V8StM3ix+mXUnSAXuv0qLntWQ5r/DykHOY3tnPZLQgj6N5+V3uH
P9MBeg37orTrAw7N2+UQ0shN93THG4Ie6teuk/MRHaCXszXr/7znsMbPT8qh
MqV5k63StwS9L9H65IMlOkCT8xvCH8dzWGOeLocYu7Mph9d8IOjNH/z3Tx6h
A/S3mx/GuOdxWOPnLeXguv31MM/sTwS95uLZDKWFDtA/QsMs+HKs95bDnOUu
vCGPWYJ2sQ3zu1SqBbTziu5MaEMu/fym4foPUiSLCyII+mFFp0Njv2gB3ffo
+tGLrbm0PlwOz8qubX/Y6QtBB3SJTSi9ogX0+8pLFxoO5rLGz3MarvdrMVe5
bl8JeuSTFbH6Lfh5TznkPYxtu3cil9aTy2H0g6zYgFORBK3ovexe5QwtoA+W
xj1pMA8/HyqH9IYuN6u/fSPou2P+/OjcEz8fajifS1q2W7+WS+vPDe0/d7zj
V00UQbMHhvuu5GgB3WlM/oRYP/w8qeF63Plr28WB0QR9I6FAVJ6mAfTz1icO
m53h0np1OfQp+lXBLosh6PZfJuauDNUAerN1ZhOHe1y2b93uGPZXNWDcvQs/
CDqc8264+QkNoO/ouyzb8ZZL69sVsPhu7rAv32MJeu7jrpeKVmjqP8fs0tvb
9ngsl02uy9MVcPvDPeuF8jiCXmvTx91yrAbQMWtKf/n847LGPF0BkVVx3Qq6
xhO06bgVCw601wBak+Uwe0wN1rcr4JN4dt88mwSCbja+bEiUVA3obYsClncw
4dH6dgV0mHOsV3eSQNAj+gSHDUtQA3qZ16C7+a15tL5dAYzV56nFc34R9PNt
JytMHqsB/WC8ndnu3jxa366A+Os7Em4U/SLoRm45P1r7qwGtmtO0ncSeR+vb
FbCqeWD8op2JBL1iZwcHGw81oGd8rk5bM5NH69sV0Pr22LWPG/8m6JEXqrqd
s1cDeumQI+vCPHi0vl0B4uO+s5vd+E3QX9w9y9St1YC+9suxIW8Lj9a3KyD3
o7hw48Akgj7SbLx/nlgF6A9bs+yb+PNofbsCtgwXHm4SkUTQXTeNWfQhXgXo
ym/ZCZ0v8mh9uwLCIh5kC2b9Iegz8X+iPj1WAXp4m5ZXOz3i0fp2Q/vYVbpl
cfYfgv65JLJL8WEVoC/NDK40/8Cj9e0KuN7BaglvfTJBp4YrVsIyFaDP3uY7
ZMfxaH27Ah427XQKNMkE3Uojby9iVICWcgU1h//xaH27AviXE/aPO5pC0H5p
0xc/s1IBmmkx38mmmkfr2xVg1q/reI1lKkF/GjK8ilUpAX1z+bIj13l8Wt+u
AOEWl8dJN1IJWufZ+09MihLQ+356nWtnyaf17QropLwxLr5PGkGHR7gOaBSm
BHS3jnOLt3fn0/p2BZQ/PPR32us0gj50znrquiAloMeEbVgQPYxP69sVIOm0
GOIhnaC/DLcZ2GiDEtDW+WVFysl8Wt9uaI/mbxrZRqcT9ODRifahM5SAXplz
3qPHPD6tbzdcr6fd97Gz/hL0h78P/p3sowR0l6A+zey8+LS+XQE/XLizLdL/
EvSMR36Pd5opAZ3Wm+k9bief1rcb2tPYyWKpRwZBvxzQ/8D+IgWgexav+jTm
OJ/WtytgzR3bp1YlGQRd0Cr0bHikAtAnttwL6xrMp/XtCng97ndUzfpMgp49
wNyRf0cBaNdVKsMNnU/r2xXwPuXCaC9ZJkFbNLy8Yfl+BaDlqpeT4z7xaX27
AhZJbzzduyuLoB98vpD0b4kC0E+sX7U8Fc+n9e0KeKuo+ruD94+gE7mCqR6g
AHRr/e4FM7P5tL7dcP2PTO51+PA/gnbbGDDU2loB6LlRIwtEIj6tb1dClfnf
yw7CbIJusCPoZZpGDmjN59c9znAFtL5dCT6JU578mJJN0N/O/+11+a8c0MFD
mpcNbi6g9e1KcAoINhccyybo1JGDVLvfyQF91rOIF9FFQOvblVC5PJnYxmUT
tFmcZacVl+SA3nVJWuVgK6D17Uror/8c6tI0h6BX77W+N3ebHNCxRPTkz3gB
rW9Xgq371J6XZ+UQdOGsBeWDXeWAbuyaeHTFXAGtbze8f87AqUvP5BD06pMr
FzgOkwPawc4hMXWZgNa3K+GIc7z1rj85BG3vfFE0tqUc0J5/Qk0X+whofbsS
do58M3xh61yC/uzZbdksiQzQ139WzEg5JKD17UqwG3jupPO8XILOXznUzvm3
DNBNHAqWOp8X0Pp2Qz9wU5fV9UouQfd/treZ90sZoFc/IPLv9wS0vl0JH+e1
U7bJzCXoLr83Hdh8Wgbo9ecnjZn0RkDr25XQ+9ORy3065hF02Y33g702yAAd
MOBWYUyUgNa3K8Gmwd0LYzzyCLp8Z79XS2bKAN1wXMndmakCWt+uhP2qF+c8
bucRNOH1HDqzvwzQN/asXZ5aLKD17UrDuGVOVGBBHqn3Xperdo1lUG826cVS
pYDWtxuO5+Tf/RJ65hP0MvdWJa3LpYD++WuLucTMhNa3K+HP0Ez3wV75BN1q
+elfhTFSQPvMGH7heDsTWt+uhOa9tDOCn+QT9NY13HkvHkoBPWGa35yefUxo
fbsSRkydMhmq8gl62d8F7kuOSAHt2DzxV/woE1rfroS5b3YdEg4uIGiXO2M/
alZIAf2n3+Kb+xxMaH274XoXO73K31JA0A38U+6emCgFtMbest+IhSa0vl0J
A3qP9il7U0DQxV4eExt2kwL6+LSZmap1JrS+XQlsk6UzO6kLCPrGNsfU9Twp
oJ9/SW3xfY8JrW83XO+8xcv2jCkk6KN7EuLYbAmgP7CtL10/aULr2w3tbcHY
++P3FxL0mtmL+2Z9kgA6xiWh5NQNE1rfroRVx+aHqiMLCdrh3ewevGAJoNNv
JZfveWFC69sN12t1l4+8hkUE7XnY+6ZuhwTQMz9Mebb3swmtb1eC5Kp1wlzH
IoL2fyG68MdNAujR902HnPttQuvblbAosinnbVARQc+yUvjdHiYBtFs1nwnJ
N6H17Yb+wd/bblVKEUF//vA9b7qlBNDXb7Zvki41ofXthnGXdNBq1w7FBM0z
WTk9qVoMaL/dDuktTYW0vl0F+V9iRxz1KCboJtfaLh0VLwa0cuBmR882Qlrf
roJrE2wGCu8XE/SLzLKiXU/EgLaxaHg8opeQ1rerDOO/edvflRcTdP7mOV9u
HRUDuskkl2v9RwlZY55uGNdtT2l9a3AJQfcbbykJWSEGtFeW9NADByGtbzf8
voPNvrRtJQRdWr0GzowXA9rcdNqSYYuErDFPV8HHRVKOMykh6FtOh/ycO4kB
/cx1NPNnvZDWt6vgt+OPuy2FpQR93q1dP6mmBtBhvzetPrRPyBrzdBX02up6
s8uMUoJeO2HuM++0GkDHZDo/mHJGSOvbVTBde6/5qrOlBD1/3xPZj7AaQM8h
DwXt7gpZY56uAv+YJsd0f0sJ+uPlbe84QTWAvvXyyy39ayGtb1dBQNc9gtiu
ZQQ9qpLVtvWuAXTukY5c8Xcha8zTVbAqIHlLzZoygo59dzZSOK0G0JdvDQ3W
pAtpfbsKTh+0ejbvVRlBh4/eaPO7ew2gu3lErWlVIaT17SoYfIqdINCWEXTR
m+uZu7k1gG7UbaDFWL2Q1rerIG7+VLeUieUEfXn23zmWmdWADnVpnuxjYUrr
21VQ00Dv2vxkOUEf3slJ8g2vBrT9Z/25r11NaX27YR604cSoJanlBJ0yeURu
/JlqQFu65zVpM8yU1rerYEcPkUeDLhUE/aXcNF7tXQ3oa2a72uyfYkrr21VQ
MUoemLemgqAbeh60azKtGtDqnx/zFPNNaX27CuYtjFvMeV1B0HNntU3Qd6sG
tIuruPXedaa0vt2w/4tC1zpzKgn6ntO9qX/0IkA/Tem7oOVeU1rfbjj/6wbu
ip9WSdCe0UVjL6aLAD2zfaN/oUGmtL5dBcuvt9h24FwlQTsOlI0fEyYCdFqR
IGvJXVNa366C3nMavV2cXUnQa5K3d004KQJ0jOX4ytbhprS+XQWzMt7levep
IujU07cCp3iJAG35JiT8b4wprW839B93Hs+56VtF0IH9ers8myAC9IiS0rkP
Mk1pfbsKRrp8juB8riLovCTr63prEaADz20YuFdkSuvbDe31ZNzT3TVVgI5e
unnNdY0pg/a2a9srQiiiebvh/FpHL8u5VwXo95MHzwsvMWXQARuuzDjZV0Tz
dhV4jG/g1XVBFaBTm+1P/55syqCdstTTvGeLaN6uhgYT2x1yaloF6HGnJ3VO
+mLKoHdlbvrouk1E83Y1fPU3T/X9UgnoFzm815nPTRn0NXvVmQnXRDRvV8Op
5BlPt26tBPQdnzllmcGmDDrccl6vCV9FNG9XQ4vJvrM39akEdOTp4LMZAaYM
2jfja/KkUhHN29XgamPts+JfBaBbBUwOTttqyqCTyjZEOjSrpnm74e8dfvZx
wZkKQFfmrKlKXmbKoLvZ23SePaya5u1qCBgXd2fC5ApA33Ky7fVrlimDfr/o
0tOF7tU0b1fD5adbSoaqywG9os/CHXFjTBm07cOJ5sv3V9N8XQ0jyv4d7P6s
HNA/VcM9ovuYMuhlDU+NXvegmubravg35GBJx6XlgLZr7KGKamPKoE8VjDbf
8LOa5uuG7RsWu6d763JAP2scujjaxJRB38q/xKyTVNN83fD3jzwKHPejDNBD
bj26nVAjZNCX3j8KX9SuhubravhI8vLX+ZUBuqrKbvvff7h+oBq6dApsPJWp
ofm64fz1yu79wrYM0Isahk8rjxUy6IllJ716rqih+boaZue2/ScsLgX02W3f
3nDfCRl0SpPNpzTHami+rgZJF87ow1dLAf2xARPf+b6QQftX+nl8eFFD83U1
bB8xeEK7WaWAXhTY6PSks0IGPSGvMHNTSg3N19XAmOX5ppuUAtrpc3iw7z4h
g16yM/Brc20NzdfVEHc98hL7rgTQ4pUbezz3FjLodgOtQq93EdN8XQ3VVh0n
R6wvAfSuqKhZogVCBt1g4wb3jlPENF9Xw15StUvUrQTQ2VWjOtpPFTJoptOR
iMPrxDRfV8PBJqYhDunFgL75ZV+fM8OEDPrTNs2DtCAxzdfVMPTfjv5JJ4sB
Hffmmrm0q5BBrzj1ubhluJjm62roWZXS+PDEYkDHqH2+eFgIGfTaBpbb7TPF
NF9XQ/xly7kb1EWAftXDpGWGzoRBX3wp/TOZJ6H5uuF4DFqy7fiLIkAvbtTG
emm5CYMeVxT/ZURPCc3X1aCaEPcnfmURoMfM2iwVp5kw6AML27Zs4yCh+boa
RB5DNk+3LgL0rjZxGUFRJgy6QfzySekbJDRfV0PhTdV07p9CQO94oJvNhJkw
6MbPePP9zklovq6G3gHjWxYcKwR0QK7TROUtEwZdNnKRT+N3EpqvG9ozZ+tX
3bhCQI9mrV6QUyYM2t/va/DeLAnBdc/cWu3a66AqqF8H7bxJx05n9pgw6CRJ
BEnjSWm+rgFFlzXZv18UAPrT93aKLWtNGPRB75imrXpKab6ugQtTWjgcX10A
6B6JghZL55sw6FcLZGkjpkvJ3ro8XQN9Vklube9cAGjzdh9XLZpiwqBLfxzq
P369lObrGuj/WDggOC0f0LGPIqavHGbCoFc/2rVq0Bkpzdc1EDk+PbHydD6g
q0+9frWzmwmDts4KOt/gjZTm6xowixdv3T4tH9CfxZqF15qbMOhdbYQTvqRL
ab6ugWWzLDoP5ucDet7cCUdiOSYM2tF1a9UKnZTm6xpg99rK23/IA/TA7Fit
sErAoG/ACkFNZxnN1zWQHjpslK1PHqBlT+J+OmQKGHSLe8s8V0yU0XzdsH22
8uKd/fMA/S92tOraDwGDHrfioPnnVTKar2vg0YvuCZVFuYD2Wmv2Sv1WwKD7
9Ky40OC4jObrGnBy4jU9cTMX0JZn2fFLHwgYdGrKnm0jnslovm7Y/9efH7ks
yAX02afPH/05L2DQaXeuPZqbKKP5ugaedWp9a3LLXED3/X6oeNYhAYN+sF7S
310qo/m6Bg4wjyIWxucAuvMprw0pmwUM+tO/3h1ntZHTfF0Dp8ZndL1wNAfQ
+c3k35d7Chi0XZaF95BRcpqva+BhkdkW2fgcQJdu5wVrnQQMum8jdaRgkZzm
6xoob+ZaulGXDehRX8/tuAoCBh2wNalh1F45zdcN7bGTvHfzt9mAtv/+MWBC
fwGDPrL+YKnvbTnN1zWQXdHVI2pzNqC3qaekVncQMOhmZt4zO3yT03xdA4U+
/G+X+uP6nxrYkbl34z1zXP9TA40n6jqEFstpvq6BsiWqP01+/wO0lQNJ91Dx
GXTkyn3T7M1xvVANDLo6Wm8+9R+g/UOL/DqX8Bm05OJAzsd+Cpqva0A9O+bQ
cJIF6MXT3ooKU/gMeuyaE9aDnRQ0X9eAc68T+w4NzQJ0n7uDnj//xmfQj8Ou
Xr+2SUHzdQ1IVYXdKx5nAnrxvw93dofxGfT4sf6vBecUNF/XwHDhvrLNXTIB
HdVpw27HO3wGvelTR5OlbxQ0X9dAm8PTuja8lAHoPKfVEzqf4TPokYv6bf2Y
pqD5uqG9/XHNDmmaAeiXqoYZ0n18Bn21YelkS42C5usa0LPNFq30/wvoTm0+
l8Vu4DNoNn6nzQprJc3XNbBgU2jjbtp0QE/3fr3vzmI+g17d9YzmNaOk+boW
wmTbXAo3pwM6xTo+Zpcjn0HP+ezhJVyqpPm6FlZs+ATXS9MA3finvGjOaD6D
LlzabKDbISXN17WgCrwfP9cjDdD/qiWXevflM+hxHVrFPrqvpPm6Fs6YeZU1
SE0F9OCx66y47fkM+sru7pHaaCXN17Uw34vV3HFMBfT0xhevJ5nxGbRXQTzr
Uq6k+boW1oqV120jUwDtPUa/+Z6Cx6C7H+C2CW2iovm6FgT3PFbcHZUCaHZI
7JMtRTwG7Xd+5b1Wg1Q0X9fCix9nTfkvkwHte6lmCZPMY9CWce3G+M1R0Xxd
CyV/fjYYbZMM6I/pbW+aRvIYtP+02I8iHxXN17Xgdsg32OXaH0A/Tgj5HROK
67tq4dGiW25eF1U0X9fCTFmi+0TLP4COWXT58ZFbPAa9dtyPB5XvcD1YLfxR
rv7ZLCAJ0KMgru240zwGfWzf8tidmSqar2vB1Gntpmf634DmBsyolPrxGLSu
bFlXS46a5uuG7bf37NjO5zegj00uH3/bm8egSzf03Pa2i5rm61qItvh+a2Zp
IqBH8OZJpi7kMehA9YzWayeqab6uha7P+zk7Lk4EtOD13ZiS6TwGLT/zyqvv
KjXN17Xw8od3rGXSL0D7pp24tH8kj0FbzsiPVQWoab6uBSufpTtuTPkF6Dve
Dk0te/EY9NsuK3NSnqppvq4Fl/3OB4o/4PdNGNrnc69mwa3x+yYM7fN673+R
CWqar2vhF/EPkQ9MALQqJUFqLeQx6EZOiyw/i9U0Xzfsz0T+3j1T4wG9eAin
+IKEy6DHXtAPSGilofm6oX2+8pm5f+BPQE9fIO/WII/LoL2mWryuGqGh+bqh
/UzfslLeKg7QYRO2+q7/xWXQ530tWnReqKH5uhYGvri2OUvzA9AtykYUxRFc
L1cL6b2OD1q2V0PzdS1sGDbhzcDcGECvHL/FvGsIl0EP3t665O1tXF9XC+77
t/Wv/BYN6B5HinK9r3IZ9KuqgSO7RGlovm7oj672CGn7+Dugf67OvfwigMug
l/YdFXO1VEPzdS1cFK17cDMwCtAN//m3K93GZdAVY2ti+jTR0nzd0L73zHI+
u/EboEWtnSe2XYnfr6GFTgnOPnGDtDRf18Ipjt/j6jmRgDYTvWkHzlwGXdnx
VMw+Z/w+Di1cVSvXPB36FdDvrpPk+eO5DPo4u3f2tO1amq/r4Ovy73t+t/oC
aHf/8uHrBuF6vzqYIu5xqnuwlubrOrB+2e2jmzwC0F2mJx7z6chl0B9WLyi2
jNDSfF0Ha0vPEMcUFtD3xyjLtjTG9YF18HJ/Y5tWBVqar+vgeffYwLnrCKD7
e/je8VJzGPTd0S3e9DbT0fVjdGAbHdmxoPdHQE/rr7NxLeEw6HW3+SGz+ulo
vq6DkIs39roUvQN0pMDk1cgUDoP2kUkvBMzS0fVjdPB3ulp48VY4oBenD2ct
IzkMetz0U37JPjqar+vgaLvD6XHu+H0iOkiyS/IufInfJ6ID10DXLraXdXT9
GB1snHx3kqblK0Db9x6a++wGrldseL/H50bd+ITfP6ID/hnbmW1+vgD0xavb
P28I5DDohG+Ndlrn4frGOphbfPf8tobPAH3zwvzcXrtwfWMdfEyYNuqJqZ7m
6zpgr9hap/g+AvT6n9vc/67mMOguS5tMntoX10PWgTd5dc495y6gdYkumw65
4nrIOjCZP7u91ElP83UdnN7nsarNtJuAFvrf9LCZyGHQYvEH+2c+uH6yDjYf
6ipe63kJ0OaTC9O+DuYw6NKNtg6+l/U0X9dB9K5Oa4/1OwVoFZPaakEnDoNu
vGdm4lSip+st6wzz6Ta9ZqXsBPTc42cflDXmMGi3ouQQm3w9zdd1ENcv/9zZ
7p71LmkcNrRCpge0+fbuy48KOKxx/WUdTB995ZAP/zBBH4qWWCp/6QFd9+vW
HJq368Dsc5krP+IsQSucbtSon+gBfTDlmXB/Lw5rXK/ZsH3t7Nqv4V0j6Asd
z8yRHdYDeuiGYckCe/x+Fh2EOlQPiL51m6Av++x9XeKpB7RtJOl2zBHXfzZc
j0/eBA2c+ICgL4/z2pk8Wg/o0Kxpny098PtcdDDxsufTYcVPCLp/2dlpn9ro
Ab06ICz9xmYOa1wPWgcPB2X5lUc+J+iCDjy7m2IdoE9U65YO8OfQvN1wfuNt
JkhahxI0f/PH93t/6gC9Z1LnW+QihzWuH62Dmd8nOPbwCiPonaHtryx8aGgH
1ON6bBo86zGH5u066P7Q0WP9hzcE7d2yzGzEQR2gp/o03Jn3Edej1kFKq415
X5q8I+gzld8jWizWAfrNkfYdfRM4dD0ZHWjZmEWtPT4QtGhOi4DKETpAN3CR
vWuQx2GN61PrYNGpXuoFoZ8IWrViBhNj6DfRBxzS/l2Wcuh6Mnp4Q470+LSf
JWiz4v6jHlRpAa0+tiq3TwMua1zPWg+CnYdvhj6OIOgbzeKPHTXcR9HPt7YZ
+b4dfn+NHsLcHL+dSPpM0CVDhk32vqsF9LGCZRlT+nFZ4/rXeqiZZpjUaL8Q
9C2XpRy3vVpAP5v70zAa5NL1ZPQwZ20bZUz3SIL2rcm4MWmBFtCR/qefuc/m
ssb1svVweYpbUAfHbwRdIXu1zn6YFtABB7tH5yzj0vVk9LDFKy13pG8UQb9M
vHPbzkIL6Pvn+4Us3cplzeoCOT2UP57QpMO17wS932v4HvtyDaDJtHw25yiX
rYtbx+vhnemrt2GR0QRt5hc9ZWqUBtC7mCsLFlzl0vp2w/F1aC42q4ghaK/X
wRGLbmkA/aPboOsJIVy2Lo6bo4dYyy+bGlvGEvSK4Puz9uzWAHrGoL4pTASX
1rfrYcOUO9cjRsYRdI2veex9Nw2gD09QtX3ym8vWxTXLDPvHcU628vhJ0KLF
Qydm2Brm6dQNnJZnWhRyaX27HsaMn27b6XA8QV+8cF7ZvqkG0ENeDeFvUnDZ
uun8Fj30fbe5u6dLAkH7WNz2XVmqBvSkrSETYhvyaH27HqKvFz8RlCQQdJPU
yKRPkWpAK1sEn+tkxaPryejh9O4bbbbs/EXQV7NTlF1uqgH9sqnlAe8BPFrf
roe/DTfFPm+cSNBTd+fFntmlBvSCsYFtX4/l0fVk9PDE7Ei7d9cTCfqcduF2
Czc1oIdxZ42Xz+HR+nbD+eqi6nRi0G+CnrE14s1VWzWg50/oeGfQCh5rXC9G
DwkzSGifL78J+njfZi2GNlUD+l3JVt/l23i0vl0Pu4PadTg7N4mgPRYoFeml
KkA7zT5wICiAxxrXi9FDUv+UDZEFSQQ9fUjM7cBvKkCnF7QLCb/Ko/Xthvbw
erAP6/uHoJfMDs2deUsF6ASXe01SQ3iscb0YPaREtG11yDSZoANObn9nvUcF
6FF2X26JWB6tbzdsz7/TBc0vJhO0+ZErk9TzVIBWjXrpzvvNY43rxRjOn/nz
H142KQRtqW0xo2CoCtC+XN95jQt4tL7d0D+9imWPh6cQ9LfE2PgMCxWgg8+3
vWgh57HG9WL0sP2Zvd2OKakE3SVJtDGnQgnoqnOmk5ua8Wl9u+H6PL577JDU
VIKOu3qjqiZaCehLLwYcEbbns8ZyfT0UnlfvfLcyjaAnteN6WNxTAjpzk99M
eV8+i+vM7+Q6JzWVpxH0TVLa0H6/sn4d+gE3AlQ5Y/js/wF4gY81
               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJxd3XVYVNkbB/BhGECxO7DbFTvWfo9Yazdiru3qunZgd/0M7O4u7Ba9V+xA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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H59 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{59}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83HVYU20YBvBtwKYYoIKBjagIioFdz1GxWzFQFGwFMSkBAxMwwEDFbjFQ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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83HdcTX0cwPFzmySkzGREsjVFwvegQcajrKTskJXKzGggMxGJZDZEiaam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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H61 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{61}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83XdcT98fB/DP/pCdJCNCIspORN7XTlJWISvZZCUro4iUMkL2TtmUkSjO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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTW8cwPHqjhAiqfxEMrKSokTiW0ZGRkRIVlRkhEjICCFFkoaRpIEQ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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H63 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{63}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83XdcTX0cwPHqrmQVylZWdkhk5fsLJSUlCmUUSiWbohQSskJWUhmFbCJk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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XlcDP8fwPHU7iK5KoQcKUdCSSFH73HkLHRIIUeKpEKIHLkiR1JUyJUo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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H65 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{65}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83Hk8FP8fwPGdXUenTpVK90GJktKl96SESqcOpVNJUehQ0U2HDpQOutCd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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83Xk8FP8fwPHdlUInciQpOlQqpRQ63lMi9a2oREr3LV1SqaQkSqUoRJeQ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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H67 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{67}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83Hc8Vf8fwPHLvZemBk0qGmhqaaneNyItSaVElHaJ0t6aUpGUBipCQ6WM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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83Xk8VG0bwHHMDNGm0kZJ0kratGi7SqUFKZUkhdCi0kYblSJLKCXRRiSk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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H69 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{69}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83Xc8Vl8cB3DzuQ1tlSRpl7YSEt9rVBpKSUVI0h6kpZKkRWmjpSi0S/3S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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83Xk8VOsfwHGlmdO+SPumTcrSKhF9J2lPSVKpVEoLad83ElpESIuoVFJC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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          
          "H71 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{71}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJw83XdcTf8fwPE7CxWVrYFEKMoqlN4fMpLta++GkK3IKCMiI9lbFMqWECpO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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJw83XdcTf8fwPHuvWUWIiORZJSM7JHx/iTRImRWdgjZRRkJpUTJCKmokIyM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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H73 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{73}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}], 
      Row[{
        Graphics[{
          GraphicsComplex[CompressedData["
1:eJxd131MlWUYx/EDSG0SpS7FNOfbnE4EE3yhLJ7KItFNSdLUUwSiIKLQEYcR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           "], {{{
              EdgeForm[], 
              Directive[
               AbsoluteThickness[1.6], 
               Opacity[1], 
               GrayLevel[0.9]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJxNV2V4VVcQ3MXd3YO7u4cQnAApFAqFJrgmQAju1uIOBQp1d3d3d3d3d+9M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                 "]], 
                Polygon[CompressedData["
1:eJwtlGdPFGEUhd9r/AcqdhFrNBqNRqLRaDQajS0CNhDb0tuuiIAg4gL23rv+
CXvvscTee+/lP/ic3Pnw5JwzyezM3HveTYslMuOtQghToTXkWgi/0eVwBLLJ
P9FaOAyPIJ1rO9AyeAajyLvQCngF48h70AS8gDHk3WgcrkIP8gZ0MVyHXuRN
aB5cg57kjWgMbkBv8mY0H57ACPJOtBxm47+jNXAIjkEbrmWhGfAOJpH3oZVw
ElLIK9FZcALakRvQmXAc2pJXoJlwBjqSk+hcOA0dyKvQOZCF/4pWw0H4AFO4
th9dCm9gAnkvugQW4v+idXAUrkAa19aji+ATTCcfQKvgFLQnN+pb4SJ0I69B
58MDGErejpbCZehOXqdn6R3wlZCDb9Fe8bXm966FenwdLAh+T4O+3fxevdMy
fBXMw68W+BbzXWknNfhqyA3+TnF8hfmsmqAf/iZaCMUwgHwbLYIt0ExuMt+1
OtCo3ZjPQh35oTmbd087/gU55t1UJ/9oDuazVGeT2o15t9Shb9qreTe0owvQ
1fxb9M7/NHdyfbSTvvg+5l0rgHPQmdwcfIZj8S+Dd1udHk9+He1WnZ9Ifht1
TTvP16zMu6SOFeOLzLunnRbiC8y7p06W4kvMd62OxfQt5l1WJyfj30fdUqdv
QX/zWWrGZ6GT+eyzYQb+s/YYvFP3YDDXtqElcAcGkrdGO/kCGeZd1j3D8Y+D
nzWd+ZHkp8HPus7gaPLz4Gdb/wGDyHej39ZvDiHfj7qpZw4jPwz+36HOTiN/
jLquM1NOLjM/W0nNFZ8w/xbt4BKkmndXnT0PXcy7rY7+B2t9lKE=
                 "]]}]}, {}, {}, {}, {}}}], {{}, {{{}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[1, 0, 0]], 
              Point[CompressedData["
1:eJxd3XlcTV37P/DTPCGSKUm6kTmZknAdhaSijCmUaCIpaRIyJPM8D0mUWYbK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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               AbsoluteThickness[1.6], 
               PointSize[0.01], 
               RGBColor[0, 0, 1]], 
              Point[CompressedData["
1:eJxd3XlcTc//B/DbvlJJIQohS3ZF1ndEiqJFK+0LlRYlKlEU2UopS3ZSQtay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               "]]}, {}}}, {}}}, {
         PlotRange -> {-1.2, 1.2}, AspectRatio -> 0.6, 
          PlotRangePadding -> {None, Automatic}, Axes -> True, ImageSize -> 
          450, PlotLabel -> 
          "H75 phase, \!\(\*\nStyleBox[\"Short\",\nFontColor->RGBColor[1, 0, \
0]]\) vs \!\(\*\nStyleBox[\"Long\",\nFontColor->RGBColor[0, 0, 1]]\)", 
          FrameLabel -> {
           "Intensity/\!\(\*SuperscriptBox[\(10\), \(14\)]\) W \
\!\(\*SuperscriptBox[\(cm\), \(-2\)]\)", "Harmonics phase/\[Pi]"}, 
          DisplayFunction -> Identity, AspectRatio -> 1, 
          Axes -> {False, False}, AxesLabel -> {None, None}, 
          AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], 
          Method -> {
           "AxesInFront" -> False, "ScalingFunctions" -> None, 
            "TransparentPolygonMesh" -> True, "AxesInFront" -> True}, 
          PlotRange -> {{0.8, 2.}, {-1.2, 1.2}}, PlotRangeClipping -> True, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
        Graphics[{{{{}, {{{}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw9039MzHEcx/ETwijXJOdHKYrjkn5cv696Vfej+1H3o1Ramh/rh5aajqwM
1dTmpuOPZHRTLcuPxFZq5EeXG2kYGjeTi41sfovaSoqsz9ttt9tzj3t9/vjc
9zy2F+gy7TgcjnLq/e+TXl+STLbNZp15ur5HbZhjmIgwurPm4KC7+CQ/j3wu
VOdaPvrsWMWaC25js7n1G7kz5Lezo5z6fVnzIL1Wzt/ll8h6BZ5ay7r3Hw5g
7Y7wrRbu2kLyVdBGSjNuLiD3xFXfew+yreRrsOxNT9HafeR8nM7fIphnIl+P
G2W8/BSpP2tvdFZ2j6R1kfsgIE5yam+ukLUvBDXv/HdWk/vBdr885yyfzvdH
lsOlhRMvyQNQWxxdp58gF4L3eN9wuoE8ECKja3rus0DWQZis4DiL7ZNYB8N2
vEa4IDSEdQgG242GwHjah6LT4FIyxymcdRi6G10Ek63k4TBdTxx3FEayFkGV
07z1DY88Armfzlf594J1JFqKjV4f5ORRgL7Izd0Qwxqw5SlEw8+ZlwI95Vtk
VWox82jgyKi3/SPyaFxxHa6I50qZx8AWPPEus5Y8BmnWWQltD2XMY1FwZenG
hhfksVCEhtl/PiBnLsYfz3VppSJ2P6VitDe7Pn8bpmQuge2z6LLXIdpLICte
Yv35UcVcCucl3Y2mo+RS3OiYrI5oTWAuQ54x6H2vhc6XoSlHmDQ/UMM8DgEW
RVtGJe3jkFKk3BDhqmUuh9Ct7mvmE3I5Kl4vrXSzo+ddAUNhpicvh85XoHW1
uuuiHd23Eu8z3iabpLRXosHiN9IgJldBMtRpdBSQq+BW/JufZSaPx5jlzLNX
QvJ4GGrL0m0z6HlKQP2PE9lZ/32qOwZnB/XRXo1+fZ2q/i65GnvkNQ59i2iv
wfjiC9z8S8yhQbLTr4saBX1fg1TBoI/NuGm6zRqkead62NHvwdFiaGDjaPAt
2msxs9Ya27ib9lrssr5qOWZkbdbCK84wVvL//6bDHX2bVbmN9jo8vq4e0A/Q
XgfP5cErm6bu7y9uGFr6
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1], 
                Opacity[0.5]], 
               Point[CompressedData["
1:eJw10w0slHEcB3CrvNbK6sqZmrfeNHTFJTruyzlxd7h7ZCqpuRBrXZQWFS6K
qF1UKLV5i0xFRDMaJ2WiSAvVqrXG1KZQq6Tpbf1/z/bs2Xef//e35/+82Kr3
c9GzDAwM5H/Pf1c6ChzihJF6Tv8/TYhjTeo42Rkblg1wyHq7tGwfuQnsBjzj
GqPtWDZHBNexMHeMnIdC9Xii+qWAZT4OTbudiBWEsLwUQb3ZSffErizboNlL
vsXwMLkdbvE2/krPI1+O7/WnU45abWF5JQRtz/vSHq1neTWemRYWNWRQfw26
uIyYgfsuLDsiNNJSN9VC7oy3htzcbx7kAkTtKB/4WUC+Dj1f+YmKrUKW18Ow
Nt3pwhC5C8KFDw6WNFDfFaL267w3yeRCTLuYJmfzqb8BtlHbplST5G54X9k2
8SXfjeWNmB9rlDEoJ3dHkeG5/NFOD5Y9sAe9aVO3yTchwczCL+KYF8si9Bqb
a0sXkXsiZ3wy6GqgN8teqF5cV+0hIRcjgafs+X1KwjJgcfvJLqtW5lrAOKS6
u+2DlLk34nfah+TR/rXecF5V1Xh8rz9zH+R2cY7CfHIf8HaPK9zM5MwlsJW8
7rXuJ5fgcpxCx+8IZO6LimsPLHp82fvV+iLGt6aoVaZkLkXzi3LToWzqS/Em
8WNe/10Vcz+Ejhzgz2SS+2G85ffXtQtov5vxOX8k6/pZmr8ZWy/FcGePkPvD
qn7FdGUq9f2xSjcnpiKHPACRr+ZqjDrJA+C5zDK8P56+RxmSq2qXNCpovgza
h9/m2SVQX44yTXFxn5T6coSJjqTW5JIrEKXWyy9akytQtcnd0aGUPBCVbzcM
3VhBHoiMMdvH3e/Ig3BnyCe51YU8CI7vNOL2QfJgjObEVtTQPG0wvMOyo2eb
0/0roRvulgzXM4cSJbroOZowWq/Ebq4pzL6SrdcrkbT08PljiTRfhUWKlBaB
nvoqPC2eOVm6l/oqBNQ1PZaXs6xX4aq1sVPSFepz+GE2pflE/z84iLIyLcTz
6HlyGJUN3HQICNH/AToyYGE=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]], 
               Point[CompressedData["
1:eJw9znlIkwEYBnAzNOmPSJEurdSsdERrrrm09Hs8dug23VZgqUGXpbOcHWKQ
R1jrUPIg12X1h1FkGEqH69SZWA2KDgslZJUtTKppUQqlXfS+fvDx8fD7nvd9
gzeYjVmeHh4emr/vvy8/a8VdyTtDjPb/aUjorCo1nM+bRtkDa7rCb9h6DJR9
IBILVnlUAOWpmDImXHFu5b4/GjoKogcHF1KegTQoNu8e90Csq4hc1T5dTDkI
DSOdR+oa2EOQs/7ax8eChHIoxoK/TZQWrqS8APHdTYsy57KHob/Cein7F/dF
sG3ZGdsXw74IPt5NHQ+XcH8xxBXnhq52sy/BxflCTdk77ktwrzFcbj3GHoHD
82pVN9Xcl+LVsOtU0r0IykvxdEdNSLqMXYZype2yqJ49EoWOrBz1HXY5imxu
fXgX+zKIGr0vnX/P+6Ng0zsc2/rZo9HfOzBwsoZ9Ofa1fpeYLTLKK1BVbW6R
72CPgXfJhL5mQUo5Fi3WvNz8XewCfoSkl5Y5eT7gXyBxRrST7wVKR47LWk3c
j0P61UTTyk10/944NIbO6LlftpQ8Hru9/O2bh7gfj7GgJ6NZo3xfAiqrG1xn
HrInYM/vwtQP7XLyRHj1FtUVRfP8RPT+aGmb0BlFrkDGxjBDqZxdgbZ32sWz
h5eTK7HRojP7j+9XQja4fd9HXSy5CgdLCl58cbOrMBIkNc3JALkayrpRh/Ml
uxoWy/SAdmsceRJ6M/0+d/jw/iS4U4YSVjviyZNR72sufzaTPRnBedesXaMJ
5BoEmw4EzjzC8zWwHNV5ZYUpyLWY6Kv2Gixk1+JJ58B60WoluQ7O2qoHJWvY
ddAcy9y15aCKPAWGu1/dFzLYUzDlcaXQfFtNnoq7TblPrQv4vlRMm3so0jyc
RK6Hn+u5620AOfRwv8me1CfR0P967A98ff3nZHK7HmH5lfWhxVrqGyA23VKk
JXPfgFltZ1Wtdh31Ddjje6L4kZT7BmS80MbkzUulvhEnvrWJPjXT/TCiOdfv
dKygp74R+WmfPF3lRvsffLpmOQ==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]], 
               Point[CompressedData["
1:eJw90nsslWEcB/AzctsU66Jyuqh0nCxyDsctnC/n4nAO55IuR2UhXSR0b8Vh
bV3GklssyyysWaGGrNLqpBtaUkPCyIwit2i11B/Ven6927t3333e7+953nfP
qpgkXZwJh8NR/rn/PunK9FD7R67SGf+lKbHRO7LWkGzHMgdmqY/9Grq0LFvC
+/CFmQoRl2VbxL81+HbGUn8hehxCwTc6sbwEJS7yVLv95MvQUp4ZVNbtwrID
RgQPLGW15KtRZNnbrKpwZ9kRJcaeV7niTSzz8KCzrcW8TsAyH2ubC4QFP6jv
DP39QkP7jBvL63F6wt70BKjviox5I/fEzuRu2NyqNquYQy5Aams1L87Cg2Uh
jn8121SoJXdHVH1X7uXv5B5YMRjH81xLLkK2wVUiKKD9eaL2VT6e8SJY9sIL
c3X9FrWQZW8saLPJevqJ9u+Disa6X2k7aL4vzkyP9BQVkG+EKNvR80Ma9f3Q
17doUHWU3B9Os5Vf7+RQPwBjRRnD9UfIxch0Sc5SxtL/BayfNztff8I8HUhb
I6z+NkzzA+HgmjnkUsa+Lz0Qp7mCFN/n1A/CF5+H+TeGqB+E8rCa8n69iLkE
y+fzNke9Jpeg8JHWXnjAi7kU8mRpakQ0zZfiWUfxqaQ+H+YybI9r67u0mlyG
HP6+loxSP+ZyjKYEPTwxSvPlGPN2Nu++KWYeDIvoQ91LJ8iDMbFhUv/xZCBz
BdQCiSKmg1wB00cDFuOeEuYhKH2cZ2JYSeuHwJer271rrox5KPQRXgNPrMlD
cff8zpqVs3LmSqjOvhmQ59B8JUL5Ab17fyqYq/Bi/cEr7QnkKnA51vGVNkrm
YWgqabrqriEPw9Biq9gaURjzcDi1Xpws2kYejuI7R853HVAzV6Mq8dzLhIW0
PzWS5lcFrHivYa6B1cl10mk6v9Dg8MjsVMNWmqfBwHCsT74Jc6MG1/x7G8Nj
6DxpoR+XzraoqK8F1+zdrmPN1Nfi2JSNTMGnvha3+4VRyf/Psw5Wn/fULatk
GTrkpbea36qjvg62okSD+5/3fwOOOV2J
                "]]}, {}}}, {}}}}, {
         GridLines -> {{75}, None}, DisplayFunction -> Identity, 
          GridLines -> {None, None}, DisplayFunction -> Identity, 
          DisplayFunction -> Identity, DisplayFunction -> Identity, 
          PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, AxesOrigin -> {0, -92.49104228531282}, 
          PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, DisplayFunction -> 
          Identity, AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {None, None}, AxesOrigin -> {0, -92.49104228531282}, 
          CoordinatesToolOptions -> {"DisplayFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& ), "CopiedValueFunction" -> ({
              Part[#, 1], 
              Exp[
               Part[#, 2]]}& )}, DisplayFunction :> Identity, 
          Frame -> {{True, True}, {True, True}}, 
          FrameLabel -> {{"", None}, {"Harmonic order", None}}, 
          FrameTicks -> {{
             Charting`ScaledTicks[{Log, Exp}], 
             Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], ImageSize -> 420, Method -> {}, PlotLabel -> 
          "Harmonic dipole, \!\(\*\nStyleBox[\"Short\",\n\
FontColor->RGBColor[1, 0, 0]]\) vs \!\(\*\nStyleBox[\"Long\",\n\
FontColor->RGBColor[0, 0, 1]]\);\nsolid at \
2.\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) \
W/\!\(\*SuperscriptBox[\(cm\), \(2\)]\) pale at \
0.8\[Times]\!\(\*SuperscriptBox[\(10\), \(14\)]\) W/\!\(\*SuperscriptBox[\(cm\
\), \(2\)]\).", PlotRange -> {{0, 74.}, {-91.02293050300625, 0}}, 
          PlotRangeClipping -> True, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, 
            Charting`ScaledTicks[{Log, Exp}]}}]}]}, Typeset`var$$]],
   DynamicModuleValues:>{}],
  Setting[#, {
   0}]& ]], "Output",ExpressionUUID->"86fb611d-9c67-4c12-99b2-8d166a6cccc6"]
}, Open  ]],

Cell["\<\
The short- and long-trajectory calculations are in red and blue respectively. \
It is clear that, in the plateau regions, the gated calculation has a much \
smoother dependence of the harmonic phase on the field intensity. On the \
other hand, the cutoff is perfectly preserved. These are the hallmarks that \
the contributions from long trajectories have been mostly eliminated.\
\>", "Text",ExpressionUUID->"c9b1651a-95a5-4999-80f2-fdbe28468fe3"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Nondipole contributions", \
"Subsection",ExpressionUUID->"dc5ebff3-fd94-4bc9-9fcf-22a1e9142120"],

Cell["\<\
Nondipole contributions can be specified by setting a nonzero vector \
potential gradient:\
\>", "Text",ExpressionUUID->"38d9115a-797a-4fa8-8f54-8cd7fd7d0a97"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  "VectorPotentialGradient"}]], \
"Input",ExpressionUUID->"8b03251d-5616-48d5-b19e-438229988ee1"],

Cell[BoxData[
 StyleBox["\<\"\\\"VectorPotentialGradient is an option for makeDipole list \
which specifies the gradient of the field's vector potential. Usage should be \
VectorPotentialGradient\[Rule]GA, where GA[t]//.pars must yield a square \
matrix of the same dimension as the vector potential for numeric t and \
parameters indicated by FieldParameters\[Rule]pars. The indices must be such \
that GA[t]\[LeftDoubleBracket]i,j\[RightDoubleBracket] returns \
\\!\\(\\*SubscriptBox[\\(\[PartialD]\\), \
\\(i\\)]\\)\\!\\(\\*SubscriptBox[\\(A\\), \\(j\\)]\\)[t].\\\"\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->
  "Info3652204688-5433709",ExpressionUUID->"500319a1-10f0-4fee-9452-\
5d79f047f70f"]
}, Open  ]],

Cell[TextData[{
 "If, for example, the travelling-wave form of the vector potential is of the \
form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["A",
      FontWeight->"Bold"], "(", 
     RowBox[{
      StyleBox["r",
       FontWeight->"Bold"], ",", "t"}], ")"}], "=", 
    RowBox[{
     FractionBox["F", "\[Omega]"], 
     OverscriptBox[
      StyleBox["x",
       FontWeight->"Bold"], "^"], " ", 
     RowBox[{"cos", "(", 
      RowBox[{
       RowBox[{"k", " ", "z"}], "-", 
       RowBox[{"\[Omega]", " ", "t"}]}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"572a0b42-03e7-4a9a-a38e-d5280858baba"],
 ", then at the origin the vector potential is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["A",
      FontWeight->"Bold"], "(", 
     RowBox[{
      StyleBox["0",
       FontWeight->"Bold"], ",", "t"}], ")"}], "=", 
    RowBox[{
     FractionBox["F", "\[Omega]"], 
     OverscriptBox[
      StyleBox["x",
       FontWeight->"Bold"], "^"], " ", 
     RowBox[{"cos", "(", 
      RowBox[{"\[Omega]", " ", "t"}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"12936a0a-ad64-4730-ad2e-c41e2e71a0c7"],
 " and it has a single nonzero entry in its gradient matrix ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"\[Del]", "A"}],
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "1f071776-3e58-4f54-8e3d-316ad7e86313"],
 ", i.e. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "z"], 
     SubscriptBox["A", "x"]}], "=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"k", " ", "F"}], "\[Omega]"]}], 
     RowBox[{"sin", "(", "\[Omega]t", ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"44b4b8d4-6201-486d-a1f2-1adf5848e80d"],
 ". This is entered into the VectorPotentialGradient option as"
}], "Text",ExpressionUUID->"652102e3-0879-4571-b072-01dee8173cb6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"nonDipoleContributions", "=", 
    RowBox[{"makeDipoleList", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            FractionBox["F", "\[Omega]"], 
            RowBox[{"Cos", "[", 
             RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
          "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"VectorPotentialGradient", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{"t", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"k", " ", "F"}], "\[Omega]"]}], 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
            "}"}]}], "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"F", "\[Rule]", "0.05"}], ",", 
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}], ",", 
         RowBox[{"k", "\[Rule]", 
          RowBox[{"\[Omega]", "/", "c"}]}], ",", 
         RowBox[{"c", "\[Rule]", "137"}]}], "}"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], ";"}], "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"e713d789-7cc0-49c5-b796-5e027fbe178c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.833695`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"17f286e2-5b67-4d27-a79d-d01938a54d39"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spectrumPlotter", "[", 
  RowBox[{
   RowBox[{"getSpectrum", "[", 
    RowBox[{"Most", "[", "nonDipoleContributions", "]"}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "False"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], 
  "]"}]], "Input",ExpressionUUID->"3d50e93d-86bf-41d0-ab28-0d1db5f6f73e"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      Thickness[Large], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQPnn8czCcdrHdjAGg1EH+x7dwqldbwUgvIZHAQv
H73GMkf7QGcHCHA49KWs+b6rESYv4PDhYoT58tlaB2SOFwKRiENag/WMNht5
qHoJh7galsrpu7QPfPWc/8VzvozDuq974mewKkL1KzhIXbjHb2endSANDJQc
5KVk/AuVFKHmqTgE/Lrq/i1A68Al9VogUnNw5flz6PEbBaj5Gg5sf4yKr0/S
OmD/crLdy8laDgmPG/RFW+Sh9uk4FC+e+9raT/vA6lUgoOcgyfzr4jsxmP0G
DtpAH+5X1z7AvS0BiAwdsg/JbVALUoK6x8jhxp+rW6qf6xw4KJYDRMYORslx
V70/KkDdZ+Iwm525PP2n1oFyMDB1+N2ZOiHBUxHqXjOHI+8c4zdf1j6gd6NJ
90aTucNKtTnCaz4oQd1v4aDieW/Ko3W6B55Y9D226LN0eGKo9rHNXxXqHyuH
ye9/hl4VNTgwayYIWDvc5zNde1VPA+o/Gwev9ScXNvQbHgj4tcT/1xJbh98C
FpP3FcL8a+ewT3/bJCsL4wNsIO9usHfoXF5xiYlNH+p/B4ctmxZs+8pueuDe
XRBwcDCK3VM7Kd8QGh6ODsfM8/S+/jA7YAly3mNHB0e3RFGFKmNo+Dg5nNqi
wKHNbnlgih3IwU4OB+zENF7PM4WGl7OD+2tBNkZ96wPv34GAs4PfhMP2S2+b
Q8PPxcHqTF2Nfp7tAS+Qd764OKj+75+yRNcKGp6uDmtb+89Wz7c/sNQf5EFX
hwJxkX1y/TbQ8HVz2HYkYcrXGQ4HAJqYS5w=
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 44.977777777777774`}, {-33.19499449467678, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"4b49ce2e-8c06-4634-bc2f-61f46cfe5a67"]
}, Open  ]],

Cell["\<\
At low wavelengths, the first obvious effect is the appearance of even \
harmonics. This is the expected behaviour, with the harmonics along the laser \
propagation direction. (Informally, the magnetic pushing on the wavepacket \
acts on the propagation direction on both halves of each laser period. This \
off-axis recollision causes the dipole to oscillate in the propagation \
direction with an even symmetry. More formally, the dynamical symmetries of \
the problem permit even (but not odd) harmonics along this direction.) This \
is indeed what is observed:\
\>", "Text",ExpressionUUID->"f4683b52-9ff9-4301-b6d1-dfddaba10592"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"spectrumPlotter", "[", 
      RowBox[{
       RowBox[{"getSpectrum", "[", 
        RowBox[{"nonDipoleContributions", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"1", ";;", 
           RowBox[{"-", "2"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2"}], "}"}]}], "\[RightDoubleBracket]"}], "]"}],
        ",", 
       RowBox[{"Joined", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"spectrumPlotter", "[", 
      RowBox[{
       RowBox[{"getSpectrum", "[", 
        RowBox[{"nonDipoleContributions", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"1", ";;", 
           RowBox[{"-", "2"}]}], ",", 
          RowBox[{"{", "3", "}"}]}], "\[RightDoubleBracket]"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], 
  "]"}]], "Input",ExpressionUUID->"f532e33a-7164-4c58-972a-61ed3f034d7c"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {GrayLevel[0], PointSize[0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[CompressedData["
1:eJw1kFtI01Ecx5ehREmJ6XQmuq2cw5w6bTl17f+dOkFFZkr5ENkqHUiXOXuY
WYa3bHtorWZh0hRiEqXGejEUs18K9RTRUJCiephEK/MCXkJF2l+OH76Hw+Hc
vt+v5IK5ojZEIBAogoOfd9CVl3EfT4G8oWeCWuTujkSabIFIthag1VJvflQP
stt49sBRM7g22rqzH4HfhpNJMbdB8R8sQUXB1JLX3alJZOdjYfM89KkbQSvF
fcvFffF4uTJ2rjtUwu6LESEKbzJtgUzbSJEYF2+wSCXsvSMopbmtBRfIl9wc
lAz68M0J/5yYvS+H737yoZ5KEBdwaQOuFBj9LenRHYnsv1Sopn55rSbQwAue
NIh2r3+eF+78nwHJVEA+eRW0b9gYlBKXJhK8sgop85OJ1ZQbPrMV9E54Oags
ZF6sni5dEjN/x7A3qvfT1BuQdRsVNuy1TmOxhPk9Dnv1NeMXBShtpk0x05aN
57InBwcXpcy/Gncy2ptXyziaVTv8akcOZpWypU5DEsuTC1GD922JnqOexzx5
+LFfNTSdJmf5NKiPS+2t0XFUvu4xrHtOYCNC7Rq3HGV5tai8lVplu85RGB/X
y8H+rNEXEpbO8gObVaGH+6I5+v6NB8g8O9b8wKxkfejwynplTZELyuHt+XXQ
FZ2PFjdlsX7y0VE3bL35mqMuLW84H6QVyv/0qlhfBWiv2uV67+ZoYZ6nAAPO
Sa7/azbrrxANI09H6wAq4eMsFwIqZ5dHkcv61ENzYOafNwbUb+AD6hF7unI8
4Z6G9VsEt3ro51836D9XokgY
       "]]}, {}}, {}}, {{}, {{}, 
     {RGBColor[1, 0, 0], PointSize[0.012833333333333334`], AbsoluteThickness[
      1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQPnn8czCcdrHdjAGg1EH+zNz0bIyS10gvIZHAQv
H73GMkf7QGcHCHA4XIov+mK3CCYv4PDhYoT58tlaB2SOFwKRiMN5p4aQLbuc
oOolHOJqWCqn79I+8NVz/hfP+TIOs895Sx45ANOv4CB14R6/nZ3WgTQwUHKY
efdWc8A8J6h5Kg4Bv666fwvQOnBJvRaI1BzUT8y6yPwSZr6GA9sfo+Lrk7QO
2L+cbPdyspbDl9TsOdoHnaD26TgUL5772tpP+8DqVSCg57Bq2s3JXvdg9hs4
aAN9uF9d+wD3tgQgMnQQcfrsPW+SE9Q9Rg43/lzdUv1c58BBsRwgMnbI8Dz7
uTEE5j4Th9nszOXpP7UOlIOBqQN7a4jNo0wnqHvNHI68c4zffFn7gN6NJt0b
TeYOE4UXnjQwdYa638JBxfPelEfrdA88seh7bNFn6XDNUt/5FasT1D9WDpPf
/wy9KmpwYNZMELB2WL/lycq5+jD/2Tj4rD+5sKHf8EDAryX+v5bYOmTETtEX
MHOC+tfOgdlg2yQrC+MDbCDvbrB3kGJsKfthCPO/g8P7Owu2fWU3PXDvLgg4
OJzyMF/1ocsJGh6ODupX8/S+/jA7YAly3mNHB5UpV/56L4eFj5PDo2XzOLXZ
LQ9MsQM52MlBMuf2j1Y1J2h4OTskKEgLM+lbH3j/DgScHU6/WhFj/8cRGn4u
DhlPlk5wz7M94AXyzhcXh+NnDvy+z+8EDU9Xh/N8/1glD9sfWOoP8qCrw7VT
QqrrmWHh6+Ywd5rVgWWKjgcAYG9SXg==
       "]]}, {}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"b12f0d82-6e40-47e1-8dfb-4b19ada586bd"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Benchmarking the nondipole contributions", \
"Subsection",ExpressionUUID->"297266cf-c70d-4be8-893c-003a2284b367"],

Cell[CellGroupData[{

Cell["Nondipole contributions in a crossed-beam setup", \
"Subsubsection",ExpressionUUID->"677880a7-8bc9-4883-9470-63258d5ffc7b"],

Cell[TextData[{
 "This section explores the harmonic emission by a crossed-beam setup, with \
nondipole contributions, as a benchmarking step for the latter. The \
crossed-beam setup was proposed by X.-M. Tong and S.-I. Chu in ",
 StyleBox[ButtonBox["Phys. Rev. A",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.58.R2656"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.58.R2656"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.58.R2656"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.58.R2656"],
 StyleBox[ButtonBox["58",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.58.R2656"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.58.R2656"],
  FontWeight->"Bold"],
 ButtonBox[" no .4, R2656 (1998)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.58.R2656"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.58.R2656"],
 ", and it was explored in a nondipole setting by V. Averbukh et al. in ",
 StyleBox[ButtonBox["Phys Rev. A",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.65.063402"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.65.063402"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.65.063402"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.65.063402"],
 StyleBox[ButtonBox["65,",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.65.063402"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.65.063402"],
  FontWeight->"Bold"],
 ButtonBox[" 063402 (2002)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.65.063402"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.65.063402"],
 ". The results below reproduce those of Averbukh et al.\n\nIn short, we \
consider the harmonic emission by a circularly polarized pulse propagating \
along the ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "b82d8c75-d1e2-4759-a1f5-e8aad525db6f"],
 " direction, at frequency ",
 Cell[BoxData[
  FormBox["\[Omega]", TraditionalForm]],ExpressionUUID->
  "c8256f5c-00b5-4073-94e6-ac8ec43d813a"],
 ", and a linearly polarized pulse of frequency ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", " ", "\[Omega]"}], TraditionalForm]],ExpressionUUID->
  "10ff82b5-f1ae-4349-ba2a-01ef3049e505"],
 " propagating along the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "4bfae265-ed88-46f2-99fd-028b2e43457f"],
 " direction and polarized along the ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "b227ac3c-69cc-4ec5-8fcb-90ad659a0c0e"],
 " direction."
}], "Text",ExpressionUUID->"f4570cad-cbb3-405a-acac-fa844b786fda"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"crossedBeamsA", "[", 
      RowBox[{"x_", ",", "z_"}], "]"}], "=", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["F1", "\[Omega]"], 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"k", " ", "z"}], "-", 
            RowBox[{"\[Omega]", " ", "t"}]}], "]"}]}], ",", 
         RowBox[{
          FractionBox["F1", "\[Omega]"], 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"k", " ", "z"}], "-", 
            RowBox[{"\[Omega]", " ", "t"}]}], "]"}]}], ",", 
         RowBox[{
          FractionBox["F2", 
           RowBox[{"r", " ", "\[Omega]"}]], 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"r", " ", "k", " ", "x"}], "-", 
            RowBox[{"r", " ", "\[Omega]", " ", "t"}], "+", "\[Theta]0"}], 
           "]"}]}]}], "}"}]}], "\[IndentingNewLine]", "]"}]}], ")"}], "[", 
   "t", "]"}], "//", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"crossedBeamsGA", "[", "x_", "]"}], "=", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{"Evaluate", "[", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"crossedBeamsA", "[", 
               RowBox[{"x", ",", "z"}], "]"}], "[", "t", "]"}], ",", "x"}], 
            "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{"z", "\[Rule]", "0"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"crossedBeamsA", "[", 
               RowBox[{"x", ",", "z"}], "]"}], "[", "t", "]"}], ",", "y"}], 
            "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{"z", "\[Rule]", "0"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"crossedBeamsA", "[", 
               RowBox[{"x", ",", "z"}], "]"}], "[", "t", "]"}], ",", "z"}], 
            "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{"z", "\[Rule]", "0"}], "}"}]}]}], "\[IndentingNewLine]", 
         "}"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", ")"}], "[", "t", 
   "]"}], "//", 
  "MatrixForm"}]}], \
"Input",ExpressionUUID->"ebef65e3-25d6-4f6b-b22e-1bb5fb1e9bd7"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       FractionBox[
        RowBox[{"F1", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"k", " ", "z"}], "-", 
           RowBox[{"t", " ", "\[Omega]"}]}], "]"}]}], "\[Omega]"]},
      {
       FractionBox[
        RowBox[{"F1", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"k", " ", "z"}], "-", 
           RowBox[{"t", " ", "\[Omega]"}]}], "]"}]}], "\[Omega]"]},
      {
       FractionBox[
        RowBox[{"F2", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"k", " ", "r", " ", "x"}], "+", "\[Theta]0", "-", 
           RowBox[{"r", " ", "t", " ", "\[Omega]"}]}], "]"}]}], 
        RowBox[{"r", " ", "\[Omega]"}]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   BoxForm`e$]]]], \
"Output",ExpressionUUID->"8bf8024a-b0a7-4cb1-b77d-eb4a04e7b135"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      FractionBox[
       RowBox[{"F2", " ", "k", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"k", " ", "r", " ", "x"}], "+", "\[Theta]0", "-", 
          RowBox[{"r", " ", "t", " ", "\[Omega]"}]}], "]"}]}], "\[Omega]"]},
     {"0", "0", "0"},
     {
      FractionBox[
       RowBox[{"F1", " ", "k", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "\[Omega]"], 
      FractionBox[
       RowBox[{"F1", " ", "k", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "\[Omega]"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   BoxForm`e$]]]], \
"Output",ExpressionUUID->"4b2c2af7-9321-4d76-a86c-cd1e9c64efcc"]
}, Open  ]],

Cell[TextData[{
 "The dipole selection rules allow harmonic orders of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"2", "r", " ", "\[ScriptL]"}], "\[PlusMinus]", "1"}], 
   TraditionalForm]],ExpressionUUID->"db532ed4-8c4c-4797-ac26-b2b5683cf5de"],
 ", with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[ScriptL]", "=", "0"}], ",", "1", ",", "2", ",", "3", ",", 
    "..."}], TraditionalForm]],ExpressionUUID->
  "a41e19de-36f5-43c0-9ff4-1b6970016429"],
 ", with polarization in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", ",", "y"}], TraditionalForm]],ExpressionUUID->
  "43dd5905-0ee8-4a12-acd0-bc9aa85c98b3"],
 " plane, and harmonics of order ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "(", 
    RowBox[{
     RowBox[{"2", "\[ScriptL]"}], "+", "1"}], ")"}], TraditionalForm]],
  ExpressionUUID->"42a1eebf-0ac2-4e6e-8d84-ac3450035ef9"],
 ", with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[ScriptL]", "=", "0"}], ",", "1", ",", "2", ",", "3", ",", 
    "..."}], TraditionalForm]],ExpressionUUID->
  "8bab8eff-b089-46b6-8921-b52a594f08a4"],
 ", polarized along the ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "bfe26b3f-6d80-4bac-b597-78bd1dac550c"],
 " direction."
}], "Text",ExpressionUUID->"ed80d9bc-4dbe-4f7e-aab2-a84ef76f2ec4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"allowedHarmonics", "[", 
   RowBox[{"r_", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"Union", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", "r", " ", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "100"}], "]"}]}], "+", "1"}], ",", 
      RowBox[{
       RowBox[{"2", "r", " ", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "100"}], "]"}]}], "-", "1"}]}], "]"}], ",", 
    RowBox[{
     RowBox[{"#", ">", "0"}], "&"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allowedHarmonics", "[", 
   RowBox[{"r_", ",", 
    RowBox[{"{", "3", "}"}]}], "]"}], ":=", 
  RowBox[{"r", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", 
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", "100"}], "]"}]}], "+", "1"}], 
    ")"}]}]}]}], \
"Input",ExpressionUUID->"e663c9e2-a9a2-44c9-883b-47f3143c00c3"],

Cell["For the calculation, then, some preliminaries,", \
"Text",ExpressionUUID->"99f4c7b5-f10d-4fb6-ae76-7b42ab26f1fe"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]Range", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"1", "/", "137"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nppcb", "=", "240"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"crossedBeamsParameters", "[", "rr_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F1", "\[Rule]", "0.1"}], ",", 
     RowBox[{"F2", "\[Rule]", "0.2"}], ",", 
     RowBox[{"\[Omega]", "\[Rule]", "0.057"}], ",", 
     RowBox[{"\[Theta]0", "\[Rule]", "0"}], ",", 
     RowBox[{"r", "\[Rule]", "rr"}], ",", 
     RowBox[{"k", "\[Rule]", 
      RowBox[{"\[Alpha]", " ", "\[Omega]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetSharedFunction", "[", "crossedBeamsResults", "]"}], 
  ";"}]}], "Input",ExpressionUUID->"451a003c-0d67-4a96-8390-d1b746344267"],

Cell[TextData[{
 "and the calculation itself for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", "2"}], TraditionalForm]],ExpressionUUID->
  "b84cf04f-8280-4411-ae0e-1e0e1e7ae737"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", "5"}], TraditionalForm]],ExpressionUUID->
  "d6ce5796-b322-4bba-88b3-4f06630ae648"],
 "."
}], "Text",ExpressionUUID->"83c1c041-0f7e-46be-9187-f1056496bb46"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Print", "[", 
  RowBox[{"DateString", "[", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ParallelTable", "[", 
  RowBox[{
   RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"crossedBeamsResults", "[", 
       RowBox[{"r", ",", "\[Alpha]"}], "]"}], "=", 
      RowBox[{"makeDipoleList", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"VectorPotential", "\[Rule]", 
         RowBox[{"crossedBeamsA", "[", 
          RowBox[{"0", ",", "0"}], "]"}]}], ",", 
        RowBox[{"VectorPotentialGradient", "\[Rule]", 
         RowBox[{"crossedBeamsGA", "[", "0", "]"}]}], ",", 
        RowBox[{"FieldParameters", "\[Rule]", 
         RowBox[{"crossedBeamsParameters", "[", "r", "]"}]}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"DipoleTransitionMatrixElement", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"p", ",", "\[Kappa]"}], "}"}], ",", 
           RowBox[{"gaussianDTME", "[", 
            RowBox[{"p", ",", 
             RowBox[{"1", "/", "1.3"}]}], "]"}]}], "]"}]}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}], ",", 
        RowBox[{"PointsPerCycle", "\[Rule]", "nppcb"}]}], 
       "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", "]"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Alpha]", ",", "\[Alpha]Range"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"DateString", "[", "]"}], 
  "]"}]}], "Input",ExpressionUUID->"07407674-f2d1-4f1b-a8a7-a59daf22c54b"],

Cell[BoxData["\<\"Fri 13 May 2016 17:24:01\"\>"], \
"Print",ExpressionUUID->"5f9216c6-266c-4ec6-b57f-175388e2e05f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"23.097127`", ",", "Null"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"52.542557`", ",", "Null"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"22.956923`", ",", "Null"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"52.856394`", ",", "Null"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"80782c93-a1a4-48ce-8364-c047ed0d188b"],

Cell[BoxData["\<\"Fri 13 May 2016 17:25:19\"\>"], \
"Print",ExpressionUUID->"251d3443-e2e1-41ea-998b-7a112b99b89d"]
}, Open  ]],

Cell[TextData[{
 "Results for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", "2"}], TraditionalForm]],ExpressionUUID->
  "552ee2cf-fb47-4a7a-9a9f-6d7202ec9c19"],
 ", comparable to Fig. 1 in Averbukh et al. Dashed lines mark the \
dipole-allowed harmonics. The left-hand column has nondipole contributions \
turned off (",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Alpha]", "=", "0"}], TraditionalForm]],ExpressionUUID->
  "582dff13-f59d-448b-9031-126c6567b297"],
 "), and the right-hand column includes the nondipole contributions and \
observes a massive increase in the amplitude of the dipole-forbidden \
harmonics."
}], "Text",ExpressionUUID->"b7723e2e-43c0-47fd-97d0-9872f0a264c6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"Table", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"getSpectrum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"crossedBeamsResults", "[", 
           RowBox[{"2", ",", "\[Alpha]"}], "]"}], "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{"1", ";;", 
            RowBox[{"-", "2"}]}], ",", "part"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"\[Omega]Power", "\[Rule]", "2"}]}], "]"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], "\[IndentingNewLine]", 
      ",", 
      RowBox[{"Joined", "\[Rule]", "False"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
      RowBox[{"PlotTheme", "\[Rule]", "\"\<Detailed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "Full"}], "\[IndentingNewLine]", ",", 
      RowBox[{"GridLines", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"allowedHarmonics", "[", 
          RowBox[{"2", ",", "part"}], "]"}], ",", "None"}], "}"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Alpha]=\>\"", ",", "\[Alpha]", ",", "\"\<, part \>\"", ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}], 
           "\[LeftDoubleBracket]", "part", "\[RightDoubleBracket]"}]}], "}"}],
         "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"part", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", "3", "}"}]}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "\[Alpha]Range"}], "}"}]}], "]"}], 
  "]"}]], "Input",ExpressionUUID->"15b331ae-664d-48b4-8410-69b6d383f8c1"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.009166666666666668], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw90glM02ccxnEkyIYXh6IIVbkqpQMKFAEV6VPL2XK0hUIpRaUejOEtzAOj
fzeYeKCIJ8qQzSggqIgoiArVOKYomhrQ6eZAZeJcZDJdxOlkW/i9a9I0Tz/5
vm+b1sWwTL3Q3MzMbPW/z/9ehx4vJQZepulW6RgjvYHgJp3eqiee9sf4SuvO
N7QMSIa2DV6vdS0Q7YwjH4fu005804URGNoOOOe7rGtOGHMeHlWuHLDoe98y
tJ0hd6yqnBzAzndFSWZpUZVXJ7k7eHMfByc2s34qiqyaP2vosactgNmOt3vP
L2O9EOZhL3M6R9vR9sL6xQ4Jj0JZ7wPBfHPTkVIH2r5YJCts9f3/fj+c2/f1
wWer2fn+OLT8IH/6Q9aLsbHL/recRifaAZBb7t+5OY/5NJz43Cp7vOVE2oHo
PPCu0lzFPAiXReb3FthOoR2M1Qcu39g+nPl0tORHDmyo4dGegQ2V2QUV9bG0
Z8LJ5v5jLtaFdgje2JqGdziwfhY2V50V6gKdaYei0sLoUlbEegn21GUJ3/Dd
aAOHB/udXQ+Sc0BNkLa93s2VXIoJ2++2PFtE53NSZIVrWrfZ8slnw2brBXdB
DutnI0Ay3Esw2Z1chtsP1r2PtGcuw5dTxt0daetBHgbHhuO1O+czD0PzrkMd
SsFU8nBMO266L8xjHo4xZ6MGrHme5BHwvJgc8/sO5hHQeLdXpIcLyCORufjJ
dfFk5pHQGzxjFKGfkEeh0XpQVr8khjwKDz80vOfPF5JHw0lkarebxTwavbnX
zSZ86k0ux9hjD0e3DWMux6gXiq5NR73IFTDURl/L1SnIFfDbKpIeqRORx2DF
rz9mxPXKyWMwLHnit7Oe+5DHYvDpKnHJSeaxiI2vzWk09yOPw4Gqt9na75jH
IaXiz5v6Y77k8Vj5oHP3JSd2fzzSrB0P9YT4kytRPHGXsbyOeiixckXdFo9f
6HxOiVW5Hk/V2dQblSi/sjFizWYx9SpcyW2TLWklhwoFu/PLtojJORVKxYUV
lypZr0Kny7lTTT0B1KuxvcnMZ/kJ1qtRZJnlu2YvOafGhNMzIWphvRp3RBma
vrmB1CegQCcan/GA9QmIvTpOZ80j5xJQODrPNv8D6xMgaGtMN/CDqU9EaP8c
pbyE9YkwiX5u+vt1EPWJyIqp8pxaQ7+vMRGGvpfrHJQzqNeg/wnv9or1rNdg
6aj4N70B5JwGVq+koxTV7H4N9vk8+ca7O4T6JOxSTeLyLeh8JOGMZ8GHSz+Q
c0n4yOJVqDf7fMYk+H9R/VR/U0J9MoLFdq8uFrL7k/E66Q/7krvkXDIaOlR7
by9kfTKuTnpx2j9fSr0WlieejZ0+ht2vhfHFxWrfYnJOC0c/rlfiwr6/FtKg
wDPVUTLqU3BP2Lhesofdn4KyRWf6T+rJuRTUjvSJtJWx+1PgXe7ZfNgrnHod
0n+adyvkEfv/6RBxbd6m7yPIOR0s+7vcujvIjTrUufWlFwdGUp8KqdDjRrk7
61Nhk16jaIwg51JR17RAkeLM+lSo93eUFyuiqdcj2rHhLy871uth2Xfn1Pgy
ck6PU6XbLtSH0Tbqceu5zUj5SdanYen55SNaO6OoT8NYx8I5ijzWp0Hhzs94
Z8f6NBj13WuPboo2/gOEWy0W
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -68.65338396257846},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameStyle->Automatic,
      FrameTicks->{{{{-57.564627324851145`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "25"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "20"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "15"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-62.16979751083923, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-59.86721241784519, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-52.95945713886305, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-50.65687204586901, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-48.35428695287496, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-43.74911676688687, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-41.44653167389282, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-39.14394658089878, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-32.23619130191664, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}}, Automatic}, {Automatic, Automatic}},
      GridLines->{CompressedData["
1:eJwt0uFHHAAAxuGbJEmSJElykiRJkiRJkiRJJUmSSpLUOUmSJEmSJJPMJDOZ
mZlJJkmSJDPJTGaSJDPJTJIk9Rz78Hj/gN8b7Ao1Dr4IBAKHRDaKaGKIJY54
EkgkiWRSSCWNdDIIkkkW2eSQSx75FFBIEcWUUEoZ5VRQSRXV1FBLHfU00EQz
LbTSRjsddNJND7300c8AIcIMMcwIo4wxzgSTTDHNDLPMMc8Ci7xkiWVe8ZoV
VnnDW9Z4x3s+8JFPfGadDb6wyRbb7LDLHvsc/G/ylW8cccx3fnDCT35xyhnn
XHDJb/5wxTV/+ccNt9xxzwOPPEX6O0AU0cQQSxzxJJBIEsmkkEoa6WQQJJMs
sskhlzzyKaCQIoopoZQyyqmgkiqqqaGWOuppoIlmWmiljXY66KSbHnrpo58B
QoQZYpgRRhljnAkmmWKaGWaZY54FFnkGVoRXlw==
        "], None},
      GridLinesStyle->Directive[
        GrayLevel[0.4, 0.5], 
        AbsoluteThickness[1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->All,
      ImageSize->600,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        TemplateBox[{"\"\[Alpha]=\"", "0", "\", part \"", 
          RowBox[{"{", 
            RowBox[{"\"x\"", ",", "\"y\""}], "}"}]}, "RowDefault"], 
        TraditionalForm],
      PlotRange->{{0, 119.}, {-67.510604732917, 3.3417075060917654`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, {{-57.564627324851145`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "25"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "20"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "15"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0., 
          FormBox["1", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-62.16979751083923, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-59.86721241784519, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-52.95945713886305, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-50.65687204586901, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-48.35428695287496, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-43.74911676688687, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-41.44653167389282, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-39.14394658089878, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-32.23619130191664, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-20.72326583694641, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-16.11809565095832, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-9.210340371976182, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-6.907755278982137, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-4.605170185988091, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {2.302585092994046, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {4.605170185988092, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.009166666666666668], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw1kwlQU1cYRp+ooKIiisgmiAiCsgYJIEs+xAAhsiUBEkiogIhLS7QuKVDh
ad1Gq85A1U6loFZAbUZAUSmOEKsw4CiIKNq6loLN1KpgQVvr0nb4b2YymZOT
8+e+++5zztLKckw4jtP99/7/c+Q1IAo+XsJ1lk020Bdw69jbJ9J7E4/DubxM
UVbzX6IRnoLt77v6jsycR94KBYfvvrlxYQJG2AZ52Y2TV23wIO+As9Mrzr97
9rZ5hGehMzrUcYuU9bNxcnXwQLXnbfJzMNHNGPjGzJe8G4aOzDH9oW86sTvO
tElrD8cwPw/Oypreu5OmEntCPapJpvzSj9gbUzour64usyH2RUvW04bZDwXE
frhq0en0TMfmC3A++liFZhzr/ZFtY9mzocGeeAFC6sp/SuhfQBwAo92uL+xN
bYmF8In/ym7i32x9gZjxemqH2tKJOAijrLy3/aZhfTC0z3mvrXoH4oUIe7zz
oZkz+/8QdMgFzzfGOROH4qLJpprD9f7EYVBkDA6rhbOIw5E6nL+hRct6EU68
+Gxqv6sLMaBeu7o15GvqeaCu9cyKBpfZ5CNQWmW+fdJ96vkIWDQar3xi6Up+
EXI+1HzIv8T6RXixwlTm5TiHfCSWXbD9Jz+b9pePRElBwecPpswlvxghW9dU
vLSg6+cXYzA8yj/F3Y28GHVvbO99N5rNF6Mmd3TQDXt2nqLwcJOnETtYH4Xl
BXsO5YrdyUfD/LpA0XuK9dGoPLGZHwybTz4GY67UGeUOAeRjwK2tCQnIZudR
ghnLz+7IyGPzJQj3SbM4kOtFPhYle1N7rW+yPhZ/eLsv+7bSk7wUYqt7MyV+
zEuRsL5baHLah/wSdKc2H2zbISS/BFfXrYtd+Tt73uIwt9yydLM583G4Ne9x
vMyE3c94DOmlPknKQPLxsK9ofFtUxc5bAnb/GfWqZoD1CagpTopZGsrOeyKs
hjzyzwcHjTAScXHjCp2qn93vRJyz85w/6QnNNySiNz5vW/t2dt6SMCH3VES1
TzD1SbCPVXbf9Wf7nQS9aXGA9Uuab0jCmY6f9V2/svMug/6W8bbDwoXUy2De
tyambz/bbxk6SneKd40nb5BBfO2S3ckMuh5ODm1o5aeV6SHUy9FlllF424Fd
rxxBN6rGCqTkDXJEZxSfrnSh9XAKSHSF2gc9odQrUJC/q6T4FdtPBZZeP/e+
c4i8QYErqkxdaxyth0tGTu2xohNt4dQnoz6zXq4JJM8nQ/Go2TA0TUR9MjTD
ilLnBzSPS4GD0+Wbiv2gPgXGJ5XtYffJ8ynYfcd2lrCTvCEFe4zmGavaaB6X
ihbB9+XVryOoT4XoRWvt/Hvk+VR0O1aMz4lcRH0qXD2y9um30O85JfweaU1N
tkVSrwQ3M7FxzH7yvBJvq/hffnxM3qBE01OXdp2YmFOhrH1tmzpITL0Ka8y0
TeZLyfMqBAot8yYcJW9QwWhd1PXcnZhLQ9aj3gvFk6OpT8NAbqHP2VjyfBqs
bdb1Ne0hb0iDi6b6dYMvMZeO8df7F69cIKE+HcfKHAOuSsnz6Rjr+w0OCMkb
0mH/cbKXLpyYUyPzo+7anUGx1KshUQkURw6R59XwFw9euyljvRqloaGO+46y
XoN35a4eRT0x1GswfEd7sKeQ9RrUN5m5nZzGeg2OH3JpaVovMfwLFIYwaQ==

          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -56.490465082387445`},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameStyle->Automatic,
      FrameTicks->{{{{-46.051701859880914`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "20"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "15"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-50.65687204586901, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-48.35428695287496, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-43.74911676688687, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-41.44653167389282, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-39.14394658089878, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-32.23619130191664, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}}, Automatic}, {Automatic, Automatic}},
      GridLines->{CompressedData["
1:eJwt0uFHHAAAxuGbJEmSJElykiRJkiRJkiRJJUmSSpLUOUmSJEmSJJPMJDOZ
mZlJJkmSJDPJTGaSJDPJTJIk9Rz78Hj/gN8b7Ao1Dr4IBAKHRDaKaGKIJY54
EkgkiWRSSCWNdDIIkkkW2eSQSx75FFBIEcWUUEoZ5VRQSRXV1FBLHfU00EQz
LbTSRjsddNJND7300c8AIcIMMcwIo4wxzgSTTDHNDLPMMc8Ci7xkiWVe8ZoV
VnnDW9Z4x3s+8JFPfGadDb6wyRbb7LDLHvsc/G/ylW8cccx3fnDCT35xyhnn
XHDJb/5wxTV/+ccNt9xxzwOPPEX6O0AU0cQQSxzxJJBIEsmkkEoa6WQQJJMs
sskhlzzyKaCQIoopoZQyyqmgkiqqqaGWOuppoIlmWmiljXY66KSbHnrpo58B
QoQZYpgRRhljnAkmmWKaGWaZY54FFnkGVoRXlw==
        "], None},
      GridLinesStyle->Directive[
        GrayLevel[0.4, 0.5], 
        AbsoluteThickness[1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->All,
      ImageSize->600,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        TemplateBox[{"\"\[Alpha]=\"", 
          FractionBox["1", "137"], "\", part \"", 
          RowBox[{"{", 
            RowBox[{"\"x\"", ",", "\"y\""}], "}"}]}, "RowDefault"], 
        TraditionalForm],
      PlotRange->{{0, 119.}, {-55.54074806217151, 3.3417071912154457`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, {{-46.051701859880914`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "20"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "15"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {0., 
          FormBox["1", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-50.65687204586901, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-48.35428695287496, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-43.74911676688687, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-41.44653167389282, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-39.14394658089878, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-32.23619130191664, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-20.72326583694641, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-16.11809565095832, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-9.210340371976182, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-6.907755278982137, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-4.605170185988091, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {2.302585092994046, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {4.605170185988092, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}}]},
    {
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.009166666666666668], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw1kgtU02UYxiccSSUUFY17BBOncjERkIHuGTgY9zEGbGw7IoQcjlwcevKG
No6TW5KklGtCgB0vUN6gIkUEr0nELKNOICrXmUmSekCilOrwvTtnZ+f5//6/
9/m+b99bqbnSdDMOh7P9v+//v9OfPwWxOtvJx4clbewBtvgf/efUgqet03EW
PjGetB2+GMu4NTR1u40zHel9G8hdZfe4HTEs2yLtUmbD0DpLTGdHZGQ6u6Z6
EXdBf7f495K5NM8VU86vNvY5UebiZeCyxwrrPtbvjoaxh93XRMR5+OWbAP3w
FM1bjojv1+nFMcQ98LhkVF8bb82yFzqaLd08I+n9lbjlO0PkcIDy25j5XBjK
k9B+VuF+79/VlocXsuyDrNKbVZIcmr8ajWayTzdWk++L6swvfOVVlP3Ay7Af
Kf9uMcv+0IQVPWhKIb4G82+/sftQBeUAbLr/3Gr2g2iW+dh32n7A5GzPciBq
7toNyObQ+oKQZyWuLOsify1+Plhz/kQr5XU4eWXMiad3YlmAqgKOpsdE84Gd
6WslwkmWtcAfrb0BKdXEhZi48tOWm0ddGBcipXBMz8siHoxzPtn3OOZsPdpg
BOl1hRkh1B8C/oLbx67tcWU8BK/VL3h/8THy1yO7sG3GaQ92ntr1GEmT6boM
5IuwYflHuxvyuIyLkJq0781TB+n8Q7FoRbv4HK1XG4rw1Sc0+d/S/DDMn+13
fIbWnfEwPNuW0jQRRFyMloXj21q6ohgXo+x6+Vf5MpY54bDoW3KovYLHeDgi
m8a733Wg/gh0Le3PDQojPwJC+4eiIWMk45GYaSY6YuxYzngkrpUuNhznU38U
dro5XlDpyI+C7qzA/EwG9UcjOFt4NXeeJ+PROH91at/YZfJjUPvCwrGskfVp
Y7CSXylIS6D+WCS4yJT7Nd6Mx+JJoJ1HzmGaL4GDq+lFsw97HxIUGyakd21o
ngRH7uRbeE+unM5tEmwukWd+7Ul+HKL73JsGnVlGHEp7K1OvPCQ/DovCn/eN
xKxifhxaeZ3c4kfkS3GzdOK0pJztB1IM3jY2DI6TL8WKIvne0Es+zJdCbe4Y
90BDfjwaFSlat1Hqj4d53diXNaHs/mjjkcuNxg61L/Pj8VdeQXFjFJ2fDPWG
WaYqd+qXYejX6/2cerpPMtxKdqqwTPRnvgyOtReyLaXkJ+C4r05pf4D6E6Ac
mnhUZEf/ZwIqrBQHL54PYH4COnwOnVhWQ+tPRHnLx0WV75CfCP2dXUm9nbT/
RPS8bsefnxXE/EQkC3jDgRvIT0LeS6Ohx5v8JFhwdxwRjJCfBIPGZJqbL2B+
ErY7uG3uFJAvB3/epr1+dP8gR9GSG3ViW9q/HKsn/fbKsoTMl2Nrv6HZuoh8
BcY3/3a/5Ue6PwqkK57G8gupXwH/SeON8aAQ5iuwx9YrfW0n+clQedha7HyP
/GSMfSAulgyRn4z2DSVeVp4i5idDt+fy5za3IpivhF4tCF1jYhlKFLgLas2a
yVdi1tmB8hx+GPOVsLSqz/mMS74K9XOaR3e8on4VnkW+6u70ZFyrQsaxja5t
IeHMV8E7qrSyf5RljhovRgw/CLZSvxo98zyeLP2Qca0aql2XG8+UM96mRsHg
AJ87Ed72L8mvPS8=
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -71.37138182293201},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameStyle->Automatic,
      FrameTicks->{{{{-64.47238260383328, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "28"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-52.95945713886305, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-41.44653167389282, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "18"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            TagBox[
             InterpretationBox["\"100.000\"", 100., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-62.16979751083923, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-59.86721241784519, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-50.65687204586901, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-48.35428695287496, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-43.74911676688687, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-39.14394658089878, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-32.23619130191664, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}}, Automatic}, {Automatic, Automatic}},
      GridLines->{CompressedData["
1:eJwV0BFzggEAgOGvQRAEQRB0VxAEQRAEQRAEwQdBEHx3C4J2FwRBEARBEARB
EASDwWAwGAwGg8FgMAiCwSAYDIKuJ3h+wPvmortwEAuC4JYb4iRIkiJNhix5
ChQpUaZClRp1GjRpEdKmQ5eIHn0GDBkxZsKUGXMWLFmxZsOWHfc88MgTz7zw
yhvvfPDJF9/sOfDDL0f++OfE+dpvRJwESVKkyZAlT4EiJcpUqFKjToMmLULa
dOgS0aPPdfqQEWMmTJkxZ8GSCwBVLPA=
        "], None},
      GridLinesStyle->Directive[
        GrayLevel[0.4, 0.5], 
        AbsoluteThickness[1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->All,
      ImageSize->600,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        TemplateBox[{"\"\[Alpha]=\"", "0", "\", part \"", 
          RowBox[{"{", "\"z\"", "}"}]}, "RowDefault"], TraditionalForm],
      PlotRange->{{0, 119.}, {-70.1844438631669, 3.405709642268947}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, {{-64.47238260383328, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "28"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-52.95945713886305, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-41.44653167389282, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "18"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-6.907755278982137, 
          FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {4.605170185988092, 
          FormBox[
           TagBox[
            InterpretationBox["\"100.000\"", 100., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-62.16979751083923, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-59.86721241784519, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-50.65687204586901, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-48.35428695287496, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-43.74911676688687, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-39.14394658089878, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-32.23619130191664, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-20.72326583694641, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-16.11809565095832, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-9.210340371976182, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-4.605170185988091, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0., 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {2.302585092994046, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.009166666666666668], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw1kwtMU2cYho+Aw3mtCiqMbdykIlABCyLl8tKW+620lBYKRdQFNU4dBsyI
6NFViQZwA0FFIxPdcIoIykSY4nHMC5dkuujYkIyhLEQyEdjqVFC2he9vctI8
532f7/znz3+c1m5Vf2TBcdyO/67//6d+I6FjB4Z8ig/6CHQDK9wspDULRm9M
4QyE517d6St4US7CrupnxtyeFcQ2aG/5K74InsRL8MZq2u6BkFmYYgeoKnMr
xtaJKXeEV88WTvV4JbEz3N8cLLg87k3sCpl8zDtD9Ds93w0e99zSTz+UUL4M
8jt/HGs8JiVejqIHLu5t4b7EnhBvqQmo0YiIJah0e3d0ci57P29cXlpX9rSU
9X0w+0Vf5nctLPfF2Y5Mf9uyhcQroczueLToU7Y+KU6dzrH2+4b1/VBcdahJ
vouxP6LaUkurOhYRr0LVr5tfd2qZH4DOrgq/gQ2svxpBw2szgk2MAxFeN1A+
/oE9sQzK9a6tNz5mfhBM05s8R/NZPxg9cYdnSJoZh8CpYKJeefR94lAsuep4
3KWe+cAc1bSZ9wXq88DI3oM7huez/QjD5hJ3Xc9xR8rD0GXx1Tp+PpsvR+H+
W9kvPajPy9GviXeq2Md8Be5P2jX2FThTrsCKgNFKpyLmK7GhxDy5tJb5SrRl
t525Mo+dh3DU2XVd7M5xpTwcZplXFu/E5kfAfnnn1sAg6vMROFFUf+haI/Mj
USs8CfXl3SiPRLt+2/D2O8yPgn+1/zuuo8yPQtyXP13avoadp2iI83+Uzi5f
Rnk0Vn4vblqzl82PQfNI+13nk9TnYyD/9q5ursSP8liUl9Re8uxaTnksXBQ3
F0qUbH4cJIpj7eGbqc/HIa3piKXfOPPjITXn7B6ZR98bH49SvbjBzYHlCeBn
Fr/yjvSnPAEDXzyQpfQTc4k4VVZ1S5pD3yefCH58w9NMC5arMPOwqXmb76op
hgqfvTQ4WPYQ8yrIRnsial7TeRFUSPbqzXQeZ34SlPnK385JAshPwpBR+7Bw
kJhPgt11wViaSPstJKFdPZKUM4tyTg2fDqNNQ+hq8tUYGWqNG5sVSL4aGxef
T5Rcp/0W1LCyffFkqYT6nAZRRZrxc5uoDw121JXbXDDIyNfgzxI4DhlpvwQN
rh7fE/bqEPW5ZMjj57TbDlIfyfi7u+8Xg2Uw+cmwKXpZnqCn/RCSwcfePClL
DyJfi8c7a1d/+ID60MLcnWRS2IaSr0VZ11iMuZHWK2ghWni69PGREPJT8EN/
yGDZYpCfgob5DdVNt4n5FARf/CdLu42eJ6TgUXOLOvsE5ZwOYdf9376XF0a+
Dp9Ub1rws7ecfB06Lca+Xr+H1iPoYB4uzyu0o5zTo8bu6J76SWLocbtMFtjd
piBfj7MbQ58d2ErzBT0CrAtme7RSzqVCLLIM3nVRSX4q8jwW727NDyc/Fe7+
VqYroL6QCo8LDs+H9lHOpaFhu3n6vb0R5KchayDCfkITSX4arFV5UqMP9YU0
XCgePmPKpZwzYIvIxW2iMIp8Axbx1qaN66PJN6BUpOt9HkJ9wYA3mW1NsXmU
c+mYbDm/36Uyhvx0CLZt3b4TzE9HQoWFfYWCWEjHW6db8rt9zM+AjUdBZpaR
+Rk4UbksbMbnzM9A/zWxlV0O5UIGzDG9d9IGo4V/ATdBNFo=
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -57.31299357131516},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameStyle->Automatic,
      FrameTicks->{{{{-52.95945713886305, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-41.44653167389282, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "18"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            TagBox[
             InterpretationBox["\"100.000\"", 100., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-50.65687204586901, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-48.35428695287496, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-43.74911676688687, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-39.14394658089878, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-32.23619130191664, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}}, Automatic}, {Automatic, Automatic}},
      GridLines->{CompressedData["
1:eJwV0BFzggEAgOGvQRAEQRB0VxAEQRAEQRAEwQdBEHx3C4J2FwRBEARBEARB
EASDwWAwGAwGg8FgMAiCwSAYDIKuJ3h+wPvmortwEAuC4JYb4iRIkiJNhix5
ChQpUaZClRp1GjRpEdKmQ5eIHn0GDBkxZsKUGXMWLFmxZsOWHfc88MgTz7zw
yhvvfPDJF9/sOfDDL0f++OfE+dpvRJwESVKkyZAlT4EiJcpUqFKjToMmLULa
dOgS0aPPdfqQEWMmTJkxZ8GSCwBVLPA=
        "], None},
      GridLinesStyle->Directive[
        GrayLevel[0.4, 0.5], 
        AbsoluteThickness[1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->All,
      ImageSize->600,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        TemplateBox[{"\"\[Alpha]=\"", 
          FractionBox["1", "137"], "\", part \"", 
          RowBox[{"{", "\"z\"", "}"}]}, "RowDefault"], TraditionalForm],
      PlotRange->{{0, 119.}, {-56.34920463749679, 3.405709259241688}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, {{-52.95945713886305, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-41.44653167389282, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "18"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-6.907755278982137, 
          FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {4.605170185988092, 
          FormBox[
           TagBox[
            InterpretationBox["\"100.000\"", 100., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-50.65687204586901, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-48.35428695287496, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-43.74911676688687, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-39.14394658089878, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-32.23619130191664, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-20.72326583694641, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-16.11809565095832, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-9.210340371976182, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-4.605170185988091, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0., 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {2.302585092994046, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",ExpressionUUID->"8c7230ba-c017-4ec9-ab13-60efc0793167"]
}, Open  ]],

Cell[TextData[{
 "Results for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", "5"}], TraditionalForm]],ExpressionUUID->
  "2b72f79a-a3fe-4719-a3cd-7f3ec037fdd2"],
 ", comparable to Fig. 2 in Averbukh et al."
}], "Text",ExpressionUUID->"d1b9fb0a-0911-47c8-ba00-ca08f6a8ceb6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"Table", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"getSpectrum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"crossedBeamsResults", "[", 
           RowBox[{"5", ",", "\[Alpha]"}], "]"}], "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{"1", ";;", 
            RowBox[{"-", "2"}]}], ",", "part"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"\[Omega]Power", "\[Rule]", "2"}]}], "]"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{"2", ";;"}], "\[RightDoubleBracket]"}], "\[IndentingNewLine]", 
      ",", 
      RowBox[{"Joined", "\[Rule]", "False"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
      RowBox[{"PlotTheme", "\[Rule]", "\"\<Detailed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "Full"}], "\[IndentingNewLine]", ",", 
      RowBox[{"GridLines", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"allowedHarmonics", "[", 
          RowBox[{"5", ",", "part"}], "]"}], ",", "None"}], "}"}]}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Alpha]=\>\"", ",", "\[Alpha]", ",", "\"\<, part \>\"", ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}], 
           "\[LeftDoubleBracket]", "part", "\[RightDoubleBracket]"}]}], "}"}],
         "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"part", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", "3", "}"}]}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "\[Alpha]Range"}], "}"}]}], "]"}], 
  "]"}]], "Input",ExpressionUUID->"79e20b36-494d-4585-a33d-b38c64917d4b"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.009166666666666668], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9kw1Q03UYxydKzlRYiopACooKQ2GCvMv4MtmAsTEYe2MbJyCEqEmkNAST
+RZ4qJkIp4lKDPI0SfJQ1IxGlie+O+EkMzoC3aVkwGkqclKdv6fd7XaffX6f
3/OM++OVla/MceBwOKZ/3/99vnkNRP/k+ay5IMjJyr7A9rTQ4Lb2ZMZcvKqf
/NuVQmIeMto0c00niF0wJNywZuQtYlc0nt3Diwwn9sDUoN13uYcVjD0xGNTr
If4oifEcPN13MWZG9QS8YW/4br473XZDzvx8OO2O983hOzPvg9Mj5zLtr8jz
MVY48K3Mne5fiKYzuj7/cmJ/GEqiHOWBxAJEzdt4kH+LeDHudvgXqw7TPoEI
ffjC+u468kHoPNZQsej5z9FveAkKX752DBSSD0Zx7EhNHe8x8yF4O0fVeyKE
7guF5lF0d5GQOAzjF9QmX0wiDkd/ds+zU+XEEchw63fqbSSORHXkF+MdfqXf
uxQVn18tqVKTj4K3fWn+lWkujIUoL+uq+nQ2+WgYZ84c8D4/jTEwKjeOvEPz
zcC4Iu5Vwwo6HwPt5SmG+u1snjkGa3KLhQW3ab4Is7rmjo+gfcwiLLmzsDWn
ivwyzHBcd+PlZ+SXoTr3NS9Xx2c+Fn0tTzcp+eRjUX1t14J7DX7Mi7HNkhVg
CicvhuDvpNInXLpfgj9Xuy5QuJGXwHxUUBQfRvvHYVh+0uFhu4z5OHQeTxm6
fY4xJx4PBPvjPBzIxyOyc61J2xTCfAIW9qU3Vf6QyHwCTqauTtg5JYx5Kex7
Ave5i6iXQiz1M+sm0/2JWCtUjfbbqU9ERJyism2UMUeGRcoW2cu95GVov1BQ
KemTMi+Hird8o9LC2CzHoTu7NuvnxDCfhP3Dg7W+FeSTEOBaIfMKEDGvgNeE
UJ+r7nS/AhZ7v0tHPs1PxonO8tHfxYyRDLeyasXl+XQ+GTfPdSz3aWRsTUap
e3RLXij1KVCUnW0p1VGfAtGW1uvPMyWsT8HJpCGJRx31KTgKe96qL5nnKPFs
1zGn4lvs7wUlSr+yiSN30HwlomC7rh2mXgnnrIx5WXQfJxXd/JqwcUdofir0
p0yTcum8ORWuXD/OmR7qU1HJFwz+9f/+Kjgv3eMa/oJ6FUQ85wtdE6hXobV1
0Y7Hi9l+VhUEsvcj4x5Qr4bAq0vpO4v2VyPbmjpJXU/PgxqW4DKb/h7NV2NM
3galRwv1GmxKuVQ5tYHma/Bh0+QcCZ03a3BTmDdxeDv1GqwXf9IhmkO9Fk1f
f3PskiPN10Jndfnl0lbqtTho466fFUS9Fg3G5ifZY+n51GHFj++VmC00XwdL
x+y5H0+i/XU4VGKNH+NFvQ5B9a3fyVtpfho2xg7W+edRn4aVf/irP+DS/DRI
ZZZHoZnUp+F8d/n0nRzq9WgvdLOpXKjXI+ZCdu/ENnqe9TgtvZ9Xq2Ns1eOI
7H617Qb9fxhQN3P4bPlKxjCgc1rPgaJe6g0wqbfEBDdSb0BBxkjTTRP1RtR4
3n7gspV6I3jN6u/jV1FvRLf+fEDPFuqN8MvU2PyrElifjlfXCpsRwRjp2Jzh
037gOGNzOl40l9nHeTK2pkNi5uyVe0mt/wB3vS+o
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -72.30913573189487},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameStyle->Automatic,
      FrameTicks->{{{{-66.77496769682732, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "29"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-43.74911676688687, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "19"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-64.47238260383328, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-62.16979751083923, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-59.86721241784519, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-52.95945713886305, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-50.65687204586901, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-48.35428695287496, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-41.44653167389282, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-39.14394658089878, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-32.23619130191664, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}}, Automatic}, {Automatic, Automatic}},
      GridLines->{CompressedData["
1:eJwt0WFEHAAABeCrTJJMcpIkJ5Mkk2QmySTJJC1JkmwnSepkkiSTJJNkJkmS
ZCbJJOfMJJlJkpwkkyRJMpOZSWbWF/34vL/veaFXkRc9CYFAYJu7TCGVDILk
kEs+BRRTQhnlVFFNHfU000KYdrqJ0M8Aw4wwzgRTTDPPAksss0aUdTbYuu8Y
Z58jjjnngit+ccNfkox5QBoPySSLEHkUUkQpT6jgGTU8p4FGWmmjg056ec0g
Q4wyxiTvmGGWRT6wwidifGaTr+ywywGHnHDKJT/4zR/+8Z/kRN+QTgbZ5PCI
fB5TzFPKqKSKWupoopmXhOmimz76ecMwbxnnPVPMMc9HllhljS+s840t9ojz
nSPOOOcnV1xzQ0KSb0gljSCZ5BKigEJKKKWcCqqpoZ4GWmilnQ4i9DLAICOM
MsEk08ywwCLLrBAlxgabbLPDPgccc8IFl9wC+dxmLg==
        "], None},
      GridLinesStyle->Directive[
        GrayLevel[0.4, 0.5], 
        AbsoluteThickness[1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->All,
      ImageSize->600,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        TemplateBox[{"\"\[Alpha]=\"", "0", "\", part \"", 
          RowBox[{"{", 
            RowBox[{"\"x\"", ",", "\"y\""}], "}"}]}, "RowDefault"], 
        TraditionalForm],
      PlotRange->{{0, 119.}, {-71.09953515262197, 3.895700762297344}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, {{-66.77496769682732, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "29"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-43.74911676688687, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "19"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-20.72326583694641, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {2.302585092994046, 
          FormBox["10", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-64.47238260383328, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-62.16979751083923, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-59.86721241784519, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-52.95945713886305, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-50.65687204586901, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-48.35428695287496, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-41.44653167389282, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-39.14394658089878, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-32.23619130191664, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-16.11809565095832, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-9.210340371976182, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-6.907755278982137, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-4.605170185988091, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0., 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {4.605170185988092, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.009166666666666668], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9kwlM02cYh6tTB8EhIFO0BDwKBcRyCHJV+uMoV1GhQFsolemQSx1MEoTp
1k4Zpps4IYLhis5FPDAMJ27qGFY3r4mCdUpEhUzEkxkRjw1Rt4X3XZOmefr8
n+/9/v1/nb0iX7lyvEAgWPfv+7/PsdcTWWvP3QlrF1ib6AvoasJWGhy8iC2Q
Uefo7iOVEdsg5s/Jga/8fIjtUfLatWFFkpTYAfuuVSn7xPOIHeGScTGl0Ir9
LKRcTYq3O+1BPAd/7/5izfRqS4yxCPE5HoVtUhF5Vzhe2nEj02MKeTdYL5M/
8Y9zIe8BmXRYKN4bROyJhm82y1wr3IklsD85vk46xN4bwWbve6+93Ih9UHWr
+1lbVwCxL4afBU/KdeF+AbJM5RvbXlyXjbEf1j+/YHv6CO/PH0X7Cy1W2Twi
vxA1ksafs/xdyQdgT++Lk+63/YkDYTQpDlV38/6DcKVg6krzMT/iYNztPn1N
JOQ+BCaz/4avd3MvhXYgPNvKSkK8CMW+O+9NnmZPHIptU2Y4BFuKiWWY1r+u
Q3P8fWJgujq0oryCegPw/Eh4y8Z2/n3CUCtseHPuqS/5MIzujFKpvwskHw6z
5szt1UfZh2OepNiutYmfbwQE0zrfPtAvJB+BweZM++81/LwjsfWOIlK/iftI
rB+G3ZpGPi9yWAVJHAZCuZcjo9BoZ/QG+SiURszfl6lYRD4KNXqbS6fWso/G
hRvaztYh2o8hGtvMLtO7V4WTj4HUObnmkpDOsyEGn8TX3R93iOYJYlHu0zKu
OTuEfCzqZx6MrJjK9x+H6uMFNmebuY/D6rLrTU6JkeQV2N4r7OoPpHkGBewj
ipaO1MjJx+PpjE9frDnLPh5dx2w7m0fYL8ZvnxmfPSqg9QyL4T7ccbxLFEZ+
CYTjckqsRrhfAlRtER+Q8P0thee3RbNEubSeYSncdhyqlz+MIZ+ACzeTBzd+
GDXGSMByr50pcmMsXZ+Aa/qS0csvyZsS4CvqaNg8N476RARA/ePuKroeibCc
p5gj5fUMiagtixocf5/mmRLhNDBQuqyRvECJh4dDzQdGuFeiY4n3/ZytCuqV
aFleVnv3XWKTEuduuu26sotYkITiz6/+lbmYGEk4r809tvct90mQb9Ktq77B
fRK+HDC6hwZzn4wGUZ5yFl+PZDQ/PhBSacN9Mn5pPVO+yDue+mSke2zKDujn
PgXGzp+annuSRwrc7rztPdhGbEjBxW6Xrh9u8/wUiMX12syj3KvwcEg4PLiH
56swdOKB7a0+nq+Cw0eprrWl3KvQk15tGS3mXg3p6snRb/7fvxpeqryJrhu4
VyOwcfOvlX7cq5F71Ud/ypn2J9DgifPoRVkz9xrInfQZ2fN5/xq4vTP75TZP
7jUoLjrcY7Gf56cidEFebH4+96lIKJj4OOo9np+KUYvKnF1p3KfC/6WHl2wC
92kwts8vs3bgPg26wM4pjefpfBnScOVj89SDKmJTGkI+mKT//DKfPy2y8ia0
9+UTQ4vgLQGp4X9wr0Xl79X1khbutSjtrwyrLeE+Hbbljzot9Nyn45TKLiMk
i/t0FG+3fmUu5T4d3q9ni+fW0nkV6BDzVU/fzCA+vzrUCfJm3mzi/48O3q26
E71OxCYd0pzbM2Md40z/AEKGMfw=
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -61.92827989830564},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameStyle->Automatic,
      FrameTicks->{{{{-55.262042231857095`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "24"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-43.74911676688687, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "19"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-32.23619130191664, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "14"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-52.95945713886305, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-50.65687204586901, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-48.35428695287496, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-41.44653167389282, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-39.14394658089878, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}}, Automatic}, {Automatic, Automatic}},
      GridLines->{CompressedData["
1:eJwt0WFEHAAABeCrTJJMcpIkJ5Mkk2QmySTJJC1JkmwnSepkkiSTJJNkJkmS
ZCbJJOfMJJlJkpwkkyRJMpOZSWbWF/34vL/veaFXkRc9CYFAYJu7TCGVDILk
kEs+BRRTQhnlVFFNHfU000KYdrqJ0M8Aw4wwzgRTTDPPAksss0aUdTbYuu8Y
Z58jjjnngit+ccNfkox5QBoPySSLEHkUUkQpT6jgGTU8p4FGWmmjg056ec0g
Q4wyxiTvmGGWRT6wwidifGaTr+ywywGHnHDKJT/4zR/+8Z/kRN+QTgbZ5PCI
fB5TzFPKqKSKWupoopmXhOmimz76ecMwbxnnPVPMMc9HllhljS+s840t9ojz
nSPOOOcnV1xzQ0KSb0gljSCZ5BKigEJKKKWcCqqpoZ4GWmilnQ4i9DLAICOM
MsEk08ywwCLLrBAlxgabbLPDPgccc8IFl9wC+dxmLg==
        "], None},
      GridLinesStyle->Directive[
        GrayLevel[0.4, 0.5], 
        AbsoluteThickness[1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->All,
      ImageSize->600,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        TemplateBox[{"\"\[Alpha]=\"", 
          FractionBox["1", "137"], "\", part \"", 
          RowBox[{"{", 
            RowBox[{"\"x\"", ",", "\"y\""}], "}"}]}, "RowDefault"], 
        TraditionalForm],
      PlotRange->{{0, 119.}, {-60.8834548176427, 3.8957001834585423`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, {{-55.262042231857095`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "24"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-43.74911676688687, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "19"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-32.23619130191664, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "14"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-20.72326583694641, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-9.210340371976182, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {2.302585092994046, 
          FormBox["10", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-52.95945713886305, 
          FormBox[
           InterpretationBox[
            StyleBox[
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-50.65687204586901, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-48.35428695287496, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-41.44653167389282, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-39.14394658089878, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-16.11809565095832, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-6.907755278982137, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-4.605170185988091, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0., 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {4.605170185988092, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}},
      ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztXQt0VdWZDpAAIqLWWsf6wLbT6dtO7XQ6a3XWPDqPTls7tXVm+prOWvbh
0moIEAgkJORFQkJCQkIwCkqDPBSKBVGqCFVBEAFFXiIEEAgkJhAIYEKSe3Pv
N+fss8/Nuef+e5997r1JbpJz1/JI9v73v/f+9//aj3/vHzww7aHfpj4w7eFf
P3DXd6Y+MPmhh3+dfte/p03VkkaNSEoa+dOkpBH5dyXp/0ZSkvnp/f1c/yQl
fZX9bzQQ7MLZV5dgTlYWsrML8cTmBnQGcR/LHqV9unB62Uz87qFHkkYiNTU1
aaz2nYL8dU3wyYqO0z49uLC1BIU6qJ5Gg/8nAx/Pshu31mHuLD07B+XP7MFF
v3OxnsvY/8cq5M7UsmfNRvmqXTjvExa7lxW7Aeg+i9UFJdh+MWCQhQYXpX/P
pF4YmhCpFCk1Mnwo/Oc2oTh3BQ59FECwox5r8wux4UPfj1h2MvytW1GVPR+b
GrqgtWykvJRoFATgJjl9jetQkL8W9R1aFf4L2F07G5W7L8FHF/sBK3adTidc
2V+D7LJX0eTTi7ZiV202Sre2oosumiQaCkELRenGUIyNROOKXHwo7jaRIYCL
O0qQt6JBG1X950PTukIUbzkPjSfvs3S748RGVM4qxdqDlzVSw6ko7/YELbkJ
6wumYkr6NEybNg3pk36Hh1OnoWDVKTSLy4eKa3+0vFSI2Ssb0M2rvbS7FLl1
H6gV96HxuQIUbT6nJ7OeXH6nFNmPH0OTuPj3WfEbbcQWdbgF5yWE+C6JC1ER
dYR9+HjvXjF7F1b8R6bu0GrytbyJpXl5qNtzUQOVFrPSrunlClS81KiR3ipe
isW7cErTE5NyVuNAmx+Bzga8WpmF8h0tOKNSPIj2Q4uRXfwCjnVoTNx5Glsq
slG9+5ysOD1yogYfx0kxKj5yo6y4kkZGR1Ni4JrWadCbwqFznz6tQ9/PwMZp
imknarNL8UrLVRl4SDv5z+G16jJsON2BVstgSYr2iqk2xA2r8rQyG7F8fi6y
sgpQ/ce9mmmSlg9VHexA/R8KkKZJdsakVGTV7cOVgLxq0VDRZbShkuCihirZ
HRUjhiiAtjdDub0tMwb4hxY27Wo+hH0fdCDAwRrXanT8UxPOi4ubdqjn4pt4
fN4a7H55Lh8uaa29o6U1fbvGXctNsCD8l8+h9apPVtwcrZ4LW1GWW4eDVzS5
unqMGYf1TV2yopzCN2l29gJ2LF2Gl/cdwsr8XtVIl22WESHpO1KcURHWVJG9
zsZmzNXs4OF23Q4e1bo6By+YboNh2a7WP4mcuZtwpks36Oexo2oWyne1ab4A
WTTJGPprWa8vv7ME2ZlTkBtyO+gyofHWrHVZ9iK82epH0NeM10qzUft+h6ic
WczfvBGFuc/g2NWg5qmdxvP5s7GqoVtUzPAVPsZaeLXhTawsSsekyUUW14Ms
Jkr/Dyk61wS0uYMIduPDbXUomZ2jebaFWLxF05jBXuMVuIJD66qRl52tZeeg
bMVb3PEli4X8wcBHOFiXjbyQV06Ch9xrjXcuvL0aFXm5yNVqmrfK9MrlxQKa
2tu4CAXZs5Gbk4eqdYc0tScsZrqCwavH8VzxPItXToKL0r8nQuOOVHwcEPr9
PH4Jf2X89eCDD7LP1/TPKEuWpqpZnvFj6taeNpKnbdiwIZR2PQFnpKVY4cy6
uQnwcHg4hhKOcDhDTpKtcPpvVBQi93Ei7SYPblDCUWmjiDTuL6myyE/6Ie2n
fdN0yqB8ikgbLYRTF14PbyLhpRTmGLvCDMHodUoUZ2+BrxC5Ep6MuuB1cSaA
B5fYcB4DenADCqfMgF/QPykOnmYvuMd2Hpyn9zy4RIXzGNCDG1C4PmXAYvbP
ZPQEgthz+EP2XyAQrNOTnVaLPEaMP9x4nuPvCWD6wtfwf/kb2X+Zj23Vx4ha
60uU5qvwaRHPePNgo9k1beqtf0fh7fc/DAH/nkDgxMom7h0HInHrbB0lbo/L
+5bLpy54NcTlOscPAS43larfH2DcqHO71tWnCXgnpp7JUdn0cwqdfLcr6Efd
tccThPjBcfUe0k9cvTOI0Gk92gR8XLEJDpZklDybwtiPomXQYJzqUdVPckwR
4vMr9s8Izr+GTjYXlSOtU4rVOrGfBqMhiLRcd8hqjA31w0QvR8jpJTjxKaTX
A3xgKK7o9gdG6t3RygUMVmXADuxq7tFEWuUURhsrnbbvPxvquNVim7uZNpqO
o5PHyhs01qFB1p8GQzbIcSSuVTwlapzgvJVA52lbdbibeRolXJPmb7FzQNim
Hy+j/aV/R4cJo6mpNRfFVNQ6Q3X5eizKezRmLnqd8mIMzk+h+FArqgFEIU2j
hS0PVxWjLWiETRNm95vyt84wacGRHqAlBYd9f8b+KVTwVtkfLdDCItkfaQ5r
uHNn0drJ2HWoyZontiujseu9JidNKxvoFKJH1KRnjKDVhjjodY0O8aENRuA9
/pqgvVQHyg/+CofyPtlQOpidlAgOf3T+Fj5KoyO0PSHqpk82RpHMsuFY8fJ7
jtrpjZAFTGacIegwIbMO7p6DUfyVeDB1S+TqeK9x5HZMiG6dOLl0Bh6ZkovC
oiIU6f+VL8Oxjl49jMAFbCubh9dbewy9wPbhTZcpESxMosM5ePOmE+a07ELp
ts5uv85vHH6cVSzYz2yGTWuMcmglwcJjJNmaYIy1aExr9jQtWwMx2jfeOpWS
tY+lCYywSWEnconhkrH7cJj0UuToo7kTm/m5OuMdmg617caT+RV4sZ4drzfN
VoR4Umr6h0JaqJvW0bwdtqG6iU429YMlWatRy9BAbSo/2eLfW7G8YZlwiNwn
QpxUrcFoIRztlyab4xBu6v6HoHmYpb1O/fC4rrXfqkVRXp5WNk/73oC8gnKs
OdNlGZ8gfOd3Y0XxHCzbeQ56SCN8zdhYno/isnKUl5UgJy0N2fOX472PgilE
68I4IrL3DqY3hdFcc4KsREgSzPbuYskylRVuyUcKW0WPnYJsO1jmsWYLbdmp
FlfELiGc8ajlof8Sc8Mt7H/XaKJ9HC/Oz8Pit9rQo1nj1h1PYdGms+jqkQuy
N+eMzuISg27wRCRbihb9rLZPcTnOWMSJUItWS8MbFxI7UxBMGap9+gXRtEhF
T5EThWvsEspaa4LWLHsB2/aZWjd8xYVPakmNfFsch89iK42VA22mEvBp0mE0
NdD2Firzl+GUrhID7Ti8pgprDjZgq5MJvI8Y8/A5FjXXj8XNoLy3CA35l7x4
pJ1MoVgtSTR16tVX4dWOk7OuCJ0hCRYPbPv+s6SdsLOTwGn7PjEsXC8aS+aG
W3RxRxmK1p9lcePBjw6gNn8xjnca8MHuRmyuqUDFrLn6SAsH+n6VHsfiHtAG
UmAQzL0aVfawsqcmipQjNs4VSmfW4itkYQaZWkUjiHmveFhv5lQMdjVgy5Nl
KF9QjYrSCqzafUGfgpqN073axdnFntWLA5zp+VIrWZQPI11OcViedGa/iUQL
VYUvRd6E8UI0yXabZTrA1MzHthDIBGQs0RODII4bt9xem6PQF3vX9yvSj9Im
Wg/H0cliDyMc62flozKWxn6dSin1HR9znfWXHI0d3jZISUpLkcLsr+vZTket
LEMj7OYn5dmfp2l3G518jRyZyPvV12KkuyXUVrfbXdGICdg9BMW8gwxxgRNI
3M0EqH1WoLv6GuinY2iRAKU50bA72uItGdkalGzb13n/0E4om3KgCBWNWj7J
M1wvpoyhFlNsE8NRum9P2nMF39u6g9RtyLqdYBOJXjkdfDrJSUUpoND+2Bhy
zyp8nj06pHFIx3c03jrUFOGs2lxtuw5Lq/yz1DG5w6HDLDDbdDESQcw9OBrO
MBXqyzhig6Z0smD7gbNcaA3ls3JTaMuQ/fdLZv0i3aaPKXRHRct8g/0zQomt
EfYq9m1zucOl75oejqjz0bLNdoeEk0B47sqN6vkbTj+Bw7aal3OtitXmQAIX
qldbG1Prru4eKx15/x1PPXkuUhxOFYUreyoU3Y5PtAR4+wD17QaeI129li4t
h/f+OruLRm632tKSPhElhVVU2d/wDKcZ5wQLJQi5qaEp8beK2FnLlSZ3VqVD
jMgNiqR6W47GUwOu4QwmjeAAag3GWpxzRsi2WbkinpsZfQF3He+yWhiBmWzT
AHYCqQjtl+kaBMe1HZZ9tliy3S/L3Ei00clx+JIcpcMen0l1G6P9mdcWy8lx
6tooT+ylcObszEnhild/k+0e/1iimsFChlhOy6s4SCra4UvCtqgfwrTCyWyl
7Qiufb3E6sjfQLQ3YrLPkr8oqdDh/JuW/S7vnHguOoZc6pBtQY93aLunGITG
kVwwV3KZE6k37iYM6ht/oQW0FOpAZpJdFaqI/2c4hW1ewG108m6ORkVxiczm
tURTnHyAT3MSCoz8rfLsXZZsycao0ml/pyt4PGFGkupO8ycsZcPDMSKs/GcS
vMuGYyvYoRVyHrXlEY0NN3eDnDj4FkW4/XRvJhD1u5FcggK3yrMb3dXoCV/k
7h4fO5PQJqiCRU30nsbrcAb7efcMeXB9AWdnQNvt0V/m4B7beXAxwyktibOf
p+08uL6A88ytBzegcH3KgH/N/hmxKNLlDpXHkuE75cSCzbWKaBK9m7E5iHdz
SKdllI/0r5Lt/yrPcJr/dxAIPI6Wwjmc/aA42h6YzOMQYjnamyhwKmrY1Ka2
lYiPWQhJqIZTBDonvf05G6G53r6JThbfKxMudh+4a4knJI7xuDfKs1XX6Scm
OBVcCpDxP+Vb+4RX/phM6cTX1wvhXEWjnSTaMULeI8G9eo49cmKI6xXhBNFX
p5164u5eur8g0A1l5WAe9bKpWaejXmaaw/79jfLsRCJEn+oHd1e8UTzIvg4a
WnA7guAumXNELVLBkV9m5tBoZ83GvuxwsNVbNg6rRnMdl3E6YRx7M3bu/Hdw
mW/HB9rfx/pF87GwthY1i1ZhZ4tPfzA+xWjrEL+EyzzgrXSIN4H7McBSbZgE
uLxzit8xYGfJILrObsXmA5fRw8q+iorKrWjtAXXNkGG+pVcDEoqWlb2LQBcm
8LHcqTTKeqdS6G5eu+zBfxH71j+udbAWTz2zQSNcFfbT9ykFLD0idJ1gI5WV
/RSBjnf0FrJhAVzavQD5dftwSaNV16mNyE8vxNbWHqphQ9kbUD0BStHAji/R
4j8GWGXcbBLYfxmH9h5Ha6OVA7vRsLIQVUc6DETdZ/BsQRl2XwqIRUP1QIlQ
hBjQOAL/CFuLA+2o37QEhXnZyJjXKzNtO+ejYOVRdGh/97S+gYqSjWj2k1rL
KszCcyaKLoIknsNwZvXVnCA66p9DacXeXtXjO4edK+ejrHIhqqrq8JqmqrSs
pOEm4oKznDc4FB/MsR39vXZ2By8pM8YSuRPivZP9k7Z5Ls9tDmUO9+A4XAKc
OBjyUf/mnNvmjw+VM/D9rTqv5SVlLsvtRGEJsxrbZREjZAa7Kfkc1OMhw1S7
OsQQmn6EwiVigzE2rB/loZ2nOTGoNZpb5G24FBmzarWle9ohcboPZpiKDDFC
f6GIJtG72Y+yYep0ivHYMQrvLW4Prt+cFvZT8oR7wV0eLffYbnjBeUd1BxCu
d+U6xbpyzX4aTFKihzv2NyN+nJeUTdpuIgo78alRr+AOFMWZ2/UGouEbFuzi
MG/4Gm/EfM1j+xA4+6q+ZWB9LEA0QXMpHvXsGyEZ5gg5zduu5cUp9/njRHVD
zC6Yl+i7eHjESbIUDxUnEhUSUKyO8jQniTJmzI63clnZmqouwj0/woFi3FgV
XM/Byg6Da6ms4hXDS6uq58Y+RpR1WKRMdAr2o8iZlsQmM+aCt5MkmGtXSr6Y
y5uXunh/pHf/OzcxmqoHo9ipwrm43t5h4TLRe9o/G6iCU7csz6W2R+jnzc49
uBinJ+znLQ/FDjeRfeP2ItFQgROHxl7P4WXrQeZlV24YU/VCaPa92V0FQ5mB
7+Rp0Rz6T/S+9bdWdZj0MxjGekq+g+BiOpZHBdQMUwb24KTMGocYVPNOQWrJ
4icE/Ah5zS5iRffx3smMheQ18OEc4xnPaI3B0N+EELPYQznfYl/hzQZK6xmS
F9HjFby5k9ND4S0BkSGUyG2scZ2jrCFcSeZxWwRsr70P2oBO1Vt6BVHxTuEc
A929RIaLV5ynIouSYuesBoye0BabPdVjdUD7Jb7T14yN5fkoLitHeVkJctLS
kD1/Od6j4zut6oXQHw53ijMc3yTQcvViTC+vscV5+tG64yks2nQWXT3yUaBM
pv1GIE7xWwnQRGFla7PJK4fFxcOv/A5XOsMp4EsVLiLU81pBqCdYQOXhNVVY
c7ABWyVMeBOvSCADO1i28HiMkh/xDaLaEdZepFDhnyGrE+xuxOaaClTMmqv3
QtwJZ0O2Td7Z8ZZskbsh0QfmNSe2yFBTKfe07cbi7GJX6kD1wqNPEGUThWn1
v8TBt4LXfITXlN+pWGMii3G84RzWlKwiTrD1dl5ESZa/Q+CXLBgZB30i7MIO
eYtY2e+6q2kwzq0Fu3peXF8ib1p9Qf9EhH4M+RhUD841sxnvoNGzp/8l4CXs
t4fXL5up/MIdysGoMFWPa5muo43ylHwmUvcSGc6B159j3wiKi89P0W96h543
C3/+neX/iKhWwt9reTcUHgyTvAimtA18n7uWUZIneBp2oJbY4vlGt/6X4DyY
6nI0tbiaKIKR6HAOgns7L+RwBZqNLws4JqeBu8uCXeTo/5holUR6zDBz1y8m
hquUPHnLzEcRqU3z+901mBJ3N8+/il5RHKjrE6N8uLuvmjPk4ZwOeVglOIa3
LV9hX9pb/WeiWivHs9nP7RyBuwcQN1uyRZ7tPzlUryBwQ4BpB/n7mAlo+5p4
mtLK1z8QCCRM2MQbJLN8ceDrRKZ+L9ywe3Qy3nB9taz1PfallX4/vm5h3Xgh
jMD1imjc7lYOsk3WoQDnwMiGoxH1gyzf5XXKnIl5+sfJp/onOSJVn8rcw1Ba
RZhHtKOP5E28uuHqgY8JitW5bdZg3+0cCnAOgmq6LlE+qHIvr1PmHZUT1UZM
Ov5Rjui/6eoZsvkO+OMob1Eej3FbTYItIg4nOAdxWc4LyQxTIVFOwo/LeZqS
bcl3hzuRZhripbJwTRPLAfQh/A5fvOEcGP1+GyW5CnLQ99+2ZIvE41tEbRIW
/rEc5b28nTaN/C8ck5JQsaNgfXntU7x3YfqDX4bTE33xhnOQrR8rkraKI5c5
VzFIE4GyhmXTbtbfu6spFnkZAou8HhwtCszZb2AJ9GrVv3EEimz2PI3qK7wx
MkP0r+5qSiRfynrogejeSAU0oheXVJ/XGe7x36pwDrZgPU9zcy+g8DVHxR2Q
bxPtkDD+JPaNELF/UKzSjG9Su6dNbu0SUGQdbg8TTOVVTZnD6SYnQZc9xHQr
b5lpZGuWvSAysoksX/0KZ50kGEehlAPpqasyU3lajMJvXA8e4S5dZyklEqjf
EK0aIe+fIFxf1r94qYi/pzvKMn/r1BN3Yf/UHav9rU6IQVNdREmkmeRwh7N4
ADQnym8FoDjRNMk2QTDvNI3ivddniFqk4iO/I4BqdIalGS4faX1W3DqD2tdF
czlAkhmilhCvPHsXdAw+OItoG1n6ILoK/zdYUHe6hC87k6+OZvA0JYf/jwSC
MOGOJdh/nDXY3/ipP9xs1Qki1bSeKMdb/8kQ9YSvMg/Ym61Rvp3aV83x4KTi
28tJwteVSU5C6BcRT2hlTsHzxw4oJYfAbjM7RL9UPNweKvbgXK88/Z596UXY
UgJess6ylNfvLvaElc1zV1Mi8bA4iNFVAMs4G2rvQaEBE4mlPC2WaB6HtRoG
lErUrSheMQSGqK6ysO8jDk1MuDh5aWSi0rsr3otGAyV3xvQ+qgVMl6L0Cl0T
y3xU//TlMRAPbvDBOXCu4HEhhH43EoUk/OnwWFAv3hvc4aXYNpY3cxJleDy4
2OAc2Nu8eF9plYn9JhBYFPldpOLZLw787uItm0QZHg8uNri4hdvF90Fm0dmb
221wiURKDy4KOCdvcgIHFZh743YO2ruoJtBJWNDUy07GPlfeIgZU5a5qK/fL
DqTE+6JY81Y+G/WcbuXz7rJNaJ1tFRnCY0izZAtvhlV0aCqJ6iV8bkQ3R/gX
kzloPF7+jUHy+mKo9L/M86KRFI1YQfFuhB1wOAfhKuSFZDy4nCgn4cE57Bsh
Fd/kyZRpe9hdDYm+JOO9LztQ7GygiGCyJzio0kI4OyEZ4cex+cBE3iZ3214L
eO1KJuhBolcuRUH8EJ7DNlVKxKqThpbPovt26CfaKMfDOB3W8hOZURMdzkGQ
7uJpsWyMzeEVR3H8z6VBcLisUHW/zLzz3Ca/j/LiStojzV3LKfkVPPvnIAwq
IUD6X2PkoyIIX4j3zebeo5MJKfZfZN8I1jOvbYkxbOFnlmyRszmFaJVEfsz4
INXbTKK8nuinNF1Y5lR3LY7FebXKrlDPRXH3kWDiNvDs6sHRcA5ibITUCi9t
jvHyKJb/LlGthOt/wNOivHXoHp5MTR6Zc9+Xu/gOj/peq4jGWh2X0CSZ3+0d
P+l/OWKzPINXI3jwFp5s48EJdLLJcEpO4+McWFGYHuJ9cTcNTZaXcrVQ6rLB
0UpftNtm4Sv6rg5nmm6007hZA4S4YghJs30v25Pm/oFzsIrf4oUEAvA5XsTd
lDclgrm08qHpsFVwDDtB+5BLiOZK5Mm8A8aJSe/gVboLDxT7ifTTHzI34Q/u
OqaiKHqVwmjquLTebIr81p28cPM7jjK/Ru9czcAFCxre2zWJAxcRmRtTNP89
vI7o3sA2l0CchFimN/5EtGqEvH8uovnvUWyhwGmfyIsreRRb9Y81mKq/Yvhd
HAL37PzgguuDOHyryBMy/XmWTcvqWwS6EfLWuQ24/7qk+g5x9QbdoouoN2NM
Ih4u77cweg8uceBiD483V1Mi+MnGugj9JCc54x7r7u4Re6U2fjJESPL9earv
iX7+wYPrM6kyZjEpyo/EI/STsKD5/pPCe+1K+O7gWdG8m57I4+DBRQHntDKP
0C/qh51dFvTYbnjBxS0mJOqCCRc77cENB7bz9N6whlNmwC/pHyc7Xc2+9Bb8
YwR8AjKidy57wOEceNK4hijqY1rsu5DAK2HGEt7OGB+Mi6bq/pAD8S6DqzM/
dylWl8i8l+hwDrJRwtOiPELFMp0UNXNU5/LWyY5pLnVANACcPtHWb+968wGF
c+Bmc1dTeI/KnUQhCYep3MLFfmwFzcnZUb05a+IAENaD6x84BwY2WUT9ppTb
CCyKHC29KeUOd3jt5wm4nvSezBu6cN5ShAc3oHBxY8D4XsuT6GTz4KKA8zac
PLghou08BvTgPAb04AYdHBlX9wuWQC/5sMOxKQ6W+xe8Ltkazx6iXB8xpuoB
fnvsufdGfcLBOSjMX/A01YgoQWwhy99K4JcwqJXnJbFaSjtjr7urOhbZmMi+
EYtM5kae98b84IFzkI3f8EKyZcptRDnOeMZ96sphWMkEJuMhUHrD6w33NQsC
pKiaPbdmeMFZRMHgHnfhaaaydu1S05XJo5fklUUc+RFVIQtBYkW9OJ9hCGcR
BONuqOiCx6IWCKNS18FFlA5Xqs+0FYqBRKq2YiL7RswMvCMLQwPOwXO6mxeS
TWe7iHISl/1unqY0HbjqDjfFwKrX+HlT4CED54Kp3V9Rx3C0EWglfPlV9nVx
2RkhChfcVanq96seHp0Yx/Hx4PoQzmlv8ZscVDYZdsnef8e+9Oz2kgMqL+5o
GMJ5mz8e3IDCeQzowQ0oXHwD33rBXbLdWCKNuqXdXddTrGmh7sZ+T7qHt2/x
hqcZfDAm/DQjoMrCFGv9pB/SfkqkUYt4LqWCunyOut/Kg0t8OCotDixCKc7r
CTgjTV2IPRwejsGNIzbDAgNS+3zN4gf1lvu5LMF4CnAC/M0bMXf+O7jMo5IC
Hcfx0pJyLFhYjYp5VVj99gW+gehHy0vFKN12AXwDBV93xNeDi9trUfPnFoYj
2H4Qi/MW4uBHRmUdRxYhf8kJdArxjbLi48Qdg0DbO3gsdyEOcDyBy2+jsmAF
TnVxl88JkUHpcXpJ7H+2GrMzCvDMwSuhjiF4BftrC/DU4XaY0Vr3WHAa98mP
12hyGYf2HkdrYzgRNQR8zSiAS3ufQOHSY/qSvakIfY0bMLd0E5p9vL0k7kA7
6jctQWFeNjLmmbiDuLK/BnNWntBPVKDzxHIU1hxCexDmMj2CnTjxXCkWvNoC
H2/M1yzoje2wGxmqjvrnUFqxN9TsoK8ZbzxdgQU1NaiqfBpvNPvYuJ/b8hhK
iopQpP9XkInUKWXY1RYITc78LZuQl1GOo1d7H3KF70O8UjUTqVPLcbA9aL7P
1H12DfImTUbukzvQ6scoExrteK98KlJnVmNzs++MpcFmnAgCV3Bo3UYcaQ8k
jRFWPArdDauQM3sNTnQEk8YTZQ03LwXB7la0nD2IdYVZWLT/ij7OSaHmBDXa
r8rB7GfPoBtosDTHnEh0Hn8ate9c1lkm5DlSzek8Vo3M4h24GOidzEaWTTaG
dl8lssp3oS1gIYzGQbvmIrP6mC4m1pYYINcwkPajz2NBVhp+92g68ha9gEON
e/FUVipSM2vw2jk/vwNAH5UmrM+ZgoJXz2uyCaPyW4yGp8/G6royzEhLxZRZ
FXhmZzO6gzobHsWG6hxMnTQFGVlz8Ni67dheMQN5G5vRqclUbsYC1F812b4d
R54twtRHJmOupih6LMS5Wl+JmcVv6Z3jdNbIEbyKY89quIteRhPj1oBGhMWY
Ma0S21oNtWNrsoVgGmNuykfqpLn6nm4vwTQ67i1FZsVRXeRIgvlb8Ke8SchY
vB0fNDfi6LYVmJOZjrScP+Bw4xX4g70+S9B/BRdbW9Ha2qr9xb9t7egxRCbp
ZovYNR7ah8Mt3TonGY38hEHY1FTkrz2Iiz4/Lh3ZgJJpOVh9qh3ntxRgSs46
nOhkVMYHW6qR/tBklB/pYMoqjLBdp7EsawZq9zbjii9oZZrL72idrXxfvyQ2
mauOYOcJrJk9DaVbWtDd/h7qMqejasdFnXx8mIjGpmh0acaLBRmYUzgDc19v
ZdQ23b+r9QuRVbKHac9ImmpeX+cHWDxjBpac5Ndt6qPzajGmZC7H6S6YaLpO
LUXOlDSkpaVpfxnf9II/otFQVXw35WZGt/yMipCG1/DjxNJMZNZ9gOY3S5Ge
tRIHLvoN5azRZnnmNFRpxIqk20ksyczBmrO+kODrRPO1HsGf5mVj4Z5LTArN
6+H1vM4P1iJ3ejGWL8pERvVOXOzBeF7U17QOuZmLsX9fLbIKt+C8v1dnBC7t
waLsUmw80gpfEKcpImkEfiE3AwssZiVwaTdKpmZi5cmuL1k6X5jD6NZLy1fy
Mb1M0/S+89izdqFGnMmYmpmPsppaFE/ROn/M7Hxlb+c77Z1PNghZm4G0wnU4
2dnLSMEOHF2SgYcnlWDbhZ7xIXJ048zqHGQuPoqO9vdRm1mAl1r8vWqyC6df
KMLk6YtwvJPosq6cfDi7Ngczaw8gNJb6oGQ8gvTqd3FFKmspVlkzKOH3a75T
R0eHrkY7TcfBjIzmjDNjAd5rNwtp9es9ePIkOv3taD13WZPvIPxX2/Bh/XY8
kTEd1cc6Ddqlz8Wey4EI2o0xuxv4CIeWZSP/+SbdtKZwpgi07cKijCnISU9H
yaYP9SzeHK1g1ymsmDUTS7QxCeo0XpyFvA0GTMgb+PB5FGTX4dCVQJhoJXOu
CVx5F09mzkDN5mO45O9Bu2a1C2Y/gQXZc7HlvN9EEylaKVbRYr/XX39do57h
R86bN4+kXl5qGkpePs0u1e259C7qZuVg5YlO+FpeRuG0Qrx4ol0TGU1MGv6M
0vQsrGjoMqiXOhmlLx/F+YvncPHKiRD1zBlhx/sVyCw7qPsqIUdOox121kxH
xuN7cf6URob0QmzQ8AVhxtCP13ycOmTOXIJjnKs7jz+FrNznLP0yFP6MMuYH
RVLwGgbia9mDtTWFmDF5EiZnlmPNgVacXjsb2cvqcVVr0hcYrGEKC7OqsOap
chQVF6Mwfx6WbT1j3DGsHxl681ksyJuOKZMexaNTslGx+h209YCRoCC7Fmtr
8zVTOQkPPjQJjzz0EFKnzUatptGDFlPYeawKmSW7cSlkCnUiab7yjmpMm16D
3W0BJnpnNxYhPXetbiGMU3qGxaxfMgMznzoecps1EqEuSzMqZ7p5QgCX95Qg
c0G9bgLDmMq8DMjqDX+Wp1l53hw1natmzV6r64rQkyR6G06tz0N23Sn9kIsy
+u6zWFOQZ0GfrCmQBrxYmYm09Pm6lxi6Ild3B+ena+5gJTZyfnCqxlyNCHRd
wPkuJsUG8ASHgizjmxagO81WRHr3EuBIdz0SeKJJQcL5tsKxH5+tJY34f2wV
GOU=\
\>"]]},
    {
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.009166666666666668], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw9kwlM02cYh4tD4yYqHpGKHIIXIHKJAxTKTygFhUIPaOmlWOwERKuDSb2B
jCkOrSgoLNhsyrSLzmMMFeakYlC2uFncREeVoTJR0CngQcRjW/jeNWma3/95
n/d9v++femj1Et0wDoeT9+/3v9+hz9PIgoiWZXYpEgt7gDTXnxw+5UpZHgkv
r8EHf7kTd4RfxcEFlWdELE+Es7XfR3nF2jCUuSgN3VXYGUvcBdk2fyv3EOWp
aOXtbbO1UfZEc8zPjSYB5el4cmXWkYZTlGei+5e793Y8T2LZC7xn3s5rXIn7
oDPA2JPQTNwXCBpdEX4/kWU/fF1rVao6hmMoB+Dqg5zdhc+IB8K98duuPVnk
B+FJUCA3nE95Loy6TUf3llEORsZ2zfH+PZTn4VVVeaXVRP0+hOufxi15LrRf
CNb0FATb9FQfivbs0wWKFMphsM+74Xd+Q1/kUJ4P+5e5Vb+voX4LILRpl5fX
Ug6HJP3SQ10d5QgYBDe9JZ2UebDcv1F+zJ/6R+Kk19r+hj7igNdWhznmFYzn
A5PfrAtJmE31C7FkY3jHCzWrz18Ic1rtwO1JToxH4ZbPhFfmbiHjURCPvbM5
u41lTjQcJ059P20E+dFQrbTdqm+m+XyY78xwHp1BnI97LXxB0XjiMehtqvet
+554DI5bpi056kRcAHzSfa32Gs0XoOuMqq9NMIfxWCw1NG3W25Efi9PeDh+0
/P++46Codu6QHyYeh1OXQtfdP0v7L8LKm7qvDO+o/yI8Tud+s19FfDGqC92D
WuuJL8aJKd5pj0YRj8cPYneXiYXE43GdU2PJuRrKeAIeF5YMhGiJJyDKSRuw
cx7tJ4T0nslx1FJ6P0LUlDXKNGrqn4hdlrmfSY8lMJ6IxJaR0aJfWeYkYXyI
p6zZjfonQZFjzozWExdhsOd1/ehNLEOE+B/TiwrSoli9CMJlZ4pvH2fcIkLx
rFvaKS/IF6PpqKmxxIn1hxg7J1zgBfrRPDGez8gRHXRl57GIwdPNypzfRr4E
0gvLP2pfS74EB0+EaUtz6H1IkGbo5ovDaL4EsqUlmz9+Hct8KcY8RYFTMe0v
xbR3SS36fXQfUvRXXn4XO0i+FFnKXEXMebq/ZNz98nT7yAaan4yKA8L9oTry
k+GqePi2/Qvyk1GeWjfunD35Kch9YccxrqL5KdgWVNohW09+CoqDinVXGslP
wcCF1Wvt79L5ZajslegzrpMvQ9d+bs7kOXR/MojP+qzvsJIvw035yxFhv5Ev
R9H2vfGTdpAvR6+xZN/qavLl+PsAZ0S2hHw5IoPfrHuvLp75qdCvMg9/dJL8
VERsmT3zOzntn4rI8q5zES9ZvSUV6bxD493aab4CmZ6mYReTyFdgeIAxUEP/
z3wF+PYVfWUXyVdg3NhXHgMG8pUQV1/k7dxKvhKGw3F5ug2sPl+JbfOyNnCP
0P5KdJ93da+y0f4qOESaWibrWIYKG/13r2jV0v4q8NJzV3pksPuwqNDje3h5
pgv5aiT3VrltciNfjbKSQSvnc/LVWHXIdLnJjnw1/uDebu28TPtr4F+zKykr
mvbX4KTeFvw2hvbXoH+PtGi6is6vAdegG7M4LN7yDyafP0Q=
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -82.12546678902102},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameStyle->Automatic,
      FrameTicks->{{{{-75.9853080688035, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "33"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-52.95945713886305, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-73.68272297580947, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-71.38013788281542, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-69.07755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-66.77496769682732, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-64.47238260383328, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-62.16979751083923, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-59.86721241784519, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-50.65687204586901, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-48.35428695287496, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-43.74911676688687, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-41.44653167389282, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-39.14394658089878, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-32.23619130191664, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}}, Automatic}, {Automatic, Automatic}},
      GridLines->{CompressedData["
1:eJwNzTEoBFAAANDPdckgySDJcEkGXTJIMkgyXJIiySChS5eQJIMkgySDJIOk
GyQZLukGXTJIMkgySDJIMkgyyGAQb3jziw1Pdk/khRCSRCmmnCriNNJKB70M
kmKaeZZZZ5s9DslxzjX3PPPON38UCkuppIZ6mmmni35GGGeWRVbZJM0BWU65
5JZHXvnkh0h+CEWUEaOWBlpI0MMAo0wxxxJrbLFLhmPOuOKOJ9744peCSAgl
VFBNHU200UkfQ4wxwwIrbLDDPkeccMEND7zwwT/krDTr
        "], None},
      GridLinesStyle->Directive[
        GrayLevel[0.4, 0.5], 
        AbsoluteThickness[1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->All,
      ImageSize->600,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        TemplateBox[{"\"\[Alpha]=\"", "0", "\", part \"", 
          RowBox[{"{", "\"z\"", "}"}]}, "RowDefault"], TraditionalForm],
      PlotRange->{{0, 119.}, {-80.77848240752303, 2.734549245352087}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, {{-75.9853080688035, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "33"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-52.95945713886305, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-6.907755278982137, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-73.68272297580947, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-71.38013788281542, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-69.07755278982137, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-66.77496769682732, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-64.47238260383328, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-62.16979751083923, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-59.86721241784519, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-50.65687204586901, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-48.35428695287496, 
          FormBox[
           InterpretationBox[
            StyleBox[
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-43.74911676688687, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-41.44653167389282, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-39.14394658089878, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-32.23619130191664, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-20.72326583694641, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-16.11809565095832, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-9.210340371976182, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-4.605170185988091, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0., 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {2.302585092994046, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {4.605170185988092, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}}], 
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.009166666666666668], AbsoluteThickness[1.6], 
         PointBox[CompressedData["
1:eJw1kglQFGQYhhdSIxxBSFkUj0QBD1xg45D7FViWY0GuPVk0EQxP1DEDxThU
YJTBg8CrRSfCAkRFbWLUZKlQUUtSsUk3PIBCRgQXFcXEaPi+ndnZeff5n/9/
/2NGcnpcqqlAIPh8+Pv/78inL/BxrO36iD7o6Q/Y5IUfbGwOpWyGovcvZSzZ
wHw8zMc1aHV+bpQnwCf5tln69ZaGkWyLTb432guPzyM+BfXR78ZfGetH+SOM
ObxnSnpbMGV7VJhZuxZgAeVZEIcVelfcm0vZEWmp1z37P/GiPBtrvjr6LnJo
IeW5iF312n2gx5uyM5wm7Z1797QjZRHUkyx61Q9GYyS7wr6tu6jk0mzibqj9
Y0aHxIN9MZq+6JhpspLn/xha/7rM6h89KLtj+j3x1Z5mJ8oeMPxu9V5bIHNP
rOoKD7g4lX0vaIbCFiw1elJegGnBmqYuEffzhmPxQFzBZmPgSPZBa4bukVTi
QNwXh285r8jdw74fLN2vZlSLeH5/NGf45FYeYB6AfHFGwL4B3l8g3vb1p98v
Yw7cMm3cOLmX7jMHyILr9zubef8LUXp/Y6+FWER8IWqWpN4eKxQSD0Kpiddj
yw9diAfBqua7wLSHPsSDEZN/RKb0ovvNCcbJA7ribJ0v8RCcGbivW73PnXgI
tru8eXjNI4C4BI4pIdlH2tmXwFK1Q+gk5PcXCl34K/NRv9J+ckIhmbirZ610
PnEpDE0T/3o2hd5LjhR+vWpZ3Vn2w7B/lqzKvCKUeBg6nYvLO1/xeYbDumvl
iyxRIPFwBFijQ23P7zUCRYNfqp4kS4lHYPf8yRZrloYQj8Tlr+uF2S3sR6I1
pdERLfy+ZfBcbbjhtonPX4aIUzY7J0slxKNQmftINccsgvhwnuZv8dJIfQXR
SJ36W5z6Gz6faGQ+l+t3tTFfhKzapmPr/COJL0Kb3TL3jL4w4jGwtHc4mdlF
fRGD0qH98tOLg2h8DJyESy6UPKP96WNgvmXp8jF/Uh9BLKo1aR1zNFHkx6Jf
dqblJwP3jcUhO5O7Ww3sD49305rnFlEfQRzCrE6YlZSwH4f0OwcVARbR5MfB
bsdo3yMFNJ8+Dq2VZgHeb2g+QTxqjYttTV1oPsRD0t5QV6WTkR+PH+65/iwa
pKyPR/W1quyyfbSeIAG+l3f0vjxIHMM5fJ5Ck8x+ApbZVj9dUcF+AtKsdxfu
FbIvx7juxcaKQvblKJu6zWpPKfty9O2q9X1dy74cXtJs9QZT9hWwyXCeJr3K
vgKzB50SXNKI5yiQYvK0tfgJ+wqMvmmrPXeeskCJnl/crFfls6+EyczUzVll
7Cvxb77yn8zl7Ctx6s2xmrwGPn8V4gWHEzsPsa+CITN5lDSK+6vwaVZ9XmE3
jderUP42P9R4m9dXIzuiPjkqln01tlzYsu5MFa+vRueolO2fGdhX40FlXWm5
nH0NTqjPH1dmsa/BmLMuDsUF/F41WGs3WCNu5P4ajBs6GmUuYD8RurTTbefW
8/0nImjSWEFfOfdPxHSbpO4XjtRHn4grG5w1H0zn/Wvh2b/VWeHIvhZBj6Qi
673sazHh796Ll97y+lr4aVwmvO7k9ZNw51B73k0V908CuleXWsRw/ySIHIzr
DCrefxK+bUx9Xi+O1P8HlfE1EQ==
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, -64.6726678613616},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameStyle->Automatic,
      FrameTicks->{{{{-55.262042231857095`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "24"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-43.74911676688687, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "19"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-32.23619130191664, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "14"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-59.86721241784519, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-52.95945713886305, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-50.65687204586901, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-48.35428695287496, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-41.44653167389282, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-39.14394658089878, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
            AbsoluteThickness[0.1]}}}, Automatic}, {Automatic, Automatic}},
      GridLines->{CompressedData["
1:eJwNzTEoBFAAANDPdckgySDJcEkGXTJIMkgyXJIiySChS5eQJIMkgySDJIOk
GyQZLukGXTJIMkgySDJIMkgyyGAQb3jziw1Pdk/khRCSRCmmnCriNNJKB70M
kmKaeZZZZ5s9DslxzjX3PPPON38UCkuppIZ6mmmni35GGGeWRVbZJM0BWU65
5JZHXvnkh0h+CEWUEaOWBlpI0MMAo0wxxxJrbLFLhmPOuOKOJ9744peCSAgl
VFBNHU200UkfQ4wxwwIrbLDDPkeccMEND7zwwT/krDTr
        "], None},
      GridLinesStyle->Directive[
        GrayLevel[0.4, 0.5], 
        AbsoluteThickness[1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->All,
      ImageSize->600,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Log, Exp}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Log, Exp}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        TemplateBox[{"\"\[Alpha]=\"", 
          FractionBox["1", "137"], "\", part \"", 
          RowBox[{"{", "\"z\"", "}"}]}, "RowDefault"], TraditionalForm],
      PlotRange->{{0, 119.}, {-63.60271207729034, 2.7345465351274183`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, {{-55.262042231857095`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "24"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-43.74911676688687, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "19"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-32.23619130191664, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "14"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-20.72326583694641, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-9.210340371976182, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {2.302585092994046, 
          FormBox["10", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {-59.86721241784519, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-52.95945713886305, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-50.65687204586901, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-48.35428695287496, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-41.44653167389282, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-39.14394658089878, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-16.11809565095832, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-6.907755278982137, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-4.605170185988091, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {0., 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}, {4.605170185988092, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0, 0}]], TraditionalForm], {0.005, 0.}, {
           AbsoluteThickness[0.1]}}}}]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",ExpressionUUID->"20e0105d-7155-4ccf-a71e-a722908df2be"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple plateaus in HHG in ions", \
"Subsubsection",ExpressionUUID->"5897368d-358a-4d14-ab1e-96fdae272192"],

Cell[TextData[{
 "This section benchmarks this code against the results of N.J. Kylstra et \
al. reported in ",
 StyleBox[ButtonBox["J. Phys B: At. Mol. Opt. Phys.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
 StyleBox[ButtonBox["34",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
  FontWeight->"Bold"],
 ButtonBox[" no. 3, L55 (2001)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1088/0953-4075/34/3/101"], None},
  ButtonNote->"http://dx.doi.org/10.1088/0953-4075/34/3/101"],
 ";. In particular,  we study HHG in the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["He", "+"], TraditionalForm]],ExpressionUUID->
  "00265596-d8e6-4377-ab1f-eba3bdb99c73"],
 " ion at high intensity (",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", "=", 
    RowBox[{"5.6", "\[Times]", 
     SuperscriptBox["10", "15"], 
     StyleBox["W",
      FontSlant->"Plain"], " ", 
     SuperscriptBox["cm", 
      RowBox[{"-", "2"}]]}]}], TraditionalForm]],ExpressionUUID->
  "d5016e2c-ab3d-4f04-b259-d93c8fcd497f"],
 ") and reasonable (800nm) wavelength."
}], "Text",ExpressionUUID->"3d1a37d6-c8e9-4732-a67a-e87114073783"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"kylstraA", "[", "z_", "]"}], "=", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["F", "\[Omega]"], 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{
              RowBox[{"\[Omega]", " ", "t"}], "-", 
              RowBox[{"k", " ", "z"}]}], "4"], "]"}], "2"], 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"\[Omega]", " ", "t"}], "-", 
            RowBox[{"k", " ", "z"}]}], "]"}]}], ",", "0", ",", "0"}], "}"}]}],
       "]"}]}], ")"}], "[", "t", "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"kylstraGA", "=", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{"Evaluate", "[", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"kylstraA", "[", "z", "]"}], "[", "t", "]"}], ",", 
             "x"}], "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{"z", "\[Rule]", "0"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"kylstraA", "[", "z", "]"}], "[", "t", "]"}], ",", 
             "y"}], "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{"z", "\[Rule]", "0"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"kylstraA", "[", "z", "]"}], "[", "t", "]"}], ",", 
             "z"}], "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{"z", "\[Rule]", "0"}], "}"}]}]}], "\[IndentingNewLine]", 
         "}"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", ")"}], "[", "t", 
   "]"}], "//", 
  "MatrixForm"}]}], \
"Input",ExpressionUUID->"2f471b89-01d2-4d1d-ba8a-a9371438c68a"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{"F", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"k", " ", "z"}], "-", 
            RowBox[{"t", " ", "\[Omega]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{
             FractionBox["1", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "k"}], " ", "z"}], "+", 
               RowBox[{"t", " ", "\[Omega]"}]}], ")"}]}], "]"}], "2"]}], 
         "\[Omega]"]}]},
      {"0"},
      {"0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   BoxForm`e$]]]], \
"Output",ExpressionUUID->"c5980eb4-6289-473b-91d1-92ec24536be1"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"F", " ", "k", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"t", " ", "\[Omega]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"t", " ", "\[Omega]"}], "4"], "]"}], "2"]}], 
         "\[Omega]"]}], "-", 
       FractionBox[
        RowBox[{"F", " ", "k", " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{"t", " ", "\[Omega]"}], "4"], "]"}], " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"t", " ", "\[Omega]"}], "4"], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
        RowBox[{"2", " ", "\[Omega]"}]]}], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   BoxForm`e$]]]], \
"Output",ExpressionUUID->"1ab83551-d7b6-4f5b-9667-d0aa12f9019c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"nppk", "=", "1500"}], 
  ";"}]], "Input",ExpressionUUID->"69460661-d9d6-4189-91b2-dd9eec4ac955"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"kylstraTest", "=", 
    RowBox[{"makeDipoleList", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", 
       RowBox[{"kylstraA", "[", "0", "]"}]}], ",", 
      RowBox[{"VectorPotentialGradient", "\[Rule]", "kylstraGA"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"F", "\[Rule]", 
          RowBox[{
           SqrtBox[
            RowBox[{"5.6", " ", 
             RowBox[{
              SuperscriptBox["10", "15"], "/", 
              SuperscriptBox["10", "14"]}]}]], "0.053"}]}], ",", 
         RowBox[{"\[Omega]", "\[Rule]", "0.057"}], ",", 
         RowBox[{"k", "\[Rule]", 
          RowBox[{"\[Alpha]", " ", "\[Omega]"}]}], ",", 
         RowBox[{"\[Alpha]", "\[Rule]", 
          RowBox[{"1", "/", "137"}]}]}], "}"}]}], ",", 
      RowBox[{"IonizationPotential", "\[Rule]", "2"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PointsPerCycle", "\[Rule]", "nppk"}], ",", 
      RowBox[{"TotalCycles", "\[Rule]", "2"}]}], "\[IndentingNewLine]", 
     "]"}]}], ";"}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"DateString", "[", 
  "]"}]}], "Input",ExpressionUUID->"58b145d2-c800-4bab-948b-c66e9a8be56a"],

Cell[BoxData["\<\"Thu 1 Oct 2015 18:25:47\"\>"], \
"Output",ExpressionUUID->"5d268baf-eea2-4d32-a4b3-8d1c880fec3a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1619.159813`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"4e353411-1f6a-4543-acf2-a8973cb76fe3"],

Cell[BoxData["\<\"Thu 1 Oct 2015 18:52:46\"\>"], \
"Output",ExpressionUUID->"0103f1b7-c38e-463f-91de-0b1b83273c36"]
}, Open  ]],

Cell[TextData[{
 "Plotting the results. The ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "a308d6a9-916c-4cd7-b19f-dc47d97dde65"],
 " component (along the laser polarization) is in black, the ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "12f1b40d-7bd4-4cee-88da-52d066eba6f8"],
 " component (along the laser propagation) is in red."
}], "Text",ExpressionUUID->"3acb574e-c8af-436c-8871-269e3dd89eb1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"spectrumPlotter", "[", 
      RowBox[{
       RowBox[{"getSpectrum", "[", 
        RowBox[{
         RowBox[{"kylstraTest", "\[LeftDoubleBracket]", 
          RowBox[{
           RowBox[{"1", ";;", 
            RowBox[{"-", "2"}]}], ",", "part"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"\[Omega]Power", "\[Rule]", "2"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PointsPerCycle", "\[Rule]", "nppk"}], ",", 
       RowBox[{"TotalCycles", "\[Rule]", "2"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"part", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "Black"}], ",", 
            RowBox[{
             RowBox[{"{", "3", "}"}], "\[Rule]", "Red"}]}], "}"}]}], 
         ")"}]}]}], "]"}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"part", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "1", "}"}], ",", 
         RowBox[{"{", "3", "}"}]}], "}"}]}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"743bb40d-d7cb-43b1-9c90-406e2717b09f"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.004583333333333334], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJw9mnlYjs/bxqMkRCHJEkkkSYsiCScVqVBpk3Zt2penfXv2ylaWskXZC1Ek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       "]]}}, {}}, {{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[0.004583333333333334], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw9m3lYTt/XxstUVIQkCpVQhEqlTN2IRqlUSoPmeR6f5mcuhMxJCJlJRMqY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       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->800,
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"e27ec087-bbc2-4d9b-9f31-f8e21ebf6243"]
}, Open  ]],

Cell[TextData[{
 "The results are a good qualitative match to the dipoles reported by Kylstra \
et al., with the notable exception of the low-order harmonics below n\
\[LessTilde]50.\n\nOn the other hand, taken naively this code cannot be \
applied to the harder targets described in that paper ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["Li", 
     RowBox[{"2", "+"}]]}], TraditionalForm]],ExpressionUUID->
  "4c76982b-3407-4d9d-9dfb-3c892e17af1a"],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Be", 
    RowBox[{"3", "+"}]], TraditionalForm]],ExpressionUUID->
  "80ff44c0-d990-4b20-9820-6e8a08ff2e2e"],
 ", at intensities between 0.9 and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3.6", "\[Times]", 
    SuperscriptBox["10", "17"], 
    StyleBox["W",
     FontSlant->"Plain"], " ", 
    SuperscriptBox["cm", 
     RowBox[{"-", "2"}]]}], TraditionalForm]],ExpressionUUID->
  "4b4531e3-ebcf-4d58-b5e2-15a72de50db2"],
 "), which have cutoffs of order as high as ",
 Cell[BoxData[
  FormBox["35000", TraditionalForm]],ExpressionUUID->
  "0af2fe3b-2db8-4174-89aa-cc87a105000b"],
 ", which requires several days to several months of calculation using the \
naive scaling. (That said, using a smarter choice of ",
 StyleBox["ReportingFunction", "Code"],
 ", judicious use of parallelization and lots of waiting, those targets are \
probably within reach of this code.)"
}], "Text",ExpressionUUID->"f8cdb542-4cb8-4a84-8f62-cd6a6dea5b57"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Periodicity of nondipole contributions", \
"Subsection",ExpressionUUID->"c9cf9629-4975-40a3-8cc1-440a98358e58"],

Cell[BoxData["Quit"], \
"Input",ExpressionUUID->"e68bd9d6-5594-4d6f-b1a5-5f838136f013"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"crossedBeamsA", "[", "t_", "]"}], "=", 
     RowBox[{"First", "/@", 
      RowBox[{"Sum", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         FractionBox["F", "\[Omega]"], 
         RowBox[{"(", GridBox[{
            {
             RowBox[{"Cos", "[", "\[Theta]", "]"}]},
            {"0"},
            {
             RowBox[{
              RowBox[{"-", "s"}], " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}
           }], ")"}], 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"k", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"s", " ", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", "0", ",", 
               RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "}"}], ".", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "z"}], "}"}]}]}], "-", 
           RowBox[{"\[Omega]", " ", "t"}], "-", 
           RowBox[{"s", " ", "\[Phi]"}]}], "]"}]}], "\[IndentingNewLine]", 
        ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], "]"}]}]}], 
    ")"}], "//", "MatrixForm"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"crossedBeamsGA", "[", "t_", "]"}], "=", 
     RowBox[{"Evaluate", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"crossedBeamsA", "[", "t", "]"}], ",", "x"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"crossedBeamsA", "[", "t", "]"}], ",", "y"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"crossedBeamsA", "[", "t", "]"}], ",", "z"}], "]"}]}], 
       "\[IndentingNewLine]", "}"}], "]"}]}], ")"}], "//", "MatrixForm"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"crossedBeamsParameters", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}], ",", 
     RowBox[{"z", "\[Rule]", "0"}], ",", 
     RowBox[{"F", "\[Rule]", 
      RowBox[{
       SqrtBox["0.5"], "0.053"}]}], ",", 
     RowBox[{"\[Omega]", "\[Rule]", "0.057"}], ",", 
     RowBox[{"\[Theta]", "\[Rule]", 
      RowBox[{"10.", "\[Degree]"}]}], ",", 
     RowBox[{"k", "\[Rule]", 
      RowBox[{"\[Alpha]", " ", "\[Omega]"}]}]}], "}"}]}], 
  ";"}]}], "Input",ExpressionUUID->"7b459281-395f-45ee-adab-56305d228faf"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"First", "[", 
    RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"symmetryTestDipole", "[", 
        RowBox[{"\[Alpha]", ",", "\[Phi]"}], "]"}], "=", 
       RowBox[{"makeDipoleList", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"VectorPotential", "\[Rule]", "crossedBeamsA"}], ",", 
         RowBox[{"VectorPotentialGradient", "\[Rule]", "crossedBeamsGA"}], 
         ",", 
         RowBox[{"FieldParameters", "\[Rule]", "crossedBeamsParameters"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"PointsPerCycle", "\[Rule]", "160"}]}], 
        "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", "]"}], 
    "]"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"\[Alpha]", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"1", "/", "137"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"30", "\[Degree]"}]}], "}"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"DateString", "[", 
  "]"}]}], "Input",ExpressionUUID->"6cf94def-765c-422c-bc97-fab3158534e9"],

Cell[BoxData["\<\"Mon 2 May 2016 16:23:09\"\>"], \
"Output",ExpressionUUID->"f0ea735d-dea5-47c0-af00-e8d9d87c042a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"8.751442`", ",", "9.806287`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11.927664`", ",", "16.527125`"}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"8095dabe-8132-40a7-9441-c9ad3b691966"],

Cell[BoxData["\<\"Mon 2 May 2016 16:23:56\"\>"], \
"Output",ExpressionUUID->"3bd05220-7da8-4a2d-94e3-de9eeb6cdf8d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"Table", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"spectrumPlotter", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"getSpectrum", "[", 
       RowBox[{
        RowBox[{"symmetryTestDipole", "[", 
         RowBox[{"\[Alpha]", ",", "\[Phi]"}], "]"}], "\[LeftDoubleBracket]", 
        RowBox[{
         RowBox[{"1", ";;", 
          RowBox[{"-", "2"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], 
        "\[RightDoubleBracket]"}], "]"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Joined", "\[Rule]", "False"}], ",", 
      RowBox[{"PointsPerCycle", "\[Rule]", "160"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "450"}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\[Alpha]", ",", "\[Phi]"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "36"}], ",", "0"}], "}"}]}]}], "\[IndentingNewLine]", 
     "]"}], "\[IndentingNewLine]", ",", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"1", "/", "137"}]}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Phi]", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"30", "\[Degree]"}]}], "}"}]}], "}"}]}], "]"}], 
  "]"}]], "Input",ExpressionUUID->"33c0942b-c95a-4e97-9d42-c46b0c2af615"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], Thickness[Large], PointBox[CompressedData["
1:eJw9kg1MzA0cx09ltIY6RuoQHh4vJ051vajuW12uzlX38hitTSujF6ycvA05
GrV5TxRP5Hke06X1Yj2G49oNZ6otS1wqNDWXvLQjDcnr/H7+23//ffb5f38v
2296apZ2jZNAIFD/eH9++QltrSh+8zTc8oscsvqkqnnymy7EAhS/yknxmCgj
Ho2zmYN6qccIYnec6y/fLVzMfgJOGT2TbXVCYk/c6JfXifvYi+C7N+W2bbs3
sQ/uPinI9bvAfgZkhcL+glNTiP/As+PV83uL2M9Gy/NypTRxKvEcHFgxobrz
Cc8/D2GPrA/W272IxTAoXZY3mTnvi8GVg6uCBtgvQodthFbaznkJfEWmnVlb
uf5iXD/TGlIjYe+H8TdUHSXJ04j94WP8y6W0Pow4AKttG0XHjvkQS3EyP6Ly
cRP7QNSU2GtHDXH9IGS5r/aI+e2DsfOjW9HAxBnEIajODNA07eL+S2BWZ+r7
xnL9UDRlr8nu0rEPw5jyRpOlbCZxODatzTvUIOX9ZRhOubV/QwbnAc3DgJf9
eZQ3AKct7lb9QfYRaGuRZGe4U94QAVdJa1p00XTykWg7MaT5msD5SFw0pZdO
nsX9o6DYXL/tXgntZ4jCtZevp433mkVejgsefoojOezlCIk7mNq36k/y0ai8
MumIIpV9NFSNl98U2+eSX4rCJfuq1M3sl6L9aHDi53IxeQVMHcb2iJvsFXjQ
9U0sK11IPgb3tbHB3bd5/hhkvh2e7ZYsIR+LudLuxsAM9rEQ7RtQlbn4kVei
RJjT2vuN6yvhM/PV3Ulmf/LLMOS1QKRP5/wypP3TcNUpX0pehfDTyiiHG3sV
ehIfuyWkBJGPgz6j3vFOyT4OMrugJV8ZQj4eO1zblufy/RviMU7a2RIvCSWf
gEBzj8X7E8+XAGXkYc88K9+bGrV3quVlKygPNdKjdvdYxVxPDXP3l0Kjmdii
Roc96711Ad+bBh8+/edka+a8Bi/O1470NvG9aPC/f/ye5i2c1+Bkr7OmM4nz
Wni6VqR1XaX/ocU6499y5wGeVwtrXdjxd1M4r0WFsOGS/l/O62Bqg3PVNu6v
g+N+bqWB9zPoUJO/oSBpmNiiwxiH8dnkgnDLd0Amgaw=
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      ImageSize->450,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], TraditionalForm],
      PlotRange->{{0, 79.}, {-36, 0}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], Thickness[Large], PointBox[CompressedData["
1:eJw9k31MzHEcx89z5CFiunDuSjqV67rcQ4rfO+dKerq7X2yX0G4YiThlmVon
HcvzRUgPHmJmaDYytZ1dNE/DXIsV1ab0h1gPozwX5vvx23777bXX7/X9fn+/
7+8nMWcY1w8XCAT6P+ffKx1HkyyWoq+Lnf+ol0v7FuJZ2jWGsQD+Pd2dg35g
7IaPZ03rbOkjGXvgzrhL8ycc4hhPxeRcrju1YBpjL+zs8+azZlI/E0dPXzPt
2TWLsRjx7rtelCeQ90Fu8a3oQE7MeA62OFqbiptp/LmY7OYXFnOcvBT12lhx
1BXyAeAzfn3WVIsYB0GnNH0JNZGXwbfqeaRaNZuxHCEFTVVjReRD0NXTvbnl
gQ9jBUandNzKaab3Ewpz6NW2ahXNvwApyZ5rDnqRVyJaO4E7nUVehVP9B4p3
8OTVqH40VzLwUMJYg/aBAnkmRz4MX+qUx84NUb8QtiklIxs8aH3h+LT/vLrv
PvkICJXvGrMuUb8IkpyHviEuGn8x+h2ye64L1HMQPt2esqnQlzFQOyx2b3kl
663AC1FFyp47fsxH4nFD5V33GtZbI7FBCrVLK2V+CWZwVSfbn1C/BMkKqbHD
O5B5LV6ZHhjCZeS18G+wxOUqZMwvRfbrtp/fg8kvRYTB5S+rkzOvQ9o2Y5mr
eRHzOvB1ysvCfAXzUSie0ntVmkh9FOpr7hptpgXMRyOjX1dm7qI+GjMswtAV
OhXzy/DTVJjHD9HzLUOuT+LWH1oN8zGQ29/X5mSSj0FjhaMlOWkh88thrtzf
94Pev3U5vCZ2NxxOjmA+FrtX35x0Moz6WBRs7EtXSGi/4jAvteh56krq42Cx
awPXHiMfj7jNmd7Wj+TjMUt7ws35/3tPQHbrqtJp7TR+Ap7tyPc6eIT6RISf
yXcPtFGfiKzannHS9+T12Ov2tuyJnTH02Pf9l9DRQvfr0f9GPHHwGWOnHgG2
rWJhD/UGjMobkbYyjc0PAz5cFIwvCab1GDBCpBmwFlFvQOFtcfqB19Qb8bn3
QpDeTr0RjVFqrtWd5jcib3v8nDbaX6cR05tU5oob1PPIFlQe11yh9fOoS5K/
FL2l/eZhD76ZuYr+LyePzhOa654OzvkbhvJu+g==
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      ImageSize->450,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        RowBox[{"{", 
          RowBox[{"0", ",", 
            RowBox[{"30", " ", "\[Degree]"}]}], "}"}], TraditionalForm],
      PlotRange->{{0, 79.}, {-36, 0}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}]},
    {
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], Thickness[Large], PointBox[CompressedData["
1:eJw1kQlMU1kUhh9KJsStokgUGSwVEBER2lKwtK8/BdksUNpoGUfEuqAYR0FQ
RkFFxRLFBeMWWWziBq4Vl1ibaMCqUAzijKgJxgbQ4OAMo3EIAsEwGs99ycvL
l+/9/zm513fFRt3qURzHab+937/sGeR35S7tmFn/gz6pehKPFMY+cCXmYN73
4p/8sgBiN3g33J4lc3chnghfZZ1GVe1H7IHhR53h7TcnEU9FVFaef4pyFrE3
2iqn1f21dTqxELYtzwanT2FehGGuKENx6mdiPyzVLM+rcmE+ACdX9ES6/eJD
HIiYEsuOtx/YfkGwcBlbF3V7EQcj3ZScM3Sa5UOAvg1e/H/Mh8K6sqYkxR5I
HAaf56uL/ApYvxj36+LPOaSziSUwNBU6jZkziKX4qIjOd8lnPhxHVykt748I
iWWwvCxt/9MeRBwBgV4snDrE+iMxN7BRIf+J+fkQ//ZSVeEpIpZjoPH9YpuA
+ShoogrswxNYvwJu0663ftjGvBLb3lUoc8zsPnnIewtG11mZVyE894lgUzbL
A4La43/0NNP+xYBpo0O07wDz0Sgs9sjw01K+OBpu15rlWcd8yatRYgq5sdY0
h7wa94s6atT+bH4MPB1ZhwOkc8nHoPVUV3qMlz/5WFzsjwvYqZxHPhYRAxKx
MJPd1wJcfWJsdDaFkl+A7Sf6+tq62XnH4dWdvXzrJDH5OKSeF6XztcHk42F1
Nldu/11CPh6O3nf9pVU0j0vA/s9LXFv6peQT4N7LG8WZYeQTMfmTciShTEY+
EU+tSVqHK/VxSaiRysr6JJHkk2AYPlMee4/6uIVQ31WPE32cT34hQr+ESsSl
1Mdp8LkyYky/LYq8BtY9Pnyxkfq4ZJS7d165vEdJPhlnN2x2NiTJyadgmeXg
nbaHPPkURBxSj3wNU5BPRdWv9uA5gyyfiiXBl0xdj4k5LazXRH/np1MeWmSX
jL18V8j6tGi4ZTetf0xcr0W1MKfJHELMpWFoYGyq+TXLp2Evdzuu5Y2K8mnI
q/bddGILy6fBM89+K8zA8jrISsdbvprpf+jgzFnT7fEv21cHgy0od7c3y+uw
u2Jlu7GW5fWwTTSMzChk8/UQa9YKqh6wvB7l/IWDniPE9Xq8WnfvbctOvv5/
X550ww==
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      ImageSize->450,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        RowBox[{"{", 
          RowBox[{
            FractionBox["1", "137"], ",", "0"}], "}"}], TraditionalForm],
      PlotRange->{{0, 79.}, {-36, 0}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], Thickness[Large], PointBox[CompressedData["
1:eJw1kAlMVGcUhZ9mZFCjgiyCHWQZBLSCAyjIOgd5gyjbLAaV4saiAZeaBiwo
CKMwAYwGNUENAupoy1ity8SKgSLTomhQXDGCorbGaKca2jqobaqo8d6XvLx8
+c65//2fd9bX2tyRgiCoP76fvvw45U+6f3f81I7P9JfyGmwv6q1SYgEvBXXb
83Y/YntMHjpaUbFWQuyAkoFy18Y/fYmdkdRpbiyocCF2g73HYPbZIfYyODRL
di7a5EHshZrBpQ09V9n7ICCn6mGp0ovYF3f8fp44pof380NDz7kLvXvYB0CR
bj74OpP705HRUluj/2kK8QxMG1rZky+wD0KBLce/LsyTWAHFQGBa8z2eH4zN
Seejn3f5EIeg7sd8mVHL9w9FcZbBdWw4nz8L9m6exW+vsJ8NfZ1Y2lLIPgwn
o8T2/n/Yh6OgL7h68WVv4jmwitOrd1r8iSPg9HTlBPMw9yNR3y68EVTso3Dd
7nahRyf7aAynxhQdtrKPwd5N2kvZN3l+LKYklxaP0kwjViJV7lLZWC0nBu43
vFz4S9SXn7kc6Mw5rj/Xwv8jDvqLzxwPbg8kHwflKuMeqRhAfi4i3ir7fnNV
kJ+LJ60+G92/oHlCPHK3GLaeqgkmH48T2hW2MyFB5EXInY7sMMpCyYsobJpg
SrTQPEGF8zc6ZeFXZpFX4eq1xd2hW0PIJ0BSeeyPwzvCyCfgRmsVmpZQXpgH
g6qm/vvVc8jPQ4QlZP0aFeWFRLRUSPwV6ZHkExG/euZXcpHywny0PTgw7LYs
mvx82M28lfeDjvLCAogP25wd98aSX4CS/s2hJZmUF5IQWbXfqvmXfRK+01sl
g3JiIRkmaaHvvgT2yVDv6u5za2KfAnPw/zbZa/YpWDWi+dV2TyX5VOQd+ua0
5RZxeSreGR54NAWxT4MpQ/L7Rhv30/Bo980NYUU8Xw3pobIyhxRiqJE5kHG8
/1fOq9HlPs6lKJHmdajxd+2jSbLT3NdAapQ+ifIiDw1ObAscmBHI+2hgNGWV
XTBRvkMDw6LSV+nN3Nei9X3rgf/WcV+Ls8t3afZ58/laXHYprrQr5/5HfuyX
Zz7CfR0uNva6Z2fw/jq4Ls+NfWeJob4O3W8MXeOzua+Dc+/oWPFbZccHok1y
xQ==
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      ImageSize->450,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
        RowBox[{"{", 
          RowBox[{
            FractionBox["1", "137"], ",", 
            RowBox[{"30", " ", "\[Degree]"}]}], "}"}], TraditionalForm],
      PlotRange->{{0, 79.}, {-36, 0}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",ExpressionUUID->"69a81c36-467d-44a0-be3c-bcf7e626f5c5"]
}, Open  ]],

Cell[TextData[{
 "Compare this with the unacceptably high noise floor from the previous \
version for the case ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Alpha]", "=", 
     RowBox[{"1", "/", "137"}]}], ",", " ", 
    RowBox[{"\[Phi]", "=", 
     RowBox[{"30", "\[Degree]"}]}]}], TraditionalForm]],ExpressionUUID->
  "cc536753-7f68-4e27-a1d7-710da39bd35f"],
 "."
}], "Text",ExpressionUUID->"8df4439c-e574-4e72-b0be-f54298fa4cc8"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], Thickness[Large], PointBox[CompressedData["
1:eJw90g1MzHEcx/FzFQnjVLTU9aykB8mlS+lzuE7dXV3/y5Ll1uGfHraYh4rF
ksyahDVpO+ahB9Ey1ooe6CgmT7c4bBjloY7CMbN5SJjf122322evvf+//+7/
91qzgeOFAoFA8+f795c+TYYQc7wQxn/LGjsvN898WWDDtgDbM+vtWsLJ7fGx
b0qPbGQ829NQdL/l2ZgruRPCNjUNBv9wZNsFj25qJ7ptIndDqmtEqTHBlW1P
mGydv5qt5N5omhwsPP3CnW1fSLpaI4syyWfjudtIRoXQg+0AfMv0z2vMIQ+E
oqMP3aJZbAfhrF1IW9YJ8hBcbZjOV4nJ58FPMul9t5I8DN3DK3Jr28Rsz0ei
w1iE0ok8HOI+ibekls5fAMGQ+UHO//uT4GV1+4XvdZ5sRyBjZc6ZoWjyhahJ
5/lxntRH4hD3WDUSRC7FvVd3buyM92Y7CqGaGV3PtpEvQu76J8qN7nT9aLQU
RvrcDSaPQdrdfcNPv/qwvRhvlW0lQhsZ27HolEo9+rdQDwjX6+vkdawvBuyz
69YpDpPLoG+X7rItI5fhint/VpLBi/kS+I7L9t+ZTb4E40uvPawOpPOXorV8
M8SNscyX4lbUSb+5Yj/my7DVY3h7+jHqlyHm2odpzXp/5nIYOVTmxZHLwbWm
GmZb5jCPg+OXtfqjJvI4ZK0yD+oagpgrsPL1z80D9HyKFXAWlYj2GEKZL8ev
CQczbNPJl2PrufBAP10Y83jIvu+41GDH/r/iePg22xdKbMKZJ2DqgOJipZT6
BJgG3xwN7VjAXIlLuw3X56rJleDk2yynSiOYq7Diceyqd/T8i1V4yx+3QBfJ
XA3Jl0+jhgByNW7kl6n746KYJyJfVXDkXgV5Ii7WeHXqYqKZJyFFNawYqSFP
Qm+H8488LGauwYnUetPLz8yhQUpZgI/4/3kaFDmUj1pVbBs1eN90c0PFJ3rf
kmHSjy0c2k99MgK6KmXzZdQnw1oyc+aBROqTwVscq7JcqOfAVzXyQ/XUczgj
anbS8dRz6F3t0uswi3oOadaUI9lR1GvhX9Aj31tLvRa1AxZ9tYh6LW53nm+/
70a9Fur80dYWBxh/A7yQbhk=
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->450,
      Method->{},
      PlotLabel->FormBox[
        RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], TraditionalForm],
      PlotRange->{{0, 79.}, {-36, 0}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], Thickness[Large], PointBox[CompressedData["
1:eJw91H1MzHEcB/DTtCQsD6smD3eq2zn0RHepU++7c3d1kXvAVSgko2MVMin1
K0WYh/IwWxeOC01JYro8dKgZmZGYpw6z0B/skGZow3w//bbffnvvtfe+3+/v
9/3+BCuzDBluPB5P9/f+96Tr6VCt8GAgHP+TK3Z5662q1tfuLPNQGBZStn8J
+TAcfqw4KjZ7suwNSWeKf8cG8nG4Yh11vpPzYdkPv3/mc+P7yCcgxlWf/jFo
Ast8LD+33ZLSTT4FDd8zA2yL+SwHojFq7eWkPHIhJjZv6+noIBchR3Ltc0YV
uRjTNNIMv+OTWJ6O6v5XnzX15MEYqfl125k+meVQjFlY6eqqJA9D28C6gg/c
FJbDkd9yzNdjBvlMmEt7iqGm8WehuuCMfSZHHgGxIFdgKiWXoOXZEP/4teRS
vA0s2J/ZJWA5EgmFfuFuieSzER2d4i8dTh6F/MBTvd428miYvZYGZw+uX4b2
nvKuzl3kc1DWplrY+ZT6MUjlp4U0XSCPhX71pJrNewNYBl55yi99vMScA5xW
07eAq0HM5XB13wX/Irkc5xsy+UKViLkCb6pnSEa7yZkrUFT8LmSI/zTmSmSY
LHeaI6mvxKkCb+vmsGDmcyG2VRhv5JLPxdXk8ji+I5S5CsdktmZjELkKj05a
PMq5cOZqPIstGpUqJVfjbHNbdK5pFnMNahf9SPTKJtfgxMoL5gcKCfM4NMxu
e15aQh4HZy93xUMeyTwe7nWNa5RJ5PEQhXi+zNFFMdciT3HahVXkWniN9tlz
LUvGPAHr3yi/NQ2uPwF1L6q+tFhjmM/DzY211Wkq8nlYpqrt37mUvtd8XIwr
vqFcQT4fL/Q1uzdJyBPx5KHQdiCdPBGKCFnyWSv5ApRsynsbUUa+AM59qfZe
eh88HVzbu61OOn/QoeaJ8FMjnQdOh1C1771u2n8OHdSiGG3Z4HnXI6zCXrWk
kfp6yLINdaf3UV+P3lr7gID2n0OPr1bLFvd86hswwlLRJ6b5wABdv9vUkuvU
N6Dy/pGxi2uob4ClVWsyF1LfCPuXQ+3qQ9Q3QtoXXrmRxuOMyPKd3rSD/l8O
I7YeyRG9T4DjD2F/cxY=
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->450,
      Method->{},
      PlotLabel->FormBox[
        RowBox[{"{", 
          RowBox[{"0", ",", 
            RowBox[{"30", " ", "\[Degree]"}]}], "}"}], TraditionalForm],
      PlotRange->{{0, 79.}, {-36, 0}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}]},
    {
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], Thickness[Large], PointBox[CompressedData["
1:eJw9kgdME1Ech0+q4E6jogRqBUQExMoq0lLgB7LK6rUV0UQaMQGjYjBx4UBb
XBTBhYgNQ0SGUeJOnZEqKUZUIhonKq6IoCSKE1Ec8f+85HL58t33fy/3zmV+
libdhuM4/s/998kuxxAnO2nteMs/eh/W3X9EV8wJiDl0rbH56JoqIh6MNr6g
4tdbW2IhblfY1Xe9dyEeg8NHEzaq+kYTO6CgyjauNHISsQj4HvhuZrwjsTN2
PEnet1IwmdgVsr11SZ3tbD9uGBIlGHrhqzuxO0Q3VKftBBOIPbDpmjnr1Qfm
vaB0K290GOVE7A2taYTLsBNsvgSCJQsOHhIz74NzKS8bTO0exL4w9Ta0x54X
E/uhqVW9KCvZk9gfEWllh49Xs/UDEKS/Vhe3m3kpKvr6PXJrnIkDccvf4OHz
0Yt4Oga2Lg4d4Mz6IDz6nltxRcy8DJIWG2Ov0pVYjqDLN9WZbswH43Hx8KiM
8Wy+AmNWvniTWsh8CPIapGOdvk4kDoW2pEU2rpn5MKh7LHc6l7Me2HncmrLg
Lu1fD/Q3PWyKKGY+HDkP1qzIn029PhwjdTNfR5ay847A9VllGyWFU8hHIEZc
mLnNi60/A+XzFjZmy6aSn4GM6r5VIjH7HyKxLFPamR0+jXwknp81+VensfOK
guCkap2s2Yd8FKSGjjkOb9j3jsbFZMu7HaP9yEfjzLG7z9SHvMnHoC+vXXIk
2598DO7rvZtXl9J6XCxuKjasXfIlgHwsvHbJy511vuSVCCjqPZqWH0heCT6n
29dPQPO4ONRWlv0w+gWRj8Pby1cbp16geVw8nhZ22sm6ZeTj4fRpl7lqE83j
EjDsyh2j/blg8glo6y7aGq6jeVwiahPL7Fv2hJBPhOf2pqVt0XLySfhZ1yO/
nhNGPgk9E099WRGiIK9C6bTKqpRUkFdh7S37M9bgUPI8pEPvmUeayYPH/vJB
ntNd2Ps8jEI+3+BObOGhqOlNf1lPzKmx6NsN4Xw969X49qHj84hc1qvhWFDj
lqxjvRqXtii0B4JZr4Gx41lrpYH1GohK0k31c1mvwRxDj3K9kPUa2AY0T8iS
s14LYUyHKe8567WwCh8vtUpYrwXvaN2s+r9/LbaYHboyxLD8BrMjdOY=
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->450,
      Method->{},
      PlotLabel->FormBox[
        RowBox[{"{", 
          RowBox[{
            FractionBox["1", "137"], ",", "0"}], "}"}], TraditionalForm],
      PlotRange->{{0, 79.}, {-36, 0}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{}, {{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.011000000000000001`], Thickness[Large], PointBox[CompressedData["
1:eJw10AlIk3EcxvElia0Coyw0UmceM2dq5W3Ox81r5vG6dfgaWa7DlHCZFIhS
pplLishZVKJlh6GYHdoBSq3L2tLKZmbmZkEmYYl02GHZQf/fCy8vXz7v8768
r4tao9xoJRAIuL/nvysdBtm3vA/dTvr/NRohr+iZpTNbsxZg7PnTkKM7HVlP
wfknuslvsoSsZ6Bok9PWutcurO1w95fp9KXdc1jb4wu/2qIYd2M9D+kOs9P6
3OexFqGvJ/LwGiP5fJSasiz7eRFrN2zP0sqGKt1Ze0Ci+1x28D65JyQrxhPW
rqC9F+S1+cbUGvoeb9iMiZuNNuQ+kJfYFhzZ7MzaD23lmQEKNw/Wi2Cw66/P
KZ/PejG+pdtc4heQL8Gr6FZzZhy93x+Gxk3VBYXkAah+l+p1uJg8EC2hWjTf
IA/ChGvE1BwT/a9g+A5bkitMYtYhmPy2WH9NSB6KfdMspR3Z5GHw/VHO/zDQ
85eiu3GveNYIeTh22NVN2HfTXgr/keCY0PeerCPgvGWSomWfK2vg8oW0o89f
LvjfRUDx+NUHGTfof0fCUSjL+F7mxTwSfbpOtfEAPU+Gj29TN4wNkstQYito
sPbwZS6Hd/7wyn5bCXM5RrSiLv81rAVR6FoSKH3oSR4FiTmssD+QPBpnKyp9
ToWTR0O28em2ezHkMRiuHQ84yZHH4JlZtJDnyWPBrVcbp6jJYyFOErmJs8nj
4PI1p2AslzwOt3MdAzLzyRWQSfaG7CkiV+DcsMP7pDLyeMx2WF5nPEAej5+L
uaHvOvJlWLXLfubAMfJlkJoa+MIT5AkILZ3UbjpDngDX7DshQ/XkiTDic971
JvJE+DWbZyqayZOgUQcfOX6NPAmCXmVGUyt5MqZXdbaV3iRPxuYMvtflDjmH
NJl3R0k7a3Cw8OrjjQa6n0OVOsivuoO1noOV/dzMlY9pnwJn/qL1iy7ap4C7
1aR376Z9Cqxyr4SF99A+BbfCPwlFvbRXwvNnZ9OjF7RX4pFmR43iJe2VGBhV
SQ/1014JrdOuwbNm2qvw28fWXGahvQpGB826oAHaqxAVXFXdQq1XQVspvfL7
b/8BbNx3lA==
          "]]}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->450,
      Method->{},
      PlotLabel->FormBox[
        RowBox[{"{", 
          RowBox[{
            FractionBox["1", "137"], ",", 
            RowBox[{"30", " ", "\[Degree]"}]}], "}"}], TraditionalForm],
      PlotRange->{{0, 79.}, {-36, 0}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",ExpressionUUID->"1b9e07b7-ea2d-4c33-8b6c-633e3cc8a59b"]
}, Closed]],

Cell[CellGroupData[{

Cell["Debugging and benchmarking tools", \
"Subsection",ExpressionUUID->"f0ef7229-5660-40be-95d3-e6c739154745"],

Cell[TextData[{
 "If something goes funny with your calls, then before you start taking \
makeDipoleList apart you can try using its ",
 StyleBox["Verbose", "Code"],
 " option to diagnose the internal functions it is using. In particular:"
}], "Text",ExpressionUUID->"c73d7b93-108e-4484-b9b8-c84809810c89"],

Cell[TextData[{
 "Setting ",
 StyleBox["Verbose\[Rule]1", "Code"],
 " makes ",
 StyleBox["makeDipoleList", "Code"],
 " print the ",
 StyleBox["Information", "Code"],
 " of the key internal functions it is using, before it goes on to the \
integration loop."
}], "Item",ExpressionUUID->"68ce8c31-9aab-4b30-9bab-acb51cc3e605"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"makeDipoleList", "[", 
   RowBox[{
    RowBox[{"VectorPotential", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["F", "\[Omega]"], 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
        "}"}]}], "]"}]}], ",", 
    RowBox[{"FieldParameters", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"F", "\[Rule]", "0.05"}], ",", 
       RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
    RowBox[{"Verbose", "\[Rule]", "1"}]}], "]"}], "\[LeftDoubleBracket]", 
  RowBox[{"1", ";;", "10"}], 
  "\[RightDoubleBracket]"}]], \
"Input",ExpressionUUID->"48c7a17f-6107-4946-92a1-b0db768a9c28"],

Cell[CellGroupData[{

Cell["RBSFA`Private`A", "Print", "PrintUsage",
 CellTags->
  "Info383672149598-4576774",ExpressionUUID->"215cc166-1a6b-41b4-b34a-\
26893c08338e"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"RBSFA`Private`A", "[", "RBSFA`Private`t$_", "]"}], "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"0.8771929824561403`", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"0.057`", " ", "RBSFA`Private`t$"}], "]"}]}], ",", "0", 
           ",", "0"}], "}"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[RBSFA`Private`A],
  Editable->False]], "Print",
 CellTags->
  "Info383672149598-4576774",ExpressionUUID->"4e181755-b115-44f7-8cec-\
5f0a712a192e"],

Cell["RBSFA`Private`GA", "Print", "PrintUsage",
 CellTags->
  "Info383672149599-4576774",ExpressionUUID->"0c1f23b2-5815-4367-acd6-\
ffc4a5371c35"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"RBSFA`Private`GA", "[", "RBSFA`Private`t$_", "]"}], "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[RBSFA`Private`GA],
  Editable->False]], "Print",
 CellTags->
  "Info383672149599-4576774",ExpressionUUID->"8a01014a-c2f3-4d13-b79a-\
217e9b36dd95"],

Cell["RBSFA`Private`ps", "Print", "PrintUsage",
 CellTags->
  "Info383672149599-4576774",ExpressionUUID->"95d646df-2fef-448e-8929-\
035fa4f94c23"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"RBSFA`Private`ps", "[", 
          RowBox[{"RBSFA`Private`t_", ",", "RBSFA`Private`tt_"}], "]"}], ":=", 
         RowBox[{
          RowBox[{"RBSFA`Private`ps", "[", 
           RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}], "=", 
          RowBox[{"-", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"RBSFA`Private`t", "-", "RBSFA`Private`tt", "-", 
              RowBox[{"\[ImaginaryI]", " ", "RBSFA`Private`\[Epsilon]"}]}]], 
            RowBox[{
             RowBox[{"Inverse", "[", 
              RowBox[{
               RowBox[{"IdentityMatrix", "[", 
                RowBox[{"Length", "[", 
                 RowBox[{"RBSFA`Private`A", "[", "RBSFA`Private`tInit", "]"}],
                  "]"}], "]"}], "-", 
               FractionBox[
                RowBox[{"2", " ", 
                 RowBox[{"RBSFA`Private`QuadMatrix", "[", 
                  RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], 
                  "]"}]}], 
                RowBox[{"RBSFA`Private`t", "-", "RBSFA`Private`tt", "-", 
                 RowBox[{
                 "\[ImaginaryI]", " ", "RBSFA`Private`\[Epsilon]"}]}]]}], 
              "]"}], ".", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"RBSFA`Private`AInt", "[", 
                RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}], 
               "-", 
               RowBox[{"RBSFA`Private`PScorrectionInt", "[", 
                RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}]}],
               ")"}]}]}]}]}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[RBSFA`Private`ps],
  Editable->False]], "Print",
 CellTags->
  "Info383672149599-4576774",ExpressionUUID->"24ef6ba0-8adc-4a67-bc87-\
071bc16a89ad"],

Cell["RBSFA`Private`pi", "Print", "PrintUsage",
 CellTags->
  "Info383672149599-4576774",ExpressionUUID->"7e25010a-e239-4920-a2b8-\
cd9e243deea8"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"RBSFA`Private`pi", "[", 
          RowBox[{
          "RBSFA`Private`p_", ",", "RBSFA`Private`t_", ",", 
           "RBSFA`Private`tt_"}], "]"}], ":=", 
         RowBox[{"RBSFA`Private`p", "+", 
          RowBox[{"RBSFA`Private`A", "[", "RBSFA`Private`t", "]"}], "-", 
          RowBox[{
           RowBox[{"RBSFA`Private`GAInt", "[", 
            RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}], ".", 
           "RBSFA`Private`p"}], "-", 
          RowBox[{"RBSFA`Private`GAdotAInt", "[", 
           RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}]}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[RBSFA`Private`pi],
  Editable->False]], "Print",
 CellTags->
  "Info383672149599-4576774",ExpressionUUID->"fc55f12e-288e-4f6e-8171-\
ab43c52d61eb"],

Cell["RBSFA`Private`S", "Print", "PrintUsage",
 CellTags->
  "Info383672149600-4576774",ExpressionUUID->"757aa3c7-8b6e-4857-9511-\
5878301729fb"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"RBSFA`Private`S", "[", 
          RowBox[{"RBSFA`Private`t_", ",", "RBSFA`Private`tt_"}], "]"}], ":=", 
         RowBox[{"RBSFA`Private`simplifier", "[", 
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Total", "[", 
               SuperscriptBox[
                RowBox[{"RBSFA`Private`ps", "[", 
                 RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}], 
                "2"], "]"}], "+", 
              SuperscriptBox["RBSFA`Private`\[Kappa]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"RBSFA`Private`t", "-", "RBSFA`Private`tt"}], ")"}]}], 
           "+", 
           RowBox[{
            RowBox[{"RBSFA`Private`ps", "[", 
             RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}], ".", 
            RowBox[{"RBSFA`Private`AInt", "[", 
             RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}]}], 
           "+", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"RBSFA`Private`A2Int", "[", 
             RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}]}], 
           "-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"RBSFA`Private`ps", "[", 
               RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}], 
              ".", 
              RowBox[{"RBSFA`Private`QuadMatrix", "[", 
               RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}], 
              ".", 
              RowBox[{"RBSFA`Private`ps", "[", 
               RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}]}], 
             "+", 
             RowBox[{
              RowBox[{"RBSFA`Private`ps", "[", 
               RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}], 
              ".", 
              RowBox[{"RBSFA`Private`PScorrectionInt", "[", 
               RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}]}], 
             "+", 
             RowBox[{"RBSFA`Private`constCorrectionInt", "[", 
              RowBox[{"RBSFA`Private`t", ",", "RBSFA`Private`tt"}], "]"}]}], 
            ")"}]}], "]"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[RBSFA`Private`S],
  Editable->False]], "Print",
 CellTags->
  "Info383672149600-4576774",ExpressionUUID->"30b8d47b-5bf2-49b0-b7d1-\
9fe1b46207d1"]
}, Open  ]]
}, Open  ]],

Cell["(abridged.)", \
"Text",ExpressionUUID->"17842386-c6d8-4934-91a5-dc9cd4ac69fb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.018125760380031608`"}], "-", 
      RowBox[{"0.00009974228335412647`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.018314957692237704`"}], "-", 
      RowBox[{"1.4444131248451604`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.018089586447102037`"}], "-", 
      RowBox[{"5.341623082981116`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.01713119725110276`"}], "-", 
      RowBox[{"10.574959930735963`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.015382278717953366`"}], "-", 
      RowBox[{"15.807757590256877`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.013212985784864573`"}], "-", 
      RowBox[{"19.949698046603523`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.011111327315597616`"}], "-", 
      RowBox[{"22.417833070221583`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.009171596193794875`"}], "-", 
      RowBox[{"23.144394298162005`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.007051057434900336`"}], "-", 
      RowBox[{"22.418761591775496`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0045435562146421945`"}], "-", 
      RowBox[{"20.687189524026635`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{"0.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"c211cfa6-eb33-4470-b65a-cbf69b095e69"],

Cell[TextData[{
 "Setting ",
 StyleBox["Verbose\[Rule]2", "Code"],
 " makes ",
 StyleBox["makeDipoleList", "Code"],
 " output its key internal functions and shut down before the integration \
takes place. Its results can be caught as follows:"
}], "Item",ExpressionUUID->"ac42cabe-fdbf-4bac-a21c-4aa32c3eb48f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "[", "t_", "]"}], ",", 
     RowBox[{"GA", "[", "t_", "]"}], ",", 
     RowBox[{"ps", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"pi", "[", 
      RowBox[{"p_", ",", "t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"S", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"AInt", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"A2Int", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"GAInt", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"GAdotAInt", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"AdotGAInt", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"GAIntInt", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"PScorrectionInt", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"constCorrectionInt", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"GAIntdotGAIntInt", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"QuadMatrix", "[", 
      RowBox[{"t_", ",", "tt_"}], "]"}], ",", 
     RowBox[{"integrand", "[", 
      RowBox[{"t_", ",", "\[Tau]_"}], "]"}]}], "}"}], "=", 
   RowBox[{"makeDipoleList", "[", 
    RowBox[{
     RowBox[{"VectorPotential", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           FractionBox["F", "\[Omega]"], 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
         "}"}]}], "]"}]}], ",", 
     RowBox[{"FieldParameters", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"F", "\[Rule]", "0.05"}], ",", 
        RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
     RowBox[{"Verbose", "\[Rule]", "2"}]}], "]"}]}], 
  ";"}]], "Input",ExpressionUUID->"61eabb89-aa3d-4a98-b33c-2d94ec5b7dee"],

Cell["This then enables examination of e.g. the action:", \
"Text",ExpressionUUID->"cb031033-2953-4710-8344-3f739fe3de30"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Omega]", "=", "0.057"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot3D", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Im", "[", 
      RowBox[{"S", "[", 
       RowBox[{"t", ",", "tt"}], "]"}], "]"}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"3", 
        FractionBox[
         RowBox[{"2", "\[Pi]"}], "\[Omega]"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"tt", ",", "0", ",", 
       RowBox[{"3", 
        FractionBox[
         RowBox[{"2", "\[Pi]"}], "\[Omega]"]}]}], "}"}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
     RowBox[{"PlotTheme", "\[Rule]", "\"\<Classic\>\""}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "100"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"88ae8af6-d7e4-45e9-918a-e10e02792b46"],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxU3Xd4TGkbBvBIiOiJ6G3DRv2wSlhd9E601cJGj7aiR4+yRI9eNsjqXfQw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   "], {{
     {GrayLevel[1], EdgeForm[None], 
      StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwsXXecFMXzvdu9293bu73bO0CC5HR7wMwSjpxBkJwkSc45Z0HJOeeMAkoS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          "]], Polygon3DBox[CompressedData["
1:eJwsnXmczdUbx2czY80g25gxxlzmLjNms0zcOyJbZSlLhQotKFKhTYUULbSg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          "]], Polygon3DBox[CompressedData["
1:eJwV2HlwV+UVxvFXCSJhCwRC2EFQ2XcSCAlLAE2ABlGsAopCwBACCchSi06p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          "]]}],
       Lighting->{{"Ambient", 
          RGBColor[0.312, 0.188, 0.4]}, {"Directional", 
          RGBColor[0.8, 0, 0], 
          ImageScaled[{2, 0, 2}]}, {"Directional", 
          RGBColor[0, 0.8, 0], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0, 0, 0.8], 
          ImageScaled[{0, 2, 2}]}}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl1X+Mz3UcB/CXc7jzm+50uMudX3cXirhQFEW5UIjcFeXQVpt+bbVpq42l
rTaWttpYtdXGVhtFUYSiCEURytUpysUV5UJRd/R454+H58c9+dzn+/683u9v
0cxHJj3cJCKq/dGrOCJdF8mO3O96J/388EXOUpkRse+aiE2yqGnEs9QxPjNi
NYMHRuQ2i3iSQ4xsHrGc7BYRr+geknspy4pYSiNV2REXddtkacuIRdQzpVXE
emYNiihoHTGfWsrbRKykQ9uIJ9iur5bD20W8QbP2EQ+ymz5lEQM6RLzMeaZ3
jNhCr8siXtA9L08yMSdiLZ1zI57mtO6IHN0p4i3aXB7xGAeYem3E0LyI12jS
2Tqxk35drBMb9GdlZVfrRFG+daKOboOtVYG1IvcK68QhRnaLeEa3XGYXWif2
UlZknTima5RV3a0TpT2sE/WMHWKtelorCnpZJ2op7x3RyXssZqXrHrIrb7t+
h1Ws5l3e46++EWvkWt7nA9axnr91H8oNbGQTH/Ex53Sb5RY+4VO2so3zus/k
dnawk8/5gn90u+RuvuQr9rCXr/lXv0/u5wDf8C0HadBVy+/4nhoO8QONuh/l
YY7wEz9zlAu6WvkLxzhOHb9yUfebPMFJfucPTlHfO22EiD/lac5wNq1ZWhua
6M6lz5s+V3r29IzpWcjQXUj3T/dIe4wMmia6TNmM5rQgi2wydS1lK1rThra0
I48S2tOTfFa4/5j0Ob37eeSzzkysNB+T5SmzspAStpqhGZTrGszVEgaxx8zN
IYtaM7fMPI6gxozOJYdVZne+bpw8bqYXUMhGs15Bge6M+V9MX3bYG7MJXrVn
1tsfQ+R+e+lRWvOmPTaKKbrD9t1T5LHGnpzACXu03p58TvZksz08jXP29Ess
0vWXu+z5B8jkdWfBMEp1B50Pj9OeFc6OMRx1lsxjm/MjX65z1kzmlLNnISVU
6bY6l2bQ4KxawiD2OMManVlzZBbLnHEjqHHmzWWpLkeuciaO47gzcgGFlOk2
Oj8rOONMXUxfdliiHO+xN7Ndd5ddmOV6JlXM4D7uZbRuupzGPdxNJRXcrJsq
72IKk7mTSYzUTZQTuIPbGc84btSNlbdRzhhu5RaG60bLUen+3JTuxYj0/7he
f0P6dwxLf+c6hiY6oxZGI7zi8ErC0sbA9DOdr5QYQH+u5qpL2y3KdLZl9OFK
Sim5tI1iYForaczDeEePtGbp+4vCdD+90Q0jG0Y1jGgYz+iSfkfx/+MYxjCM
Xxi9yE3rn36vzoiF8QojFUYpjFG0Tc+R9qE0LmFUwoiE0Yis9Gxp/0pjEF59
eO3hdUdGGv3iS9+v/wEHwQmG
       "]]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwV0tVuE2AYBuC/69wYMFw3fDBkgwROuAhugIRjYHeGu7vrtq7ede7uzsPB
m+ftm+9v0qR111qu3IyEEGLS1hTCrYshtPI223mHMd5lB+8xzvtM8GpjCEk+
8DnFh0zzETN8zCyfMMfoZd8nnfpTW57P2MXn7OYL9vAle1novkP69Fe2fr7m
AN9wkG85xHccZpH7uIzo722j/MAxfuQ4P3GCnznJYvcJmdK/2Kb5lTP8xll+
5xx/cJ4/ucDr3v3SF/XfXOIfLvMvV9jKVbZxjSXeJGVdb7dtMMbQ7PcywjgL
mGCUpe5TUqgnbUVMsZhpljDDUmZZxjL3aSnXc7YKdrKSeVaxi9Xs5iaWu89I
jd5j28xebmEft7KftRzgNg5yO294N6Tv0Ie5kyPcxVHu5hj3cJx7WeFNVvbp
E7b9nOQBTvEgp1nHGdaz0n1ODumztsOc4xHO8ygXeIyLPM6q//89OaEv2Rq4
zJNc4SmuspFrPM1q93k5o6/bznKD5xguhdDECJtZwPOM8gL/AT74r4k=
       "]], Line3DBox[CompressedData["
1:eJwV0mVyFFEUBtBHFe7uFtyCBZJMZOLuExcsOAkzSXCH4O62FfbBAnDYBef9
uHW+vnVvd9erlzWYSaUnhBC+qrycECYmQsjlJOZzMhOcwgJOZSGnsYjpZAjT
5WJ5BpOcyRLOYilns4xzWM4v2SFUcK7nSs5jFeezmgtYw4WsjXu+8U3VyYv0
6rmYDVzCRi5lE5exOb7b/HfVIi/Xa+UKtnElU1zFdq5mR/wP8z9Up7xGr4tr
2c0s9nAde7mefdzAfmbsbZQH5E08wM08yC08xK08zG08whE72+VBeQePMpvH
uJPHuYsnuJsn4xnZ+alOyXv0TnMvzzCHQ9zHYe7n2Xie5n+ptJyrl2EeR5jP
USY4xgKei2dv/rc6LxfqXWARL7KYl5jkZZbwCkt5laP2yuRrcjmvs4I3WMmb
rOItVvM2x+zUyHfkWo6zjndZz3ts4H028kG8C3b+qIdyk94jNvMxW/iErXzK
Nj6L98b8X/VcTum9YDtfsoOv2MnX7OKbeMfM/1Nv5W69d+zhe/byA/v4kf38
xAF+5n9ZTnTF
       "]], Line3DBox[CompressedData["
1:eJwV0dVSVlEYBuDlRThj4IE34IlHnngRnoOKXYCB3V0IKhbd3W0H2GIBdrek
LdaMzz745nn/b9a795r9j49PnJIwIoTQYzInhhA7KYQMxjGLU5nNaczhdOYy
nnlcOjmEGXK+PJMFnMVCzmYR57CYc1nCZTrz5FJ5Psu4gOVcyAouYiUTWMWR
E0KoZqLfNUxiLRezjktYH92HDRzlHb2mMXqfXROT2czlbOEKtnIl2zja+T5z
XF5ld4KreZJreIpreZrreIbreTZ6tt4G+Zy8kee5iRe4me3cwg5u5cXoHjrb
5Evydl7mDl7hTl7lLl7jbl6P7qyzR74h72UnU3iT+3iLqbzNNN7hGJ1+c1fe
b9fFA+zmQfYwnfd4iPc51vkB80A+bPeQR/iIR/mYx/iEGXzKTD6Lvqdelvxc
zuYL5vAlc/mKeXzNfL6JvrdOgfxWLuQ7FvE9i/mBJfzIUvZG/41Omdwnl7Of
FRxgJQdZxSFW8xNjdAbNZ7nG7gtr+ZV1/MZ6fmcDf3Cc80Pmp9xoN8wm/mIz
f7OFf9jKv2zjP/4HYMu7Lg==
       "]], Line3DBox[CompressedData["
1:eJwNzdVWVlEYhtH1091hUXZigAEodgeIYvcFqOd2XZQJiN2o2N0FArYgOA++
MZ+9xnjHLtmxq25nJITQ6vrKQjheEUIvTzCUh3CSEZ5iFE8zmmcYwz3VITTo
WN3IODYxnmeZwGYm8hyTuNfmvE7WF5jCi0zlJabxMtN5hRncZ3NVZ+przOJ1
ZvMGc3iTubzFPO4uDSGfLb778Tb78w4H8C4HspWDWOgfHa5A3/NWyPss4gMW
8yFL+IiD+ZhDuN/uiR6qn3IYn3E4n3MEX3AkX3IUD9i80qP1a47hG47lW47j
O5byPcfzoM0HPUF/5ER+4iR+Zhm/sJxtnMxDNu16iv7KqezgNHaygl2s5DdW
scim003X373N4A9W8ydn8hdn8Tdn8w/n8LDdXz1Xd3Meezif/7iAvVzIPi7i
EZtQGcJiHeESRnEpo7mMMVzOWK7gUZs4XaPjWcsErmQi65jEVUzmah6zSdH1
OpVrmMa1TOc6ZnA9M7mBxTZdbqPO8raJ2dzMHG5hLrcyj9uYz+38D1NGjCg=

       "]], Line3DBox[CompressedData["
1:eJwNzcVaFVAYhtHtXZgoBjYGqICK3QnYAXroOocOO+lGsbsVuzsZOfZ+XIP9
rPcffM+Oj8Qyo8NCCP+83OQQhqeFEOEI5nEk8zmKBRzNQo5hEZvSQ4jTxXos
SziOpYxnGceznBMYZbPNRB3Tk1jBBFZyMqs4hdWcyhq22EzTtXo66ziD9ZzJ
BiaykbN4iK02s/VhPYdHOJdHmcRjTOZxzuMJ/k0M4STnu09xAU8zhWeYyrNM
YxMXsplt/lqkW/RitjKdbVzCdi5lB5exk+02y3WXXsFurmQPV7GXq9nHNexn
h81afU6v43mu5wA38AI38iI38RI7bTbry3oLr3ArrzKD15jJ68ziDXbZbNM3
9Xbe4g7e5k7e4S7e5W7e4x7eZ7ftXv1A7+ND7ucjZvMxc/iEBzjIHpuD+qmO
8Blz+Zx5fMF8vmQBX7HXplC/1kV8w2K+ZQnfsZTvWcYP7LMp1x91lJ8Y42dW
8Asr+ZVV/MZ+m2r9XdfwB2v5k3X8xXr+ZgP/sJFD/A8Koo54
       "]], Line3DBox[CompressedData["
1:eJwV0NVSlWEYBeAPsbvFdtMY44mceOBFeAlegJ6rILZiK3a3gt2BikGHBXZj
t9IlPhysedZe837zz+zIjFnTZ0aFEKqkcEoIs6eGUMA5LOJcFjONJUxnKeex
jJFpIdRIuZ5hq+B83uUC3uNC3uciPmCs+1p5qC+2VXIJq7iUj7iMj7mcTxjn
vk6e6pm2Z1zB51zJF1zFl1zNV4x3Xy+v9TW2N1zLt1zHd1zPam7geya4b5AP
epbtIzfyEzfxMzfzC7fwK7fyG1Mnh/Cd2/z+we38yR38xZ38zV38w0TfaZS/
+m5bDfewlntZx32s5342MMl9U8c7/YCtiQfZzENs4WG28gjbmOy+Wf7pR23t
zGZIDSGHUTzGTjzOaKa4b5HO+glbF55kV55iN55md55hD55lT2Z5d07vpZ9n
b15gH15kX15iP15mf473plUG6FdsA3mVg5jLwbzGIbzOoZzgvk2G6TdsMczj
cN7kCN7iSN7mKE7s+B9ktH7HNob5HMsCjmMhIyxiLCe5b5c4vdgWzxImsJSJ
LGMSy5nMCqbwP5KdrYk=
       "]], Line3DBox[CompressedData["
1:eJwNzlVTVWEYhuFv09hdWFgHBpvaoKCgmICJ3QomKtiK3e2MJ4r/yu4u7ETF
lutgzfWsd+aetdIraytqIiGEG54hsRAuFYQwmJc5lFc4jFeZwWuM8jozeb5I
a2fZN5nNW8zhbebyDmO8yzxmaEJxCPn2PbfhvM8RfMACPmQhH3Eko5qIZpT9
2K2IT1jMpxzNZxzD5yxhpiZOM9Z+4TaODRzPl5zAV5zI15zELE28ptR+41bG
tyznO07me07hB07lR07jBe0ne7r9mTP4hRVs5Ex+5Sx+42yei4Ywh9+9z2UT
5/EH5/MnF/AXFzLbNxL83yL7t9ti/uES/uVS/uMy/udy5mgSNZV2KAyhihGu
YBxXMp6rmMDVzNUkadbYiW5rmcRqJnMdU7ieqdzAFqxhvbalXWu34ka25ia2
4Wa25Ra241Ze1LS3t9kduJ0duYOduJOdWccu3MWYJtk/7ra7uu1hN+5ld+5j
D+5nGg8wT5OiOWj3dDvEXjzM3jzCPjzKvjzGfE2q5rid7naC/XiS/XmKA3ia
A3mGg3iWzdZPiUc=
       "]], Line3DBox[CompressedData["
1:eJwV0tVWFWEAhuHfU/sWPLLFwgAFCzuxFRUJG7A7b8Au2i5UVFTs7i7sbkWM
O/CZg72ed/9rf7PXzJp6aTnJ2dVCCBU+q2JDqB8fwko24Go25Bo24lo25jo2
4XrmJoTQVG/QzbiRMdzE5tzMFsxlS+Yxz6aVztetWcBYFrINi9iWxWzHLZE2
1RND2KrbO9vGOG5nPHewA3eyI3dFv7OpYbNbJzjbw0TuZSfuY2eWsAv3R9e0
qWlzQHd1dpDdWMokHmJ3HmYPHmFPljHftpc+qnvzGPvwOPuynP14gv15kgU2
A/QpPZCnOYhnmMyzHMxzHMLzrIwJ4QKH+n6Rw3iJw3mZI3iFI3k1ej7+o5Z7
uqZHObvO0bzBFN7kGN7iWN6OnqVNbZs7epyzu0zlPY7nfabxAdP5kBl8xELb
TP1YT+ATTmQFJ/EpJ/MZp/A5i2ym6hd6Gl8yi6+YzdfM4RtO51sW28zQ7/RM
vucsfuBsfuQcfuJcfo7eDZs67uuLnufsK+fzGxfwOxfyBxfxZ/Tu2NS1qdSL
nf3iElZxKX9zGf9wOf9yBf/xP1CSoVM=
       "]], Line3DBox[CompressedData["
1:eJwV0GVWVVEAhuGNhQVK2IhitxiAinIBFWwQdQIOQOdgd3eCiond3R1YmKhz
sFuf8+Os5z17rW+de3fG9JllM+JCCDWeT1khzMoN4SNn8zPn8Avn8ivn8Rvn
8zvL80JYoH/ohfzJRfzFxfzNJfzDpfzLCptl+p9ezpAdwgrGcSXrcBXrcjXr
cYfNGl1fr2UDrmM817MhN7ARN7IxYzZJsRCa6E3OmnIzE7iFidzKZtzG5sy3
SbZJ0tudJbOcKaxgavRb2II72ZK72Cp6t63UrfVutuEetuVetuM+pnE/20db
mwM6XVexAw+yIw8xg4fZiUfYmZU2R3UXfYxdeZzdeILdeZI9eIo9WZQZQi+e
9t6bZ9iHZ9mX59iP59mfBb6R4h4y9QVnA3iRA3mJg3iZg3mFWbzK7Oi/217T
Ofo6h/AGh/Imh/EWc3mbw6N7srmjR+i7zOM9xnif+XzAAj5kYXSnNo/0SF3N
UXzM0XzCIj5lMZ9xTHT/Ns/1WF3DcXzB8XzJCXzFiXzNSSy0SXUXJfqNs1K+
5WTWsozvOIXvOZUfOI3/Abi2lnk=
       "]], Line3DBox[CompressedData["
1:eJwNzdVSEEAAhtHFLizELkTFFgsDBGd8Ay8sTFRssLtbULAVG1u61Qfx3u4u
VDDOxc75dmf+2Zi0zCkZESGEh860hBAeJYYwlY85nU84g085k8+YyuecxYLk
EF7o2fol5/AV5/I15/EN5/Mt01ho804v0O+5kB+4iB+Zzk9czM9cwiKbL3qp
/spl/Mbl/M4V/MGVrGUGi21+6kz9i6v4m6tZxzWs51r+4TpOtolOCWG9/utt
A/9xI0NSCJsYwc1swC1syK0ssW2kt+nG3M4m3MGm3Mlm3MXm3M1SmxZ6j27J
vWzFfYzkfrbmAbbhQZbZtNWHdDseZntmMYrZ7MAjjOZRltt01Dm6E3PZmcfY
hcfZlSfYjSeZHx/CKXZ3P80ePMOePMtePMfezGMMz7PCX330BR3Li+zLS+zH
y+zPK4zjVVbaDND5eiCvcRCvczBvcAhvcihvscpmmL6th/MO43mXI1jAkSzk
KBax2ma0LtZjWMIElnIsyziO5RzPCtbYTNCVOpFVTGI1J7KGybzHFN7nJD7g
f62Mlvc=
       "]], Line3DBox[CompressedData["
1:eJwV0dVSlVEABeCNrdhBo6JP4I3eODp2UyrYgV1go6Jid+vT2N2tKBYWdnfH
ty/OfOtfM+vs/+yTVVSSX5wQQqjw2dcxhG6dQ9jL7tzPHjzAnjzIXjzE3jwc
+y4hJHUN4YjcR3eUfXmM/Xic/XmCA3gyfodNss0peaDuNAfxDLN5ljk8x1ye
j+fZpNhckPN0F5nPSxzMyxzCKxzKq/F9bFJtrskFuussZAWH8QaH8yZHsDK+
u02azS15pO42R/EOR/Mux/Aex7KK43g//l7bdNsH8njdQxbxESfwMSeympP4
JN6NTYbNU3my7hmn8Dmn8gWn8SWn81W8R5tMm9fyDN0bzuRbzuI7FvM9S/gh
3rNNa5uP8mzdJ87hZ87lF87jV87nt/if2LSx+S4v0P3gQv5kKX9xEX9zMf9w
Cf8ysUMI/1jmOXQKYSkTuIw1uJw1Wc5azHZWW2fVllfo6nAl63IV63E163MN
GzDHJssmUV6ra8h1bMT1bMwNbMKNbMpcm3Y2zeRNuubczBbcwpbcylbcxiTm
2bS3SZa361K4g6ncyTTuYjp3M4N7mMn/BKyZEw==
       "]], Line3DBox[CompressedData["
1:eJwV0OVWlGEYhtHXE1FRuhQVUUSwG2PoMEDFAAG76yDs7sQWC7sbA8XuPgn3
/Ji173nWutb3zcRUN0TqO4QQ2nw6ZYWwLieEjlzPztzAGG5kF25iV25mLM/l
hrDFjrO3Mp7bmMDtTOQOJnEnkxnRxOaFkGLvckvlbqZxD9O5l924j91ZoInT
ZNj73XrwAHvyIHvxEDN5mL1ZqInXZNlH3PrwKPuyidk8xn48zhwWaRI0/e0T
brk8yTye4gCe5kCe4SCe5WCe1zbbQ6L/C4dGbxzGCxzOixzBSxzJYk2i542y
W9xG8zLH8ArzeZVjeY3jWKJJ0oy3r7tN4A1GeJMFvMVC3mYRSzXJmmL7jlsJ
77KU91jG+yznA1awTJOiqbQfuk3kI07iY07mE07hU1axldXR36t9Zk+1n3Ma
X3A6X7KGbZzBV5zJmowQZvG177PZzlq+YR3fcg7fsZ7lnpHq/Rrs926N/MC5
/Mh5/MT5/MwFrNCkaRbaX9wW8SsX8xuX8DuX8geXsVKTrllu/3RbwV9cyd9c
xT9czb9cw39cy//Wu5sP
       "]], Line3DBox[CompressedData["
1:eJwV0VVTlGEch+EHu7t7xcDEJQ3C4gtwLip6LN/B7m7F7kZFpcXuxlbMM7tb
Lw92rvv9z/xmd+eN5OZlT4oJIVT5TEkN4VVaCJP5mlP5htP4ltP5jjP4njNZ
nBHCBz1Lf+RsfuIcfuZcfuE8fuV8lth80wv0dy7kDy7iTy7mLy7hby7lGJv4
zBCW6T9uy/mXKxjSQ1jJGK5iDa5mjs0gmzW6ptta1mI+a3Md63A963IDx9pE
bTbqem6bWJ+b2YBb2JBb2Yjb2JjbWWrbRO/QTbmTzbiLzbmbLbiHLbmXZTat
9D7dmvvZhgfYlgVsx4Nsz0McZ5PgNx7WHdwK2ZFH2IlH2ZnH2IVFHG+TaFOs
u7qVsBtLGWEZu7Ocsaxgrk2SzXHdw62SPXmCvXiSvXmKcTzNPjzDctu++qzu
x3Psz/McwAscyIuM5yVW/H9f+rKO8goTeJWJvMYkXmcyb7AyGsJNpni+xVRW
cTBvcwjvcCjvcoLvSPaf7ulhbveZxgdM50Nm8BEz+ZgTbVJsqvVwtyccwacc
yWccxecczRfM4kv+Aw7tn28=
       "]], Line3DBox[CompressedData["
1:eJwV0PVW03Ecx+EvqNhiJyoodmNsgIBB29itKCoG2Nhid3fHldh6A96C3Ynt
sz92ntc+Z++z/ZZSWllSERdCeOr1PBJCflYIz1jAFyzkSxbxFYv5mmP4hney
Qxir3+pxfMfxfM8J/MCJ/MhJ/MS7NiX6s57ML5zCr5zKb5zG75zOGt6zmaF/
6Jn8yVn8xdn8zTn8w7n8yzKbSE4I//Q8txANYT7juIDxXMhaLGVtLrGJ2tTR
i9wSuJh1WcZ6sc+wPpeyAZexIe/blutGejkbcwWbcCUTuYpNWcFmfGBTqZvr
1WzBNWzJtWzFdWzN9WzDhzYbdFu9ke1YxfbcxA7czCRuYcfYb7VJ91yd9Fa3
ztzGZG5nCnewC3eya+y5bDJsUnW1WzfuYnfuZg/uYU/uZS/uY28+st2v++gD
7MuD7MdD7M/DHMAjHMjHNkf1IH2MaTzOwTzBITzJoTzFYXxic1pH9BlGeZbp
PMcMnmcmL3A4k9JCyOJF77N5iTm8zBG8wpG8ylEs9x2Z/ofR+ppbLq8zjzeY
z5ss4C0W8jaL+B81LIq7
       "]], Line3DBox[CompressedData["
1:eJwV0tVWVVEAhtGFb+IreOWF6L2J2AIGigEKNtiNhd0dhKTd3Y2F2N2d2Bhz
XZwxv7PP+PfYa4/TMD0nOTshhFDr06JxCIWJITRnEVuymK1YwtbcyDYsZRLP
Ng2hTLfV5UxmBduxku1ZxQ7cxI48Z7NZd9Jb2Jlb2YXb2JXbmcIdTOV5m506
Te9iN+5md+5hD+5lT+5jOi/Y7Ne99AH25kFm8BD78DD78gj7MdOmSbMQ+uuj
rmXyGLN4nAN4ggN5ktk8xRxW257Wg/QZDo7vh0PimTk0noPD4rNxOC/aVOsR
sZnLS8zjZY7kFY7iVY6Ov9vU6DH6GseyluN4neN5gxN4kxPjvWxu6Un6Nifz
DqfwLqfyHvN5n9OYZZPoXUzXD1ybwYecyUecxccs4BPO5lPOic9s+0zP1c85
jy84ny+5gK+4kK+5KJ7P5o1erN9yCd9xKd9zGT9wOT9yBWtsPumV+jNX8QtX
s45r+JVr+Y3r4juz+a7X6x/cwJ8s5C8W8TeLWc8S5jby3+cf30v5l2X8x3IG
96xgAivZgFX8DxU5uwE=
       "]]}, 
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwVzTdwCGAYx+E3OoseLIgeJJJoC4lu0OugCwYt0Qa93un9Tolu0OuAEPVO
rwvRLXpb9LZ4Mnz3/O7e+9+XlJ3bNychIgq95IYRJVMiGrMKu7IuBzKDY9ie
09ibizic65nD3ZzD41zJi9zKezzIFzzDnMyIz/qG/sdHLNco4i1r8AcbsURq
RGtW5lSbLrqOHsB0jma7oht7cSGHcR0ncpbNLj1bH+MKXuAW3uUBPudpfuJ1
Lrb5qx/qsskRb1id39mQxZtFtGIldmYS+/ObXZoepbM4hT25gEO5lhO4k7N4
lMu5we68ztN3uJ/PmM+PvMY/LGSZxhGvmWdTTX/TDVgsLaIlK7ITa7MfmzGb
mdxlM1n30PM5hGs4njs4k0e4jOe4mQdtbut9+ilP8QOv8jcfsHSTiFdM5FfW
Z2JWREJ6RAtdgR1Zi32ZypFsy0nsznkczHz/rdbj9HbO4GEu5Vlu4i3u5ROe
ZIHNe31F/+J9lmoa8ZJV+YX1GBkRzVmel2w66Jq6D1M4gm2Yy26cy0FcxbG8
abNNT9eHuIQF3Fh04x4+5gm+42X+5H86rZIJ
       "]], Line3DBox[CompressedData["
1:eJwVzzVskFEYhtEPtwUvsODQ0lLBF1wHtNiA64C06AAUJ8F9AIozYEUHtGiC
60JxWHBboDgDp8Of8yQ3b+5/647OzswqFhEFvuTGEaWbRqSwGnuwAQezOcez
E2eyH5ewoF3ESL1RZ3MP5/E4V/MSt/E+8/iSZ/mFN/mPj1khMeIda/EHk1gq
NaINq3KGe7rr+noQm3EcOxadsS8XcwQ3MIs5Nrv1XH2Mq3iRW3mPB/mCZ/iZ
N7jU5q9+pMsnRbxlTX5nIkumRbRmFXZjPQ5koV2GHqs7cDr7cBGHcz0ncxdz
eJTRPmKlvqBzeZcH+Jyn+YnX+YcPWa5JxBvmuquGLtSNWSI9ohUrsyvrcgDT
OYbtudtmmu6tF3IY13ESd3IOj3AFz3ML82zu6P36GU/xI6/xNwtYNjniNRP4
jY2Y4F3FMyJa6krswjrszzSOZjtOZS8uYAOboXqtnsgdnM3DXM5z3Mzb3Men
PMl8//hBX9W/+IBlUiJesTq/siGLNYtowYq8bNNZ19aZTOUotuUU9uR8DuEa
TuAtm+16lj7EZcznpqIz7uUTnuB7XuFP/gdKXpIe
       "]], Line3DBox[CompressedData["
1:eJwVzzVskFEYhtEP1wUvsGClAm0pzlLcBqzogOuA6wAUJ8F9wKUMWNEB9wTX
heIQEtwWKE7CYbg5T/LnzX9vzaHjs8cVioh7TlpSRIm0iHRWZmcmsh8bcxTb
chqzuZD5WRFD9Do9gTs5m0e4ghe4hXeZx+d8YXNKf9bX+ZcPWTY54i2r8ztT
WTw9ogUrsRPrsC8bcSTbcCp7cAEHcy3HM8d/cvUsfZjLeZ6beYf7+Iwn+YnX
uMjmj36gy6REvGE1fmMKi2VENGdFdmRt9mGBXUM9QrfmFHbnfA7iGo7jDubw
EAu1jFimz+lNvM29fMoT/Mir/M37LJ3q2LzWVXUBk1m0QUQzVmAH1mJvZnI4
WzHX/SbrbnoeB3I1x3I7Z/Igl/IsNzLP5pbeo5/wOD/wCn8xn6XqRbxiAr8y
iQnuWCQzoqkuz/asyV5swGFsyUnsyrlMtBmgV+kx3MYZPMAlPMMNvMndfMwM
m2P6vb7Mn7zHkvUjXrIKv7AuCzeMaMJyvOhd7XQN3ZMZHMosTmQXzmF/ruRo
3rDZqqfr/VzM01z//xt38RGP8h0v8Qf/AaPbkkU=
       "]], Line3DBox[CompressedData["
1:eJwV0DVskFEYhtEP9wHXBWtLi7RFCgwUtwEpPmBFB1wHXBPcB1wHXAdcB1wH
KA4hwW2B4oTDcHOe5M+bm/9WzR6dNSpPRNx16iVGFK4Tkcry7MgE9mFDDmdr
TmY3zmdOs4hsvUaP5Q7O5BEu4wVu4h3u43O+sDmlP+tr/MuHLJEU8ZZV+J0p
LFQ3oinf2ZTTHXRN9mYDDmMrTmIW53EgV3MMt3MGD3Mpz3Mjb3Mvn/EkP/Eq
F7jnj36gi9eKeMPK/MZkFqwX0YRl2Z412Iu5dvX1UN2SE9mVczmAqzia2zid
h5g3M2KJPqc38Bb38ClP8COv8Dfvs1iyY/NaV9K5rMUCqRGNWYbtWJ09mc4h
LGnTQk/QXTiH/bmSo7iV03iQi3mW67nPP93Uu/UTHucHXuYv5rBoSsQrVuRX
JrGi+/KnRWTo0mzLauzBNA5mc45nZ85mgk0/vUKP5BZO5QEu4hmu4w3u4mOm
2hzT7/Ul/uQ9Fqkd8ZIV+IWJzJce0YgZNqV0G12V3ZnKQczkOHbiLPblco7g
dW+xWU/R+7mQp7n2/zfu5CMe5Tte5A/+AzCzkmw=
       "]], Line3DBox[CompressedData["
1:eJwVzTVsEFAUhtFLcB1wCgxoKd5iRYI7A64DrgMtDgOuA64DrgOuA64Drgmh
OIQEK9IFisNhuDnf8r9XYWh6j7QcEXHfJSdG5K8VkcLS7MJEDmBDjmE7TmMv
LmJG84hhep2ewF2cw2NcwUvcwns8wJd8ZXNGZ+kb/MvHLFIt4j3L8ztrMl/t
iKbMtCmlO+uq7M8GHM22nMqeXMihXMssm/F6p57No1zOi9zMu9zPFzzNz7zO
P3zEwkkR71iO31iDeetENGFJdmIV9mO2v+rrUboNp7AHF3AI13Acd3AWjzBn
i4hl+oLexDvcx+c8xU+8xt98yELVnc1bXVZnszrz1I1ozBLsyMrsy3ocyaI2
rfVk3Z3zOZirmc7tnMnDXMrz/9+y2ahv6718xpP8yKv8xQwWrBHxhgn8yiQm
2OZOjkjVxdmBldiHKRzBVpzEbpzHRJtBepVO4zbO4CEu4Tlu4C3u4VMm25zQ
H/QV/uQDFqgZ8Zpl+IXVmCslohFTbYrp9roiezOZw9mSE9mVczmQK9nMZqze
qqfzIBfzLNfzJnfzCY8zk5f5g/8AtXCSgQ==
       "]], Line3DBox[CompressedData["
1:eJwVzTVsEFAUhtHLgNuCF0gIUlqcFicQXAcoDgOuIS1WZKC4hOBSBlwHXBOk
aBlwDQluC24Lbofh5XzJy59baUhGWnqeiLjrpSRGFKoVkcqy7MrqHMBGHMP2
nMZeXMhhHNsiYq2eqHdyNo9yBS9wM+9wP1/wNDNsPutrOqpHPGJxvmVF/mAt
Fqwd0ZxlmGnTRSfq/mzI0WzHqezJBRzKbE5gls0OPUsf4XLmchNvcx+f8xQ/
8SoX2fzVD3WxpIg3rMDvrMkCdSKasTQ7sxr7sQFHsS2nsAfncwjXcDy3cyYP
cxmz3TqvN+pb3MtnzOFHXuEfPmDR5IjXXGdTXn/TNZi/bkRTlmInVmVfpnIk
23CbzWSdpudxMFdz3P8/zuAhLuU5buA+m5t6j37Kk/zAy/zN+yxSI+IVE/iV
yUxoGZGvXkQTXZIdWYV9mMIRbM1MdudcDuIx91bpDL2VWTzIJTzL9bzB3XzC
E8yxea8v6V+8x8I1I16yHL8wiXnrRzRmCebadNCVdW/W53C24iR24xwO5Eqm
85rNFj1dH+BinuE6XucuPuZxvuNF/uQ/FmmUkw==
       "]], Line3DBox[CompressedData["
1:eJwVzjVsEEAYhuG/C24LbiFBSmmLtjgkuA64DlAcEpwiA64huA7FbUCKD0DR
MuA+FJcFt4XiPAyX500uX+6qZUzoOT4hIh44abUiiqZEpLMCu7M2B7MJx7Ej
Z7EvlzGvVcQIvVlP5T4u4Emu5WXu4H0e5iue40S7r/qmTkiMeMJSfM+q/MlU
FkmNaMnyzLTpphP1IDbmWHbgTPbhUg7nJk7hHJu9er4+wTXM5XbeYzZf8iy/
8AaX20TtiMe6JN+xCn8whYXrRrRgOXZlLQ5kvl26HqPbcwZ7cwmHcSMncw/n
8ThX8xK38S4P8QVz+JnX+ZePWCIp4i2zvFNZf9fJLFQvojnLsgtrcgDTOJrt
uNtmuu6lFzODGzjp/x3n8hhX8SK3Mtvmjj6on/MMP/Ea//Ahi9eJeMNKzGcd
VmodUbB+RDNdhp1Zg/3ZiKPYlpnsyUVMtBmq1+uJ3MU5PMqVvMAtvM0DfMbT
zPHHj/qq/s08FkuOeM2K/MYkFmgQ0ZSlmWvTSVfX/diQI9mG09iDCzmE6ziB
N2126tn6CFfwPLN4i/v5lKf4gVf4i/8A6Q+UqA==
       "]], Line3DBox[CompressedData["
1:eJwVzzVsEEAYhuG/hAS3BS8yAC01aICiZcB1wHWguAR3BlxDcB1wHZDiAy5l
wIouxWXBbcHhYbg8b3L5kruaOeO6jU2IiAdOVp2IkmkRjVmFXVmXA9mEY9ie
s9iby1iQHTFMb9ZTuJ8LeIpreZU7+YBH+IqvbC7orzqfhZIinrAc37MGfzGD
JdIjslmZ0+y66GQ9gI05mu04k724lEO5iZM5x2afnq9Pcg3zuIP3mcuXPM8v
vMXlNgnJEY91Wb5jdf5kOotnRLRgJXZmEvvzu12WHqXbcgZ7cgmHcCMncS/n
8QQLt4xYra/o7bzHw3zBc/zMm4y6EY9Yhm9ZjT+YxmL1IpqzIjuxDvuxEUey
Dfd423TdQy/mYG7gxP93nMvjXMXL3MZcm7v6kH7Os/zEG/zLhyydEvGGifzO
VCb6U9H6Ec10BXZkbfZlQ45ga05jdy5isk2OXq8ncDfn8BhX8hK38g4P8hkz
bc7oj/o6/7CApVIjXrMqvzGFRTIjmrI88/yrg66l+7ABh7MVp7IbF3IQ13E8
82126dn6KFfwIrfwNg/wKU/zA6/xN/8Bc4yT0A==
       "]], Line3DBox[CompressedData["
1:eJwN0DVsEEAYhuG/EBKs2IJLFwottAWCtNiCa4L7UNyD60BxCcF1wHVAig+4
DliRsuDSBYqzUPQZLs+7fMndJWVP7jUpISLynczkiMSGEVmswZ5M5TBmcSI7
cz4HcBWftokYrbfrmTzMJTzHjbzFvXzCEyxggc0V/UPnsXi9iJesxE9M4h9m
sGxaRFsW2lTXPXQKhzKTE9iJ89ifKzmK2ziDOXaH9GJ9lht4k3uYz1y+42V+
532utilWP+KFrsiPrMPfTGeZ9Ig2rMburM8hLLJrocfrjpzLflzBkdzK6TzI
RTzDEm0j1usbejcf8zjf8hK/8R4TUiKeswITbQp1bf2LaSydEdGaVdmN9TiY
zTmOHTiHfbmcI7iF03iAC3ma63idu5jrPY/0Mf2GF/mVdxmpEc9Ynh9Yi0Vs
yFruV6pRRCtdhV2ZzEFsxrFsz9nsw2VMsRmuN+up3M8cnuJaXuNOPuRRvmYT
mwv6i77Df3zKcg0i3rMmf7IBSzaOaMlMm8q6i67LgWzKMWzHWezNpczmJk5h
nr/Ypxfok1zDq9zBBzzCVzzPz7zNv/wP0A2S+A==
       "]], Line3DBox[CompressedData["
1:eJwN0jVsEFAUhtFbICS4dMFtaamXEKy0sOAagmuCOwmuA64huA64DrgOuA44
FBZcukCBIgvFzvByvuXPW279oZN6TEyIiHwvJymiYnpES9Zmd6ZxCHM4kR05
j/24is/zIkbr7XoGD3MJz3Mjb3Mvn/EkC1hgc1X/1A9ZKjniNRP5hQ34l9ms
kBHRmoU2tXQ3ncrBbMEJ7MC57MuVHMVtLLKZrg/pxTzHDbzFPXzKE/zAK/zB
B1xtV7JhxCtdlZ9Zn3+YxfKZEa1Yk12ZwkEstmuux+v2nMM+XMGR3MppPMhF
PMvSrSLW65t6N/N5nO95md95nyVSIl6yCivaFOp6+jczWS4rIo812IUNOZDN
OI6JNu30bN2byzmCWziVB7iQZ7iON7iLT3iM73iJ33iPCakRL1iZn1iXxcxg
XX+VzY7I1dXZmckcwKYcy7acxV5cxlSb4XqznsL9XMDTXMvr3MnHPMq3bGxz
URfpu4w098hK/Mg6/MV0lmnkrtnCpprupJPYn004hm04kz25lMO4ibk2k/U+
PZ+nuIbXuIOPeIRveIFfeYf/+B/CKZIO
       "]], Line3DBox[CompressedData["
1:eJwN0jVsEFAUhtFbZMFtwSkMlEKpLLgtuCe4huDQNgQrOhS3ELRogusAFC1D
8QIDUqDAgtuC24Ke4eV8y5+33MQx2f2zEiKixGvXOKJySkR71mM/pnA02zKb
PbiQQ7mGk5jZPmKHztFHuYznuZk3uZ+PeYrveIXTbH7qe7psUsQL1uBnNuI/
ZrBS84hOrMscm766mR7FNsxidy7gEK7mRG7nbObaHNFLdQE38Qb38RFP8i0v
8weLudamTJOI57o6P7Eh/zKdFVMjOrIO+7ApR7I1N9pm6m56PgdzFSdwG2fx
MJfwHDcyz+a63qsfMp9veInfeZelkyOesRo/cqdNov6j01ghLaIDa7M3kzmC
rTiVXXnAZp4epFdyPLdyJg9xMc9yA4u4h/k2JfqEfs2L/MY7LNU04imr8gMb
8DdTWT7dHbEWe7EJh7Mlp7AL53IgV3AcC/y1Rc/QB7mIZ7ie17ibD3icr3iB
hTZf9W2d0CziCavwPevzF5uzXIb7Zk0W2fTUSXoYW3AyO3MOB3A5xzKP01ls
c0Dn6tNcx6vcxfs8xpcs5BfeYrjh/8z4lCA=
       "]], Line3DBox[CompressedData["
1:eJwN0jVsEEAYhuG/2ILbghZJoF5gQYssuHXAPcE1BCs64BqCFk3QYgNQnKF4
gQEpFBlwXXBbsGe4PO/yJZfc1RsxOXtSQkQUO20bRVRKi2jHusxmOoezDaew
GxdwINfwSVbEOL1D5/AIl/E8N/Mm9/MxT/I9r3Cq3S99T5dpHPGS1fmFDRnp
Ec1YkR1Yhzk2vXWaHsbWnMyunM8BXM2x3M5ZXGhzWC/V57iJN7iPj3iC73iZ
P1nEtTalkyJe6Gr8zAb8x6askBHRnrXZi6kcyt92rfQk3YXz2J+rOIbbOJOH
uIRnuZG5dtf1Xv2Q+XzLS/zBuyyVHPGcVfmJO23q67+6CctnejfWYk+mcAhb
ciI7M89mru6nV3I0t3IGD3Ixz3ADC7mH+TYP9HH9hhf5nXdYMiXiGavwI+vx
DzOZ2DaiXBN/StdkDyZzMFtwAjtxDvtyBUdxC6fzABfxNNfzGnezmMf4mhdY
4H7f9G1dIjXiKSvzAxP5mxks2zQiizVYaNNdJ+lBbM7x7MjZ7MPlHMlcTmOR
TZ5eqE9xHa9yF+/zKF+xgF95iwn+8n8g+ZQ1
       "]], Line3DBox[CompressedData["
1:eJwN0jVskFEYhtGvWBfcFrRIgCoFFhzKgksZcOuA08KA61DcQnBP0GIDUJwB
p8CAFhtwKCy4LcgZbs6zvPlzc/+knLzs3ISIKHY6N4mokhaRxfrszwzmsAOn
sBcXcChX81mHiAl6h57FI1zK89zEW9zPpzzJDyyxuap/6wdMbBrxmjX5lY2Z
kB7RipXZhfU4yy5bp+tRbM/J7Mn5HMJVHM/tnMl8m8N6iT7HjbzJfXzCE3zP
K/zF+1xjU65ZxCtdg1/YiJER0ZKVmMW67Mc0juQfu3Y6T/fgPA7mSo7jNs7g
IS7mWSZ2jNigb+i9fMxClvAyf/IeyyZHvGR1fuZO32qo/+kWrNjc+7EO+zKV
I9iWuezOApu5epBewbHcyuk8yEU8w/Us4h4W2jzSx/U7XuIP3mWZlIgXrMZP
bMC/zGSSe1XIjOika7MPUzicbTiJ3TiHA7mcqTZj9BY9jQe4kKe5jte5mw95
jG95kd95h6VTI56zKj8yiX/YnOVbRHRkLRa5U2+drIexNSeyK2dzAJdxNDdz
Ku/bFOh8fYpreY27WMyjfMML/MbbLOVf/g8qf5Nd
       "]], Line3DBox[CompressedData["
1:eJwV0jVskFEYhtGv+ILbgjvUCyxYgbLgUBhwHfAiA64DriG4DmixASjOgOuA
tOiAQ2HAdSkchpvz5E/e5ObmrztiYnZOQkQUOFmNIyolR3RiXfZlGkcyk1PY
gws4mGv4rF3EeL1Tz+IRLuN5buZt7udTnuQHFtpc1X90Acs0iXjN6vzGRiyW
EtGSFdmJH23q6D46lSPYjpPZnfM5iKs5jjs4kwvtDuul+hw38Rb38QlP8D2v
8DfzudamdNOIV7oav7IhE1IjWrACs1ib2UzhcBbZtdWTdDfO40Cu4lhu5wwe
4hKeZZnMiI36pt7Lx8xjIS/zF++zVLOIl6zK8jZfdAMdaRHN/39jR9ZibyZz
GNtwIrsy1/3m6gF6JcdwG6fzIBfzDDfwBvcwz+aRPq7f8RJ/8h5LJka8YBV+
Zn3+ZQbruWO59IgOuiZ7MYlD2Zo57MI57M8VTLYZrbfqaTzARTzN9bzO3XzI
Y3zLljYX9Q99lyWSIp6zMj+xHouYzrIZEe1Zgz2ZyCFsxQnszNnsx+UcxS2c
ynzvkKsX6lNcx2vcxQc8yje8wO+8w+L+5X/2wZKF
       "]], Line3DBox[CompressedData["
1:eJwV0jVskFEYhtEPpwtuC1IKFKsCXZDiA06BAdcBbZEB1wHXEFwHXAegOAOu
A1J8wKEw4LrAYfhzntzkzc2f3MRheTm5RSKiwNchOaJiSkRH1mYfZnAEW3MS
u3MeB3EVn7WKGKe36xk8zCU8x428xb18yhP8wEKbK/qPvs+E+hGvWY3fmMxi
qRFZrMAO/GiTqHvrdA5nNieyG+dyIFdyLLfxi810fUgv5llu4E3u4RMe53te
5m8WcLVd6QYRr3RVfmU9Fk2LaMbybM9a7MU0DuNfu1Z6gu7KORzAFRzDrZzG
g1zEM0zIjlivb+jdfMx8FvISf/EeSzWMeMkqLGfzRdfVRdIjmv4/YzvWZA5T
OZQtOZ6VbLro2bo/l3M0t3AqD3AhT3Mdr3MX8/3TI31Mv+NF/uRdlmwU8YKV
+Zl1GBkRTZjkvrK6ra7BnkzhELZgHjtzFvtxGVNtRunNegr3cwFPcS2vcScf
8ijfMsvmgv6h77BE44jnrMRPTOJfZrJMZkQbNreprnvoxhz8/4y57MSZ7Mul
HMlNnMx9nM+TXMOr3MEHPMI3PM/vvM3i3vI/ZCmRmw==
       "]]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJxknXc8V98fx2UUJVEolZGRKLM0cD9WCBVJUSgrUWaF7JGVlT2ydyJ7ZNxr
S0ZmRYmIJrKiKH7f+nzuOf369M/n4fk933PPPfd9zn193u/3eX/2GFlrXqGk
oKBAZCgoqP77XL/2+1+jFP5J8effjMy9X6yBXIRd2O3va2siEw8Imou///tX
GSr70kDuInFMYnVtzd0tlvDgF5FfavNbc6yQwmh//1lwj0Ds76vMQNKljvR6
OSzjT/e+BDcSP3lvSVNcWBEb+P2njCehnMTP2hkIn3uvjA3+/nPEidBL4vNd
CXzyEyrY1O8/L9sRxkl8MoNqFzdBDfszPE5bwjSJC58o2Tc1QuJr1wgLJN61
/eSl63Vq2MrvP92vEL6TOPbZ9aj9d1Vs9c94DAk/SXzLMzbv4McqRL52kbBK
4imLA/1t1CewP3+unQP8PP2Pl04rikTurgE453mu7spHChhxfk8Q8HlWiYjc
qCErR+KKgFtqvFgn7o+QuDTgNx29mY9WHyVxCcBtQmfqFJUPkfgBwOW/aRwQ
EBclcW7AZx/amzJuFyDxHYAnODGebBzgJnFGwH/siw65ab6LxKkBbyxMEj/N
uY3EZxCc99trS0pb05H4OODyBe7BrCNr6L98wrCzQSNrjsS7AX8os6Hvcts7
Em8A/K7npUoKk14SzwBc+5SATuFANYmHAs6rLcrorJZI4hqAt9F1hRnlmJM4
L+Ay0hWEGfrwyv/+YGY1KzyG8/v5UwkbvxmR2u0A7e9vdW65N3SP9Lcs4Nk9
wcPnVLJIfxvA676NnrJwLSP97Q+42kmCZ15FHelvCg+cby17w747tYXEU1Cc
P0k4Tclh0U7GS8NpnFnOPCPrJ0wpjf7mIM4LQXunMMOSrpQOEq8DvAAxHYg0
aiVx+Fw+toa2ZrTU4+0BP+62a6rJrJT091vAtXg+Mlk9DiRrPyic8vCIzkP0
X26p0vxh6gD+HKGduAjSitLWNOJ2AsYpMfT03K75J3g/gItv9QwY//GUjM+4
GVy4I9FGdt01Ky+v8clWMt5s+ph2zqKFxAsBL9aZlm0l4OOB8/zhndSQ+RJG
1v78cP6m7xEVZO0tZn23GFXizwPa7fcGhRLW+kyy9kfragSUkuLIeIfCDIfW
6QAyfjJr22fZTjsSlwXz8EvPKWXupw7pb1HAD451X5es5SfrJ2an3AXniSO/
14XBdjMbsC4aPxjfuHUdXz/fpXH+8y3zp3ZLTTI7TBepOBWYcJ3E4Xr0SXP6
5G7lQta+Pau2OrTbj8Q9QPvEB0NV3wTCyHjaZ2GXlt3RZP0cKLjq6rn3PhmP
Xr1GmZqQQLaOvnH2V7/5lUDW/q6ImZ8yZzzeHlw3fs8biogl8uuepqhIrFuH
P1e47oQiVswU8r3I1pdzwt4erUlNsvZfxVIjRulcyJ7LxvNfwkxLAtF/23P8
snyvZBxBZof3NG5M/HgYQ2bnWvbBiK3QffTfeditq/Vd1xJw0D5zYtWAoTeW
rH/dHrVGmwPRZPbsQnndXCE/nIzvVL/x5qZfMIl7wOvO2X556OFDdr9rXrVM
wnKuJO4P2n80+aUclW9L1n6zVBTSlW1ExlGUSUXhuTrZe+Gta1G3YpU4iTMC
3nPJgL5NlZLE3wI7n59Sptt9gvG/9eDhRLj78ijOcf2E6ylcR+149GtS3+4U
Af/EdcL+7QdM530asCUrM5WxPb2EG4arf/jrB8q3Fs/GYVc/MDaphBURDn8m
tn9d+uhGxcs7GM09hSeKESkErRUit2GV12RetcNOHt05WdMeQbi4SuSZbGi6
fLwldk1lMi3SNIBwnHTdz5mMF0uum2IrrxT4J8u8CGkkHm+7cYO+ohHWkMKR
IuLpTOggcWOpIwcn2S5jUj8/xrsl3SKMkXj4RWbLvYy6WIvJbPjun1ZAjx07
cHJA+qU2FtLYkbpicZWwSOIOWTriWzedwwxWxnXOLhoSlkn8q9zj6vW3NTEm
R20a19mLQI+FH3t0hGuLBrbfcNTXWlcLzJsJK2uYZY4adup7L+HtVzifEcbD
C3weyliSk0F4+cJxoFvM/bhKw0MVsAYmTVX+uwTAv91tvWZNK4s95UrmSX0F
9RUXGqIxUn6M1F4Y8PaQCPZ2vkPYgT/j4QX8nOVhx729wpjaNt2XBkFQX0mE
drF/79mLXW/u59dE6QF/oLJvk7M2F/ac2cTk/j1KwHsW6522+rFibq3v5Zob
ob6yF6CyX4neTOpnCPBSvRdlUhqUJN4B20/48n6i/IYqC7+zHt1XAris0IEw
dHiCxCPAOiquc9o8X9qHHtrfc86KOxnws7PrqRO31KDMf57LfcDlTkWcCEyO
RUs7117lXvUBPPzpae+2w8rSx+WoX3l1KoD18sqaalc7HRtKafyJviXXHI7z
nFCcLDVPzfXH2Os7VCKgPetiY5H0vkDEoTLOTO2GI+gf11dplwd+SOgEAO6m
9fRrsG85YvzHrsIAl7RQZRR/X48Q5ycIcNNXsgNH9XGdA/eHZLaknMj4TlL7
BND+uDEHZYRRN0Kct3Qw/ss0k4XKyTiH86zN5BnD9/oZWXuFM9+aRjqeknGa
OtGHY/sakX+fY1vPnNV6QhmJ1wBeGfddeJU1gIz7XFZ93hyQS/bcac95nHu0
CyPxRsAT1EoRi+PN6L/9jJ93117ue4r3A+1BKVvYu6edrP/T7jQvL+/qINtv
qWm+2tGXtJHap4N+IgP1zv/Wb//Og7Bc1iY3jSbSePIA9+jOnovWryO1vwPn
2f/6Yd+Wx2TXldLv+CBtXURm58q3tgYgd7JI/bvA8TxJXKGTuE/iFoCP2Yx8
aN4bQOrHGPC5PaFOX91vkfhZwPWi9TKbas+iVcpGzvsaFADn5xE285/9JRWz
VUyu+u4s+N5tMm31bG26pebqW7263gv84L7iFDRE9ojOV5+53Wuf+XIVtBf+
kfVm0uUU4hf+grEpQAr0v4GvZLcM7TVk8MfrdrZ5bcBDZUx3DKi7IP+O867e
8YVMFn/k3/s9mXyFWig1jNTeGIznTOU7k6Dn5DpnnaX/ZTeGeFL7m1BHreuk
n2xIJGsfk2hVVztCzpO5lO9JruL93AH9LEQUHtC2i0H+fY5tPZ6uSvZhZP3g
+urf9k+qIyPFy5RI81MBuGLhD82knc5kdpJ5TJhXICiYzK6yksXDbm6NJLNb
Y+/12u1hsWTtF1/2iySoxqP/3lftEg/dyGlyHtQ2GJhAfZ+Mp4UVntCaikb/
nWcCa+Ojsf/GTdrfwHiqy5UaDzKEkI1HdDa0Kfm7D5k9x6p9dFcNdSWzZ9TF
xn/LA3J9ZRMsnqrMZURqD+28F1kUeq5yijSeA4DvF1i+cJ5eCCXu2zsBP/R1
/ElWR4dU0TJH8sQzI2DnoZlUfRrHYmqI/VOB+8L9ULhfCvdH4foJ11O4jgq8
9bZO9qoLAf9MwP0/25a/0wW/wcS7HMw17CYIn02+/eFlQou/YkeLsCb7c+mX
deoIkjnE9tb98/vva8VhCcFKEdS+Dwkec0TO3Wm3fcT9Lua47inHmG0C4dBP
Iqcx6/SlPuCOOTuMs1xxCCOEk/RYhu0XH1oXO4y//PQyyu1HuEQaTwWnkZEQ
tQ2mOvf5Wv1mD0Ihidt/UZpi3m2OFb6rH+dqsye8IPGYpJd1NKom2Ojehs06
N2wIn0l8E491r1iVAabmEzadXHkV+MF+5RaPJrXrYsw0v36+UzEEfrCtZ895
X+DSxgIfBQjRDOoA3eWxMSf76J6zWGu+gcpgzRmgr/YILT/dZq2OBf1pfwJw
5jfHtM95q2CeWzWuFubIAT0TOm5Us2B8HNOVYa/zPHgE8IwhHV4BSlns+1ZH
1X1/6asZyWFN+sijmIngnj0CDTxQj1W2n462EcfoP3nQO2RtBxw956yx6YMg
duBiY+TO+Q2AK9DPSyMz3Jil9IlMw6DvwH6ox50uZ/uzYVn0WWI2utDPsHuc
tee2NSOpnwrAd/xS/tT+gorUvgnY7cbTp2baqBbRfI7Osgd8TwHP9zmyObJo
AvWJN87pYIDtQ8Xubbv4sAelXHXJ7dpeDXjTZhfNrsslqOSzV0eG32cBzirj
degMq6V0sYVnfxeTOdBFG/0CrGi8fJCyAR2/gORYME7K4gcuLmN6aJIjcoeT
PRHwkt1Jcrf3eqMRW5xPhlJGAC66ubRVeZ18zcYs5Yk6qdPwew2zb+iehWRE
JFCK9+2GKDCe7ZYmX9RulSLE+8oAvOf11b7w+HqkJPvtUtN/ugPn0idt7pZ9
bkUkLD7vOIvmAR5YI5fZNvmMjKf13V24KtVDxvenstaml/YgPCcSGMf+2p+7
1HbHOrt0kzjUFbOZhhIZWe1k7TvClmkNjzXhHMxDDHfwQcGzFfh1AQ88/OTl
qZUQUnuocyxSvIzv8DxC/23vuLf9ww/lWpQ0HsAJHFd8ePe0oP9eV//ii9Vb
Q23ov+N8zifsdMWok4xr37yswncC5/B+LZuf9gc0tpPtz0ILsXoOma2k9vA9
0kVBtaf5UxNZ/9Q2HipjD+pQov3HAF5POKS7o+cx6X6hHt6jxrWraH8Rylnr
/6y5MRTw1TNBvVl5mei+ngLN1WD4veCR0mZaFdZYlLiOvOH3iFTkbOSID/ph
WlC+YuEWtB+pZs2Zh9dQg9TNI/T6hoA7BvYEoCe4pJtGqeWtzLcBu32kOWtz
vkweIe4bZ8E8385zfx1pRIuGEPc3+D3ImJWyY488OjMonH7pzhnA68vdDo2f
21qzdbRXj/8DO+jfaOt4V5+JIdK+/ueKyGaor7jP+RcRKG4jYu9evDiscw3w
wZv6RaoavkjqnfCvZxdtAY/P20I3vBiKEOfZAfDSBKES3fBokr39paMYeVNa
NOJJ9gn1KguVAiMNXxKpPXyPK9PNf9RLxTl87mw7vgyluCaQ+oHfgxgSjByt
zuD7CLQfXF/9+9zppFck9nB4k7XH9dW/djVVHnMu96Ubmd1iHonu31mCcfsE
8x+Q3/XI7HAUmd1eCLte4t4eS7aOKg3lnbmuxpP149JrK2KTHk/Wz+FP78zW
FcWR+E3QnndqtsKGN4bMnve9TmiQ3xWB/jv/R4zdd2y4HEziUD9fSSy+WCzq
g/77XNoYMjW7GpxJ6+sq4Fs+X9ri0WxNuq4B4G9vP2L62qyPEu1KFfCH3YVM
n1B59GFU5c2gusPwuTckPb07MiUl88Y/erAsAuiogtXL7IdkdyMVogvHRr8K
gfsNSjMUcVt7WUMc50H4PfH367zgHgGP7+FxvaskPxTul8L9Ubh+wvUUrqMM
Gfn0Ou5GE/BPWpIu4uM2Un27Mok9mlxtt3WaI0T6v/nDc8xvatr412EZz2QY
e3NaCbE8xPbPKZZm+iWzMGzJYz31gWJCxjsiDy3EdrgqRWH9667Gb9uSRuD9
QeTqJ+leuZf6Y7n7PPrbuiMJ5SR9KPMt13TDfg9s9Hog7T6WAAIr7o9iXGRZ
e2ePuUdc2R2y35MQTeKCO2ewE0y22O0oUy0ZDQfgBxML2Gew8dQ1LFFrn2Hk
ijXhPYl/OLJZ3CPPBKN/vDdVkd+UMEfiY1/01EIsDTClqGgN2ZpLQHedp/w4
JCV4EdPQ3nNOgeEc0F1nVFgOtndrYU6sN0VikZNAX3m+4DwZa6CBzVjo0vPn
yAOdE1V6qedHsAqmXrOjMIv+KOB2DXlaXTEKGHvKwQPFd4UAZ69k7N3uiGCR
Ybz5bxa5ALdfc6SOTZDAPup37NFaZALc0DWL7/kzYSxCgesr4/lVuH/y8+vq
HeHDKsss30XxvgZ8Wo1Z5NvMLkyI/nwdb2gP/B53Xh+VMWXCVljn46P13wJe
tv4C/+IeatJ4II/+9HW8YmEBXTVe8jTFXgGeN0Xntt5iDM3xZlCrPgz7DyrT
+DSS0IJOjUcI1opggO/Oq3X0N/SWrvhBXa9X6wn287seVF3an7IQESW2d7Vm
8P3+MWGjppPUfSR5qsLNYyP0h2yOnFzYVOCNXuW5G171qxrwfLn+tOrDqWgy
s+Tw+4tlgK+ioS99K5PRHrpESrvgLMC9LeyN+Es0ayIm7x/fs98AjOeWKX9x
qnku0vDFTaiLPxPuMylX9x6+hyHSgrei2r4Vw++PsdIeLDVPECZ2jp8P+Crh
PjAk3s/97BkieuFi1sIM1JnxRagBS0YPQveBvtiauxZwT53+md3Xe5Gsn0rm
Z9EawC+yMLK9tepB5t+OntG/WA54ynJnpplHJ9JpFak/EAive/ukQAxHbzOy
86yI0thf/iLvpKKYX+KVZP245jcU+daFk/rJAVw8dGHtt/77l1ckvXy43qmW
jD986LNRtbQF/fe6pxWl6Ru928naP4imjH9c14l6BPy49Wy6APBNulaFfdWd
pH7ge2oPhd4G2Vd4P3GAzxieTXafbyXrRzUhL3Ckr4nsuvZLid63TtWh6+/T
diTXQ/3cy2v80aSvAiWuryTA63KVmktbC9C3/NUv/9Zj9LtuTd/6lYYS1xF8
Ty0j8dwcC+Gk/qG+ErjUO6F41gkl2s8NwA3XzlXP3TkoLZbgcHNXHj+ww00l
ndlCewyRoaBicbfZa8BueWhnna5u0UEEbE/t8g+5BddFTPq2UVNR9Oi96zNC
C3aAp1VfePnioC5K3E9sAXfDvBmiavXQWJrc+W0PTABfJ+LuaHWMpyaNl6d2
tQv6gdNtLymGvLVEiPMA35sF+dzdcRu8EHPvZ8w1e6GOupbWkkunGIKUm5n/
am6EcSUXXzGGBLEokh36Ar7XsywxU/k+GQ8877bR1zORZJ93AddaGqLf4ZlE
snOoc8qY9sYIvUlAiPZwD/CM29reIzaxZHxbznVFN6ZwMo7rq3/73/aaUofR
7SJpPNAfjvuv/rVPXF/924+I/JJUSn0k+u999W1PGr3wMRb9dzx8/EXl62vu
k7W3FKjxYB/GORyP5oPPWccd48j62e0+ubyqHE3i7oBXTW/lyzgYTtaP2fjG
Y/0FgWT85sf3lUEid0jcHHAVs1FN4SIH9F87MZa/fzrznhlpfV0CfINpH19M
4hnS+wXqK38v67fhG9ZJL/u93nd/QxHQUStvfGzMHh5Flpw/L/7QVQB2m6Gx
YHNASxwh9n8acFPvze0K6FoN8X7VYfvfr/NGXwKeJ4XnR+HxPDy+h8f1cD8U
7pfC/VG4fsL1FK6jTHvtDAadHhDwT6UpYvsfMpsTpBMWMfp5lD89d5lgEFNC
jJdVZZ0dftWKxftJP6FT6iZU6RH9Zonq8jz5vIWY0veQN7RnygnR3cR+9rHV
NfcPJGLPP1Ad3T+UQaj6RuRuLL10VVWhmHznRNzdlmjCGEnv7WbxUf/E7oNp
XdIIMdkTSHhF8oO9WPbf5/PUBVN5cmIgc82D4E2ah4C+06rMD25hOSeFAi4v
2RFaSbzj2oj57gdWmJWiXdh/ehvkg3XoKpc2i17Fug5uZqQbNQK6SzD5cisX
Zoipq3Vf5szRAXHGS9OKLcGHdLEIYSmGkAfqQHetnsvgyf5Pd8mVvenI91cA
uqum9lB6XYA6Nq9PL3OBC/qvZHO9XKUClDEq5d7qiE2CgHNzGvtsUZLDko1P
i89gbIDfWPqWS1F1FDOvcfnsY0cFeBrtIz8GfjHM7899wbjPYJLK1MHPezGR
WX0dt9nPwD4fUx0dPsPFjqV+u/WSMDQH+KcTxQ80NZkwfiR3LXM35H3vmWuW
iykxHqPZDYU2k4Bfz3gZzYHMorRdj5/WTo4CXvRAXVA48wW6e6lnnbsgzLd5
J+37qM4pWvp6Q0XQ15YIsD+rv3tfSJDCkJhtEolZoS1g/AIDmapjz6qQjC//
fftI6YF+jwRmwvCNNMRf0JrLIrMP8Kwv/Q0BiWkoR8bq9rLLvYALY8gNXbky
NPijIePV8k7AuznNtDxUK9CNLhMj3/Y0AX7CgDO6+ls+mrzMzKPhBHWd2ilL
fdcJ/Rqz+ak5x5RrYPwx81ds+OpKkAt95ZZqATCP4ryOdP+mdU0I5SrBfNIF
BbxEZu7X7+dEM/jdYGxfI+BNFxLs2wx6kHrGSB5duWbAO5OOb1b370Wmqzjr
FPlbAD/76/nB7sEeMu58SWs+bH0Xsndh+6PVYNgPzwYdvqFrT8g4c9wR9obi
arLxcH+8TLX3bgLywCDyzd96L5ljqzLtXA5KtDeo9+4oxr1uccfQq4LnFY/o
VAEe+/Hh08b4FrL2zQfUbkTztqP/9p9C96OoW7UTJY6zDHCLw+L01+07UaUt
R37s/Cv+kvLKY2O5WTtZe7ERv5gg5lZ0HB1kbmmEz8WuKKXa/00jmuc9yr9Z
vwiO33zwHtN5jDRO6D/s7v4UfsKqjNQ/1NU9ri7t9jtySeOH8W7z90fat48m
oIPClk1L8uGAU7Ycd4vq9kGtH/yslv0FdcXel88HpVnlpc9lpjeUaR4GdtVA
MWx+QfomwrZ7x8a7bk7ADoePodWuCreQgJfxh9Ne+QD+/S5G9/mJCUJc7wGA
P5OgnrdcU0XbN7969ioDcknPl4x311uimknpKp9u+gKe6M11rP7tDVS8Y7vG
rUSYH2XESQiN57RAj1pTd/lFQz3mntObJ0QnUjOUMhidwSAJxk+9JUPnRaAd
QpwHqBvvmA63VD70Q5Cts6fi73kBnspu88rrdjhCfL5+UK9SJ3n4744l2SHU
A+9/HnN1pktA7NQ+SWr9Fa/P9Tplr1OQiESZ0vrZ6EYCrrebrXwKSSDZP/RL
d4vJ3a8viCXj76cvTDwMxsfzlz/zRLdBgYYPGb+8bLNrWukSQrQf6O9KyNHV
CNN3QP9tP8vgcjhGIAj9t/2Xmcj3dNciSesI5kusvaOz8V8XS2oP/Uhhk5xz
k4z30X/H74h5f/it5/6dzzQ59u/SL2NQ4nqHfq0ODa/HOQ/x68K8CK4ntrlK
waEocZ49Ac/vZZZ57ehPsn+oxwKy9dcL0XmQxmMHuG+h9Hh0vS1a7snfF1Rn
Cp/L/tTFwmpdkh2eB/xVfd/JU/ObpZciT0voCzUBHbWrO4yrw1AVWQ7nNK4+
DP2up7Oestz9eRLRoHfNuH9eH3CudOXh3XtkSfZmBLhr9GDKwR27SPuAIeB4
fjmeb47nmeN5UXieFJ4fhcfz8PgeHtfD/VC4Xwr3R+H6CddTuI66OpLPeudM
GQH/FH9CbJ91VdzLJHIV2/WL//B7xnUy0pjLH56itneHhW43ZrF3afKrVR+h
zenXH57qp6/rVVSKlTIMZBWwVRKGUGI/haYEipfJaViAaNSPkCNZhGHSOKku
US/kqUZiU+tcxKToYwiaJN0lNyyS4Tnkj7m+pan6sDOAUEO637Kmqybz1h5Y
SJoV3SyrO8GDND/bZdVzpXvtsTwRNR4N2puENhIfP7bt2fBlG+xDhVOb8+2r
hI+4Xjrx6OTjyatYszyW+KtJD+bbm3/7WJhjiPkMbT9deeoM0F3rLAXFtbde
xBgmtBk6GY4DfRV5JnIn84GzWL8j+3oqAwnAX5292HG2Uw3z2ro71uavPKsg
A1ehT08UsA+UR0XCizcDXu1TUXXARQpDl4dLu7PzgR2+eDM2vHhbHNOIYR21
O7UC9ZJgn5VdLT/W/vaIsEI+JZ7PLsNHN632LX83FvzLyJVJZB3gFjF6P4Wr
tmA2+oM/faOWQT8rltiKnMgqGiPz43X97Az8/sV9KJG3dByVUJm27Hg+DPjk
XPG1O/WZ0o+2jtkGn08H++0A7TcbW9Fu5Jdk8paqzBfAnpUeWT9iEulBFn0r
wjksxwBX3pT0vmKhCblrXRr/M2MC8HNRouv2esQg3qfNLTIaIRcI3s5lmVSJ
DlzaZcg/+A7w7O/bEjwyW9DvnSFUAuIwfzvwlePdbaeeosNbqYYbmAagHyDD
yDfqUDOqmNe10u/4DPA5U7ayM6yP0QOFtNH0vNBvFtot73LLyqQmfuMNz6ra
G+B+M07vUSIglci+UY5bUSbQL1TSy7Z945MniHDuTsHh81DPqE89faP3pgsp
3fjQeN0GGG9VuD7YHUHbi4j1nG02oekA3Oe7scXBrz1Ir9umG2JCz6Df4C3D
ivdEF0K0n07An9X7lsRRPUWktn3mYWlth88r1GPC7EYtco8nYUfsG3jdonOL
8fd/pCNXdikkvehtA7xY7fXRlPoM9N/2qWlUFUL8NWiQVvEiFweMCwfcHfw5
sb8ZNTp5weXyNqjr1ieuuNJMPkXL9TbZ/q3rdPsKt1sod6AbLdErVwj1gOP5
VxFzPpJbEqEe68rwVOoUbEOZNoXl/K3fjKreqRiHtKDjB09v3vWXHgu7EeBc
wtRAGmcp4IslFCNPGqtI/UN/V2SEliZHUxFKtcwocEAqG3CprT7vi7dmoD99
TSbnjiQCzkc5dcKYLxTVHcyT2csYCHhhdclS/7OT0nfHek+f+U9P4fykcZDl
IylPRN432uB0O9RL3ArygT6NPghxfv6KByW2rf6nzxDifcUAzsCRsS8uxgLx
Gf29H94H3J5xLpIuyAB1SrbW/e99Dfjjn3dT3tY4ke4L9tMxGyJ1ZacX+tbE
5Ev6wXDA1QseZXqc8kQLPl06lMN3F/C8j57U/JN2aLKva1aKpyPgEqGJ725b
SNSkxtZrVsnC+z3DRj1yx9cZabIMnKXLvQ3mx3s4y+2CYBDpvqAeKB4221GZ
GIkQ970QwOM5yzOSNeMQh26fY3WxUEd5GU+WbsyNx+cHcO08n/HN6vEke4a6
ZWzstnHQ1lgy/rPdKCpSPRwh2hXUP2crnT5NKfqScdmz/P/pGXOyfk5k0Xdt
dLdD/+XpFH7l8tP+KIN0tt/Qr2jAz9Apv7+jF05aL1AvyUbnKp7OjiZr3y9t
kZG8JZasfdgN+gu/759o53B+Kh4bmLzJiSKtFxgnZam8Q3/0Yjipf+gnXF+2
SaffN4i0TqEeo6LYtTjQeAcl7jOugLdJJG07IOOAEt87UFcLV3/7pupsjDKG
0EahnDDenZgxkPsslFV6/+xT95uH+oCOmt5vEoTcOU/a9/SAXSEHuDMJ6frI
D+L7Gq6L2x2BVYU6JDuxAlw4dMh2xU4Z4Zz9xN3SaAO4VcCZrZ9EhUn7DPy+
gJ/Tw8/t4ef18PxyPN8czzPH86LwPCk8PwqP5+HxPTyuh/uhcL8U7o/C9ROu
p3Ad5VMaFZj9vpaAf7Z5EPvJ22PLwZRKWfvB5dTtpAkqGfHjSn/4szQ3mv1u
fdjzpJLbJbrPCUPVP4n6qvLpSBD7Y8xOSPhYDWcVgaKI1I+R2WmHg5lYov5x
m6i5TMKtWSJ/FlnQb+Afjb0uQuIvx0YRxEn3tUeYo/7ccAB2o1MgxHe/H6GF
pLtqsvIU1xQ8Ma+KT/Odq46EINL86PJIXeKVccBGRcx2hz61JHSTOMqsid3m
scGuXkT7ZH8ZECZJvP2q+E6tdlMsVFOYraRBE8QTRc446ciLGWB2Uw/aXsYr
AL/Wy7z+Abmp85hIfdqs2GFxoK/WlH6s12TRwKg3hgkb/ZWvzrv7HKMtjxKW
IUCVORAI31++EWnhhHQEe8jKFxY2Rwt00dJzhs5XzAexBOdbZ4WoGQF/YPF+
/QEZfiy9qIr2/IvNgL/he80auWknpnn5jZzXwQ2A225nyc5XocPGDzQqUBf+
gt9fooVfsQ/MokIN/ldctL4A3vBMzSLFokT6TZXlk/u2RWD/LOKSi2Z/PozY
d0XzOOTD/K77r9bo2unHEC3q+gGWU7OA62QP33TifI0IxOpVVCwsAF5/k8Zs
7HIr8rTimZDwwjfAU9eNSfVfyEY/7NZyodsFeZrhpyaq/k5U7uT41fh7c4A/
SLzdUcv2Ah3QdL8ePjYNeFNdv8t7jgHU5DPH4y9BHwCvvs4/lR77HBVkzDwr
+RDqMVc95vaKpC7UlsJvmEOiH/Budv93xfJ1KH1CdFE+PTwvOb5tfLFkxaxG
jXoHa3qKA5ifnd20SpKXUYR//GvHTRMYH7xsPmJcv/wUcTby2slw6gnga9au
hxDDbqQv1bPz/nmolxp2PejU1exBiOOEfkLnHVT5RRTdyDLncMg3ARifdaQ/
WLkj+ymSzRb55s0ibI8p3ilj/VGHbF5QePZsugtwov8qj4yfVK+xjeaNR+te
7aKz4YY8IEukUav/MTorv//aER2ox5TGHSztbjSS8YR8wlNpqVZ041LxTniO
8L/9/M653N/teHIl2//2s72uDo5GNrShJ46t19JahLpr9CbLbGHzE1Rrm+qB
lkZ43jBERJ65lKcJDbJzXvg7DkvP6bXHWKgWtS/ydmGth/6uvQqReRklZaT7
gvqKSXkgegbLQS/bKZqVvYZxyYL9F4/uGY1CP+rcbmv7Bv1UITtbL42naUmn
zo7KPddTBc+97ZHTpw8jAYjorxaZeUZ4Dsug92F4/MdwZDAkvfK/9zX83r0s
tv5qVxiCneubJQylAT7tZLYWdcAfIY4/E/AG1dInSvNWSGNbntzf8e7Hr68k
nyqzRYnrCLZfbp9XEjztiw65HZrT2QfP83J0+doKhYegxOeeDDhb3tYMNed7
6Opua/kcvjjAg0eVJWV/3iWtF3hfRx1jf12KcUVf0ummcTtAP9jAJ/uQbgfJ
Gj7vAYOYMSV4PkVRYIFtswdys35egem8G5hPVdrsfVUzIYiM3lmRaF6oVw0J
LLIWx6OQsevnh5nu/ZWXntuVcTMyFkHfBJyr2Qv11b3uoJ3xYnEI0Q6hzuFd
vn3l+4No0nVh/BePD/7LcX31L39vNNyqbHOdtF6gP5OYf2WFkp4v4NK53K85
BHxR4j4P44bPpK0pRS1CydrnMVfmyJtGojZNRqH6F6G+2hH8+LwmQzSqzfh6
xLE2FvDhtNBvjrJR6LTi/fLfeg3n1PlFJ6k3R6CpB27M8oZCv98Z7vnbR+ZC
SP1DfVXCetvINcmXtO6g/4pL/BrfOLMLWkSl7Kp6AepkquiHPBdmzEj9QD9V
Q32npJErh3SIYMeqmOMI0FEUhy3uC6QbII/Nimh87eB5h3TWoVOBfmZIvIwG
jYXADcC/Hc3u9j5phhD3bQfAj3XeVsl4ZIgQ17sz4MVPXPsjKk6RcZHacbmu
DFmUaFeQ4/UO8PoHeJwLP6eHn9vDz+vh+eV4vjmeZ47nReF5Unh+FB7Pw+N7
eFwP90PhfincH4XrJ1xP4TqKoTfptSXSTMA/bTiI/YjJ3HFVGKCuHTtzJl3Q
gkbGO4OLOE6/9YRoo+dYbo12SVrzc8IDPaLuauE7mVT5pRLr05r/NY9UEkTz
if0MhvRYBqpmYRJxr1ROsWQQZnDdNVjufoErBntzr/NlT0Y4IYSkuzJMuLeX
/qe72NniOW+hXoQF0jzsdmT2rm3wwA7nnkPmfG6Cc44ZuzZ/fTBqh7G+3v1U
+YQJYYjEJ6905F5Xt8TWjD4zfjbQAvHEzpWuuYsfjLEfwuZOb3TkgV/r2P1Q
r5NbdLHZO5btG3MEgL46ueuK8PBhTUzv8OxzKT+oQ2hiNg91Mp7AOg1Xz7+i
Ygb654jJpZT7jwmY1PT7gOrPbIAX9w1aiJSKY7FnC42EHu8A/PvNk/KH1/Nh
Opf3vqtSAfUYZOq6/Y2KUpkxN88o7S/TUKfl5sidUUj6hbrN77dapl6C62jx
WJu5fZ20+tBmTrsRFOyH0dsOHM5S+oL4mO/KPzoA9VLsM9Qvb34GOeb9LC9c
DOaDReV11TkaTyLP5+vMlx/C84wl2UfHT20aRbglaHYfEIR1JFSvCC7ZSNYj
2zWNn0T1wngox+3SCXreDvRaf4Cq7QnYjzyT4ObA5mFU2ILr09Vfa+C6X3ff
FVXbOI6a+yrKCBovA94iOZptdngC5Sxgu74nEeo64elYpTqzdyhncUmqhhnU
Y/X29xOjJodJ7eHz4tn8YkyguB+lc0fftR+CfjCXNosZhtZG9MvGca3Ejc2A
54cUCV+cv16DPNh7n0fWGcynfHXWe63oWoTmbWw0QzLMT5u3VM/5T28g5T+j
DGYwqLc5Vx87Fot2IcT7hTqnUi7PbLryGRK25aCu1iLUV589JjSOfnmKsK7z
9uHk7gXcheG2et7reoRrnO9VmSPkJw5kdK9RF5G1l9lfayv37Q7qqvK1iF8Z
9i97hp1C2q8UfRd2cVjEAuq3G8KyL3sX6tDjCS426BXof8uOmxyct2tG5/+s
C3hfzw/tlmiNfILG+df01EfCuGfzYN539e1PUOJ6gf4x+gc5x1Lqm9Cbpqf0
w75CfcVQkKCtP1OHblAtuvV3vFJZ0b8lrvUxesLm0YEtAzAfjC+yS7SpJx8l
ri+Yl6UocjH85t149GLHwNLWZ/D91RclIO0koSstpcpES5d/BjzHqQP6c++X
wxGfhtv7oiaiwHO/bsBU4vk2Adn06Xn9whTM/79TkFnerJmEBElRJlN6PwQ8
aVS0PI4qDslx6sISegoA55xMkhe4G4IQ578I8MYvRc/tZszJODH/ygOduvVT
vKURnsd/9PnsCCE6DDVSNLLysHgEuLxibufbWzGk55ID+BKHAt/RPXHoKL88
xYYSqMcGn93PYOqNRiNLA1lsuKEeixLXDOhiCUOJ+1gk4E4VctelaLzQRe7w
Ha0EmI8t33i59M4UUrN0WXiASQHq0lDFQC3x454Icfwwrlrj66X7wvgeQrwu
jBvSvpxl8DKORIh2Av02ui22Glc2RyOfUtrtb535K0/vE3PH05lIRLLy1S5+
BqhnCrXCbJPpwhDi/ED/JK6vkmOErq13gjqKkibSLZ/FBiHaP6yTMJv3sGe7
tDn6b/tIPy0TT2kvdO989I3lS/GAbyZcCw88EYT+Mt3ClUoBdeCMxDvEMD0M
fXSawnlaAerGKmeU9dXXcNTm5yH333nxON+yKWVglSGcZOdQf86PHKk+TbhH
eu7BgLu+KeAIZvFHTdkiBHuHYX6gYu0KmuzvThqnM+ACg9+dkJuW6Fahs087
C+C5BoNTVZ9ExrmlEWpvyqC190BH8W8O2lMibYqMoALcwz/MwHM3Z8/w3dtg
i1SIpXV5x0O9pBh90X64/CbyXTvJT2+XJ9TzsUc9lTVsEcEnT4RP9ngBvnzr
ntU5z6sIcR6gH7hK7MN/elUDIe4nMA5uFxp1ISTjJGk/8QYcrxuF15HC6xXg
9Q7w+gd4vjd+Tg8/t4ef18Pzy/F8czzPHM+LwvOk8PwoPJ6Hx/fwuB7uh8L9
Urg/CtdPuJ7CddQ0B3cfbeZTAv4pXEH0j9VdO/vEK4mmlrfs07H4//6/o1d3
/OFmQw5xJxqfY12T30fiEvsJBq7E/rnOMUgMDlRij4xZsJeR5QSDcuJ45tFl
R/eaTOz4M3pD9bEUguACkYfwXf52eTUKa52IOLdNIphwgnS/9AlvG1Ne+GPa
duWUJ2ecCEdJ8/NYTnUulsYNQxlmQ7TXzAgYiVtQUSGSEzewaX3C48tL50A8
scmxwvudihl2vJr1SymfLPBr9S4I9vdcu4wFz3oJLFCwAr8WR69IzE9eLcwx
l4VtRY0Nw3UXcuhCX42kCpYaOBhruIMX6J8tPVoB+eoETD1z64v5Fh7A12m7
rO5aEMUmaDdJGktyAt7kYn/4bgYXxjvEw+ugDnVa6V6lbgIjLVbUlXGEbhTG
Da+fKI2SW9cuHaX3Roe2vhXsb0lbhV+ErF9CGB7pZ8ol/oL7eaNN23zlL8Sg
21TC4DQd0Dlu1A/fHw1aRhh69h2sqN4C+HLM22sbpeaQ4TiTtPzTMD9fQzZl
M7/KW4Sifsr7pSHkQydt51dlytEDEtycFR6wrhcx/2oMvZndI6FzE8ZPz1dO
/crYMIWeCbZQH3WG41E/sm3BS2kWfdRJ2VKxAPXbKZ0jSpzps+jI1683biVS
AK44tkdtZc8M+qhu+CnNIDx3mX/Pc6Y17TNq9wwRtGqBelJ2nXbk2+R3KFWO
8moTK/SDTY1qOV4IGUBvr606WOe/ApzC9SLfk10tqPZEXNj3cphvxp2Zf+Tu
tEWNOSfTwmVWVzD/VTMbB28E1CLjxe7miV9gXMzLavjuSmsr0iF1ZlP6aegX
sh8s3DRi144w0VTy/J3/tsFA5s2Fj63IeiOveMpuqIs+bq/RUbFqQJ6frPy8
JA911Ph189RzuSWIWmGkwd86jZjf7oLM7zvm9/f5BaXOoB1Vp/LRf6+LpbHU
lMrXoCp391kQ0qH/7R6Boyk5tgH9cL1q/esMOH7Pdsw2S70JFXoy82T4PdRX
MRVGUl8eNaJymy8NvIyH8cTsS36V3wTqUe9D1DnbrOH8OKc307PeqkJlKSSH
+DxgfPAc+wv/cZUitEyl8wLHTxhnPxZ5mPGtSAr67eSLgY1U0C9RUG8eql1i
IH08oTmlctt58Fy8zt7UzqiPRXp8L56htYoHz3FD6Zy6DH0GYoE+V2Xrhfqk
wPyM5P22LCR58v28XzTUP0vDFLd37c9EXB4fY3l0FZ6/yKOybm0XS0G0jt2Z
sWB7DDhKJ15D2R2GHNan0srhq/xHX10g48T8qwA0zi+qDJOB/ag32v56TXMf
VUu3MUl7Ba8bEXVI5vVMCnqTm//u3+dGlV1udzN4pJHmGeq9xg62smPBqSgP
b5WMUdADwLXPVEmZUyaiRPtJBXzLNXTWTDUSvTRUefvTzWjAH++lHODb743y
iA1LMT+A7zu9wiubH56RqeF+ElLbO64G5n8dLa1euJInwqLRYD6uAv0qxY7y
tIeTg0n7D9RdTO0ObtIbwxHiPgB1160dLN2p7OFI3Q/+4ZM3oO7apHk/l6kz
BPGR25fZHAD1T/5y1b0N4j5IXklV59/+pQfMagbsy7ZknFj/Sg+NdbKtpOeF
fGJDbG1aiRv6b/8cdaIfWHz8UeJzhOO5lr8zY60uGO2XiZpW5If+q9xHz9yL
Re+hxPUL/VTfmai5LukEk9YjPGchtvHC7NZlP3TLF5v9f8dhd02v0Ng6e5Ce
L8ynkk7k3993zAbd/+hBl1OBFeBrWq5ej8r5pF/LaGV2B0wDHRVpaufDqXcd
Ia53S/Acr0hlPLoj6YAQ58EF8Jn3dTFGuc7IT0xtm68d1NtNCpuaAv2cEdI4
Ae/yjRcOrrMnPZdAwF/ScN9IeGFBmn9YR0JckemuSrcGUjtJNXb/fDDgxPoM
2ui/HK+/idfjxPOC8LpReB0pvH4UXu8Ar3+A1z3Az+nh5/bw83p4fjmeb47n
meN5UXieFJ4fhcfz8PgeHtfD/VC4Xwr3R+H6CddTuI6STXLVcdfqIOCfpVZE
3RUq751t+ZK6NnLmwLvn76lkLIxF/3Ae/s4bxuH9WL3deyoNhl5C21aiP+3q
7Lelvo8VmOvU18d6PsWEFy3E8UgPzb7anJSOvfbPulCdFkewWCLyRDlL/ynV
COyH4kWWUnZvwj6SX+viFMtVGVYfTOjeq8x7+21AHteWz1fROO/bGOWKMfvo
mjZhgMQl4h5bvnKwxJh3XNhUr3MM+LUq19lvSP5siF0/+VmqpZERw/XV87fZ
QVGx57DlrBba4/EHgL4SSez8tCirghXzby9vahIG+udEXbxVQ6UUVtBW/3jy
wz7AHdq0hadnBTHOqyP6Vy5yAe739uAnpmvbMIHxLdzebgyAxz01bbrR9Fy6
9up61vh9/WC/sr5Ds1I0Qkl4sTroPbCFFuiNybrAJJX3tIQUcXfVolRmwOe3
RYxO8GwgsOUszT7fshNwVtNCHnqBdYRKxzujXaW7Af+138lTg2MeGVxREdxw
gB3wNSvntV6DTuTbTpt1jj92AR5fYakVPDWG3kd7awYCYZ6/V4WMur7RPHqs
f9jG0oUV8GzNTZ5qVT9Qe6nR0vNbtsG6ZPdXLghb/ERHP8umxzhAvdds33qw
he4nShEd3nB3FN7vzbO86+7Z/0B5OyU/KU1B/1j5KqF57ew39NqhiNzmgBWw
HofEWHi/XppBN71sy361fR5+n9p9wvbrw/doxdD3CNULHwH3mVce9Xj1Cm3R
VmLOUoLnOunm2OzQjy2ou3LnriclUHe1jQV9Xeq9XmO9I9GC67ULrFMxJctF
oYAiRDuB/q6AQO2JmnvNyPtkbk92eugXkvnpQVhP34I4Frzdv+c2zNfC/Vcp
R9uwJCuoi3ZO+3kNmZYhH2eNp/6OJ+od9OW5sC8S+anryv+3jiL6rzLQ570R
kesOwf6J5wfL0S1Mb+UnnsG8L//3vie4nTCUTi358kXnVsBPPXTXPZlVh26W
vM722y+F8/SHl1CO6Fq0tip0w4sJ6Kdq/R5h0MxWhYbRtnDSzsHzklc+ZNqa
bylGg58Vev+ShHnsarlDzIY9qeh38SdhjuKpgIcXc0WaCRlLL2ixcsk/vQDm
eY+S/mHf7UnI1bqIQyt7YJ3Gm5t6DPkqchCOIKFG2Zp8qE9e9Cg/OFCALHed
GVkNhrolcJ3vuznfAsQtKW/CFKsCfM2cbSlIMRfpYPdbEr2PAW4lKZX3u85F
H+9DOQc2WE/yhW9kj4p5OOKwbmkgWh/ymaO2F2o9DdBdwwo25amQeyD1GJtY
FKofWqVV8LAWcC+z+ZP7vdPQudnK6zfXodCf9u2u4CffbDSff3LRsRbqsdO1
Uu9/n7csZn1cWEsD7yv5RktECmUOahLzJumbANSNNp8nJZn7MtF39hZftjND
v9zMIy6eFxMpaNx7/YgINxj3nPlO9/wSIRp9U7ifNrgO6i7epe2Gqh+90er2
plOhyVB33c3ZLbrdnlBz8+fBdZF3oe6KzbFrE1vvgUTfQfc864f+rpZGynul
M3eRYLblKw250G/jsS1TZIdUMPJMYthPrA/6eRisJQ4FhgQgopy9fQljUM88
KgvleuV9B7lipdkqeQT6M4n1RW8gxP0K6iLl/VRh/SdPkOwctv/6vL+1MNAB
rQ+jEfs7T0zt4EXO3MQ76IcrRzP/jgN667+Uyx/3Q++JnVlsGIc6yq9YScEh
zx9dZ7lh8u/zgDmjsd8d+n1I14X1PGPKRFyFqD1Qyz/vIzg/9YTGsP5CG5L9
2MDvHd+H6Kpk+KX7Tx6IN46bAzpqzJ9nul7WmmSHMK8pq1XhnRG7C0IcjzvU
55+m9VJ+eCK3B65TDl2DeoniUnlBO8Md5DSLZf/fumjRsSXvZaAn8rjEEr1n
eg/wFM8q5NuMM/JFi/pyegrMD9QqX+CXFLFFDjEkBf+drxjBsnfqh7I6WfuH
VbYntz0zRP9tj9cxx+ua434SvP4mXo8T92vhdaPwOlJ4/Si83gFe/wCve4Cf
08PP7eHn9fD8cjzfHM8zx/Oi8DwpPD8Kj+fh8T08rof7oXC/FO6PwvUTrqdw
HWXeMvaBsaiDgH+amhB116fHOx55J1PWnrK0/lCxdZ3MRguDP/x7zY/GjJUe
rN5VZfne5w5C5Bei7pLlLGKqMyzF+Fb4mo1Vcglmr4jj4YpRsgiUTsHmprPz
C6ZCCU3LRP7hmu63g/0h2HDo0TaNWHvCHGke6iOLRtR5PLDDDe0rYet1CTWk
edt3L9X+aLst5t+o/kViTQjka6V+yL5Nt2qMpeWsPehwE8XwuKH9cTXWd4fO
Y51H86NFNx8B+mrG9qfNhI8y9nF5Pq7v6UGgiyYMtwTPqhzGGAPS/I7oCMJ8
db2F8ql4Tsz0eA+XRDaMD27wezZ4xn1U+oiBeM7PS7Burcw21bc/PBkI/A8N
OzyvQR3CiV56O6vOTCjqqRBYzYZ1Ib7Z5mu+O76NYBCnfmiRhg9wwmS49Kvh
zYTTdcePv5DnB/w27WMK7UuUBOrFCT87FHI7Xk+mr0KfEcMvzc3+03uhH6mw
mKVregTVDa+6NiQB++/dqMoU7PodDXl6+Wv4F1jH3j2t08lmDyXmKZH+tVsD
jvO1/cLFoMs0mOL5Df1PbkKdxsO9Q9vYdD3mJ9faOqUI9dheR5t6aR8aLCxh
4E1hDvSbbTV5bHlInQpL/bOONsFzmmz6Sq3iFNhVrwBlxzUYr6xKVOyRuvYD
TfKLd6PV/AnWaXvUW39Bmzl0hfVEneRGqLsye4a/yhz6iEY/+FXemQT9XWUV
bg0K0q9RJme7A5OTg4B/2fPGzYCpBc28ruTlvxfGGQ9Wd7yt7TOrYWfddzQz
zAk836vz1uUNjJVIcfrXDOtwmHeEuI038PHUIxoRqPgCBfQL6TtXszAF1yJP
ClltAq9CP1KnrQ1Vz4UyJPm2FQ/6HuoizdGqWdmaJDLO9nxclPZBDEq0T9iP
9qbvdnTdhSiraKTJzX6YZzWj3kNL01iBykqVJf+d914dTtf6vKkSfW165D6T
CMyz6nY09N+kVYGmqX1gep0B433mejZFP02L0NBcmmM/mWF9jCr/fdXxkmlo
2kQJy/L+NMCLVKt9OaNMpGc2eXJs26sH5i34ufKH1+ypyOqnunydVuhvaQ59
JzrSmY+EB+d6XSFA/bCHYpCNv6sEYT49vXNjLtQhUc81LxdolCGxMy9+bpeD
ekZleWxk3fpShDhOmKe3yHlQZu18IbJ8KM2+5y2syxocNvg6G8tESPMDuP21
wcXCnDBk1wsfuQINyHuFVY8vO7qiV1LGf215Ac/D5pyz4eyaTkbNTUTDxv6q
+5pUpNUnLZiDWu5z4S1zrge85EapT1pIASqYPr3fhhuOX+Smhr43XxH6hfem
gF8U1IcOHWPh/h2FaF7W0t4k2nLAzynLFYiezUfXXkWc3awP5+1oqNzW1ScP
0Ita647HvoH+PXet5VeT29NQ7kvsZn/7u84f+P7zRUg0SrxfGG/Nak6hYd3t
jb4o2mEUoAz9HlMzHZ9c3KVqZmMa8p5KqYDnG+i4Zvf6tjMS/2d/hvnYtxsK
RUXSvBHieGB9g2NZy3U7BXwQlcy5LVZj0P/zzTjMlyPTAzm+RnFQ3BTqMdx/
9bzrxo49f+WTK0jMMJt93IwWXFOo+vs8Y/AHhrkIcVvS/gb1knH/OcR51RUl
2hvMj1pwsCh8JemFnu0wZ58/AvXhUPo764NfPdFO5dezzrehP0pyror/g6sL
GmF9puPZVaijko99yerOskbfnHjzzkkH6qi5gH3vR/fxS9cwHv1yvmcB6CgJ
ytjo9/dtEKuN3FYcmX/pKJXWNz8i3ZF16LFEe1+YXze9W/5JnoUPcqyE3bHK
Ev7ORUD/905eb39kL7f5yl4VmKdHrM/gjxDtE+qcjDvp7mlOPiT7h89do7dD
3l3QAzEair2G3IE6nDbUlFM07Aayfatk/tAvyPH8duL8wHMc/sm1gbnNZuii
zfl3q8Gwf/z3YPDfh8H9IXgdc7yuOV7PHK+/idfjxOtw4nWj8DpSeDwRr3eA
1z/A6x7g5/Twc3v4eT08vxzPN8fzzPG8KDxPCs+PwuN5eHwPj+vhfijcL4X7
o3D9hOspXEcx8/4KCfZsI+Cfj1OIuuv7TAiTZugqdqqQ3WqpYJlwfGfcHy4m
/lN5sroD43C02yX+qIlQ3kJsf4txoPZGQAFG7Xa4j+lkKqH1C0nnaAnJV/DH
YrosAfOtbZ6Ea6R4Yje/2shgrw9mbVud+oDbgOBLmp+4Wxxd4tftsBNngn7e
2/0WwfPixvX15oLSr2A/ctj87t2QAXpYZ8Q0VPzaOYxHcbb/nKUM0Fe/Grqm
pbQUsMjGTdun4yWAXuLN7V877SaIZf55jjBuuCAmZXfId1K6zn5Dm/viZ7Cf
3NtK0TeSvYPAd3Mw6T/9BXXRtVgtCh0uwvW20xH6c7AuxOlUvhk3aU5CzG1q
n845UcC7jzzYV1q8g5Bi4RxeUigOuIkWHV3bNkYC5Q3LCWTrQcBFQo8yDKj/
RPZvr/181AG2t9hHFf95oBvlfZtp0LFPDJ6LvLPcXti9ikZxzdm9eQLrrB6L
mqANFqHDNLSHrO+9g+N8G7WXpeHEFmxFvtLm+hDUaRUcHnaG25kwloYjksKf
oR5rZKhe+MLMhGXkp3455swBeMuBms+ZC1swj3ieY7vmYb1WD6uSyldy9JgR
pWHwV5WtcPxfOSjlUjZgPRKBYid3Qd219t8aHS+ixATa0spdXaDu2sy34dSN
5yuotWjccH0lzPsKw4piDA/No1Z9xe69wTDOqHDPaOHmzw9o2pnqIFV1eC6y
rfH90JHsQbSqb3RLcB08d9kdbh/3oaQRjZuiFM3aDd/XKxK7ar+bmtS4KTwy
f3zXHthDxzjXppbQEqT+fqWq1H14nrFS9GY9i8hjhPPF/pwYDOoZ1Vj1vHaG
EuSeigbjSg30Iy2cOv2tMCcVOat1qHyLB9RFrNsf8T5t8kLzuTe7C0XA9vt+
eHR/u5yN0jgIyuk8aQA8SZGZdVXqv/e1VvgL7wkY12OaOpGarVWMftjZEx57
EPqjfObF/LdJ5aPBedbT1CbQH6WeV8n2hjsVFd1zLM1yFPqjnrKffU/pZSK9
pv28/rQv1FFb0g97CYmlIQ2q3/QopKH/JCz+sHCAchEiZ6EUr0BdDPiOaq1E
uVsVyOn7bpMst6CukExlsuWuq0J26dmkZYxAfxHv/oPF5StVyH4/CsmlL1DP
IOy0ueb/zfN3H92pWQvon7xcOL/+aHExQrTDJ4DXJbzgH7qWjVAfEXU7c78V
cDz/yodlRIahF3L24xL1D3eEoWs1txwuVcN+Ild62vMzslCH7Lz9EhLwuj8H
DpclVxWiNjYRqa3voR5b/WHy0ka3FCXaP7Sr52KO88rbytHzf/Y3eL/iFUu7
+obK0M37swOP6MD5YRXeWRXzvAS9ITTLK38e+rsUC8SQZ/2FaEydsb7VUZgP
lsdoWdm/kkMafzbgBxy0wt+vT0NZx0rji/76nRef1TsG/+kt1KQWYzSvhH6J
1tp2dv1lT/TxeTf1nW7wve8wdo4nZfhwzfEn2sofTinCc76KiwI3b9khilkb
RkTKYZ62eEL3uqcarkjRyDXKbEpYJzabu2BBStAJId4vrGNwlEksaXinNZLo
4G/YeQDqn3hhza26+yURjvNHeAJMIC/PLkzmtbqKMhvVsWRkwbx9hbnFhSvu
dijxuUO/UxwrA2Jq64hO9fvqhcvA/CipK1a0asX2KNuQ8+4YH1i34eOwdqeM
33WUa1tUFlW/JeCNXbdZBNX5pB1z9o/uV/8GdBRrWmankbUNkjtRZZf11BrM
28Ygtbosdw+EOP9wPjW+XjraGumHEJ8X9EcpjctnUPkHkfqBfqdP4c1xqzEh
iPkxp+16sVBHMWcULHA/CEYcTTYW5GdAXeQ389hopPwu4tcr3egnB89TfHDY
fUdr0ZOM4/rqX75l2DvAcP0xJFrW+qXBMIzjE/PbbdB/2+O/q/f/v7P3VQb/
PRj892FwPwlexxyva47HE/H6m3g9TrwOJ143Cq8jhdePwusd4PUP8HgZfk4P
P7eHn9fD88vxfHM8zxzPi8LzpPD8KDyeh8f38Lge7ofC/VK4PwrXT7iewnUU
9/zL6wo0LQT8M2gzsR+pJzSnG2IWsfNsM5Ov3OYIhRVtf7igcGTwrHMT5mbJ
9VOdr5IQbU1sX9pwcWSfYybWznaDfmBdGOEhKZ7Ywvfl49h8CCZgmXg73fEK
YSNpHjLTlIboKxyx8B03+M2uH8LwuKGni/WbylOm2BetYb13F08AfVU643lU
Q18Tc2VS6r6jJw+e44FrZltTIo9gOrRR1hvMxGDelMWLyXr279KCyyoPRjcs
gf1ht/XWYESVl9Co0cbL4wZ1SNm2jKwgXUECzYS/Q4fqYVjX/YijjdGXfYSH
Bq03nSqk4O/p2IWeS63jIbANV0gon4G/77NLI8x+4NBOQl9c8ZP0BsgpH8wc
r1SmI+S7/VixzkIAH3F+lfk7b2OSUgOJ9IP9TyfwSQt8oMJuWQqETZTBOquU
8ZY/IjOYMJ3p+Xb+VPj7QT2iinuD61gx7Xf8vHKOUKe1irnvkQ1gw4jjgXrs
5KSL4gXpnZi87EHHdzsEADfoT9pQLsuGedy6L9HJAOtgbCiSljPcsh2LLN6w
57AI1J/hYk/ktmxjxl7SH0tCSqDuWrpo4PorjxF7d12cwj8a+rtQBplT1202
YmfKmgRX1GDe10HKvM/+E1SYz32Txc8J6wC/K3imXeLIT3TTt02DX4KWwLp+
nFhAQREwhx5dSFrK/jkFuC87q37wlvco8bqjgN9amWZIPPcCFVo+cE7zAqz3
Fd3fuO0Fbx1q4KRoeOoarCMxwa2jxGFyqcYB45xOOmcL7MeHsu5TD20uQm1e
pfB3naivPZO/rr3MQwwEzw9tdYc6x2x9xo3EwhTEZGY1K/MdrIdArN8uglLm
OGgX2kD+wFVsg69nIurO7CgjPwH7eVh2aFf8cBaqdVvSt4sfnuNr2kln/P1B
FqpsLppTKwLzo9id6luLXiegwQKflv8+nzW5xKDjkG8kveYtsIHG8iK4L0In
q03vWCqCPFFq6mCF/pDBgZF+pm3FiG6ROf9Pl7/8UScHt5svVSKqB7KoIzdB
nRAa8ObgG8NahPvsm6xvAtDPo0r3wvF7ax0iEbKdJ6Ue6pPRaHuxikN1yK5r
iQFUdVDnzE/IfT69UI2M6lLc+31eAdjVn/yrMgTZaf64OaAd8Etdk8zh6x+Q
ceogY+3f+Sj/cnZKycyTHPHov/03ZzRs+SSaj554eiZZ9QLUYypVL3YH3ihD
pzZ+sqvZC8dZjb06xspYhbZdZD+xrAv1oUFWFFdDcTW6bVjt25tFqK/E3FMf
LV+qRl/kbX9QfBfGGZ8mKIno7KlEifMAfw+iWcOJci24DE1YMTtY0gB1rKfD
tbgQpAh1ms5349WGvwvQe9qz5LJ2DvrpuGyuQAM8FxC/q9j+fEEK2vve6g0n
H6w74cMmea0sPhxdiJbcNPYV5tVMRpszXXdzRZcuFJqWt8M6Em8z7rD0EsRq
Nu3+ZiujLgvsZ/pQg8KjMkvEOqGUw0IA1hmQe9nHNRxii1DTd9T84IbnHNfV
fTmUI2KGLJ53XVqSh3W9OMfMH43tU0B4y8XoZYYg3xFtby/3RB+9zM9j+fe5
PC9REe+5Yxao2HWPHtka2L+tuNDdua9W6DOulq3BdfaA+28/ifIoXEFHvucK
TGeaAW6w1rWdqW+P9DZX/nXsufNAR1klrWu3mrBEhDNfrs/Xvg7mIWtTWJzW
eg+EOP8wP4q693v2Z1N/pPBweoH+RZgfPi/whU9I4B6pPYzrbWS9uLGwJAwh
3lcY4LulTI2DpcIR4nqH/iK/7kd9a9RhiOCIsPTf9UbOJqz9j6zrDsfq/cNm
qSgrI5TKSBFF9nmtVEgkK5RVRsMoI5U9I3vPkJBNNufYe4uKjBIqVLJC0u/7
/b2e83T1/etc132d67zPe9Zzn8/nfu67mOv1Y2S/0BmtKC7Ii9SXs/39grwQ
fYrHbMvzEC+Sofleym33H5zYH5TZei7gfbI3y6GVmtYBTfOtbH0TAPnV/6fh
31oEkFcM5mWQqwdy9kBdC+TBgHwYML8DH3Pgaw70QsB/E/hxgjoM8I0CPlLA
Pwr4HQD/A+B7ANbpgXV7YL0e0JcDvTnQmQNdFNBJAX0U6OeB/h7o64E6FKhL
gXoU4E+ATwEe1f1oaFfwbA0BbNO2fCROnW5Mvb04h+kfWrxM6TxFMCmY/T/+
qTN8f1VHOXYM20Ugp8sgyPcR93/FuOzhSRqD/X59n5xGzZaQtzX+ioLymQ8l
LljOqQlt9U0lrBGcH4Ef21zHr2F8FwTv9V1Xx8+/4ECrRHzoWczc9MSmkaAs
zqPetH7TZP9GiSRHm38L5KPEr7tYaXGopMUJQvdY+VJMBPQpnb/hw/s1/hRB
oPSFdJWmAo4f0d/+6FKHMMFMavn+Be+zOP7zhriwYvFxQtSJ7FfriBKOd1GT
eV/i5SLYUFm1CclCnFTlsaCPPQOBWmPySSoNzLlu98/S7u/qQrIeXUt4wHYG
x4P2HOn2C6XGyl6aj+9uhePpkglq7uhmxSzrj655y8P8oFjthydF33BizT4z
jxq9IU+juXqK9ff+wxjbtWdsP55CPuZY3e/+4NNhjGv13W9jHhEcL3RQrnzj
eBhjHRxqPi4N629ofEOpkPAhjG6lhOvkPci77I/ei04V48RaXp50b0+COURF
9VKmvC/ZtsYDdWKuL3N1FRaYsIPsXS/Cn+2FvG7nftvHtPSYbM8+EkpJqO/y
lwgf61PbtbU/JY57og420SnkWDtiQpnBBtcLRFSmv8n3X0eZB/iy7Hqhv0TX
Yg/fz+h5VOlRat9eBthPPNNlbFmQP4Fe3RdLupsP6ucdstFzVs196AhhtIH9
KpxnV83WvWJflqHbpjUnLlZA3bIf9xwny7tL1RtkWeSqt8zx+aVHyNbk+9kn
iNZU/Fc5V+ir2RKZXBqsFYusSTN0HxCBPgbLP3cihyVtkLUBBc+yIMjTWK6t
hwnfD0FZTBQnPDpzcZxzkLTh0LE4dHsePRvDU5iLlN5wzVQnNgK9InOqf40B
6ljKT40F0PFflZYS5IuMeKGFj/N6F+POyJ9PEFXW/Qox09DfoC1/4ZLxrUIk
pWek/YY81Edxsit/js6oROKv/eIbuAzn/R6Vdo/Jg//wp56v95jGYV+MdzW7
5ui9BmTzujXdUhfkG28bl3ZMMTcifI+og5KuQ37yYtyRVf99PRKZMxj6J8/J
ynvAJ1JRg3j0rjzNJYE+wCTfKgbFxkqRZz6aZ1TfQP/bDVJysnOpmf/BRZ+q
5fyba0K8fyAuddP0X70W+vfxO2Mdcv71zSfeJ3A81lzerGdiKlHvfu3Rg29g
XUuI/kdH6I0adOmH6z7BVMgbkZhXdM87a9GL8vd9brlBnhm4rXJePLgW1WeR
aI29CM+bgVmJ7NNgDM30K3aty4f908U5F0O1gEpUXa7dsoixGMctCutZrkeV
oF8XazLOLMLrVeV7484pgwL07g9eao056C9BQW5gxTCUjiojO3+0XU+Cx6f+
KvfEIgG1X319hFoX1kkuNRyVPFociBKfR7i+LI+qYvpnsz06nE9n/aePfZNZ
XmTjG55q7klXn7Vvp2AdOKo0o0rUeOu6Qx/yiVXmeIvHhsi5Af/gDE3Ix5Kf
WHX+qpNDjvlXZ+n2wfyj9OMuqqbV6mi2P2PFKV+YB2SbZyFo8ctw6zxAPflB
ioMPLZP10dsBMRdIY6B/1Al5co+Q0/ukxzqaY3Y0fsN5VL+fz5P7cRYIz8vT
gg5S1/H/VUitmvXE5SHyni2F/5myA44X1+04Gsjhi9SYLabXjMH1es/M5EcF
7YIRplyBZMbd0Pcs7JoBR8VaGEK87rBOlXtusa3iXQTSK3foXnA7rCtK1fhk
VdNGIsbsa5IeJJBf5W5+/jffEDFiU9rfGgH5lelDYZ3Y0WDk+/KB95Xtf9SX
8vTNjy95/wc3+PaiHqm033q+4HsgS1dqj6nIRVTqmpQhzEH657sm1CzbUe7h
1v0P62b/n55d1Qna1Guv7/9UxPkVyCcGecUAB7l6IGcP8C6QBwPyYcC8D3zM
ga854F3AfxP4cYJ1c8A3CvhIAf8o4HcA/A+A7wFYpwfW7YH1ekBfDvTmQGcO
dFFAJwX0UaCfB/p7oK8H6lCgLgXqUYA/AT4FeNSGL8eV6A9FBLC1eEnc/y75
N29f11EsibemZIa/n+Cl9vP/OJlDzpW9j9KxZLm4HJoKT0LBFg80cM27Pvnd
HWt1LPksTqGH5W39r7czeYNU269iz3hiqea9L+Lnn5JTZcOPihnJM5qtj7vL
BN+Hcr/t2ARlCdeYSzY9QiEvStB2lcEM5AkySiYJqwYauM/Dps2PfgZrGYLn
jvbT9De0cFz4YVT5MIMYYfVoq+uyiDaOq7OnCJFF8xN8vqxMJsfC/fX2pjG9
I2ElnPo1olnLA3OuLW9fm/ab+oAGl7gLUYpr4ON5n3ORucSHBbsaojUzQqeO
49Wrvte1bbmw9b7LQsI9KjhuShpe4s5wFIvxJU2b8ID/686ZRJ6zZwWwClst
MbZYyMeQw0ttj82OY60TFN6m1LI4HnjNlHvimwB2wNTGdR6TwHGV4/e26Qjw
Y0+66o8HKELeJSrZZ6rlxYepXH+6znlNEMeZI7VJ1ZR5sOukd5jUW6BOLF89
RkS36xDGySHPxFF5EB7nzIYmRep+7O7KjCZ3ONTbK9EfXr2wiwXbnZbYy88M
+4k/7MZGYg7QY9YFeoMNe2BdazmQdtmMZyc2FMtwtrkBrlvUZr/a6D5Fiv0+
+dVj8in09XqvFiO7f20F3Qj/9qK2cgbWVUyRXBvhWdSh9nQTg/U4jgdku35K
zx1BFfcEpPz63YvjF5RNjWUk2tDBS54t12Rh/aHc9NV4lmMeGiFny+X+G/om
DZOzPGPTUayO13LROLAJ9d4+ocscBaL+yFyFErJEAvW3izeT3kdT2SKHb153
jPkK10lZDUT3Kge7oDtbyO+rDUO+ZEgTcCvkhTcq1ia67OoKdbkPp8RD1UU1
pUUbyujpQlXx301srTcwp4hFfqR3eR5MhOv995xoNTCQyUNGTG+XFT+B45/i
vifXI1SBSB3art9rCusk2z1fJe/TqEM6epafV83AdXZl33gX+MiaEAGBIPaf
0fD8GF48o7F/bwuiInnusrYt5Bu7kyhT78i3IMT7B/IrZo4fVo5nmpCuBdTy
Fj/kMyqyN0+nWdUhJ5KcEN7dkP8c4DfZaLIsRz6P5E8zNf6XX8UGN4Uo3IU+
t8T6lTn6Xj344595DZe/hz+alcpC/z5+op6ehtPVMtT25aFIu4ttOB4VJMxE
itWgFRFzs17xcPzaDC0W0T716HfE/vSeN5BPGnonK8QON6An7u5PMGCD/MpD
9an/klUDKnE0TnqGEdavPpxyOk6+UIfWcdLMnk2F/MreP+JVtGMNKhdgGPfn
+kQWVdGnVosVW/8L1q/UJH64qJIUo6TapfKRU5BfVfCNNLg15aDE8wbzRvkf
fPARfZOKJmatW/3pC1GXGe8f8jkS3VvsW/vQAeqCBPaHBb3h9kadDBUixHSh
Tz5jPsUc5eRNdK0tUqF/DOYEzZTMTBq9ZamuGBQe+S11BL8/qwO3YVm/ziNV
ZcXZp0ZhPmOGXqMu26IYopf9Iz1pEubr8bwi1Wd/K4OuLc1PJvQZ4vhr1uzB
bIIy2kqZING1WxPHyd+ZzuVO7JFWDnv+sJF0CudR7WVUzGKJxoiA7me0yV8f
H+dSfdKkRbYDkjioRftsBfptMk0XuV/c5YU0mSXeeM4N63ihrcmZm6qBiMRv
QvyBQ9D34BPfUVLThTCEzuqH7J/r+KzK3/v4kUQhxOsF61dLvfxyLVPRyKPz
fN8X7sD6VeGT8kk6k2iEeF9B3tutHBDothmBpMz7f5XyhdeLUuXBXARXKEK8
fyAvIq4f9EHcZ03D16/COlXCrMOzN/52iHHV+6ivCpCnqcqLXI6c0kIP+ojL
pJDA+hUxH8cV/Xt/4vYc4YA2Z29FrgJe91Bd7Se8+6ZKuMbEFHr7uQrOr0A+
McgrxufZrVw9kLMH5n2QBwPyYUCfEfiYA19z0GcE/pvAjxPouoFvFPCRAv5R
wO8A+B8A3wOwTg+s2wP9R6AvB3pzoDMHuiigkwL6KNDPA/090NcDdShQlwL1
KMCfAJ8CPEq5Q0SHOi6JALYFq8T97wcf2hVpX48NDu3eK0/znECWQsQLvvuP
MkV4YHf3G+1/qGSBJQPe0qLo414ihHRJ/LTUtxOC94NibieFz0VCbOyKDMf2
q7hvA4fhIAW5mTohVJUl/sH4NdznQafgU67y5XMErh+//D6rmuH4orncxTZH
GcLzm2G7rz29juO9JNa9nc5ChN8H8zVPbpriflxvzlGakpTREpqvd3gOzhjj
vysiuurMdZAJ63DI7CLcNMRxhgtvtbxf8WFXP5D5NOzQx3lX2FwP/y2+k5hi
TW4303fI3341yeRWhZzC/BP7n2jyXMLxikQSVQ5DMWz43WCEUogazits3bNu
SrwXwzhbqFqXQmDdzGRTud1RVQyLIl8rybx+GtaLVrvf9r0/haWmE+48IYW8
y2T9RWTJW2Hsic+2mc8vYb3raPNdAUPPE9gN0Qush1/DPuMnYweTtFUB7MM6
lTA6fQzH0xyTPlmMH8Ee2/Sgj41gP9Go5k61IRkXtvd3V8DTdbgu8sJeCzbD
fQcw1gPbGC8fgesrOTKvC4zqMGM6vKMGUVxQryUv4Sev2EOLndcdKbDrgn3D
b61WZzvpt2PcunznplJWYN3pZOjezI1f6MCu3s0p41lYb/86Z+bPsYCWdYaa
vN4FfVBjxzxZx0gmUfMSpSs0V2Cu0LBnkbm65ks0hHQecbaF86Pp299vPNUx
lMWt/2yFHawbtD4Pa/3wLQm1kb2+WBUF34cPw4ZTjnoIVo9mrFwxea2Azy8l
2W9tmhBjJJ9NQu9EF/TJieFp1vW7aor6G71YK2yD+hb+zEFy7lfy0tn0r5Wa
KKTx44w9dTYQ9A5G1F2HM9erYJ0hklwg2ywhHblgjU3+2Q8SLpBK7OEtQcpM
rIdvfYb8KjPC+ZfXVA1yREH98Z+69K18Z2RA9r082x855p8t1SiKHrUiwzRD
DnTacB3fFFXrsv7tdqRNukejcSfUIympspGPsbYjZ+YKCsZKoc6c/ITp4uzj
FuSB7f2m4dOwH2fZzq4bMVeP7GzO0mF2h7yLYLnzsOZyBUK8T2C/79CNWkme
nvT/7J8YPUT6O9AbLVhRGH7VD3Effb0PGYP5KJPIeM+bAMijZHe/XTcaq0KJ
/xfyqKsbNjvGbOvRv8ff83hloPNgE0pr/jH+Tz08icfypZhzzahIoRcFrxLk
n7piDLnHkGbUNJJuUEcQ9lXvLF1vOe/RiEq6PBTnyIG6d/Xo3+YG2+vRv6+L
0vp7aqUPKGpNfkaVVRLq3k+wdGD5WmVoA2VJlKk31Mu9s41Y20taiLb257Rf
/gTnX0mS4yOzc+no8fs3zjU3QB21vmxx3SmyBPTZwokZ1xm4DjFEN6ImvTEQ
7d7R4lN5+x6OO2fq/2z3cNrCoV8T60IGwx1DA5RmemK8Mw/ms4QbJw1rx5FV
1zbbSTfeoMfv53LG9DdjLocR4VGZpYsUBPz+H70S2W1awIUufJYzj7gpjeNH
V0/3cZasS3kZadY/Z4B+5ll37ea992kige/LSloUlPHfNab1SeR+a4Wwkb4m
7/lqiOPuNlpsL5tdEBkVu1sMe6BPwmjnaTGlFD9k1d8l25AB5lFK3vYS/X0i
FJl+QPOt38gZvjfIBAVq7kQixPMPeZefCXn8v7lC7/L2Vo38gn1DmfDt+f/2
4YjH+aM/uxLvE1Ubi7x9z+E7HQevi/zKqtX2yqit48N6lxXdHLVTTejW8wt5
2h1RNlT5sh+SzXc+/Z015GOt4U+lI2vvbo0H1qMC0j/wtjWaoH/vz1W6qa3z
w2PrPofvN+JWkaAUHrFTXVYO51dJ943CSpdOE8JNx5a43c7i+OP/16/OEQ4K
rLcxWKvh/ArkE4O8YoCDXD2QswfmWZAHA/JhwHwNfMyBrzmY34H/JvDjBHUw
4BsFfKRAHQz4HQD/A6BfAuv0wLo9sF4P6MuB3hzozIEuCuikgD4K9PNAfw/0
9UAdCtSlQD0K8CfApwCPOnArzGRv5W0C2IL+qcpet3NWB00R3Uf7A+yooA9t
BskYi4eSBSGfRHzfgQgPAuBdxhZpzz+Q6xGG3jEy9n93J4B61+8Tr7j2kigT
lI8PDfwqcSGAPmNU8Tb7kGsihIDLhQpvS52gL0TpIFUI+zt0YsDUa/9Ne3w8
68o2av47j2ONUX724h22+HrGTbrgMn41CUzUznqg6t5t3EdiH8t7shABWey2
vpnv3D/jBddRf2/YxnFrecx09x59pmnI03zOt35lTVbAivKdfz4QMsL52ONJ
9YKPqwpYgMzOAR12PZxfJSU+LvSOU8Bq1m6vk3TC+liT+Qmr2HR5LD3q2N5G
C1gH+3jBwKLrjBzGtnz3rb035F0hToNr3UIy2JXuH/JOgbDetV9PmGrcXgrb
7qQu5u4D+4xYmuEN6wgxjOwyWfGtcajvmvGNp42pEsZ6U5+z7piAda0ozoyL
FRxC2FXm7uaep1A/L7mxN6LShQ+7eTM6R9oD6rWI/leHsVPMtmb6crBvmF73
a/tRMQ7sBPlpX+ZCyK/Oz4d5On1gxDbyOOREbSC/sqbNWqaPosYul9a8/qYM
61dBaMkaYyQZJhw47CDhBH0edn6JKW+OXEFDh85SUpTD/uDsc5kccsXPKKe2
R7vWGJx/7/10utIlNYRauTYGuNHDuk3ag9huL7UmdJ3L9yJjJvSNTM3vk78t
no12+JgdkvwCv08pHGW434p6ou9VjJS9yW7hOI0o5lhLslEl5OYrRkuA88sz
v80+bYu90oFx0XcthWhx3P4T1wLacg/JKrKiDr8Cn5cXJPUjH0ZjkQ65+KN8
j1xwnExc3VmpPReZITXwskuE7+eLWonSLXUVyIch0ua5h7COYffIpexJaT1C
8fGp4MBlqJfW839ZFbHagkQ77hqwpIXz+4Kr2tWC3g6kbaliX2At5APsNBR3
qWy7kJ+2FsYFNlDP1im21y4gsxOh+tm7m2UG8g1Htur08uI2JEXiSBFf/R/6
JeF23ySXRsRmh/6D1GHIZ/xJQt82naj6Dw70Vx+/HH8mRAN5EQfPl6j44DA0
iKyX8gwv7OvZWNzp5yV/gbLs33j7b64UwJG0bXQh7LXo3+OJyaxYmI1qROdN
btzVXIF8+9w2HjkytAWV47HWLKuC/b7O7ubGj7OtqHnEgVyX75BH6UeeCGgI
aUUv0U7P/+lHYVn3m93yYzNq4H2w5pAj1LGbWJPqKW1r3DoO9G3Q0bLfFEit
3RoP1Mvx55s7u/NUot/zVTznMdgPeqj68Xwn1wvUySVK6U8edfjxB9Ne3ix0
5Bh9i40+5FG3n4/vMDqdjMoMBZ5mW4Q+lqQnz+73nwndOr4lrMO0HPIyDXZD
+VNPxYjp6uF44FhGESWdOUq8Xoqw7vepbUakSA696KNGOtp0BMdFmS6ntTX2
Vn2We7k69vYdzpc0FhWLk6g6pMIrVgavvknD8ViVZ8lcOtLIi+nPVrMRXPhx
NoJafS6UGiL5e+5YC1DI4njD6AVWEo+7COFxjojrUXUcL1N79eIWhQeieaWF
JP6PPD69+v0C6nMBW/e5GTyfh1gcNGnCt44D1wkeJCcjYfeJRv4+bxwVVyi6
8+MQ1pujs//64QEcI6V4UUmWgBCvI+wzbotZnHlSEo/8fV3KUszUg+xjkFLU
2OrP3KWTXSy7vQzCt44P3z/86+sf3wQ8QojXBeZp2ioo72bXskf+vh9uLQXI
CmpdQ/8+DkdB5Z4iT6//4MStNOG2+ivSk34IzqPq6TSUeR8RCJa+nMVhIbCu
5U6vbl7wXI7AOCqho+WlhOPzt/SpeZ/LE9xfHTgfY6SO43g+8VZeMZgHQa4e
yNkDOMiDAfkwYJ4FPubA1xzMy8B/E/hxgnkc+EYBHykw7wO/A+B/AHgCWKcH
1u0BXgH05UBvDngI0EUBnRTgLaCfB/p7gOeAOhSoSwFeBPgT4FP4c3RQOaMh
0poAtsB/jNAianua5jlGx/v2Uax9PV7v8rX/dHiz3BOjRwYzDjxKx/uMZytk
f59Vs8VmyFM/mpPG4PquJdWf0zz3r2NatWP1TEtBuK6edII2xfewETb3ZDZF
o98bX884ePX6wYwd+liA2ih99WE33EfikK19MT25Ljak7GT91fMeztN85fPL
+9e1sGqC/e+iyTu4b2ptWYU6vaYmdkHZZJZFA/Ixff9vImIdGtjqh0fKoW2w
ntbAnek5qXQROy8lcy0k0xjnY5NLmnakjmpYR9mzxXghfZyP5TgNFcornsd4
SWyouf/gXYXqQbwRJEqY+InS4tAbajj+UnXw5BSqiFX88Hhp4gT7jNNU+mHx
wfLYvTjdAZI/9F0NN5uYjjHLYIIH7Kcoh2Bda0daKQ2ZjwQ29SPx7CF/uJ6R
vZitWueGCNZrolohLXUEx+MFY3zfjghiHA8Zr3kKQ1+IpsWFgzECRzDTgvxd
1b9g/SpzZ0OndMNBzDj8yy3KOdgfrP4h7PKcmxWLqmPc5HKD/var2Qt9OdR0
WP6UHMXrj/M4/qp/bL/fPCXGruDruCoI9e0Wj33OP3NeR7+zTOsJhMH+0U0X
xlH3m1/QZdbR7D1FcL6T4+jQ2s4/ihKPD98/RUm8g+VurVv7wzzWwZFrlI85
8lGm6E9G9pRwPfv43s+E16+9UQ5W0p65VKinvSVRlSvOxCaNUJG1vn3JCP0i
NK47Zqv9rCpJmtQ0+OO7/pDtXrun7Q8Q4vWCepKinTsFXrxLQOpmS/bNc9ji
+KWHMTmKQQWIWZdt1p09cF05A4esfG1YNUI4mUtp538G/1/Vcaj49NNG5Lq+
Tp8BFfzuJj2U4HDUtB1h/SI2V7oP9gU+O0ckLNt0I/1nPG5aKEGemSJ7lP3L
gV5kL3e3r+EmrO91znXdIT3fg7D13Ur6s89FIi/2+l/dOXE8kKc5ow/igzaa
kG4Xlu10ApCnhdMqS0xMViPfx3WtUoMgn9lTary/rDzjP3gZozTzGd4oVM5v
I6TkCeR1GslnhmqXS9DnEk+/XELh8RO4bUZDnOvQxYZAzu6EKhx/qUk2slbV
jBLPA6zjEfXt7ahfdbT4V0t4/9zuYBucvtyBvjxaxhGhA/nSQYkr9zXq2tFs
jjdPXDugvyj/Y1e98opWlHh+oC6d/YJu9+6CJpT4XEC+JHslSlnrfR1KPP+w
zqDh9+Gy9p7qreNAH4aN6eqK8JBi1GtJYCBKFdZnjEIOvy39mY0Sz7825P9i
SimMOiko8X44hN8/5TH7lFg4wrfGfw7HtWnvk8fluG+NUwnH37zyG+qItUCJ
7wFZHK/dHpb0ZFAe9VV2Nnxjwovj4bOdL015uqWU7OvQpyTPcR51/SQln2dM
b5Vr+JklygXIu+5/67icy0ZAJr09rag9D+PHqbut4tPeaYQgtWH8Vz3Fcdy1
pLLyV4Ed4p/cOcN6Tw7HBwzOyPDv8ESI11ERx/ve3M62cAvcuj9FcTyq1oHx
Nys47yRuAJdqRVcqhmP+g9NnfvDdx5eA/H2erSbctL84Jm49dzBPebxTeKDo
dQLCvINcMoAa6up5bkqI9U7Ebj13djjOeCw/aMexiK39YX7NNDpMb475b/0u
1I8BfvU3TuwPXkeJzxH044rP+4y2Tnuhf78fiNtThLtOXoziVeI4L2rjfHI4
ZfgUYflR6w1rKqiX1pfhqHUXFiOETJpUL5mexnG1apaCdGpxQmTx1b61QMi7
Fq9Qy1zmFCNU14g8rfVXw3GQTwzyinE/zK1cPZCzB3CQBwPyYQAOfMyBrzmY
Z4H/JvDjBDjwjQI+UmC+Bn4HwP8AzO9gnR5YtwdwoC8HenOAA10U0EmB3wX9
PNDfA+cB1KFAXQrwLsCfAJ8CPApdkBO2MUglgO29LT98sRvjd2f5+zGb7Zmf
AlxHCR5bfUnycZYLNHQZ2PzpYzK1HeW4rp61ka29lzQU+yqh1CPi9Axfz1jT
vnrdvt0de5Rgh43wxuA+Ei4rRUMhMQ5Ys99sVfbLIDwPaHhlp4+ygA2W+N0h
N53Rm+ABrktQh7wTpSV2urDr505yF9yvPrLhW+PnC9ewPj8hcYMxezwnSGRb
NSW6ZIRlX/lZt+uwDV4fu5JjU3as0QAbMRtXHfpqjudir091nLwcoosxMxu1
r2OQd1lR887wLWhip869HPc4pofzrm+9NWUTjRex0B8k6clcsM9YuK9avmJE
FXsxEpe2J1kF8i5raTeP8nOYpl1Y98FCWNd6xWNHOnbyNHavKpIhTweuZ1z8
KPJ0VVAWW+8YspxKg31DxNqWbuamBLbqrag2HQH5lY/3ZakeZ2HMgHRut9tp
WL9SQ6sU9rMLYNqvfjLKjED9VauqfbLWTm7sYkGN3Ec9qG/fbNzH2qzBgUm5
VGn/mauYfu5EcGEwA6aCOj2ZOPJHPrXfqxKSSirsV7b7IQITrFe8tlaQ8RH9
hXps3135pw9hdXV1YLn3N5R23wu3ah7oW97DEn+GZ3QUTZk/OqClBP0Znmd2
RfluNKMZBfcVt/ND/bnGGc4SIZoMtKkzMETjBvRFrJCIOvuS/ZK0TGGByJkJ
qI9qM1sQ5n1igTRM7tmmPgj7eh3FyXUnN26ilKPeNDEicH68JKvE3SwpUL1f
qXAGsTyNH2eGSjVLjCQKQTbWWi0l4fp3QRP7XOlT+cgz9+1CiDrUcR3vWhka
f1WNbMq+j80LgbkkQ8dseve4NSHfm5ZHRYqgb0N/t66x5esOZO+92Gz1MejT
/vFE8LjsqV7EOnZEf1wJ5oxca3n8pvFkH0K200K1vwvyzJkqxcSj3WB/+H+d
qt48P5TUhUTYy7CM3ID87dOjU47KGi0Iz3umD1PbYX3Ge5Gh+3ENtjUeyN9i
RVi//UKe/wfvC03iD6yNQnmn23f0fIU+6jml3ZnRh8tQ4jhh3o0p55FjleQN
KHE8sI7XJlxyXV26Fc34YOOg9wDyooPLsSof+zu2jg/zbuI33O+x9nRuHR/W
Cd9EnRaV0AQ47Aed5208sfyxDa24mDrwJgDqfHoqjTVJM5pR4nm4iJ9Pphfl
hh+z6sH+OP6skvl0wu/qrf3hOruVsGZkG3kJeuVY9i8jCehXcKZYLVxWOgcl
Pkcwj7j1/sVxnQMp6JqG2v5wRXgd+0gPk/keDkP5aP1X8z9A/Tm1ZARZ3Q8X
NJFf9+y/ejeAN3w7VmPOa4w2/vase1ZxCcfFY28bafmSSZ/9fCBH9R7kSx4n
LrInXuBFBLxDjzj1yOPn4YSuL73FwBHUXZJituC5HI7vjshHnKnIqh1fel0u
egG/RxbUjjK4fdNBwt+NJ9+cPw+fa037r7Zqd5Dr5RSEmk6o42JCfp0pOe6B
sPZ15P/Mg+On0nnA+402ENkvWDQcbGYNz0/s7yEb6QhEMEaQnjsEftd8TP6m
VnE2FhFXOyd3jeUP3b5OfnxXewJCPM9Qnx/5DqN6bZ60dZ/D43BKqKg9z0pE
iNfXEsdPCFrz67nGbT1H13H8h5/inuC1iP8c59FtvZR/1ysScfhdBvjV38ef
PybwtCXqBvr3/sT1gyBnEfJG4pafYBMyX6t4VuSv+tVxAicapD5eKoHjq/RO
ykf+wdNGdLn4yCDv4kgW5i96JECwr8/R7ImG9S7ys/1V4buOEmSzPZyl/GGf
0YOePcZGn4swfEmv81KXCo6DfGKQVwxwkKsHcvYADvJgQD4MmB+BjznwNQc4
8N8EfpwAB75RwEcK4MDvAPgfABys0wPr9sB4gL4c6M0BDnRRQCcF5n3QzwP9
PVDvAnUoUJcC9SjAnwCfAjwqmMrIMya1ggC2I7lb9SLXht2UzlOYilf/rO3i
HMFoS4f/eDrKS4u7ArsV8/bY0oNGQsSWbv82h/+D6+dTsF0kPZ9U/fNx/67F
kC569EsI9mz/vsVn0sm4b6qz3iFHfnYv7AvzsfZjKuG4X/3IIcKllW/3sd3j
Qz5ur/zwnCDWqkx+Ba+7WAzZlJ17nRuez6i2dA11rL+NOdOnmCfJOuK52D8Z
bN8O3DXHDCeUhWwMbfA62NQePpvvb0wwqxe1/U6C5ngdjKmR7pBzzFVsTYAN
oblthNfBXugMxdm808VeXCBhvsShg59//iO2Zd8ENDFh0cthKvTqOL/KDt/p
woCoY6fmnGrGVhRx/Kqg5GuHTiVsdjiVMl4b9g11tLAP5uKnMbmDlgduzEN+
VXLE255ylwxG9caj+HwY1L0X+j1CBi6LYWtSsSKf4qB/6TutI/xW9CcwuoPP
eu/XwLyeZslo/9lTR7Bhvxjdp/eh3/vzWp4cFX9OjLBsrJ75DNajNK2yJr18
9mIli9ZuO46l4e8BQnFNk6X9TkwyyFyoJwPm1/wiSG+u7NlEadMdlzYDB3Fc
gmRO96bvV7SlyqhH8DbMr7kRwac4sTCETq3e33GGF/qLqi7unfXQw9A3NDcf
8irBPL6QM3RMJx/ZSO++f1jzttIN/D3/xNPrzOnrMUj9mCvNkR1wvk5PWV38
8PMhItk6t3KTE8775bLD3wmfHqOUpDpl1CLZOB7Q1P9BKzocPTh6LIpuBa7/
yu+ZmqEdkK++c8nOP11GH67bylsNvu3xDAnwyeUskYf+DO+uRGz23q9ARKSS
O2NGc3C8bKNnR1B9I8JHeuNkLQv8X0Yb+gf3sXYifTIO0vaq0BdCbH1UTbO0
F1Gjdsrx64a4Q86rZ9Mk/YhDoFWr6ww8ztLBT6/Xy/oQ9/orR3ZNwvWSCyL3
H7oW9iBJj0JrF8Sy4PkPfrWeytmG5HI/kNURhOsl43ipKGz9apHgLxmyQbKQ
720qM/iaReUgxPsB+lJ67XOc+zffpTH4MonVIegb6VhR46GhVIYS94d8I+Ex
Q77w3Yb/4PUcr5n8pdvQdB0fkmfCkD+LiO9MV8nuRKvrrtVW8UDfy2yyBWvO
0q7/7M8V/UB3hrEL/Xv8hl6c0+cT29FwzVQjcwLM7+sX2Tuetti8NX7Ih+MN
7+Web61Hic8R3F841eLnzpJqlF07QmhbBczjG6pSWX1hXoze1HW1WJqH3xel
VHnt5RFZqLO+KdXJaejPea7ozuBKURL6XjswRssB+oh6akqxxmsHojSVWQUp
ddAPoSqKpOikzF20qSc8oD8Z5uvxiP1MWX/EJl1Hden3Q751nEeVPd77Wzf3
EjJ3c7woT8gYv5+7jmhuvpqUQeyZ/XguekEdF8ne21rMbYqohrjbA2VWcxxP
pV/h5ai8iH6VS+S20zSA3ymOeqxvY5mrq5MDmhpGoK5+Zi/XQzFrc8RPy5A5
nR/yhzstT265kbog3RdMsPYSyE/YN1THecz8t+7P+zjeldZ74PfB8K37Gd5X
U2+5lCXTYhAx3tu0K88hX+053JR52zcBKXxsbyQkAP3BrlsRLHkTk/6Dl5Pa
oU1riUgW5sbpcgL6oH4oRLhLP8YhxPsK+n0ZqZUK3o2I/M/+RP/2AOTv+/mb
cuO56ReOyN/PBegPEp87mFsN+BXxPoe+GcTtIYL8sjo/30khnCfw/3/9IBeh
Iyico4Mb8q5rRw8e5Ks/TJiXHNOgjoD1rohQrrzRFU4CRwVtP7MT7DM+Mb1w
ch5jJRw6YOq95wzUd30kExcMK6IhPDZyFvjcAvkYMf+7DeVi16K1PXwGx0E+
McgrBjjI1QM5ewAHeTAgHwbgwMcc+Jrj49/y3wR+nAAHvlHARwq/Llt+B8D/
AD8/W+v0wLo9gAN9OdCbg3kf6KKATgr0GUE/D/T3QF8P1KFAXQrUowB/AnwK
8KhMJK22L7CVALZB/UTfCXuTD1xDLgvY6eENp6boFULOlu9EavlgGW9uI6bb
uSb9o6oT90319VZwx5SysS/TE4HxxsW4X73fke3qZqmx2DzrM7o9SU/xnKDU
x6fbJUQDsedZNO42m5F4PqOrS94tQq0H1l+puzA14o/XwaKj+u0Ttt3H+Lor
zyvKuROAL8cdXwllCbK7mE+SJteZfgcC8PHw/LwxvbP8FraYTkHWl2GF68Qo
FkMYy7nMMAJZ5xu+9Gs47wq588QCkTPGGJkb54426+PnP+Qgo8eDH3oYPY1O
SaudBs67/CZbmDPItLBwM3vOrzTncH61/6UqZ+Y/vOt2vKujgD7075q0JrvY
3n4OO9Ze0v/EGPIrtcQIV+MEeUycd4ynuhnq2xOyF2Kb1aUwd7HrHttPQp2V
a4fKtxxfYWwx7Zmy8S2op9r55Lw9+/Zj2NLci8sxo9CPvSHRa3vk/EHMoIAq
jXNqDNaLDE4Vf0xiwlQ/FfrNY59xXP/L8MNDgTux7BH+zfN3ID5tkfs7QHwD
zdjWa809/wHHbYz2pJ52+ozGsqjw3tcZwvGDNd7cvlK96JvZKtuP/pBfzVQK
pTIwe0m/lx5g2yPtBn0Xz0pYuCq9QIjnDeq9rd2rLk/z5SIqzp51I79gPS1s
+r2QR5w9EqE9t3nBEeq6f7RM0TpVpqF3DBx7YzWgvoiYj5OHKuyT8fS89Iee
XGmXodDvdPRqbWhTzQNYtzniEhc1k6NeHUR1YnyS0hIfZ+blqaJurACZHs54
dJE6G/9fn49F8CSX1SHceSwDmEw5jr/wTQgyutmOnO1k9N+TCH1N5TkZk6Q9
exGpEv70nNfQZzWEorziuHo/4topWrVoA/1RFRusDtFc7kfetIjMqGhAvF66
wV47vxepvUe/g1cJ5vi80g95ddWhHbljvdv89S6IH+8WP9PMW4+QKo/k/pvT
iN+HHxIecoQXINUtT/suf4LjLz1hKvdvnpyD4s3lzUDIA12zd8rlPC5FU2gu
8R3cX4zjn9RuWT0xakAJnPq3a2MgrtH9jqvGu+0/+wN+daLhJGuaMPTDl2T5
oij6qwvtGpS8opAH8U8jfpbvv3eiBgH7VP/0T7t8PUdz2KgdJf5fiHNV37Fa
i2xG70RsoCcEoL8Z0b+9Ht3Zl3H3OTfM197UyremPVCFHpE2v5SvDn1CGDvD
qQSyilBzZ8bhbnPI05zqCxyX5tPRj8EBlA/vwdwZh4pCQQM0GpW0njv1p/95
DpvBTDTBHTV3efA8UB3yDdnHJqH2Z/ilWWponzGnUuP3W3/+3tKm9BsIOtPw
SFT8Ln5/blfrPWNCZ4HolAVcYWeAfajm25u2FS+UkC/ZRyiuxEE9kp18R3mc
oR5q7BUd3h4JfTvDi5bfPHSwQH+P5U4nu8O6X1cGvwrj+DU0uJzxak0P7K91
dho+EJDhrr5lfbawqVoUH2fTi5CQIYU7iIfr3VDCU+gv+k6CqVJ41QsJvzFz
TYUV1vHMg/05xKdDEOL7DfKiHeR0e34NRCFjVLUyvpGwnhxTwHnG7lY8sjvj
3/d5EI7TbLoyB00kIsT7Afrex6h8clUOSUSI9xXk7YBf/Y0PTb8NZmyNRCw/
yadMHIE++Xcur1Nooo8R4n0I97fSIHgW0N9HVhMPhf7pe9/nNFglwGuA/o0/
KQwwjuf0Qv8eP3HLQvie5WBGy8yH8wcVBv3XRo9ZCFq3RZ14+mFuHfVnN2rH
dGYCZ0XHhSibk5C3XOk8qLlCR3D47UQRkwB9wi2rH85425MT7vxYziaphHwM
XR8r7s3IQ6u8yyr5H0rheBYTd2joAhXmE54aRngKeRoxh54VE7t2NTmunAD7
klv5xCCvGOAgVw/k7AEc5MGAfBiAAx9z4GsOcOC/Cfw4AQ58o4CPFMCB3wHw
PwDzMlinB9btgfkd6MuB3hzol4AuCuikgD4K9PNAfw/09UAdCtSlQD0K8CfA
pwCP+l6vFB9/+iUBbF1YiT6rz1puGK/mr2P3TNpuaoZsEsS3fFbD+zOZH8x0
Yp/53lDk/uzDc4LShuI+qnoXYePimucSP5Xh+YyJVl+3U08kYxlCo5Zj1c/w
XGyfKL1y3WdhWF02Z9PkgWgC8Im9PrNwtPiYL/aD93ls+5g/AfjKfkzwzudn
ccXiy3bUpd1yw3MbbfoaGVi/22PbJTubjmbYEYBvrQsrr7MuiQ32JvvwwGnV
GwTgc3thYv8vym5zDJPl9HxZboT3GaV3DDk3vzPG+E6NZmf91sT7jKkuNod9
Z/SwDcGKR/OYEn4dKXIGdNePamI/vXTv3DtLwPG6ziqeiW+qGG1alVlKPPTL
KvB56dUwoogdPHKRXZUG6qzKKC7diVCQwfayrrzRcNmO4xXL+d76Faew7Z81
ktavQn1LionbZxcuAWy6N0Ivc3oRf34v7M12aEw9hI3wBu2PfbsO32MPNGke
GzBhJFE0oW/l13CcZZp+4KEDFWYYtHiuPAwepy+KL6lwdQV9mZIU6PXrE+RL
ZyrPt06PoTtarkhYxLzCcfVKsXkG3whp1PNZqPhoCP5cKJ9+2SYd0Iw0p9v5
Y9LQz+FqAzvF4qlmxMzSo15zDfLDyOzh3vVLpYiP0epupfejOO6zY0TIwTUU
PRDoOdpzFOLfL7DO+x6oQF9aLe0IloLHqfYaVAkzr0Mvn3S277ryEscNs0Ne
HZeuRaXfmjd/EoPr4NQ5qCMbyl+g5s+uUDMNQL1QCa/Q4BCiWy0nLRAsNH4H
/1/conr7k+NLkbZ1M0r6YFh3yi+uYvu4qxnpX6U++vwQ5FE873/S+gd1I/tU
Fr8y7IT8k/w4C/fHt33II9tcgZwRmJMopzuHJHn0IxEh8UopJDAPiOdocRt6
oA9xrLy9tPM5zH/88Isrj9K9E1FruujpKgCP8yZF92LgkwbERaOGrqwc5gcd
OFhQsv1tEbJzfTt6RQ+O56bblxwx3fvocQtfwT/zGYOCk1FDhhJU49W21Ikj
MP/6aLF0hmxEPTrmrKb6qB3+38uT2F1v71aUbK67puME5HvTlKImJDs60Rpq
zQr7EJhrGfj6Z8MSbxd6vjjhGvtJFMd776ayX6fsRInnAeYWGQXF3vE+34bm
jPMnf1WAfer6V82O+nJN6GMPk/N73sDr8s8X0SmBsn+ue8zRG6vvIB9rP1lF
vXKkHD0nQGL2kgPWA1E2t0qJs/mou6md0L5imH+0vuCdUSWaghLPJ+RXWQ2d
a6Hv/VHvGVpB01bIH2ZEjUSlFsWkjZxHS8faWfH7Z3mI4Bp+/j7yotq/i/cs
5EUj18N3PMh3QfSeCAd/vAL7oScvB3z6am+HpFCqRPgwwHVw+2xVF2XCVBDi
dYHr1GasRBufH7i5dV3g+rjLEgxGbc730L6G8AWmRnh8Vrfd0Q6299H9zAm/
PtPBfjSj1sW1hgVbVLfhRwZTHVwPKC3a4ux+Q7CaJlHSgopRDv9fTBwN5uL5
9xCpL20abpZQb7lO7hRhc8wfaTqOrUj5wrqQ2ivHiYrcf8Z9kdT9ghrkpcYL
31cypmKQs2UsPl8oIM8h5g8mINEp6hYUG7DuqjPe+w8vSkDuCvct10XAeqNr
TrLwJlPc1nMB66LsbG3jCnmRyN/XkZMh6/3aoaD/7E/Md36IcIpPLp1NhTjw
Z5DwtVeJnIJ9/ynRj787mjzQt7fijvP0wPEQt7SEhPu05xveHMJ5xc2mAV4N
lJpwKqSHY7WPB9a19Boi9i1uJ6BaD9R3fYQ8JFyB8xut9iZi7JzOPdgN+Zjv
//1FO5FUqlzf3bzQP1w9mum9vepP9NXoxNjKPcjTEh7YXRKgoMV+DO7uGmaE
eXkxlwpMBMpZsKKXQ7cEi+H+U1S7JE0lD2CkOg832ZZg/Q3kE4O8YoCDXD2Q
swdwkAcD8mEADnzMga85wIH/JvDjBDjuG7XlIwXmX+B3APwPAL8C6/TAuj1Q
hwH6cqA3BzpzoIsCOimgjwL9PNDfA309UIcCdSlQjwL8CfApwKNKoj4xB7kP
E8B2xGP9/7jiTRuTUnrSGldvbl3fJ2QymzeJuUJKbe6mp3f3Y4qNuba2YQOE
VpBD1KmzmBNRioVUaTGRD1UQQG5RdH7SYU3GNOzY+ZNXMpTTCSDn6JCeXoZ0
XCRmx/t6wd03ioDnIh209Vnb549tpjP1NQz7EUCOkkyZSIsYqTt2TMhKt6Xl
IQHkLp2060voUHDELt2y0RiitSWAnCZ/sREJxxs2WPbKQw8ZtWsEkOv0pNCd
nTXGHAubNdhf91KHAHKgHqzYnxBnMsaeU1oUfiZTweta+uqDeuVVuthT+WF9
g1Jp/PombxdO/9FwEaupueL1Z/7OyFOznxU8Shh5k5kk3XGop8q5ubDX64Yc
lmK1d+mf5wPOp48i6z+bimEaG2wiBRrk+P0pXh1bvuvAcYxv7aGRyWMq+L3z
eDKBXeUQJnEtwpukYxuO7wjS5eIwYsR0/cutfyaTwvu/PMC/LoEc06eoalAI
X8F/1+5nDrufzizqZW6tw5g5Cd+TcgZXzy2kSp+L5dEve/YEfy4mvm632Bfz
Cnl5wqpFd3oMfw+LLWxqr2sNIbHx5i5kDz7j+CElcqovbn1IQJO2MN+jrzi+
eeR8iRBNGbK4lBm/7vkNx1MpnhlTZpSgwtPMN5zuQP/5DrPH6sk/2tHSk28k
f6rA4/fldffsNupDZwubFE1+Qb3Za+72KGGSPvQ505OGa/kjOG4RFzgQatmO
ym38ElFtgb4TOh2nherMqtHq0VNGE7xQ7107lMmv/+1qdfPdhttXSZ3w87D9
qeb1E+5VyIDwsWP3WKGfPLb/afYr+jbkR6ZAw/1QmPvD8vSD8mGNXuTuax/x
VSOYt6hOsdJzeaQPudNV0bhSBPOsOeNvZgmI9CHlBlNfvaZ6YD2EcptbG3MX
orntc0YhCczF9rS/Z6DJ3ISoC4T7vJiBxxnJutbvQV2K7Pt6/+eZhK6/+RWy
Te1RHgcTvA9dz1OpvX1UiJ6anxy9zwn5HvPKsbhszjrU54S5Ctsi5G++tkEC
D5lb0Dth9pvfb/3BJ4VEdsreaEcn7+7PGtwO+dvGO6bsjeQOtHeA/0qOO6zX
3drpnftv3uTYoPGF5gbI0xx+f5S5YNSCEscJ63IFNRdjM081oMN1LWYN5pB3
9bbRsarzoFvHh/WxVwuR2u9evUDTW2r3XqGB9cnIGEY1zy/paFwkY7+MMNTX
Eb5WFriuh6Ey/38Pw/rJ2OtfK4RPctK7sjPVuBy58PvB7O2AcnO/N0J8D8D1
aOmK/f1cioFIvJaMhmIv1NFhKXZkP5weIZbcQstTtbCvnXhA4d37tYfIUyQp
RZ0b6uuI+YMCSNgXfzJBOYhXn12ho793Dz1pVm9pJQ5zfxauJBm6WXqjB87y
cKjPQX+nlJYD/+zmh5b019+/9wv6cxY7qTQtpHujpCujjxmbIR9jdj76Le61
E3qMEBRn4Qb9Fk5bnJNdNxOpPk/vZlP56Ax+Ht74UR6f2O2C3BT8ZfHRCvqr
RBqIXE4dCER0QnaxY59gX3UveV5xOWMkwn098J7mCqwLBe6VDLnEH4ukeeS/
1WaFvEXA9AVpYHgc8rugU2N3P+Q/to4cdRcvxSIL+dHGS8Gw/3tszvkA6dlI
ZDLPxGZYFfrpifHudGmvDtwaZzyOR+0wDCbd5oIc+ZY/ZzQGcaI/gzz69/55
KMP8v3q+v3HiloKwdiQq6K4lG/4eHmS8di0umIyQqXRk1wMdThy/LX3umfHj
VUSBelEamYd8rKLk9odIrreILC+vvoEYN44Lfr+i6/J9Bh1KUvoiPAN5Wsc7
seMKeWTY56MvrexreHH8aWEllfYrGizz1vQ2fhmI6xryfKhUYsBW756XF90G
j881cpjLUY0Ra3zoIPooDY6Tb3LPIS+X3ZjvO+HPdDcYcBzkE4O8YoCDXD2Q
swdwkAcD8mEADnzMga85wIH/JvDjBPMv8I0CPlKgTgL8DoD/AdB1g3V6YN0e
WK8H9OVAbw76a0AXBXRSQB8F+nmgvwf6eqAOBepSoB4F+BPgU4BHBYWpfLR0
fUcA2wSXH//HIxg2BQanyWuaLO1srF9TyBht5Wgf2mURUZI4gIUuM15WbBgk
GGzlbns/CWH/hlRg/gTFawmzFQSQ0z1TEnfKYuEZln7SqDhB+BkB5HrTjp7S
7t8VjYnJCHX5KkUQQA54MSVHdxVnACYqdMpfid2bAHLDdehj+vT43bEL951Q
u/cOBJAzvoFURl9uccBM8zTe/2a1JIBccvm80ztoma0xEauNH9xM+gSQY854
wGTu8qPr2PMPgtx11So4H35L/YpOe/UKdjy6/dWangTOu1Loc03bqjSxARVm
mzLTg/h1j3/3+ITA2fPYTo8TJ4Qy4fOuFrOsQ/VKHpNsjf7Fv4MWvz9veTf9
OCwsjnGj+3UZMxlx/FfMtNr3BwLY0S9hQ+Nn4P1c6n/58K4QTux8kY6Y6C8a
HGfnmRJ6KkiLpZ5Ptfg3Xxrg6GzP3DrdD9Qy/sodgZ7v+HhWOjJzma4VSLPM
me6UGszGn4v6+zoai5mTSMTiauGTy9AvyzduV6XO709IkfJ1v5Nr0F8rsJXr
KdfaB6TuAZNviQTMpza78YT0091BBLF10BqngescXbtUtP7NsdjAprvOnYL+
83a8r7IU7najq6Nfvvp5wrxFqj26o5nxw+iuvpyXUpHwd++Ph6w0vBpHTdOt
69T3Q7/6QtYQ18ea42ikE+8hJwE4/gfv2iTTzw+jLrT3GmNyJ3C8udH69E2t
fjRot9RklA7MZ8z4aSSpzlWPKjfrcRx7AX0J1FS6v1FPGFevbVyec9npAueX
0wq8sSiGfHWmnPuuCOszBbmmH+gt2hHvyvy6ojpYd9IrGd9VfKgXmei3U7I5
BHmUdcie2k6XXuSF2YJKhRrUvy3U/yr7JdOFvLcjhGaSQx3dhtlo+nOKZoRz
hNtJcwXuH+lLesTkXgWiVuY5jjFAfEt/hTTWBH61D4I87T39u9pckhz0GkW6
EwsCx3PlmF1Q7S4MFTbasfznd8FiqStbbmMj6uYvJfvxEORjfbxXrUT4WlEV
T2n9/tuQjwlFKErm/mpFE2j7tpVSQf45L+b+PRBrQT9LkmsoWUHede2E3NWO
wkZ0mLrAr6cM1sGifrC9M7hRi8Y55DbWnIJ9z0/MqZ99LMpQdqcGFoo6mC/p
0ZN/XMssB/XgMvQYXYa6taWu5I/+9TEosud23MpHWJewkcm3I7E4J710/+WC
YYAAzGPNdnDw4QpBRDro9KdJYB2JUzVOXqI4Gglz7+KtkoL8x64giSCfG41Q
aIcUedNCnWHr9W03MynDEOL7AfpLPPU2u3CNxQM5Fnda5IUG9EdVPshEI1eo
gfKKTbw04YC4n5vNl8fNXuim7k5aGSp4nI6+1aQG6lC06Wtm+xAH/F0Ws5Y6
He4I1LonakIOgz5gFKzb1swUw1HBX+kR5H7Qtzw+76XQe4kg9OYtEY/vfrCe
ljfV86HHxw1VJ+N3fb4G63K0E8nsT7eJV48lqqKiq8r4eePj7VQs6nFD4hnT
drzeA3VNBc86z7j5BiOn58IcIsNgXesgP8MEzdcIJOTj86lGC1i/Mqx51iMW
Eo1cG/RPLM6F/EpZ6f20lWA0wnBu5XsvPeQ5YP2gFE93yRIv1OOZqbWX3px/
jBgQ3pc79kO9303jk6une10QzXvsq6/MIU7kVycR4vsWHsc5aihZmOUBSrxe
kL9tbZGGgqSTFw7A97ZL67RcU8M80rdSd5/elwnH06nTT9joTyIUk/cNM/xY
cVyAWruWK6QP/arCKLg8D3layrLda8LIAlpOLj52kZMDxwN/mTjTCZJi3Du+
qiznseO4huGonIfwdmyU+y1TxK59cDzukTqzX6mw2l4/k8IUOO8U9qSJ7XhP
hhXznOkl0MLv+hrzbUzxRwakY9vMGu80DuLXlzfLuNP9BgNBhkH53Zr7bpwX
gXxikFcMcJCrB3L2AA7yYEA+DMCBjznwNQfzLPDfBH6cYF4GvlHARwrohYDf
AfA/AH1DsE4PrNsD6/WAvhzozYHOHOiigE4K6KNAPw/090BfD9ShQF0K1KMA
fwJ8CvAoIUf7xN8TEwSw1R5e+j/ucLFIOe4WZc2wr824VxKlzFFzlv/jL87n
sSc0DWIpIa71j00GCTkGRN71vWrSqetAJcbcUNyWxVFOICkkjqclbdBHRTwd
expx0iPnSSphbIGITyZ0i71qisIyBNG8jooQwsQW7xrbLsB7gsUfC7pXajl1
1I3ACOp+M+cLwre7YT2ezmURZDaEgi3cZso1cSDYDluw8WVTYDbEfTBYT1/z
+ufVh9lRafXFDavg/cSpU6F6od+MMT2SDaO0n8L4dWzIY2wlxXSw928Pfit4
Topf92JaF8bOlQuYntUky3wzfI5stqU+3HiigO2TopqLugK/C+6ucU4U1olh
j8SsbrMbwvqqi4xpvVDeUcxwfTYkOJoFx/ebnoiNE9+HxfO8eP56bA+Oe1cH
/WT5TIZ90lwq2hvyC3/ez630h0UKV0knpLb6IPfL8Oei8ndQ9P6e74iqQe7p
FnqYY3g41D6mJmoF4epgp0WSYN60vjDzplLsIhKHDdclO1LhuMTTS+znH35G
FGjuNH6I2Injznn1hT61/Ygi10MbnnsQ96cS+ton24yqnkyPOVcNj0OfyaWQ
dPA9ysQ8pH98Ca6XfGgcoHzA7RPac7gvKP6f7z+AX1CUpm7wmkVPUR3hnPgG
eZqG+mHhmBczqJZsb+0NEvi/TNw1ZH3pPqJ7aZbC6aKhf8Ug/XZygZT3KCNJ
T/4s7TSOa7tQzRV1vEKl7muJC6fCvuSPcwWfXx5o2tof6sdujNyli6YyraY/
2Wp9JBnq0LyfnYtiG65BhOio0siCoV4rZeP1qGZbG7IoL5I9cBHyExmrxd4o
ry7klI/9G4MbkP8YDcqs6m92IELBWgbOOyC/eiTXkPr8SjNS/MY0ddAD4tQa
eiMSH6uQmMCVkj0OEA/5KEW9Kp+K2OffQmIdIO8i+l89RZfD76g1N8DfZQ2r
eCf6oxydq9iYlq2G9bGFss+EFcl6NGx3WkUMAnlX8TLpvhmjJrTi7MUkDmrY
37S9te7sQdqMPp85nMVUB/kVR6ve5LBHI7qHaYD5pCjkV6zy1C+pROrQLx5U
u+K1IV+VrypxlByoQLV3jEw2xkH9WEj/4A4mhwKUzadZx8EZrlMIpS2KMWZL
Qr1V7w6aeMH5l2nSnK+k74J0npS13o0KYfx63R8eVMsdj0QYvesY7tdA39HI
R9Ly8idSkANZyx/HpqEP7ZpCP9254VRE3f/RJ1UTuC7D9Wja9gLvZOQgJavm
lxLo/58eo8f0vicKCbKof591Aeb7ONDI18Tv9ER2e1X3OJNCX4sAJLHqc5QN
mqyzfb9ZN9zfn3lOPDE3BG1uyRwLIYP+Ho51Ycu2cbGoaS0v6dgK9MHQap00
sBBJQtN+fVr+09+eIN47yy+WhP79vwzdtvW3s8ShtOPjUo97YX2MQtFpQa07
DI3+OXZbXw7WwW5cmZU8I+OJ5r1X4Fk5CP2pXjJVm03TSlbL0L+4w18N1wsL
BDhT+N5wR7Z7lgW4K8B1nXUsSYWHm4KQUzLsG75aMJchvLgrhkonHKE4EnHg
rh3kw7dLpVhnNSMQHrtt6qdk4LpgJF2WO004DNG/1/aOmgvyn3Sf/muWrwMQ
V+1Llz0PQ76kRZOQY3bKFXkqMtq3duhvfqWB6OWj1UWP4P7R2Wf3reTYb53P
v/nVJDLgoCMpbb3jr/7gCOLAR+7wMwp+FxP7g2UI+yRT3z1r+N39k2kxPurK
O3RJ+woqY0aH47xI9u9n7Avo53NFmRoaELe5MrThE7mO3oo22DheCeeFSf4G
BYqCX6gt896MPCU4HpfFY1brFD/Q7OdyFxWS4HwRaTCqS1XXKn3zXHGkHGkH
fr1ebQ55vdlDRbD2pPxZOA7fw4V9ZXybGZyEA+jVd9/VoL9Q9D0K764FIcKF
FO55F2m4Xh7kE4O8Ynz8W7l6IGcP4CAPBuTDgHkW+JgDX3MwLwP/TeDHCeok
wDcK+EiBdXPA7wD4HwDfA7BOD6zbA+v1gL4c6M2BzhzoooBOCuijQD8P9PdA
Xw/UoUBdCtSjAH8CfArwKI7On7VfqSYJYDtgt0j8X4HsVwT+2c/w7sBP+TcU
MrfSOP+P78iPa32iP4gdRV8ac7u8JLyrIh5fiiC9lsZagX2tPYw5FhYTRlDi
eGZFxZ/3vU3D9rnJOGQOJRIqt3wqyqv61037IzABJNDs+Qs/QunW/7WcLcoX
5/HFim5bGW88sCdc3To/+scSzUqcHmDkee2i1QomeD9R4c3O78VzNlhIDoVV
lbwKXteK7/pM0iJ2HbOsya2lVzuC1yF1N4+Zf4rVw0I4nIS+n2PB15nGLMlw
e1xTx3jJmd9r6R/B72fh9l0C2o4KWIT2gfnGEojrS6lMvEs8hS2XP6zRxA7j
+OxTSv833NxYR4rG1KFW+F1Tw7b35MuQ3VgGCV/cD3L4fWGXMM6tT9EszZn0
W/7kxQb8uXhuJeflH/ILYeO/KOnxCT4X834MTVYXyQnUlj/bk4VocTxZLkTe
MY2UIH3/G3+3EXxeCnd3yD66sIboGq1VzRow4filL9MR89hnxOItY31DPMRd
91kFarSnIeaJYXbCblDPj/nU9Gnv+YCqE8asqYMY4HoB1bcFjBvzqIgEQyUP
Bcy/Hn/aQ+l8dhk1iDfqcoqkxnGW4K4nbs9WUJ8+le67rFDPNruW86sqYRkV
yzaU6B6F6wXqbnW6S/UsoOnnTMlJnWF9TO6Ma5jv5BeUi1Q7OD4Y1sFkMqrS
ldWmULOpzlHpNZjbWNY0e/felyH0/ES9E53UWxz/uHtxuKesGY1gqGO8Nwt5
16l7S3vOtplUm7hUmrsxuuPX5bD44UKpHAzpesogNhoOeVcyTZoMm34Lkl3w
w0xwDfKTSiuTmdfTrQh1wLM6t3ewvkSrflVX06YJ2bZNYfm4KeRLCc58duwn
UeSJ7sVol2SIX8vcf7K4KBOJcrEpzlSGeL+NopGuXTj6rGrH7fnbkF9VyO+w
nc96gVJmUDecEID8Kjnf7XEWgqE2skGfv4nAvmdO7AEaY7p6tGj3QN4kM6zX
fShd0/u3PqVZcPTbC3PYN/Sw7K57l1uLdvkodleEwf5gxC7H06W+lehcYN/g
n/r8e1V2FYf7C9Erv+8ECt+HOquJB+J98odS0E87hfTrRaFevSRQ+WDYMQ3p
pP2/Cz4FiuPnny494V6+TzwSeUDSI5sR9um2/NuRzfq7jRNOkIc49pcZPFzM
Qn7K9CuptEI+s1lzz2hGKAsZHtpDmycNc3zyxFY+cZ97hhDPD9RVKkhOXu8+
Ho/cKStd+dNnLJNRxYhj3R1pUD1eMb0N5gT9j6zrDueq/99mVtkV2ZG9Epnn
2AkZiUjDTGYhRMNIKiR7FcqMSGYyziEr2aNESYg0zMwo/Z6+vM/7uZ6ff851
3dfnOs7nnPM57/vcr9frvjfzB4OwnrCXHpKi8PMfJPM/dtIlY2nnr/OKCUG/
1qcj8dXPpTOwr7vyWpasYJ8hHu4gE3QyGyPfUyrOxw152vjDC6sF37IxOVl5
cWezf/ExLdU1it5MjPPADPtPW+iHz/Rukupp/QPskYzM5X/7uLIwTSIRLvHY
5nMA+p8/ebn7KEnZDcxm5UqD1xfIu6Zds6KoVZVquH9n2vGfNySuC9026ck9
7YEIWXIvuZYC5F2+kjH/m/tzmNfWd98LeVfvUPTpIO8oZPO+gnrXt/EdKyt5
kchj2YU2+nrYf4XSaJ6WUw1FJCeffsyih/UF7/DfXGWp/lvXC/LwTX8GS8TY
6IDLr7MQl6odV+/Kcse6WB7Yt6bD/WxuxxGNpwERuz7+gfrY//hVO1J2qr9c
2ZjsP/pVI8b2W+drWz+sO2zOD45g5dtOCC3zURA4v+08VZH7FNb3mbVmrQTu
J1H15/sX83PYuhu+ri61QfxfifrbZ6+afsd4EyTfcQ3A+oXR0A4e74+YCu+y
YquTTx1x/umfnM5WT/2NpDFL9t/dBt9PH8oE6BWns6JTdeFpup/he7F1spHs
MuU+dMmj0OSTFnyeP3S9ElNaJIN2y+cKl5XA+mBfcsnLzHoU5TCO9hmQ3UPg
IJ8Y5BUDHOTqgZw9gIM8GJAPA9Zf4GMOfM3Beg38N4EfJ9C1gG8U8JEC/lHA
7wD4HwDfAzCnB+b2QD0R9JeDfnPQZw76okCfFOiPAvU8UN8DdT2gQwFdCuhR
gD8BPgV4VKcRnzZt5ScUbHcNbPKuU2tXRh9MkNfqJoQfYUonU92rdWiTR23b
m/ftfB+eXeTQ73iyG22/vKmn7WVTPrVk/Aw/sXDa67pAEZrQvXWchyvPt9Nn
4B7x/peYdOJRgZ9bulbwE8YM32j8t8En93DRADRm6zyUOwt3Uz6/jlPSaXQy
uTgQfhHBTmfK6lW98Qvc5CFC33WJ+cRddFU6j1od8UCfxJ8bEUsI6Nd6tPP9
+Rekp3FLtSBBDyZp4vrm3kx9dCDRGJdNMVbZvQD7BkdVmNekfqjjj68m0Kk4
SMHfl88PLlmN/fi2qTE5ixoBAn++MnPN8jkbflPnaJiyFdSZneaf3BzN7FH5
8yadR+ZSF/G7KNJ0oJ8hp0ZZ++9Rf46COi0lUnzlyEcGVHaA/ZSWIryfzzbY
0576tQNlU60InI6C+m1mr1yuxqttaFRU6Idk3b0E7sfW/ylncA0JM7xCV5EN
8cpfJxZ5poeRZzKZozYLMG/x6upUw8PqUWzR0zlXPwzu3+40fiJ6bQmTJY1+
V24M868zgniQjqQN7DDtTd+8fTCfkZflqgBNOCn+PsbAkPoT5HvXdqhEHRog
xaOvXvns/QbyQ++AR/PrFST45u8X6mYXhyrHGjh/Y+Pf30e0/kuX8zIhz0Fv
rWB/7tkdeisF65txYUwf3O7MY08GWTMeyC/AepDYZU/27ElMnrI2Z1AR+uFz
ta0/C9d5jz3q65r9Ogj98N/u5t19srgZi/bLfXyFA/KuXdeEL+bK29QsUbCQ
bRhCvSuGozMu1LYaCfF48tbTCuo2/g6BAy99GpDIvd3h23FYd+OgusAb8KMe
oUnzWvl3/c4c76Dzu1CDXHDyipzsgrzoS4in5WBwATL/Nd386iTEL7HVe/Ef
ccVO2plIzJTBfi1dN7sgsaQC7EfCCsX+i5BHCRp8K1/8WoGhVN4vxZMgj1L6
eYPdbaEGeyG7quKjDHWq4Iah/Id7MKzmY+Krt46wT97H12a6gaES22uikygW
C/vb5RjLb7ybLcZC9sbsCvsG631MAj65H//hDwvzZ8rJumHflGOj5b6TdKYq
pjvTzrjdhXlJsUukkwVSD5FdG+SqspyQD2BfXo88vlCA5L/rXqG6BnlF2piQ
wnRTMZIbuC817SzkJ+H1HO0ZoSXIUWv1qx5CkP9USO3s3VFWhEifOmHc3AD7
92i7DAY6PuUhrz6R0/nvg7lIX5FOybHZVOSow+TC2fsQVzsmNPnX52tz3YT4
s6u6HId5ojAt2ysltcPQJ/9JZ0OtcXM69t//6ydOc2L4Zy6WsY+nhI4HztWG
3/p+d4zlCWayI1FEsBTmLxyqZ9cgX3mC0aw0vojNhrqZqbTiP3wmH5M/w+DB
vhfmFDjednBLDnuEvYu8zEwvAuuSkTm1+FhZOnabfzqnlB3WH2duFZ7beT8B
61WspT8kBHnXexHJdfPiG5jUU/JMJgXIuy5/uH3hcaRCTV2SseLG/BHiOjpZ
WScy/b6GaD5fVaPcAeuMlRv0DR8dbiHkKXg/idUdAn9E7+QjrBuKGJ69Y6fi
CvvnI6p3vzIuC0ECvUYH8qWgDrZjgF2qZfAKwvX7M/9ffzji+A0Fjxwns0HS
rrFO8Q1AnPnRawGlfgeMZe2NJ+OB//a3dyMTNh31xjk/CFxH8tOFUeFSxGfi
psBXsiUCL+TuKM/d9wqjNTSYayWH/bEbditBDvg7LOHr7HjF4iKBU3c9f1U7
NYq5ZL1N4EYgX5LTnXFrfzOM4XtlUwXKYD/thyq3l/c8ilXqO/VdH7qWQl3d
iaNQYWAeSWARP5hzCPZRWHc7yFkb0qANDe6tC5WwLsCetzL/hmEPusASOzrB
D99nDeu0tPo1hFB0Kkbl3TD0FyLzdJtAmA+g9qY0NK0s8Plc6P9z/UIOgpLl
zmlV6kDf7Meh9ilXOA6hrWGPj/d2wBxVkE8M8ooBDnL1QM4eWH9BHgzIhwG6
FvAxJ3zNt3Dgvwn8OEG/FvCNAj5SwD8K+B0A/wPgewDm9MDcHpjXA/3loN8c
9JmDvijQJwX6o0A9D9T3QF0P6FBAlwJ6FOBPgE8BHuXUw9KCzY+iYEsxt/Q/
/OiKT/A4I2ltk9KymF3cBmqIX/0f/j5qWzjboW5c7vXtmIZ3LWjVqc2+/ZEz
LTT84iV4r86R/EPKOWjWp83j2XGyIffbhRR8fHpk6kBQKHpw63spBIXYRZ4L
wz+KO/ehSW6o1tb5MSZh5Ar4eBn/QS/D8G1cB+3dwq3WJZrcIlxx75eHBd4o
ixK5mRN+Psfe+J3Bkz9nXbYMVSauo4Aiie/6KSPc8lwv19A8nJ9dvKQdLsKN
4Fm7+M6a9MK5jPY5XbbokwL4Ou0CzasQWB988V5cUtVpSOV66cTS9xeDxO+i
+3kAkmLFgrJTX6OTfQ7fC0zYhdiLXrGjZ3LN51YF9sG5DDkmWbNENvTLn7hW
1kLYT0j7mIv69hEWdA+NZ0DQFQkCZzxSlfr5NjWqWUsXdJcP1sFPch32UF9a
QPxozlOz7YWfP3tRaNXAcRCzXHivdZoS5jCeL0yP049ex/aLsavZy8I6+3Zt
Jy09G0o8tUjEI4EaHud4q9mdoWkanOwCya5vLZCn2Q90XdrZQodr1iScDOaH
fKyG+01Urj4dfl6l/Fj74d0EvrPY+qYUNQ0e+7/fHZwvMGe09YhKpsTN6SzL
qe1g3tDVJcypN54U90/d3vf5K+RdR9N0up0G1jAG03Y2hVfQf6xsJf7A6z8/
MFtPj8ZwN6h3vWs9bjRq9AU72RWKhjyFdUYbo6u9LQXvMEnNxCKGmAEC57lY
Z7GdvgnrEGIpc2mG/V2HinfTzkmcrhGa/O1M0neVuO7kweO+6W7PEP/Gvo1X
COyrL2AO/nhEG0PU4pVM/ubGAJyTLru3jbcSOWLcSp5XBvkYeeVtw6CbT5Da
OoeX0T8gL7qFHtsh1xGI9HIPb6ycgfjTT4Hf9s1nYJNu6RbX0mAf+6GDKEo1
XoxFiAV+z2SC/1fChUz6Xks5VrBHP/jKO6hH0asqyZVxlmN0DtZohyjkUSVR
6zdofYqwLNum19cWII/6yPSK9vBoOkZl+JzZSwnO93EkjFHdTTFVOU+2Evzm
G0qcH9l995MudKYjBlyNPHP74fru/aCQXs6vCPHp/rI+Pwh5AvMbTYGlqnIk
vfSA12oX5Bs/Xa9nXOd/jmg4clfmBEDe0lpwWjEpvAJZ7Vx9m6gKr9eQXaTJ
c/0yxOs3RXycNfQPyTk9cMV7zxOkhDV8gdkD8moGHn41q3cPkO9HTphRMcLc
Iqs1d46ZQ2eQI+q7BFtuwc9v+jMkY75DNdHcvXD/y957lNPic7H2Ayau6kvw
eE7oPWZ8dbkIq6rw9GOXgjxtutkygHp7KfboycXxSAfo5y99hZL0YF4p5s0W
QZ0RAnUw0T7WmIGIkq3/C3kXzXHxYTreIoxp5h961wB56bVQmwr5tDwsaanh
8vgU9Jvl7Y8nuaqfgf0siuLsn4B1xqNZr/WXhBOwL0aKqdVa0G+/9sMPjTuy
wdhqrdbaM2boi36lGkU8teVq7vCoizdf0SWu+11RIXqxBF+Enfy2rEsA7KtP
X/1wm7MgCPHkcDM+XgX9r07nVE1tow1COp1sj51Shb4Ktsdvnvib3xP3gcMo
/Beca7gfEMmR8MsGCQzI2r0vCvbhL95tpMqmOo2NXrT5MkEF8c1tPfJYlarP
qhXqLZv8KhZTkxCPxoYnCDzkvl1eO30jVhgivyOuGOJ5N+j1qw/2YAXTNP7b
XMfg73qlhzRAtBsrzjUSlcyG891PmMc8Io5nqkz9KHEOfpFNnB+frgT+S4Xj
SDGvegLXGziXpHijsyBm/waS1IndKliA/RL0PcIHKqoZUH+Kx58V7kCdv9Iv
eLSrjBPd5VDEv10E1gUolidueWNCqC/1cxLzM7A+Ira79pvCJRlUKkqBfsAI
vrdOkRkjcbeU0Y9X3mX/O7eiou/cR/oWTfQug3Dn7ejtxDq41nNC+kCXPlqz
euvscQ+oP4B8YpBXDPgVyNUDOXsAB3kwIB8G6FrAxxz4moP1HfhvAj9OUE8E
vlHARwr4RwG/A+B/AHwPwJwemNsD83qgvxz0m4M+c9AXBfqkQH8UqOeB+h6o
6wEdCuhSQI8C/AnwKcCjrkjkigYPfEDB1of25yYf23egPT1/DQ/7Li2llLKM
uiaW/g/XGua4TfK4Bf+2UU9tersOTeLf/L+2qbLxL0Me4yHMFj8szJLRwK3j
LLIn2bBqicW7JQQkIze8Ucut7+uTo6v5TC0I702w9P61Txt9tnV+ZG718h3j
csd7OH+aJVOp4XNb+LJ3FMWi3BlcaNTaR6sS8mTOmxXS5ogeriqYHixLrkLc
D62hGPLWfz8+Zlp2XtQOzrfanVUb5HCfVBHrWda7kDwB6xfmDu50N3nQVH6F
7r++vMTvhfMX95MaATS4zDTptAb0CUnMdzw2jvOjI09UeranwvlW5qi5eQNb
HtToyuna/hfyBH735NvMoTxWdCZrKs9ECub+FBTUeb5CyNFPB3lNaG3h531T
iqTfFT/HpjzD/IWr4f4LajVMKo1I8ZmqF00u4XDuwzwydlqxfgeeFUsn18IE
j1Ow2yC6b4IZN6CnMvzGCnlaacnraZYJVjzmQcIpBhnIxywXkrxPqu/Em+9h
S2/vw3o9y5nI6ZOSrLgeTbCB+15Y3y9f/65hJ8aML88+HCehgfzzZaWaxC4m
Brw71uu9+G7Iu9pPtB355z0Kr5ItSku4CPUupcfyM998yPGVUytm0+XwuaEr
XvrZRfUXVnBE7/WIzU/i+YDu9yJfplnAnv6I8A88A59X8hm9un7yk9jm8cM5
RzaK3CEN8QHM3q0tLPD5awLnFnDi76Kpx+Zz4oq6NeH6rrPnbO7u+8dr8j5v
2ytpfIm4TzRDmslJ7xYhe8ysqN1qoV9BUup2ujSZUsRFzlRBJBT2h9+n199D
8fwx8vtG7EXSFKgj3TXITidlj0RI/4h/Pj8CcYb2iNuvdBIwDvm270dwyJfS
axrWeB7nYhHPc3zL1aDOduz3hckfLIXY7Lrbn32BcL5Pf9cuLqamx1h1xXux
lKuwrkdhI/NAfv0BtvnchnqUwzkq66Y7x1RED+/6PNgPeZTMuuXb7SoZyP35
N1mHJqEeFa03XUn9vhgZHBbe9X4O8iihx5ebQyafIyVf1+2+JEP+wJsvRc2r
hiF7xTa6hXSgLjTs1H5u3BFH7kR0WbLmwhxG0eSDLGVuNYj8/Av7ByGQFy3G
Fombe1cgi+ppipbnoB9IQ3RJUxtvEeKpekqR6zzM8bxa6FvBO5G2dTwQf3Pn
wuxfn/G+nR2G6SQQ37mfNNsiNgOT06ytXP0EfeFu6rwKyBEuwnx/jI0jZPB4
xN8GDhywLcc21yN4/Itz59tVlJ9joyIfjENb4fedDRv482LhORZOm9VB/wDq
XY7hA3FVVRVYWeIGfaQy5J/l1yrM6qbLMK6u1cvvyGGdcTPfuRjbvN+g79zF
YAN96h952D1vuX2tldkEHsfeK/05Ih2jtz/Hz/MV9tXj05wOfJxx2FjgmZxT
HNB3gtn7dar6lUBMTuJb6sdbcJ6xi+22FsWQdM2MUbPy4m2Y4xDbrDQTI+aJ
BH9Pbo25Bn0kChzptF6fuIQU4wKHdEihL2igNH0DZ4Un4qdrr8R0DPqIDhWc
Shc5Zo0cvKfG0C4L/Uu/hAxzSlgaYYnuxQLGLyF/29xmIaFBZypJ7GHfo6xY
j9n5vQ+wkrrLOxbK+gicbONqftfuaixqfySL5WNYr58ejxWtlcKxO+XGXz+m
/Mtfpb7izmxzrMonlZtP6i4nEN/3t9IDhqrsfmSAesndQxr65JhSvBjYaTCP
3Hv3h6ZtO5zrebNQ57T2mAyNL+iq87Obgvd/sn1GoSETupY44kyrDN8fB9d1
RanEudDfYpeDjLmhnm/zvanp9owg6i0QxDQr8Y3ABUayrduF96OuwuT3vw3A
fgMvN5HoiXIFdCZln4rIJKyHOtWL/gzRUEc7VO82t3XCfpikW6RZY9d1UDvS
2PIgFrhuvht5E6cbZYRWppIYcFlBn1KQTwzyiol+ra1cPZCzB9ZrIg9mKx+G
yIXZ8jEHvuagngj8N4EfJ6hzAd8o4CMF/KOA3wHwPwC+B2BOD8ztgXk90F8O
+s1BnznoiwJ9UqA/CtTzQH0P1PWADgV0KaBHAf4E+BTgUWNXH1Udk+pHwfax
0KY+1iea3Xn+8g+8Lin94Mf1KTTl9of/4f3fBCsuW9ThvGzMxXdGi1GlvM3/
e+AO9/61mIc4nUOE0Xh/MGq6vokv5rgYVLTcxDXwwlWXl+qo/9Z5ePhGq50r
yQPvfOe/5OJ0hNAP5739xFreWOJ+OuUPGB0Ow5zN7PqaRnM13O+VTVm8C7zu
DSslP/StFlUYw7GvLjsXoH/Ur4FjRnai6DknEevX/pCHxFp/uUPZK43SmH+/
/YoL+sYnNS8+9nKQQulPN4WXzcOcRH7qF+Fc1cIoV3niNolLMN/nvsszZmcr
XvRqzfGAq2kQZ+0nOzo9xoAmJjAHHn2tQeDSwc9dFiNbkf67pj/uOf1r/1QW
+4acqfD3WjoHrquqEnhrz4/z29CduCDjTMShYzA/KM5VwrQnkQMnsXYtljKH
PC0hbkE+WY4Hj7icZsYWCPmY7a7dagGivHjUoE6tQD/My2Z8dJiN3JUH5/1S
ZV11R4TAb7SiVFeYuHC242P0PzYg7/qsVUp2I40dXwnOqxQu5IZ8LG21MLF0
Jy5ZXxOrOQL7xHx5XvoYRjDhX0KnqDIKoY7tuedrRi4/HW5kRanSlwn18OKn
6SsMP8jxQ2zv3rrKkBC4EbXEB/mkdezIyFnuGEOYW7S6IOA5XPVXx29qbSmA
z585F+4fpCHj2FTql+AjX+B7JV55gJ1c+jXmEutCpZfeBdeXWHnpKMEaTCE2
uHsPG+zzubh+79cPQ6Oa/Gk+ReyjO3FfmayhXw4IZSOOVn5vnR2hL8Eh6+qa
WYksZP+z31FzbtAXdOeph3f3F0Qh53XWexqDYf5R0iWtnPptNzEPQY1+12DY
T56t+qPcsj4NGyNlXixEoB+CZ+1QdTJpBiZaGZQa3Qj9psaWKZYityVjCtxj
c4UfYT9wOfNTy0s1xioawtc2VquVieMPFOoYfMufjlTFUMRMT8Ocna7nJiEH
FouRuN0XbRkDoH6ieUEM7bpbhagIcU1ar8PzU6LxMeN7RB1Sedpoz/dSyFeR
kdWs35r1CDuv1J54d8hDHEUDc0l06hEy0cqa3hbIW0rPvm3jvFqHXLMplA+8
DvmPwIpcZrNCFXJGk/LJftZ2At/3+U7yY+Fi5On27xq+vRC/4mR4eEE+FVlJ
yiyRUIF1kM36YCjmECjTV+8IP7+pX+VhuneuKfnvaiPwzfnBMixOQzQFSYG8
K8wjplDeogqztKxzLluBetec0BfvfVkYNmm1ujMpBupdP+UXR97F4tjokdpR
Rkt4frpEu0/+5sGwDtG4jmY12D82ppFoGsxehTF3Uq3/O49b3iOZ5E9bOVZ4
6e44/Qy8LpxHSJauURRj9wPM6zvnoK7V+pnv8vmjudiGmtdlswLIk6eNr1m6
/8NDpjz36/G0wXoidrw+Wf11FMYQyc449wnmOLPVUettr/LDDsv30ut8gP5d
rttOnRL7JlQjlEbxSyANgTrwTNyTp+g5ZBvLxobRBPRN3c/uJfWo3xFxrOXF
e5h9CZymH5kSFbREHsZELZuJXCVw76j4E3ezVLauF8Q3t1GIuYGIRdFANYGz
+plTXpu/hx2b30aRygD9RpQ638kPf87BGndcNemygu9HFT8pXpyqDVLhLKj1
u21zgzj+RBa51JyoZsTo0+ciVBny4eWbFTHcbmPIoScXnjBJQf8ZkaRTFRWL
i4jFo+GLl3lgv+heOUpOcVEKtPSRwrgBHcwBIXkxfeOtDRNqrPZwh5DuCIEv
7XEn9fvJgf45f+VPrzW8b0/GVDkPye1DDYpKdnbNfCSOP573h/eHl5JodfBa
W1E37AezmFloE0qXQ8nuu/2My4L9+c03v4U2hiBo8vGrMgcH4PxXpYeZPEey
Jup5KFVQR0eCwHlfUrcsRumiHkGPXRRH4TqbkyC2s9HRGG06t/98co4GnAvY
yicGecVgvQa5eiBnj8i/3sqDAfkwoJ4IfMyBrzngXcB/E/hxAh9O4BsFfKRA
vzfwOwD+B8D3AMzpgbk9MK8H+stBvznoMwd9UaBPCvRHgXoeqO+Buh7QoYAu
BfQowJ8AnwI8yuBsozIi3o6CreDFTZ7GF5EZoOs9gU+yVP2hiviAztlv1h91
A9X9DKOLcVWb+wGMpsnowW+b+29kzuQPLYnEjx08KnYuQxndtvW9jjaPnbYY
9sCbJXNI7n8xw4GP1kHUIESNxARfC0bSfQ7qENfrg/3tYZd75Aj3SdTM+zEZ
cR8ypdzVM3SRR3nlUytCzKHPv0xu6OohchVUO0K60x7Rg32DebkBbPMKaL6I
ZlnwaSPYBxUU93BsVgbdrkjlo5RoTOCiohE87ibCqP+N0PGfdhDXGLxXNPhy
F8q1W56VbcmQwKc31nmf9qYjUe1r+bt1jxC4w/GW3mFzZvzStmrfOUFdAkfq
jjqpMvDiYeSSgZeGtQncLIS+rKpfAA84Vh/Ulwx52uxs6fqtOCH8XTHDeRJ6
yMdOyi+/X44XxteXuHbsd1Mk8KqoiSInMWFcoi+z3MRNFtYN0w+U7M4XxJcq
OqyCWKCPq7987dFFWwF8YZfF+NMRqHd13dXKk8/lw9+9j5Py64J9YiTVlbxs
AVy4bMO8jUEvzCe6EfjGvrd4N15f2nyQkh32d31Wy/4edpgZdzzr3HRVAfbV
HyjMRCX/0OJWRySth4/DeuIAZ+Uy0ywZfs1ej9LAE+paDjknEpsWV7HK04ym
YhxQ16q/Kaaw33YGm0wsPSzjAHWtJIev95gSR7DWyh0jIw/eELiKNirI4N2J
seQ53oiXheum+KXzuWF+pZhB6P54r0WoG4R7PIi4dEOj5uNRyY/xn+xhHS0h
KHrofDzirvSNTmYJ5gRtl2FUs9QOQ0alhgdp9KGPwXCo2i6ZYneMK+z+hJUm
xE/8cKHUcozCBHPeh3NOQd3p/tyI7cdbkRgp4/zlrFjYb3zx3qSlf81hFR8L
l/Xg63LE8ZjiuRysH1IQrQnf4glSmNdsaPjgEr1PESIyhpMEN8A+nwtx3D+u
i1UhSpH1nXQUcH0PSJq5fvHsC+S93Q43fXbYH7X24beL0D/8yWrfk4/Bp2C9
7GB8iZbCyyZENTZFNY0a1uOUcXcSeq4mpF16I1mRCepRV9S74yOT6xGG58Fd
f/O3AY5fa6ZvGqpBvq3tRhfk4bpzS+mcW6h0CXJMlYbShALmp0+eNxo98SUJ
ETHXuB5TAj9P567v8je38r/74Tt98TvbySKMcqNnxswH/l/j8IX9k4cqsf8e
5+eHEnxdM7VYrJ2oNlcB/F6fNQ7f2/nhBdbilJYzJgz5lV0Fvk1FuB7LYpRk
yZn6Vx9Xb1jWF9cX2FzoeQkfA8ivzgbKckpY1mL+s83BSDDMH+/34+E2jazC
Cls/LuwkhfqhpOjvvlrKcmyJrYnz333ypGUeDcusTzGvZMZ0uxBYzxVf09tu
Q5m99b3g/ZBNf1PCVDMZ42/5HsOQGkngXl+cUa/LodhASY7PGxPoFxH4ezVE
occD67c68Os5qyuBm0x1z82RctWQz/nXKGrJEPdh2eW55dmH5oj1hpiViC3M
CVrPLJyjajVGjmVSkH/ZA3OOuIqqGEqCBbDN+8HlP/zKGBEwl2a8og/nDcs6
/rzLPxeCqRvEHg5/AP0lSlyDXncxOansUr0ue3SXG3E8UofYP9U6liKhgeRd
5l/hXGfWd1k1zoc9iMhAtt5YJ9RjQy+U3f+VNYHo0KV9rliE7wuvKjol/ubU
vrhI6ThmBXn4bhO7l/G95KjeWdEVdyWoZ4rL7eWpCGREh454LGyowvese1hv
zUA4O3q/ws00YhrWK+++spqN+b4X7aXVY4q4tkrgxuZDF/76QirGT1BHSMG5
RfNPQgLqfjJoj7S2YEQdnK/nsM/mWMlUQHeckWP/ww3nvFrGKELstquhCP/i
qzsO0Gc1gfxnee5ZLdR2Q6/1kgHkVxxLF997h+iik4anHDv+lR+ksP9ZWbSz
EVpsfFcojkSXWK9BPjHIKwY4yNUDOXuAd4E8GJAPA3gX8DEHvuagzgj8N4Ef
J+APwDcK+EgB/yjgdwD8D4DvAZjTA3N7YF4P9JeDfnPQZw76okCfFOiPAvU8
UN8DdT2gQwFdCuhRgD8BPgV4FK9ltQv5jWoUbE9t5WVLoCN2Y3y9+I+lny4/
QupRT5tNPvbt4jwNWUASrh6j5XUnWwbN3eKHb5G0EjYSN1z5afDrrxaniPrg
oOC5gz81diNCe/m704J3Efen55fwtjMHdVCmP4dpFUhMoN+sAz+Dl8NhNPL7
Ub3+N5YEzsH++GlfhSZKEXqPz1nuDOH/UMfudPJFuDKaLHNp4thliKdI/BpP
YJJGL32gcDImPU3sJ1L7D+JwkA21NeO7OZII9z/2xtk0tJUUP+b/8EIMbk7g
dzmVtdoM+fBt7sjX3ZgpgY+27T3z8I0o7v38k79W41HIr3g4EmSSpXFectIz
c98MIC9KiK1YOimD6/vRz090HCZwg/Ovfif9lMG1EruvnTyoReBqp52rxNJl
8JRL+ye/7oc8s6/h5rpj2H48cFWDj/Um5F2f68zbA0ekcKFLH5hqq6DeJcfx
7tzPn2J4rmFmSdNPWGdE3W42zTcI4Tt537ypsBCE+HXBZwXJ/Lh16vVoU0XY
b4/T8mdyCfPg4jIyJ++zwj4uo1xRn9vTu/GsPcwV21cYCLxoZ4j8YAYT7l3/
5p/3d+gj4UYjfPL3a2r8s1lSlPzOf/XJf00UioomwSt+n3wjUjAP8elLCR+f
LmLOikKKO6QnIC/qCap/VzCJvQy6b3ifB/ZrvT7HNCVJNoB5Oup+1z4M11Oz
g6whLgyNmHK9WLSTCezHjl/uaBy8k4M9Fs5NbXoG9R/0mVCu6VvpmlfMEkFP
vhwjnueOdxYmpc5eRs65Vr/OFgwnnpPfK9Us3PcaYeZ53M/bR+Dc1thpLeVj
332x5/ZBrleyoZ85Y9+PC6weKioC/uk/H86IEPtfTj0WLxMfhwiMG9e034Lr
Y9Ek+zPW1sfIhnXldBEZXGcnxGnuxnpUICf67dXyyCFv3BM5qzjbX4dMOqbW
uddCflUqsIvcSaIJUdadHb6TB+fsjN4ELu5hbEFecxmp/80RAji97vLIiS8t
yH6HhuN//VkBzqGmf7W/9yWyuV7A9SiEb0XB6FIjcsOVMcxdC+pX+iQbfRXM
tUjChxPcHDxQd+pmOir3oq0ESbHwXPvrtw1wGpV1OT7uuP+Hb9YH07FOTWU6
0xOQR72yY5rZx1aGaYfverHhAv9vE++n+QkeHPNYb15qcoLHSWtwXiIoux7r
Pq6mHEEOv9ewvTyXfWEjtqw/EMthB8/DR3JyPk+FJkyGquXXnkmoh6zcZ1HM
kGjE6g1oj41xwnW8YE3Pm0SlHqNXUKL48x7WB4/uXfCV/4FjD/yvWjYzQf2q
acJ4KnT0OfZFIyPf/Sr046pj3x9VUVmCfTN79D5PEOpXt9DD3KrUj7GzlAmI
qQT0ZW3orbsU4f8Qm35cbu7ufpfAyxEJDj/HGGzz+sJ+re5JjaG9bwMxpdxv
Cs2DngSuNxdrx5prj9mF0LPdz4L5jFo5NSWiu+hqRrS2HVyz4CPuW6WyY4aX
jyFIqXNXgLyfAXGfn1N4frTclgwzP3ny6ZiPyX/4lQDSStMVbZsHc6K11Cne
Xe/QVIl5ZXij9aAOsf/yAYtbYQ+SENpbYecpr0Nf/QfTFf6BtDXIlxRak8vK
96BuKXqB1zW7DzmdwooOe8Lfyw1DJ9eshgnELF6aVDAQnrdJTtOrNBxLSDrp
mPLrE4+I43F+HabncZgM5fYtm9guAOdiLj7qkbO4uAPd3D/kUYqvh93dru5C
r1eoGp22hTkgQXKZs93GvGhARsdldz44z7iuUenuMiSIjsQL7qw/DP0iNucH
JdGW/QF8amGwDiiwOvLHRlAWvVTTG3TlC+RXPHbuAXO4Ihphb7dvbBbqVxk5
qOcDUjX0yGrn+55RmB90unNFwy9CE43ye/OzU1oV6mAr1/ts/XTQPoM3MhOY
NoGXDt3LYniojxbvqdGoHDIg+BXIJwZ5xQAHuXogZw+syyAPBuTDgDoj8DEH
vuZgPg74bwI/TuBXAHyjgI8U8I8CfgfA/wDoYGBOD8ztgXk90F8O+s1Bnzno
iwJ9UqA/CtTzQH0P1PWADgV0KaBHAf4E+BTgUc0B1kzHvVNRsFXY0tNmzbY1
UU3k4hvHC5yv8XOgJsubuOG+10WBU/IImtv91ShUnrhvH/JFXp+2OIW+/cNN
yUvihgLeZTGUQFvwxQwV9NFPPDXsQfjGVylfj3547gjqKV3xhjHJAwV1RlMN
LuEKajXUdlFOz4HLndhPXky/5TdpUbRQ9ZanToQr4cd1pctBwvzCEoYYLR96
1OpI+M+n3qYO2K0rjJN+bs9kUThL+EgoiO8/TUUmi6cH9gvtm7UheJqG/j3h
vrOKuKHH3mztpdMEnkBbeG+kRAXPmskM/FRpQfCuvWd/FiuiKL51vxG4PJ34
7yB7FL9R5EuuqQx1s2cMN812GiM4ddtF7m+tUAebyR2I07BRxp2YmvtMpSHv
atHYfbqxVwHPfB10W0kI6l0V8Tff+n+Xwyu3S+bfuAvrjKeHyt8975TBvZxR
3cYQWFfVpsjSsz8thW/+fmE90ctp2z5mFxH8xJTX6WRZqGvtKu+kSyERwJVM
Q/2ajOHc4iP2C8as7tw4rctRww126BcRcphVbtlwFx6lbldZZ72NwAPkhBnW
bBnwXjry/DN6kF/RP5j4XrFIgdNzzEtqWkB+pVd8/cEepzVMzJhPp4N+nMCd
Dja3t7+ZwZoyWm7glNDvNJQx1ANTH8HoGgt6uzKhLsEvlXYk73EH1jYd73FS
HfKN78X5QsdPl2M9J45kVB+E69eTWTnmjaUYzKx1fruFKJzbOuAnrL3+krHG
ip1v6GOPLOyPvRTvUBDEjInRsAS0LdoSz1VPdmlcT3CvyrsA1rPocSbi88/a
Cqm+PwpBsJ+zs7EzvsT+BV56sil+T0e8JDgnftpFEfjQj6ztqxolSOM7pab2
N//K6dZz5i9VwRC1B8cdbO/AupLCXRlN6Z2NiGNiEF3dFNRJRg4qbRTGtCB/
JJh/xov/q34aIp/L8A9fUV8t/nZgF+QP201yfvH9bENq7DypVjUg3wiR3XnM
xb0VCb16lCJyFOoAZ/yVFd/caEYU32kVS++AdUPXF/eOmGXVIYsy2WJlJZDn
SDVrPvnbv8s4E3Ulbx/kw+OWOQJ/fZl8d0puM/CEOInJdR23m9nY4KXK97gq
3A+T8ozwlORz7L//N6pif35YxQss9hLe434SHudm/1UTRt3Nr5HDCb/XKZJF
jwHbl9i9T15kPcZQpzIUid6R2P8S212aIf0+C/KoXb7eSiyNzZh/0PjBJ+fg
fZU0pfoPP2nEZGreXpKggDxqOt3QJSL8Bbb5faFOpfyZMl3AvAYTCGeIuR8J
+UCvf+Qbuovl2NNwyhx5C8gfArSMyqQVC7FpVoUfRXmw/2ro3diIe14mxs1z
wkb53k0C1z53aEpkNAFrOzS/JN52mcDPkT45eGjyJkZz/Z2errQbgbMucUuU
Unhik6QftPeiJwncem3AetLxKLbkdalUSVCDwI+57cj7U/u9Oqzkps8oCxnM
qf9f/mBjzcpM9ZUuJ4F/8yvWXY5FiqoqFejc9phKgJPZfd3enO+EvLtAztFG
w058Ps0PCebhSkXISnKvXh07Bfkbf2hM1e9qZEfc1CLdU5g3xJ21sbvcqhfJ
+f66PiwVzn0MnOGwERr8hIhE7OZ1S4PzL+pHxs/99Z3JsPnaSP4azgVLuvJ+
Pff7D6LBJLojvAnm2B6NcDUavUKDHq+c/p1FNU3gPsqjZccZWNBHJnRB+lUw
f037ONXrlxc50Pc+i5Z3rCgJ3rKzXl5J8ttetII70NtmN6wDaqgd8PvEJoIe
mbqqfUIF+p2yvxlsllSRRot99KoGLkF+9aCjXjJcWxbVl/TdZi4hDvGb2759
7VNAbddK48vfw9wfKj9j+aCbCMpteYD6ozfMSfS9Z/GaREMd/Ux98p/7ENYN
Tb1iOvmKNdG+CyqB15/DnGu5Kb/a4WVtND+W1p8FMSb4FcgnBnnFAAe5eiBn
j9BVtvJgQD4MWGeBjznwNQc6GPDfBH6cYN0HvlHARwrwMeB3APwPQD8YmNMD
c3tgXg/0l4N+c9BnDvqiQJ8U6I8C9TxQ3wN1PaBDAV0K6FGAPwE+BXjUnMkj
sjvL21TAFpxnr7ontv4CHHhHxC8h+olcgnctU6f9KMySwcNTSJ9uC0gi9K7L
9AqF0hnK+OHyTxX3SyKJOuOzqGKDtEZ1fP37lPdQy02iv+s5Oz2nuJg2niH8
mcVYLYjoq3dY15w1ntTBNXx2tMt+vEzMM56lL6Run9XFvT6etPNV9SZ8JHIq
/Os1VfTxCz7M47HT7oR/Vwh19Bmnt/r41vUieNqehnXnzgZ9fHDZPFf69lnC
r96MvzH9EYU+nkR7pa99F+RjfKs7Y7LqdPGt+4fgV+UB3L8aqA/jDdt7T3aT
mxH4B7NHtysXtXF5zeWlOiXIu1gfsE6m5mriOOPZKCEM6l0XAmNQVkV1/OSJ
C3tmomGdcfFg1exgFILrso1NxrnC/i6tbfNJv5sVcHkVymd/xqGuVSwjuaBz
WBaX63q469d+cQIfPvA0xU5CGnc/0fjtZQjs12JINVX33S2C80l2ns3Uhv4V
x+veD2R+2ItvPR8IvGfgd8VOOw78wv3a/CYfqF/xnBAdbOFkwU31m//sjYf1
wVMvGn+Su9HgW88rAu8oS8m//O0PtvV8g+/pd45eosv6gW09Dwk8Y+3uRnzb
J6yXscqatBj2G5ukrU93O/RiPXnBGWpxcP3SL3hxMv99NXbnxIjZt1bIowrZ
ZsreHE7FCuT0McYl+P4e3ertaPjYCZOesn53cIWNwDd+tVrEHzJVNJwLVqlm
D1IEuKScvdn6gi0iJDhq8w//Ij4/ZqN0gGYsElER+hlFIWdE4KZ52tlWh3IQ
5c4sk+YGd8ijbNvY8/3LEZMPaaTpe+G6ucvb/Unqizok98Svuu2MsA+nq8rG
lPRRM/JKT+mLj3Imgad57Ehv9m5Dnj62W/+3f6YL5brPRaVO5GLnkDCdIZxX
2h5ytL+ouxO5sZB90ooTnk+ub9FCDKntyJGJcMqkz7DO6PfxCXOuSQsie+Fk
0i9nWE/5PVckS9X1Atk8/5DP3L18cB/FzVLE9/mO7OhhiMvs/0n+N1/4/Hh+
wQ0M1un0PeZo9Y3ysP9+Xrvop0nanmrs/bWJewbl8P/S3xgTvhXUgEVJoswS
lnAecHGxion78UuMKmVwlewi1PH29toHUU69wtJC7rX8mYF1Pc/i/t1SPK0Y
z8vER/+e5zq9zCD5Z/srLLuflFwn5QmBB21vTKlNaMZOqHypdr4C+9W5hEJf
5R0ExwP1Usla2o7Atzj23+t4xm/iTXRgBeZsUzyD64bD+1B5UZGrtAhLlD1w
97k6zK2Ovm6bUVOfjd2x7onP5/Ug8IpyupNW+ckYqolF0dyxJnDmo7xi77XC
ME6t1K+c5XoEfvDgXSvvLu+t45Qi8BPW0yeENyy27n9qeN/uNf9djgth2nEC
bcaKL4l1QfKp8Pwii3JlYhtd8fx2E4JHbW7ZkHuF0ym0S7bwPnyOvw8ml1Lx
MZNIVqPgrwF4LMOVI1FksUgpZ5q6ryDkUQ9YlYY/W5Yjheqv/74fEXjEFxvG
c886EEkc8fznfYrAVzvukovIjCCPVllSArNhP/yASYBLzNgMkpvq217LDucN
nW5qq4rarSGznKHS+rTQz+FJB1nzP++DqJE8y+L1Q9D/YfSbWmbiJQbU6d76
CUnXXwR+S72lZVp7F8q/l83czgHmtWUVpn9XvMKNNtBXL35nhfwq0OueXAe9
AGr9Oo3qmRrUr5iWywVkfEVQ7H7DM+kDMCdI/2zmGq+9FHpQqcfO7AbMy3Y+
aMjO/1YGFW2+KGEVDHMYyU6Qlbl+lEPxLCvnC3GwbijF4z1BOaiANrg07RLb
DXUt3+p4lkJzZbRf0It0WEaLwL+/y6C8fxxBz0gpvfVp1yVwt/sBlyROoih3
nwFv7j+8C+AgnxjkFYN1EOTqgZw9gIM8GJAPA9ZZ4GMOfM0BDvw3gR8n0E+A
bxTwkQJ6C/A7AP4HYN0Hc3pgbg/oOaC/HPSbA/0H9EWBPimgF4F6Hqjvgf0A
HQroUuD8AP4E+BTgUV4L0XxFRx6gYGu5uokPY2vK8yH1uOWTnIgJvl7UfUsf
o8dWghhNk/EizlJNw+hior8r0HuXyUh/MD5MO1lBFfuQ6Ks/sVA7dX7DG5e8
mJB3qSWWmGdM370WMp3kht/QqooVPBdG+EjMGXygbXJxwOOesWt8rrhO+HfN
xj7Zb6hti7e8nIqn9LtC+KYiZg79daxW+Gua5o2oSC/Cr/6r6I5nl5hP4ilI
wYnq3RcIPqYpf31HwBtzXA8ffa6WeI7Qx3QfCrcbUJvhmmomNK0fbQh9TNa7
4Uyahwlu4Px5WH3VkuBj2T356o6MxvigUcbwHnGod8V8kig8mqWPhyygJeaD
BgRuJUCjxOmng9/hvzdnisH+rg/HQ1GuaE382ZxSgJcY1LVe87Z8lPznPuFN
M3x8dhTOM37/6at7CVPEBeqMBMdmYd3wZcTY7dfCsnjWx8I+jVXIr2bLznzc
9koS3/z9Qv3K9d2hG497BXF9l1mFECNYH2xJ4mGeMuXFKz3jBxcU4Vzh3eAJ
1Xz/Xfgqix4HhQecrwl/9FK75/YOfHBnxj/vTXB+hz5pXa1Bjwy/jJZ18h2F
daLdx5o6R6iWsGCHwaMcC7CeQiLy4rj42MQWDv0Sr7KZGHeU92Ha96cHwlzg
+2zZ8ANzIfoa7LzkXQ4xBPofXn80mY8+SMJK4hQrfANhXe9HbPvN0yniKkba
kUxuM1zEOlK7cLZuapoNu/iLV+TRYyeop+3iXlnsoa/5lX1zPF0E9lNJhKUz
Tu4LR8wU/Kaws5eJ/R8/b5BfppuDsBis60odCiPwTHX3XrMbz5DltfF/eBec
i3/XKL4/9PsLxNS2iB99BufoZZMeFXbatCA2gdLJ5Q+gD5KPqo6DflYH0qn+
/VrG3QvEcfo+u7WR4diNdHGPPvp3PnJK0dM3lTHdiIQe8u4UNeSl+w6KMtD8
6ETiBiUkO1PyCfyZRoXF37m+91YuC+y+UDeL5H3JWfmzHtnZIqw54wR1HkeS
xav55uUIza20lWd7YN32RcRa19Dvm/8Pb6QOPj2/r2Dr+kLcdx/lNeNtODbV
W9vVzgf3z7aoZ+rC2ITpbXCQ6ZDCOt3rpNHWnPOvsM3zA/WlG+SDebPjbdhv
bdaCgDaoBxqk9KkqMbdjfDSld/dVQr6qpXG7pia7Ffvc8IeVSQLO9xnIJIXS
krZgYd7J299OQh3yp+ftB2NnGrHN8x9A4Htuyc1uWNdt4VYEficqpIsi7zmm
OXtSJ3y7PnEdTV7c86uwK97CYV8TvW9LefDtnK39XIB60Vkdz0jRexjWmZA+
Ow4/P+u7TfEUXxjW+OH4qfxBewK/uLqHP9rfC5v9LpBE22VO4HXsTp4H8WPY
WXQtWuaFBoGLKunszXOrUhZmx2O/Bk1UA7xLgEN0yPllzQoSZHLjhRD8nf7v
Tw25x3ylOXII1sEvVSY76nv6YbuWG4pVhCGfpM3RmahTNlSR3lHWokOqQfCu
HppUMu+IHGQDi3p7sxL2SdJenfi4xNeIdPM4mgbqwfncYWby4XqmAST8nV8o
iwH0Jbb/xv38+51JpLHu9dXP3AMEzvOU3YUvdRFpVhp95HgQ+kJ8nJ319Eol
QQ0s5A/xZEJ+RZIQUx86So02+bQcaKaB/Co6ZeBDUR4TKujn/kIlBOpXgff5
FTkWdqPN4jXfshdhfTCuhIrvoBQPSlWsom7DsJvAX/bJBLWm8aPeor6JGfKw
v/0sqecu45dC6O7446RGejBv8dMa9QHssxj6xcbHNmsV1g27M/LYacak0G+3
7jMmVUNda2IlVWdv2H6UJuvZDrKbigS+1jboNJElgy5MymauSqkRuDqfE4/z
nAxqboZ/OqcAeZdYa3nvAxsZdPwC2dHWVqh3MWZVO6Tfl0ZftFf/s+4YEDjI
JwZ5xQAHuXogZ4/oz9nKgwH5MAAHPubA1xzgwH8T+HECHPhGAR8psC4DvwPg
fwBwMKcH5vbAfkB/Oeg3BzjoiwJ9UuB7gXoeqO8B3gV0KKBLAT0K8CfApwCP
ynN/dGKasRYF2zO3Nj+f6PYHoYz4gJtKrxw+4j2Bzmz1g5HWD5tHjBbjLwWq
Ga5a1BHzjIu9FROSZsn4xV+mTm9DHhM+EsyNj+K+BYbi6Xs/GAi4pxD+XR6M
YW+OiAXgEzzucw99ownfVK+L5T2+V73xl516a737bhF+9dQS1TdoyN3xI3xs
iDRVIJETdGroR6oUuxPOKG/+2f6lD5HPeHfgKde8gT1edNz62W4Xd6K+afop
0v5upTXO/OH469GOc4QONmT4lVLt1Un8qJ6WYIKaDaGD2SiJTG3nMMcvqzqY
BwxbELzri/Z+liP8x3AzW63dL18cJfiV47j4CMsFI3zbnWecPRS6BI5RVQfX
39LFv8Txaa1owXnG7BvLjj7ntPDN5wysG+57F/8yh1IN3x72OEfzIvTvahYK
iKtJVcAvFrm48vJCfnXtzapTlpcMroyFac80wrnChCC/ol8fRPHutVGpOVXo
gzcp/k0r6steXJ7FX4E2f5W4r5b4Gtj2R7DjG3PKlYOUsF+96uOdG5MujHjl
zZevhn5D3WBn3rOgP6/J8fPGLrmnOKAfgrxTpv4rimXsosjgDtUA6ENVs6Jn
er5kAnP4dfRu3CT0m7pW5uI4/bgHu7v38qmcbugrdSw2/OqMVSl21X7qCsNX
2Jd+zfS4W2b1UZWpXyHzymc1CV7Uqa8S2nY9BGG7HhWd+RDmwmwPoeRPaz6F
+e+w/BOplwp1rVXP0BWhG9hPl/LukGWYT6fZXr9j3l685m1CoeVEtCmx/9Vr
gmvx8w+Q9TNSqYJu0Nexh+RE2XnPMoRGTNf1k2AWgX8tQozp018gyhf9f3U8
hXOIigb33xrN/MOv7orvoE9/QuALtA9aBr53IjHOl6UUTWE+jqFX7sgD4x4k
VWyPusCuXAK/O/ySZ6CoB7m2smES2gr1ARkuuYYV227kerfrcxdJmLdSt3d4
3Xq4DXHwrpUqPQR5I+n9I/FxxxoRLUNR70s3oK7SuVheoENbsYXDOtd246wf
/b1hyPakLrtt5ZDvHcaH+2jqCrE3o14m8RMwd0bCYmczV3gttnU8UPejcpGQ
t2/GrPPe/pZyhTzn8wdnXpKOVmzz+94m8JZWihyjvR3Yf4/Tm2m5xc2RwInv
9b42qf55Rxu2eZzBBG7kpp4khLVgK9S0O3oeQd6Lv80vz/vSuLUf6Ad1/+se
T7ykbms/sQTuYrhsJTnwHHv2sE/6PiP0/8xWYmFhFivGcCs5qVobuH8LeZaf
TNnZmP11bTvmbuiH8O4gXVLBtiSsdz2w8tgq5Nu24t+56T+EYAHffHlE1b0g
P3mhm3+h0Bkju3+4GeOBfezvtfYtXQ8dVLYrrAv9zk1F8JwglmnRfeUayMtL
5zCR+mPEeduWNqNYL0yDDXl4r1ZNWfyHX1kjj3oihs10YV96htXATzmLMOy/
uFS4ssAIVTy2wHozim8R6n6xU/e0+MSsVW64+tgKlZoQx/NgjZXf+HIpctia
J6F6qZA4fu2CrvXXfp0If5btzXhZ6Osryph9TOnxCFLtIjSdmfQG8quS0nRj
xxlEcibpUJ0j9Ol6Ujf8inJwFdEe49Nf55sjcIEOpa+HpsnQi8cESCN9YH0w
3ZLVTZCRDmW2f+7279xbWzKbiFldZjTwfGnlO3XoZ/V2u2IaUrobjdn/Up2B
BeYebs4PcqEl9cp2Qn0wb5GXS2MXVxUf+tQ4SdaiA+pad9y7sDvWAmjWpbQv
jh9hHsqZ3Z3NXZmCaALvo6OVXNBnstvWoFJFWRjlLOOoMXeWJfDVEG2jz3HC
KHLBg+mbC+Rd1APXy47ECKHlwiHelHRQ71IQGhasaRZAjVLjAmxSYJ2RT/go
p8EOXrToZt+NhiHY30Xe5KDEJMmMDmU6rFcKQh0M5BODvGKAg1w9kLMHcJAH
A/JhAA58zIGvObGfLf9N4McJcOAbBXykAA78DoD/AcDBnB6Y2wM46C8H/eZg
vQZ9UaBPCvAHUM8D9T1Q1wM6FNClgB4F+BPgU4BHKVp5FVpMdqNge7tx0++r
V6ViaWh9Cl84raficfkHmrQ1/zhR2HDjxO06nD/COofycQvh3/XTtPqriXIO
rtMZNMslXkL4prLR1Oo/PBSPewwdHhmhzyD86gNafpfFlN3GM3dYd/zuiSNy
gupwO4c6sUDc0HYjTHd3GJHPyPt++ZbMuA9+xKwzc1EsiMjFdvMt2CvD6IGL
15UEPtG4ROhgXDHRmIe+Mz4Y+ClNisQdBfOneQ+kH6EF9vhOurb+FAEHFMyr
2rsodc27WuONtLKP/iScIXhXDRXz7HUxSzxRcafbzXlTgneZvXP4kdphiufs
WK6pVD1CXK8T3epHrp81xp/whnlOZMG6IaNYziz7XV28vJjjYs8HyK+23R6t
Fk7SxJeOn9/3RhfqV8cecgyveiH4rpnyfXGjsL/9Tq8gcjRNDk+sbvx5PhvW
Ad/vHchM65HEw0QEZ9RqYD711SfbAirl9uFn4vuP1LZ/JPApV1l5lW8c+KH4
BbFYbdjn8F7kENW6PRPOfXGaJvLICIG3GnOqFvFQ4NHr4fOZ5KNQd2LlcTm5
tIiNPnt0+y7Le7iuGZ0ruOoyhjnfMS+Sl4Q+OU+YbuqVpTRjQru2ldsrQZ8r
jntea3pxjioCxW4eMrtPETxn9/6V+b85c13OmcdUrGE9qJSpdzxD7R5SRnv0
Zh8DrCt1ocdcIrtuYIoTF0+EDcI5MontTx0p5NKx37KS2iJWUFfRd740ZPb8
ASat8n7F/g5cR8o5PntGZqnUKGtQHN87d5Y4HgMBmhQ/53zkcWEsR61gNnH8
pxzK1TIjcSTx+Fi6gAScW5c621HwovolUjrFmZjOCvtMzp/5ePliZyfyGKEI
EHeE8++/pG5jk097kNC71IfCZaFPVx6v9raXjr3INfpEuaU5OEffXDCRyX22
B/lOMny4Ugfu/3fIpLrlnQ7kxILAqWtpcK7qYWc1v8lUE0KjZTcafAr6VFBJ
OVxlVKxEbFzJBG4pQ78vnzbjJ391NE8RzQ5WOcgDE6POdAqzPcG2Fw0GWV6B
PND2sKjktrxazJC+ZyFlDPJkSgM+l9CoZkxBS4R/yBn2Lbeb+z+0MW7D7Ad8
G09bws9LuJBGxJR0/L/91xai+WvY/8c7Hg5W7GdtxzbPQx7USeSuRf/+2ILt
vRxkwrEA/+9vETp/jo5GLOSW1++NCHgdKY4wUFgdq8N6W2vf8hVnwnU/wCCu
sLUCmzwjbnGJHeYZab9QLqD58BTzWKC6lrcP8tsk6XYfU9JMrC5sZ21dG+Rv
Vitn+Y4v/8PP4vVe0RdBPXbumUhww9HLGAXP4aDzGhcJ/LXGb9b88m/KsbzC
T0asOQjewvaZt1+T0wax0y1XSH7oTNy3dk84qvm2WyDFHI1pgde8IC/6Xz6O
NMbBI5Zx7xX0hdjc3kZaRxKmXa/B34Xd+rjFseVozN/01WzETfietekvmoXt
drP/ru8Fdcj67/4SXULZmJeDUEm6E9RRHRemf/g9dFbRN3A7fW3iNHH84kXU
CdsFapAfDuzlR3fBPCkPklvD3HKvkWunWNsq0mCu1qZ+NY688LmXGj8F+6+8
OxHR883zSGFk0FxLxjcCd5aNzW8KW0eebaBNf45B//lz18N0/P6Qoxnspw+1
yJAQ63KPXPj+Ixx0qOssN5n6QyqoO7nIkNxOYEJXLK2v/S6AeYt8nB2lsdk7
0YC+JxaaP+Bc4cXlb6b7YtnRg4d+mVJkcMP+rj8d4ZlrnKh1rWeNFRn0HXVx
SSxQuc6DKv3aGVflD+uJXFdZ7YMP8KL3pZJuvR+C+SmnSKfoA7V40JshJ5S7
rkG966dysuyXexxo8e1Q5PUJWGcMkj97nUpmJ5qS/yO52Rj2d+1kXx4w8adC
KyiOecZpQj6Wfn7n4t9cjQKXHztvOMN5RqWWxN/iNIy4UdKSOXU/5Gkgnxjk
FQMc5OqBnD2AgzwYkA8DcOBjDnzNAQ78N4EfJ8CBbxTwkQI48DsA/gcAB3N6
YG4PrNegvxz0m4M6I+iLAn1SoD8K1PNAfQ/U9YAOBXQpoEcB/gT4FOBRcTcU
kmkNh1CwLcA2fVMnTMms5FOW8Z3nr3Rl56+hDlt+X7airFSN71pwb9XtEeyH
ugm/erW9NJn+AkX45QIxJdqjz4icoHLdjc7rg6l4Ioda99D7LCKfke3sKR3X
qihcuY0+xLcpgcjFpixW/p7EGYIr7zCwG+ENR4G/WcbAWv3iq6u48VHm2RGS
IBT4oTkVvDkTlOuFX9tOPzs7740C/7Sxa4js0ZzzeF69U07SM1eiH6yBIdxB
V+YcniH1q4p/0JbgXae1DRfRWhu803tP27VIC6LO2N9jF8AmfxI/e7kmQ8/b
CNYZQxL3OXSa4trZMfE1SZrEdbQv1M7gumGEU+rn0pk6wuvuv3qD61KYDv7a
zPGCAjf0q3diyteq1VTHC6Kfc59pg3VA5/L1vvwKBZxsu7ClyEfotyDUHu/d
LrwfP6gsxM8YA/363t9qFsn7Log/YUy9xSIPnz/S3otJ7wW4cLvLBoHef2Au
xus+AzKRo0x4SuYjPEUB4gPX+fVMS8nwQDNOtgazKQL/aXfybbraPCYhqnuA
dTuc35Ev+8LL+agfW+wYjFPaD/36RF9bCLzvvKzSRLPQJ/TnAswTuVvlxofg
iDnDBpXTg3/l8rzYO3K3rwpBPXwXivKgT065qs1X1YgMZEake39NeR+Bl/BV
vZXKyMDouLbp7TvbS+AfvI1MMpXLMfznlK13HuwTe2zwxUdCvwJTM4p06meA
fdf9rIEDyguF2PzrHh2py5DXOY80fA3Yf6im/9Djjy7knsTxUydzJdvipcj7
TN66xbuQnxhYWQ+coGpE7mgx+Y+rQ7509L3uKm9lO9L0WdlXfAXmRLd/qf7y
xaJna72D7/WKfCS3+5J7kegKlafaWrBfpetZ3VOlbz1I1p6i879JIe7q2ica
QduFnFtquEOyB+7nTEU132ezl8jLcQq9xM4GeF3u7EiZza5G3up/Puv3AeqT
wP+qbmqEbMod+rVy/2y7cl39Mcb+4xRpQhfkyc+br0/XV+LYg0c3kJQ/kDfG
zA2weZg1Y/tOF/hlSEF+mMYXc+73zjYs6an18lw65IcKZ1Kkh307sJ6BKlm2
93D9BfrV1rpP4CUD9hvm8W2YaYxxx+FTsM9naK3v+gh/C8bq0avj0wT55BT/
CeOIgQZs83vB6+WaX3J79BSOKdTxKFpOQx3ybQETrZFrOTasSftEQBnyMYmZ
D8zdnPnYs21hD0VcYc5ypuaE8th4Cra5HkG9y/ZNzvLd/hDMLCLy8FdlmFcY
4xKDv2FbUhYMKH1ynlGE4CESzzn6PJUuIjfbeh7MGMF++BmGUY0nCl5IlILF
oagBOMe3LVjsrMZDe8Tzq9+lIMEwAg9KvqK1zUQP29wPxDe3JIH6R9Cgggo4
R7CZP3gHU3LVY5T5DPvoSh+NrDSG5WM978/1xdyHuIqoV3zrUgkm//Cc4MFI
OJdxou+Zm35YEZa4cNZ9Xx38Hd2n9QyqqvVUierWuOp13p74vttTEooLt9cj
3Vy3P5VowPuNJgD71CY7gPDv6B8TKXlN4OR5OhuNuyYRNVLzuJEHUNeie9v6
6N3uBWRo/06B2TNQ10q7dd+f2uQXUpWq3aPsDHUtkdaMZ9eukqN/mhyx8WI4
V3i0vFF0XZ8GxehVDVzcaQlcrWsPCaUSA3qEltvjDiMzgdNnpXb/9YPWZeZf
NaSD+TjsPNtYTwizooY7HTms9sDcE7ndHg4n1Xeim8cP++Ttip7S1fxmRZsW
fvAlSUC963j/OqvqEDNqhFVrcnPCOiMTX3b35dod6IiZsPh5ZshDFrKy9Wxc
SdGANv3Zglv/6qv/apK2dqb6/8h673iu/v99XPaIlBEhMqOUqMxzrMjMiOyi
SQntUGaEsrL33pGR7Rx7k1VklpkyS2T7vV5vPZ6P1+/z/evcbtft6TjP8zzn
PK5zv1/360JKl995mJTCeUbdTbbTubokOL93SM33a5Cn8WGHDRnTGXFrj/o/
PGIw58Vb3OYu+xVO/MEa11heNfw8yCcGecWE6/Nvrh7I2QM4yIMB+TAABz7m
wNcc4MB/E/hxAhz4RgEfKYADvwPgfwDWazCnB+b2QH8Q6MuB3hzozIEuCuik
gD4K9PNAfw/09UAdCtSlQD0K8CfApwCP0j5W55soN4GCbf6J3XzGGHIWJ/Pg
bdz1s7PgN/o9sgp//e2zrW422pp04ukt5ozTNj2EfEaOPGP7h3nv8cp9BhVh
rKXoyF///LgThWGGcYm46ofwFgeJVBT47eePsMuqqgXjJI4qmRo0YSjw53cv
1A3bGPDCG0MEnp5h80GBnz+/ScTnursu+Fu+tHZjFmcU+P9T0HezMfc8xmPk
le92ET9AQV6AEeuZ26OX7XAqlPac78NbKMgXmPjQmum+cAtfD7x4+ka9KaHP
eO5A56OKNAv8KvlVzwlVHQLvekMbq0zMaIyvre3xTd2E/Gr9cPyqhcBFPPFA
KeOvl2cI+CYV/UGxRnU86qD90+QH0Pf+zuC+tOvNinjoE6G+NGvoZ9V9RV9O
7bk0fgpf/BbMC/NZXOqNmLTtRfE729xWHqZQbzC3zGdhViGAqxuQ/nORwucG
gzjJSak8djzhlVhXgtAeiAv4MLEX7sON9L2TIz3XYR3GPvOy18ltzPsaq7bg
L/i8ok3o1AoqmMD0dZsa/80TA7hkvb/KjVRvmdnAnHPMy87Qn3ZZJXRTpBN5
ne7kbpQO5w3LduoLxE90IQ9fTStoW0Pdl1obt0MeUT0yGKdZq/0e+kJQKz8z
YFsKQ1qD3KcKxyGuXXXnSWphKfbUb0ZBtg32PcXOLsqtZDVgWScaQ3LkoA8h
cQ77lefazViBPmc1QgL9JdoduOjkztZjZDGs4ct20A8qFuXlCWcqwWLe+7gz
HYV1M0kJzdltfc2KfQZrpqc17KFvat/C+JhkKUKxek5w3A7yge/LaSG11Y2I
vTxZh5895DlOZr2dcyMdiJPkCz+6Ydhv9eHsIM4h70Y2x9domkjgfDqF24XS
G9tdCHdgpOrby7AOmZtNO/6WtBNRFXvEQ0QH8c0fQrlJ800IxkqWt8EG9xNa
FetOnoMjOcFOv/3XWgj4xYfaDlXhyUioRey+l0xQJyMxbbueZpCMDfxZiwzM
h3lGC6cSgkapKrCaOtYirw+Q19lI7nmDydRjppovOD6/gv3i5D9OJ3o/NmPx
41/Sx47C83BqwFt9RrUN+5JIF3/4BuR7Jy18bjzjasOm08OnUHeYMx7suRaf
T92ClSh8Zhcuh/zteDD5x8+uDdjZ6jM0KWKQpykMei/Z0f3Da1+oZNdRQ9/a
Y0N/2MOKyzBG7ng9i6B38Pgzql631eZh45G+V2KbYJ1NjXpLs50uGYu6YHDn
cTv0oX1BeeG+OX8ANnf5gZbpKNTvZWrQRTMWbEiPvsj60lsoRuAVfgE+jn6S
roiBK8dcRC/kS7Nlp8+5FXsgyLDia4tZ2NeOV7IXNVhxQXavW9gfZ7KrWuVa
voOM57IKVHLCOUdbdDPcuNcc40genatIhX3b3W08dqBwmIM9oeH/4EQuNwfk
PkuYwfnQM9Y/WC5ibzEZDTvvwh//mRvlOLyZzleKVYbLuDBVwLlR4m3UavYZ
hl0ylPlIswe+vxwdPfww5HoRlnzhiDKKwHkNdVIW5qT4JzITDBMrBRuWhPMz
Qz2hF0NdjzxrsV6ka4LXydOd7Se2OQPI3KievZEf1GsVD60GqRlNI+vsKvcW
MqcI+AazSpUU9RLSGvLVS8gOvj/aikSMVJeuI7R8FJr3P20QcI/I6ys/oveg
YsRvf3hNwn7ibv2KDPWRDBrp0qIh4La5xp9q91Ghfx6ODIVzQt5lIDBsGspL
g3Kk3xAeNoA6rlMk514ezKNBU6u3KITEOQi4RdCcNdksFZpOXdsmU3sE8r3c
SvlvxmRok+ajeH1qPgI+4BVumOSwgTRIhfnMnIF87PdsgVH4cD9CHafxiJ3i
GAGf6gw2Tp9awhKuunx34oU8TXDtmfnV15S4REVECQ0n9O8SmnvT/0WZAd8K
n9L66Qg/f2V9JsA/jAV3kr1WI5ID/epbE3QnuZtY8ZkkMp/PfPA4QT4xyCsG
OMjVAzl7AAd5MCAfBuDAxxz4mgMc+G8CP06AA98o4CMF+BXwOwD+B2B9B3N6
YG4PzOsBfTnQmwOdOdBFAZ0U0EeBfh7o74G+HqhDgboUqEcB/gT4FOBRI/Zb
zbdmvqNge3vPzP/w9q+DsfsSiCuv65wUT5wkkT30N88RD2ef5nHqwWNZHzJH
m3xCQf5jOqm3QQpHCf7zQjJHJ2cZCvIit3S/X3klloK/pRRNDvmVgoJ8yZOI
SEnpy1DcJ1flZ0ZECAryKElmLpm+HvHBUUuVoavHX6Igv5J2SyHdWN4Vr8Gf
XCsgdUBB3uX091gGb9kn+IzDnuWjdXdRkI85H7T2Q4vHDj/dNiRi9ducUD+s
YlMSvNJ0E88czcx4/kGX0E8sJje6WHTCHI/o6PiYmgp5cpjukCzx/CVcdSOC
85GAKPSL+Np3sIZRGx8sek0a7gLzcQzHEpTruJTxYxqs89T3YJ38+fChBDQJ
wXWabpBcPQN98KQqu5pKmcTwtDts+pt0sI59WfNRm5ucAL60z36SbJqWgGuY
J/f4Ux3CrYeXbn/ghvXwIqM47JIqFU5bdDnrV8EW4f8qdyQgOn0/sZtDxtM2
qjNwPWJ8M+2fGCqTsWEtuGDtS7gvyj2pN499GkHEvW7WjBRAPwf2mwa/5CjH
ED2V7kwmWej/YOk1OqvKMYicoFW9V7D8m4BnBNaypNg2Ib+9EJd+8hUC/qS0
0k1XNQ3bfc5A//mpXqG3pS3t2JRTkpRCEszL2BPH5n6Dvhdjna1NHemaJ+Dh
mmwcd1k/Y6yv69dN334j4C1Wpfdsoz9hlRLox6BQyMei1kyIvRM7sO/HoloV
hGFO0J2Ot8VN/7xvN+uSxOxQwnm6I2yp+qyaOhVCIYqiZ1shzywni293uIwh
RlSWHk+vQT7wMGezc2G1GcnzZkQ/GkHekic1xpN4pROhq8upy/eGfGmWNNqd
yKAL8VBjQSdewDoh4Fdpn86sd52C/dmf5ZxlIzXNiEnF+QXzAxBfeRU0zLpe
hXzu7HGpeg33c8lr7exjzSyk1mmZZO4dvA4ZBokN6Z0isckzI49OHoS523k0
whYpXiVYCvelgO9uMF/7oz6+s36tFjuZdnVWNQvytAGbD4HOwk2Y9QFXRPI/
uZO/a21dzKRbME6+y9PsWpCnBc5y/pqlb8G6xaWDiH7Auh8LsfXISEcjpkxT
n6h6FtY9mKfyXXVo6rAhn+oLig1Q7/f+Iykpm3glxlISkJt3E9a7yveadNDl
FmKS/O/NRuUhv1LyV9u5UJOBdSfoS/Tuhbo7Ph6jSI3RECyBgl4qbQvWqRj4
Yp9d5NiR5rxBWXTgqzSBJ2T7ty/7ffFB4rc1OQL5oQ6t5VyrOMWvN4i4rjPD
2U2oz9d1tdKwaQhEnp7LZyldg3MNZtXxDdf2eiG5P6wbglLgXCSNoPYDhre2
yAOm050f7GG/m3pjMl6z8B6m7cPMONoGP7+7jccaoy8QH7aGPma79atoLI41
NiM4CtZ7Ab96VSGf0jIL3ztEjIxTfy+WY+eHRD9yf4A4Wf+q+b+8uUD219Z/
/dNOZB0SGrn0D97NepC6EfIxgYmFtgfXy7FDnZTKUlfgPCySzh/JI+cok+OX
d8J46Q7hfBpMRgSuFv3DC58b8zWywfptg4EyY6ryIOKxdH7UZWAAvkekbxW1
x35DUrpGFmRPT0P+3JPv3O37EwnE88IsTkO/LJplmv6Z138QbyGd1jPi8L21
BblKlsa2hbhjj+3CEiDv6o9gON9QS4Qu+9Iv3+SH9S4Nw6Hch+17UAVJLwWl
Dvh83szhkD9rtwfVWHzjbj8O9V2h1YzbvC7bSMUfMacMPji3KO1Ufulf/9Xt
ukOsDbqQj6HLFtrpKaNIRhX/W3UfqLc3zaVM5pocwWpjXlCELEKeNiTgdzhi
cB27wJT1uC4R6sQkrwd7ELWS43tfT0Szq0NcI99A/OwWLV7kY8RDEwD3H8Vf
kNE3sg8/fO1URKQE9K9IIxKM/ENCiVeyMYn2BNAR8J1PCZyiTzpkrH5me44m
dRGehyCfGOQVAxzk6oGcPYCDPBiQDwNw4GMOfM0BDvw3gR8nWH+BbxTwkQLz
ccDvAPgfgD4XmNMDc3tgXg/oy4HeHOjMgS4K6KSAPgr080B/D/T1QB0K1KVA
PQrwJ8CnAI+Sv8chWW0wj4Ktp9T4//AsfoPvcp9JK69OT4adtCaTvZ3MtVuX
K1gaD7j6CWdLan4TXf8JzTTd5V1/zvHe8ZwpxRM/VY4dRktRkZzd43GudX0c
oZaKO30eZ5djTEYX//Iu1U/WYUZcYfgb48SxmylvUL+/vKuWSmTpxrAPnser
fqiy0g39DXhXh/okb40L3nTvjTD3iweEOcdf/ZFZkl8e4bdKYnzCNK6jQ39x
Rfqz49917uLEOGNCl64eoZ+4U/Gst23yGv55fVSJylaBUNfqaiJOUac1wY/O
jbvatggSft8Ob/I0YXFdnHPua4+dCeQhxY+RsxJ0KrjUwiVuMlcGwvXJrNmj
0F6J4lwDpX3+kvB63sNp5H8vXxRvWbVJefCf9wLyVqMPXyn48IITki6FinA/
p+b6nlAkMuKnxZmHjKYpCbjHz3rl1pgtTK18YFaM4g/heUIadKml/HeijL5I
456NggjCfdF1YFzGWGUGUTtRg//uhXzp2lter/Ffi8i0AOq5XwTqweb0x7gH
LWaR+5tlMbQFcJ6RfuxIgx71KBJHOXls5QgpATebezxqRV+NLPfJJuh+gv3Q
Jyw1D3k02jDfxqMyYepwP1VHtc98+jCClT/ePFLwfQc+50X+dFymmcCCfrtR
qt+FObCsDPcQ5rOTWNdamuH3LMjrtju9bidfHcds7vV8v2MN+ZielcqvsbkR
zEXrJr3bS/h7SZ/jKfiS/xGLoHj71OUErIOdYXQuef3P+3bmdQrFeFron7lA
V83FFKtbQf+c+CmfqhvhfEYVCGbcCKlESDZ5SBzfwb6b31ir5hG9FuTI/pqX
kQ2Qn7SF9RzzOdGBlL+7r03ECXmR+CmBuPGaD0gKG130sXHIo7rJ/dUofzUj
e4wcss67wLy5wjprx3KqGiSacuKnui7EdX5sRN1A8xAm5w875IlwP0feDufX
dr7ATNrnROoG4P/NmSEvO0X1HvPxkFyuvAL5WHrovsyR7Srs0zv7qbQ2WDcL
9tTyUQ+px8JZo8/IbcLvpUNr9OF1dCNW3aP3/+OZZfM7Ks+PNWKPKqRV2+lg
HSzNIFHvbVMdJml2U8WuFfIr25h811e/qzDd1mek7rWQX8WYSmixtZVgQ4oD
+T3NUC+368+Qgwn97z6FOi7yFxLyJR5RWF9NArsYDv3MhdneJ0W82ZJOZetk
ucAN5+lazJ62fV97g3h42q6fnYD6//oD/WPZA9GI9VdWrVXqZAJu8pqV/Ipx
LDKjOBL5jBLql87RmbzI4ItAIsgfSV4ZeEfAH73a4ngf44cwF/W+238Szoc+
ZSHhyBG9jTwjv2tFawbxvKrCoBJ5F4z8TNSd++/hnObulsjl/RsyRyYdyIt2
852TkHPXDhMHXYV6A8CvEnu8f9+Shv16qm978225K7GoPMycKRni1fTBPCby
9VidUfTjFnOIv6fOvLaHohnTmmseNh2GuVqOV90O0Wk2YlesvlyrXod+a2Rf
w0Pp4nBMoTx1Si8U+ntYce7/fYX5uQx3So6497w14fw7n29nayxoQKh+sT7C
piHv2u/46PjsbD9S+D9/IKgXTdQpf62mNYko+l/9/WDzG6zT/o79k7Y5h5TE
vCMi8oH1roMfBTMfdv5CgstSP7/zgXX+HdF5t4mkZeQS++U610nYF+AzFFSZ
TFhBFppszrcdgO+zRkWVfQtqy4gtfebygVCoq383KU/a920RWc361fV2L/SL
UMfs48aOjiOpKqf88/zh87xwydaF6lgypmeTOfHCk4mAa07neS3i3zFd0zPv
v8VCnRhRKG3goMIaRuWoR/vaFOKGPiW2G/F7cCo/Q14Oc8j3EjUSLf+dB2Dn
nxRJOgn54bTe73ymgC3Mo8Jvg+U77I9wxe4oiOrUyjyM/sJnQtpAeL4x9kZS
TgXQobmKN+nmSSgJz+3L6QaLq7x8qC6rAGtuM9TDgHxikFcMcJCrB3L2AA7y
YEA+DMCBjznwNQfrL/DfBH6cYL0GvlHARwr4FQC/A+B/APTeYE4PzO2BeT2g
Lwd6c6AzB7oooJMC+ijQzwP9PdDXA3UoUJcC9SjAnwCfAjzqXMM+v9K7iyjY
SimO/A/3CaasdY0lq7RSzZiI+ufvpG6x/A8/UbvEq1T7CQ/Q4jrxPuYjavp8
d/+ROkSnlj+X4jfZcLQouAg1L9o9HiPT3oONFSl42YuQR5Rj8ajQ77/8xytp
6tR2CF51Umet4YwvqvL3+678UJrI7vXC3W1L2Sl+OqASf8/PXFRfSxKpE54S
k6KxRGqF4n9xzo1DEo8m7uNfB8afWK3rE/qJ85/fRturWf5zHmspNYXlCHWt
wM4gxXtWV3Cu5B2p56LMhLqW85doruO8ejgxtXF5yBwLYZ5UmZ7jtLG0Kn7g
4Tq9GQ/sR8/YqM2y6qA4xtvWOlUP+/WtJ4svX1wSwSmN1gQwKdjfLz/8YTIp
mQtnkOi0UtOC94vvIm9y9j5KfPMQtUnVF3hfHC4wOd5anCNjlfudeqII5tpr
Rd6w9yL/g3z0GZK8FbNFeL4FHUrz5CrcQnKXG86iKnBucYpIk/a95zoyGHe6
6XI+9Isg0k066iz3CzF10NuZ0ob6/BBHhzNcal+RL8ocW+lXIX65U6tYhLYY
m/7JI9hyF+YtrsQIHcl6NIZpPOVWZPCmJeDv0p8yqe2dw2iPhVn+toTH41nE
8jJC/icmRX195eEq5G8H2t41vY3/ifHdKD5FEwLzGQsM1UZKuBex11kjJvMr
cO6yc4+ExGDyD6xx9PzRlBLIJ62NTzx7HDOOHZch1qaVgnWwVtKhmfu+nzGX
m8Wa+m8HCPjgpTfDGhwN2E8mZwmvfNiXMSPy4Yqw160YiapbiX3iTjj/7jKj
s5k+lcjuegT7Yjc+v7k22tiEyBi/UQ2wgH29n80mmWP3W5FNJYb3vBqQ/xwe
1aHaGmhCpE8OI0n/4V3e1CZs0x41SF8Uc9dLA8ivJuI6g7q+FiBB/j/bavZC
fLd+5YDs8/KlG1OA+xknO6l5RCEHIzJY22o/CP9vbMR0nrRbBfb9bqhNgx2s
vznLinFOh9ZgHKbH7CmD4fF3nmSgiNOuw85O2YdICUJ+dUCugv9pcS021ZY5
GuUG+0Qnz7r4DLNVY8Zcz8oN5eD5OV/yVjHSrgz7lppYYO8I/QF8FmS+Zijn
YR0r6lZ8X+Bcm7Qvi0z1iXhMfeFb5jkmqKdyKi0wGqVdkR7qyrZ6tqxEWMeL
Nkp8h6vCkbXapAbKl1GE31HyEFZUQZaMLNdXBy3i0L+0LicuO7w9FcHEO8ee
NEP+Y8t1x1ZEOAVxIEvKDXgCdeaMvYfNLx2MR8jZO2ZEP0EfDEG6poDna4GI
uaNe8OUx6E+7b+SFjwW5EZKVoXT8cR3E7YPEt8xHXoHz8H/4VS4WqJy490H/
/+VXBcgVstnc83GQX/GoRNOPHQ3CjiUwVya9h3wpdVPZ6iJWgbkaflxkvwN1
j/NlnFVKAg1Ye+w5Wi0viJ/qulh/nawNU7zT3xlECfGeBNf2yEvt2I7t89OI
Bfy/RZsh5ot4M7Z0VytD3BDmAkzkO1vFzFRiZYvU/fd9IO+yZYmx5hp8JtMy
9nrhTzesd6XcUXbz4q9HZo4MO5nvh7yrrGd0n29VL9JSOzUkntYPr+f/6dtH
EU8OZjPffbDPqOqd2MXE8A1pX+oQ3AiDeonNoIWCqrIfyKhWuNzhtRVYv6Xp
3J60mEFWRQOZ0jdhX0DMd+CxpP004ocVrjGGwOcwu+LLJ6snR5He7pHDXovQ
R2Iry5UbZW5A0rx6C4nK4HuxlN8tkY60bgx9X1lv9QjWzbKGjm9r3P+OmcwN
POP2hfgVvyWVkjdLGMvUgY/PHsP9mJCW1yoGrWA3S175VEf/J886yuy+cMdP
DJvpmF3fD9+7oxObPBGHYhmVle43IWLlhOcV23EdKbdpYjTDRv6FTwBcL05/
ZjU9J3kIJUPyHDW+wHVheie4hTFHCBU+s/+0fhjs42g5mlX2VoujBwIWf2pe
hf1BkE8M8ooBDnL1QM4ewEEeDMiHAess8DEHvuZgXQb+m8CPE/QNgW8U8JEC
/lHA7wD4HwDfAzCnB+b2wLwe0JcDvTnQmQNdFNBJAX0U6OeB/h7o64E6FKhL
gXoU4E+ATwEeVXt60DfOcxEF2/ShXb29LPl4pnUfaaW7gQpv3xSJ7O1rIrv1
tJweWes3H/F/Xvwalei60ZYDu/W0u0v9e0Omi/EgZosVA498tLdh93iK7hvY
0cUm4RnVhr0+iRGo9Z9d3ONZxPp59SA8W9Bjm4L9BXr0b12LW2jjIT+TB36S
0eXwjLAd6vb3/EwHn5dscn+KX7+4yXiP1BD9/Bc3ErIof/H0Ls44TXFuQ12S
UNfyUm3rPfzDAs9QN223r6An/I79NgXyzuH6+OCnU5LEYccJv/v2aAdbFKqK
T9mtrQ0Xwj54iBkqoVMmjTM8X3xv8gP22fVbjnuS/hLCL8YsTDgawfqtUJPS
J+nbDPh1kU0zJxdYp7XJc8ykelgi43CwXDqDNJ9wX8g/rDIb/UKM7l/0ttOk
h+8XPrIMNGaTlOjDzJ6+xniYe/iFMz4s/ggF2nti+04fJfQ7feUgteXOuwe9
wsB4wC+XnYA/PaLzze7PL+Qyp8vhYU4OAj4T+v72H+d2RAWZXLowB/MWF0n+
TAUQj2MH/N+c1w2E7zUN+15dEL25hGmJ0me7ucH7qFl3Xrk4bQ3bR0H6ZYED
1pnnWCzMUbNNbMIt6vVHU3hf7zstH63EuIn9+qDcLdoHv2+gihlD4qM17GNw
u53TPKyPRSciXU4XlrGTD7jHLkdsEJ4bWTUMrteuLGJcg4hvLg30E7txW6bt
4tsp7J7H6qzBhWkCvueJjqJR/wB2MONKp40SzLF9vqJR/+h7A1acF+Vytxjy
rjX2OyFKq9oVaxKkJkqKkHc1HuR78VgJQ7JI1/Yz4rDeVXmZNHrTvx7xMhGg
CdsP60Jns3JP1NI0IJ9CvesfBcC+3jrDowDPjmpkuJHqc7kH5EVDiN2hf/1U
WaTklIULIS7cktp7JjgYOcLyMwCXgXhptG1NeWwy9gfdOvLnDtz/7vxgEdaw
Q8xW2wP7hi8a1c8GOODYu/tLe0dzod7sC36mkDunCuPyzLcj3YR1KpX7GZGJ
UZXYJQHpm0UHoS7rigt5dwtLGTbzpEGJ8hfUyU+OBqhL0+Rjxok7Bz+oQb2i
tp75il1nAnZQ+a3uM17od9FD3KrY6DAqjaZelxEbViGsy3nGCsbZbLGIEDHd
dKxYPOF3eTsWEBRVnoFY89ze7m+BuUgjkU3DNxXfIdHm6bnM1ZAvUVPWMUo/
eYf4PvodVFAP/ed7GKtIVLmyEJQ64/X+S1AfHnKq7cq6SRKSpN9jpXYJ6s/p
+DTyvz15g/xippQIToV4lLM/W+imBWbqI7Bz0hrihsdFam87hmDEuWriKBnk
IbvbKswh0KKgIx7270D9ymC/axjfIORdu/wqCetQZw93fAb5z9LXUR0z4yLM
mIme9asN5F2AX13c+iTW2Q/xbiea+6eEP2Aeq9esxRYgvuvP0InVsKW3m+hC
fNe/vQPj3C6xzxeB9a42aR2apAstmJvNiPdGE9SD5QscLKqrwzHqOTkuIkXY
Z+RgPiqREuggI1be9rWyB+q7IuaIRf7ND+h88zjiWwHk7cLrx/V1jbqRhxvz
dDH60O/08qGIPXSCA4hyu4VV7js41/O46lw9g+0XJOAakm0nBnUUxW2BV/to
viLs87M3fThgHSyw/zwZackAQj0XXtIQAvnYT5YpY+E3HxDL154aKc9hfcyN
gq7MzDgU67NVlPU8C3kafeqT39u+n7AtVGZ7ZR/Mp04j77TlWxzHpiyzd15J
wP5mT0Ks74utaawrVDA2bxX+3xe3bA0Y0yewhxtv2b0M4PGzzF6jlv6UJbPS
mp7NfD0XzlObZp9rPPAHKdvxCzvcAd8391pttMSL0KOLXgz1Njqw78AiW+wy
F8CF3qi9Tm26Cd+LD1Hdd3Z1FEapMzkovTTgc3s+eTZD96QE6mfSlzSUAded
sNADLjofFVDGXmKduTH4PAf5xCCvGOAgVw/k7IF1FuTBgHwYwrr818cc+JqD
Ognw3wR+nKCuBXyjgI8U8I8CfgfA/wD4HoA5PTC3B+b1gL4c6M2BzhzoooBO
CuijQD8P9PdAXw/UoUBdCtSjAH8CfArwqGy/QY5fffMo2N5WGtvlaQHRVh5x
xJWdn2cLSg7skd28Y/4/XD3tMsPbjS5c681zPdcfbWjwzC7vyr5Fcs7L4j3+
TFRDrUE1C7Uc+MtnBA8deiYTj4cavBWonwtA69Z38fh938M1P/rhn6WnyJrC
HqO//p6HLypTtxR5XPBUjUxbImoTtOLvedsTJeEm0XoP//G/6/wEQa9lfb3X
sn3rGh7+6knZlecihDqkuVedtfKZS/gH+sHkuwziMMezdpCt/8V5vPCuL1lC
C5z7SGInHdNXPYsrklJRZhlDPeHKzE/romhOvOvTYNLDdNgfFJ0/FCVpWSvj
1/tsvKEdg/5RX4MO2rjSofrudC+v3obXc+8zvruvtRjRNjf+xJBk+F7wa/Vs
AbsyA5o4xZy5Sc5HwL02mVSIRmjRm41RS1qIAAGPPVumbWxGjF7JcsMOlEF8
zO7Lt3r+HwhZ5KOntj9g3uI1C1rOf/PsSyvKL7CKwf07Bj9Y+569ig05K966
MQNzgkS9Mir7BYjxO8FN3YKX4HGS701cdb9JhvsaxJdNW0KeluQxJVp9lRx/
9PxycYEG5GPilyp71l+Q4ZeoHvAbJsO62fd0NanN8yS48ELARNUONQG/5Rl7
5esJIlyU5Nz+22vwuXGcQpGR/eoaxpo2djpQDuYNWcVJaTpa/8LkpR8/n9iB
erDkw7ovRE9PY+snWC5SZsJ6V0TAfPOW5CDWd7zJ7/xcPwG/XqDVo/nP+7be
Hm+JyMOwz+iofCfevU2jYu2Gxfn1XFfC7+t31ZirkqEUMeyeEGd0gfqujUn8
FjdXNfL29fkXa5Tw/b25zDlK72UlEr1focP+JqwjVat0mr/TLkSK3qcwrv5H
V4/EM+WGbcYiF3HvpFP9kC91R9iV2DuGYWcZLCsMr8D96OoYWb/uzsX8Y3X1
2JZgPcqZeIWzuKQYwy+kSU2OQR71JHo1vKG79O86C3kUpc7dS8vmxVgrkRiT
fh7s95kUjXmwXs/DihYO6FkxwznB3fzBROzCd4e4OVHoZxvuJuj/SG+0vCH8
xFCGphphnV3l22kO40r4u17A57OgdN2e/MEcRPCwxanM87DuFOP+6JtAbwFy
4c6bd0gfrBf1vHzH0n+lENnlA5DPvKkQHjlG+x5xX0xp+XwA6vQWyZYW7ljl
IlGv1G02e6BPPun7B36JAykIv77sgnkD1Icfnti8TXf8DeKjbmIu8BPiokr7
vVU7XbBGm7hqLT2Ip5LwcXfMx2F26X8OZVyE+9/ddiLvkJufg69CfgL4laLO
ct2XNtinA/WrnykWZ5JToV6r3SbY7POrUix+vT3F0gXqtfh/H8ze9q3HHC/r
LQWSQ170jVji5L/+G+++0m28mIT4OueI37JgF+bIQpKTRwT5W+A+MRO9lS6s
VP6t5Xwp5Hv7yUp5nIU6scf9uTRfHsHjmYrjduXY24z5vDKYrPCH90t+0kKy
7Zty7NaSbVENPdTVOylmW5V4P5bZOMNWuXoTzjOaOyhZaN6uQEI/1jL08sK+
8xA6XMt+uQV5nIWp2DTA+q3SvlcJWzudyKss5+nU7CECfqtQ1YzWrAuJGHFn
HSGC/vNcl9xa9EdakJkM2bckSt8J+DLrcNa+/ELkjhPjsOsdmPtDf6jApYK/
GKuoqPAt8Vgg4I3l5h0n73ZhkkSzhndezhPwCBZ1AQeDfszOfF/iOXu4f6pG
M0nL8F7sh3KZRtMUnEtSieA3KU6Jk1mXN72s8iuR8DwJXlrNizOaQWocDHSX
0qEugreVnR6JJUF5Ah+FV4ZCfayMw8LxD+aMaLx8gMKT5D2Q/wR4D0eocqNJ
3WfSFZphXptiJY2r35ETKL1GWcyUF3zPHT/LpUt9VRx9+7bqfjMCn7e9fnq/
Iq3kURH3kju//WE98wl5+dNFflX05qWm7hEDOF8A8olBXjHAQa4eyNkD6y/I
gwH5MIB3AR9z4GsO9FrAfxP4cQIfLeAbBXykQD8R+B0A/wPgewDm9MDcHpjX
A/pyoDcHOnOgiwI6KaCPAv080N8DfT1QhwJ1KVCPAvwJ8CnAo1Y9icJ8XX+g
YGtD8+N/uO32DV+dgG1cge995/q7dVTqUMT/cIVM+kdr5W14N1FJpUB2HVrU
sKvb1yVh0Ff0eYeLWPv4XNZIQJtmdo/npMVN5l8C4TiRw847pMUVvf23n9hp
fMzeo9sD17vyXpiFxxz1/Ht+PnjQsnPdeYRXLhz9/D3wCwJ0cRedVdmak27g
gYzyZs1PZAl8+ExmTc26lT6Oi1ner78rS/h9Y81+7D+np4irZXvM8kXD+Vbj
YNHoE05CeBKlTdERNdg37KCP/3BcqkPmBod8isFGE+G+OFvuKdiUzoJOBaX3
5UbD+uojmkJFWiMuVID9UKXTTzjf+t1KUmNMihOtvpv94eESnMsIalTn7i9l
QdXZZn3v5UPdoBSl/E2pA/SoF/monCAzzP2p0z5pWXdhE5FQn/p18Cn8/N12
wfu+fZ3Y5AFZ1zkBmMPoUONOPNCyjW2wB4/TfYQ+q4OfPl7vlqDCN7ydaxi+
wuOs7PKbjtDZh+MBb/YW9UCehhl8tv83Pwzfej5T9gXysePpupc/M+zH94+b
K+BPDhNwpdteONPWPty5QLr3xg+Yly2UKe3Ir7gXl5VEKk6pHIDPgePq6Plk
Cjyr+/v7Sj4aAp4jOOW99Y4Y1wrdzJd2gs+BbYaqx0ktG9ivOPOVsCGo+6qt
m/HQF13CrOt77QP84Xuf6D79xMdb37BZ5mOvKHXgXOR3vvcLtmn92O5zCc5d
6j58qkeRX4tdNybqfMb7n/y+nJ0yk+vKFU768ToZi88J10MLzfZHf/8CJOdM
tMGhKDjP2KPxipbhTAnyCVOluVwK+UxiD8vYDfICxIn/6O/HVZD/lFavhqjE
JSB3DGciX7lD/fmPn3pK69TumHivSFB4Mvw8tccnlw2DNMxsQZDfqhTq0mnE
2TynT+dhE6ZNtXfWYV9PwmN5WV03H4u2FXTO4IP1qAM1v0s9ZHKwI0Sdor/v
wXrUjyOSx/34EjCV+EHLtClYj/rcOOGXN7ReXnDMzO5ityph3Rwt7RCqPJWI
HGTPT3khAXXjuc1zL0o185BsHlnGYrp8An57Vqi/1LYY+SFaTc38ENadIuKZ
n7k1lyHdCpJTQXOwXrQ/YDFVnLoc4Xe+Pxgp8Z9cSPOdi+byJcjuegTrk9ck
6pYNp/ORQQ2XwjU6yHPSri2xmz9IQ5qdFE3puiEeSnXFfw+5H+J2QmPjZBHE
y059IxaxDsC2f29MTrNDXMzyFPf3V6kY0fe1W51e/3dOsAqZbgpoSm6Afgu7
+vY2hKxKJHPsKORjf/kV0ha4TmkhCb/XoYsnlceOFmBPNQTDDndDPgP4FQ+F
Id/Qbahjl2b4wcPU1Ip9qPYsiCCB/C2NNXh4eKUTs98rVsqSBnHmPS88OLm7
sR8uk9oSMxAnv+oWRdzZhVGYyw7/m38OcPt3X48defoBk910Qcn3wu+rHYSJ
/iZqwBCniRo+Hvh9qyNL1aQji7C2CS6ahgDoI/EE55yP1b8nM8ltqHz4+mXC
9UM+pTemU1qArN5cfxHRA/vOny66N16Xq0IuqF2zkJWEdeOAPYvI83vVyIB7
/i1tvR4CbuNc98rlQCnydMPerF0a9iV39VcBiDxHqz7F8WECnrAo9FFftQjr
YIlS5h+G+OSqA5WyQAN2O1hQaewX3M/nmfJ733wasCOVHnwvpWGdGXNPCZQY
DpDRLhNfZHgZTHg+9JyyaTScGkHG5iksD4XD50y+2g0v0bUV5GUkTZnBDqzD
R+ID1fFPKFETsYPbqhGwbm9ovlY+Y8qM5tG1ynlfgPlrPhccaYpTuFF7lt7x
1H74PLSnsqFk4RZGTThU7skvw/3M3vdxOlp+Bn0anSsykAfnfwfPnRdzk5VF
d68rqGfzITnh8mRECUWqdKxk98E+DhfJnsuLPzRRhJMtVDQC+riCfGKQVwzW
X5CrB3L2AA7yYEA+DKiTAB9z4GsO+onAfxP4cQIfTuAbBXykgH8U8DsA/gfA
9wDM6YG5PTCvB/TlQG8OdOZAFwV0UkAfBfp5oL8H+nqgDgXqUqAeBfgT4FME
HnXPW20heQIF2xc5v/6HX/oYylkbtoJbaNw8O+j0C80pbvkfnmNPPb/sWIfP
a32hucRXigbb7v7fYZsFOw77FFxR7Fvhxz2BaObffiJPSF3p/JIfXiIfM6zp
cAOl/nsexClklT4X2eMF5EE1prdO46BveErg+s9GzZt4VqxKiZqRCoFfaUmQ
5kiY6eIml5YTFMwUCL9jicBdS81gcZyW+nLpfkvoE3I3TmD+IO2ADJFhkk9w
4SfCfXGkNNJOVI0XfWllYOvtBHlIZg1b1RMTIVQ2POGrvupZAl7IcafSbeYo
msW+6TNWBnMS5Ub8n/VV8aBaSHgomzYK60LPS/uoJQ+hKblOP9yqIB76yPYq
qxQVypy8HMOSjMD3lBkuGYfP+Yhc/9RUvxPcf9Z5h8qMeRK8svaYEHsRnJ/N
YZQooE7djzNK5U0dj4X5Qa/a43pnPjDj6Ocw3OQh5GlcHkz0A6GsuLyUwNDX
ZsjHEKtt6ffih/AQng/e/YdhXrYW+VH6W4qsuMm5TqMQUjiH0u849iF//0F8
djpfll4E8k//K8dzg5gZcXK96PzWQsi7VoXOhAvm0eNHWCWPYK9hvetxSaCG
ykNq/INZmv53Oaj7OuJWt09wnASfvrhKlxEO3+MOJg4HV4puYj8s4zbYPP8Q
nicvtL1/3fX5hXXI8px0mIX5jwbH+NPe753CHifO7xFOGCXgTTFHvd8Z9mLG
RLM/bhlAHcur5zGCDf+8b9vTZboet4Q+EjqOEmynr8hWCCtv6BesPoa8ayPp
SCNlFvJOCTPNxKEf1DWhLYP9A2+RENqdzU4HyHOmJDn49mfHI6EhjQPHPkGf
q1jeG36N/qexmdMaKsm+EE+RPMEr+DoGszdW9Kmqh/v5+eAnOetAKhbM9D5U
/Bic47NTmtzJT0rFQpFXaVRKUB91zClqQ2MkGpsdj6a7+AfmsBxmX8uQTiOt
2GmgfqcsdJ6wDtZkZ7BGjScgGqWh1Ts8sB61vvi8bGx/PmIcYHVV8CqsR/H0
LRp3fitFQoK0D7AwQh7V9c2k6JJhJfJ/1+VKet7LbI1VCPfFn8J2TZBvxI2c
UZ+VrUJMh3WCpFsgr0gZGKIdlapATJfDpg1OwvfuP15K+/zX3iP5PotL+o9h
Heb+WTZMzSgdkfOsmngoAPt3ylEcT65weiJyF5zjP72Fn9/Vt0diciObB8OK
4f4XX3Ff727P/n/4zO72K3LOiW2uzhL6he7yqwqkpeuXDTkK+5t/9e1IGLev
mNBFqOMC/cEXsXlhW6KwLgTmBxkjxDlq8qHfrz9PNEv4cDM2G+AyaXkf1vdo
fyt++DDfgeFK7oXMa5Cvck3wDRTad2PP6J5qvR2E5/+TRumPPwrd2PTBCkNV
G/h+ES/RgsfadP4/n2/MZbZ7dasFM3MsZ9rvC/8vZ++xjDC8GisVeVDNdBLW
IUmtyhQbanMxD+Kq713/mTvYJM4k0bS+JePFN8vF8vUi4XoLlr/H67qTipRc
6/2S+QRetywu3edLH+Yg1wZ3Prtrwz7+Ou9LHcb0ZCTZMeLDi//Mye7Wrx5h
+bECn0pcYN88LddBieJ4NpaR3h76cvM/uY20d54JqBZgmktMM27GcP+jMh/Z
9sm4yPwoE0lkOPiCcL83pD70wWU6EbVzPc0yryD/jIi65UTs+B0R/7V9aV0f
1s+rHZlfFkpuIr5NvEm8a9D3RpH2ft14MDUqmXSRXePZdwJuOchYUxvFjF6c
mwpexCFeJJo0arF0BC3dNPrNOQdzbI2XBs+ZkR1DbzwQWNW0hPxwvqy6/s4r
MfRtpYJuqRacF+Cnn/dVviiN7l6fUM/vfLHGtSdCAdX3oHtf1gvrD+r2dD8n
21XQstCg4mUTUQL+IvcpiaK0NipOc3zL9TpKwEE+McgrBusyyNUDOXugrgXy
YEA+DFjfgY858DUHeiHgvwn8OEEdBvhGAR8p4B8F/A6A/wHwPQBzemBuD8zr
AX050JsDnTnQRQGdFNBHgX4e6O+Bvh6oQ4G6FKhHAf4E+BTgUTGOzmy5MkMo
2F6q3/VNPX00i8xmaRZvoAooIHs+iV7N3fWX0BhN/VHaWoLjE4uGdPvTUIWu
3f+bI/UFe7AnHNcotDKT17qH5vw9/mKx3KNThU64fN5vFaYdVbzu73mwt1mk
uPnlOl7GdOHa7xvahPOfP+Gz6hV4HqehPNN54j95Uox2V0MlrnyTYX8zmLqp
MkG4L4TEO07SWp5CbzPf4NMIhj6lLqo2Kw+iz6BNBSyqVnqKBHyhMk6BskUM
dc2Rmit7cZ6Aa4xlpciUnUB/DBx7PoSqwj7d9s3Z10K8KEuil9otBOI+PDaV
3Y8ZUOJ4ywlDWphzfeapIENX2gfEK/IbZTSXMgGvGOJq4QzZi5/PwS44tcDj
sZ6Mk4saYsXZ1o5i+/6TH2SlP6R2a5wLl29nVQ9/CHnaDcc1qQucPPi9KSua
oljIx76VBif/mefBj532esjFf5qA6zSXLTR68OCf3pbJOgvB+ptuRF/SLyFu
PH1I8mWiHeRdpAWusS9luHCWZ3LTnwPhfIqj4bgp40c2fPjlUQMFR6gTizIg
yWqYZMZ9HUdOpqUzEfCIpBjORKYD+FXTfBl2JqgH0OIQF7a+SIMvVnXwbCXA
fG0y+67P5yJJcLIV3fT4Q1D/OXD7vHGzxzp2yzDEJ6QT9hNTzFtjWkIWsUNB
lI0nD8J+Yqw7Of9Q9hh2L4InXOIC1M8/lrXFXzV1YVKfjJXO3oLrLG3ygUie
T8WYDenBhZ0S+J4+nbbnLpGgWIVL9Jyh5B8bwvWWHuppVqwah7xq8b6t7wZ9
NU2Odtuf1IlA7JcXF2xOQR8D8knLYl4NOyQbDZjnegV52rBc052zjwOwoNct
gwF1MCfoI8+rw0v8kdjT+o3bATHQVyrKIKfvV2gwNil6oWEPOfRFd2C8N2T5
hqLilpJ8M+dtOK9nk3FS2WItDnl584N06gj0N1AuqOtyuZWHXDpbFH3qJNRH
fdnf5meXVvb/8ISJ9W/tVIerkbUzLUfKg+D6e2b8Xsyh57WICJNz1LEcWM8Z
/c1o3sZShwhI6JK4SUAexR8pzLtTX4N0PbuzZ+Y/c3Cvqm5fbPOpRM4LX6aj
kYB8yVK20yX74D/HwWTqGvIG9tduHp+xufo6Hbm3E5qHZEM8euZxymefhwin
3BSXkhnEn7WLn958nYT1KvCMXOWA+792hjnn3/rSj4Zte38EXg+72ypEj2d6
v00JzBkE/Ko0YvXENjP0I92tXxUgr8429mlu+BHw3f5gBvY8pybPswr6dKWb
Bw//O1fIPX2FhN8b/i432BRje7tbsDz9lajINZgjCfjV7udh7jmoX6kcT+7c
IYV8WD032PzfvuHEHasE/az/XM8/r839Wwc7NP/Sbegm5IdxT214sKlWrP2e
HUmXEcT9VbXpNyrqMLVwrbetdHA/5kKXhg44l2ILXbNbt/vg8ehPRs3LO6dg
HSL3rv48D3OCovSddDm3jWQGSFhS2AzgHISd3I2l8tAgpCnjTdP4ApybaPW8
yS019xpJfNelcFcii4Azh02bPyJ7jn0auk72mgPeX/VtvgG6t8MxXWWuQhFa
mEdA58Cjd1f1tkyA8n5mUW87wv27m++MI8nnJS2dVeH3umnlVqO31o9crmUn
XToD+dWr+ktigt7zCLcqCeWcC9S/Ifce63+h3UZu3o7bM/3gEwFX4n1mx/+U
Gt393eH73a2YNw/FXJhQ50M2vrotcE729/3b6eo+XOiz1dna+HKYA3LqGKvc
9dNHUZuchGD1QOg/lhxEc6Zp/ynUwD9oTrIG+gsRmVvnnTQQR4OthfW6wmA+
0UDePhsiOll0YaFg42WwAAE/F9b53OTsOVTTpnkrfA3yK8rWB4d/tKiiRfs8
9Zm0oW+8uOLKcpWUNjqsn+ZV+hvmB4F8YpBXDHgXyNUDOXuAd4E8GJAPA9Z9
4GMOfM0B7wL+m8CPE8zNAd8o4CMF/KOA3wHwPwC+B2BOD8ztgXk9oC8HenOg
Mwe6KKCTAvoo0M8D/T3Q1wN1KFCXAvUowJ8AnwI8qrpX8cT4+w4UbI2pdnna
px52OS/nYdxuJl1l9ng36qa18T882umG/yHvVDzJ64wIaak7mvuXBzIZ04aM
/HTFq8iUKg1IjfGcv9/rPnXt/EGKy3jwXp+8eQ8dwvmvGBL8+E5sVcb1Z8nL
pS/LhPvC0+lhruJJOVSh8JZ1fCDkRZRVFKUjpgpoZnM2p6CZLvQpNbxUUGYj
iyrIXeTostIn4DSHH6gYMYij4erHNLjPXCLgzGqHL+WEHUe/ilEXEEXAz29Z
+DV/WGRBnWr/uEXzwpzrQ0IftVW5JzCJrnMGK+K6hONROGNoffU1C973+2m9
AoM2Ac+QbiUKt+fFSaYiwk+0qhNw2fXJaQ96Idyx5SJjwCv4vUzeXHMrlBPG
751quFoXBvmYHb/KsxtPT+DG+sE1piRyBJzBS+Ls8oow/lrP79PtEkkCfjuu
lWPz1HF8WSueH1WGvKuPTaed0ksQbzP+Q89rBv1SVmVYyz4q8+OqcTHF0h1Q
JzbI5p7/oZ0bZ4/Zd0M36wjkq/dCbskmHMbJpPmKQxOg3r6rXkyThJYFXym1
iZYVgP1EHaYpuWmuA/idWzQ1e8lgXetB0N6cWQFq/P0Xy0fuVXBu8UDTHpHc
8T34g5h7aEAC9PXicMq7Nba9gjkcix2nLfsBn5PCZ0u3js9gziNfAlm0Yf5R
71AS+c2cIeyIDct+h22oY7moZjrfLtmMDWY3TG1KwvrAoIanu4B9DkbWQnmW
jwjmdCux2fvv38tT4X0YaWXitSBcn1U5rmMCZ30QoW6con5PKOF5+PDzqlsN
6z1E0BaNERuFfpuXVMgpiF85YZ/Wj5FkDEC+ZEri26T93gPL70D8lF/4E/CC
hjxjPXvSCp/gQApVZQnCOiVSLFRFTh6BaAjSB/KGBsP6iVWM/oNzOUjU/p6Z
jbfQ92lO9FOxMHcpUmQnaDx0Hvb7+vjidJS1qpHZd3dOlzbBessJoa2eSrJ6
xEHhYG9ZETw/6QqN7jwsjQgN2VeDC6dhnSra3GZB+FgjYtWrNlzwHPIr9UgN
VQeleiSOTvYtFwr5jD9PqPoth2pkYWUPxaoe5D/vr/UdOehagiy+7fs9bAT5
kgl3OZdDZTrCa8817UQPdUcR67cP3VWxwrxb2DZdf8L9KG7U9ryMzsC8GJXp
omdhXYsuWdT1VnQxtvt9/2/9qgrpPxGfKW4I/erB/KDHFbVP9T5w3Qf1K+t4
t2vuPJAnA34lGvB751//BoC/VHoU+O9cYdzhA+cpf0G/C1C/ylcflIivhn5i
VQNsVHbcHZiGVsW9UN4oAv5cdSFP4HwXJnus8p78MsyXXDoq+bL8bNff//sM
1pdMngv8q8syFfPkMToKrxPAr3RHy37KVcTC+0LvdNE+l3rst+aF5dwMWOe8
vridmjJegVmSJ9+PyYVzDWsyDB84T7/DGkPii/z1oV/rbKkq8psoFPMMXObI
PQt56XDaitnVPkWZZ28GEoTcTsI+tbq5mgexNUL6RJZv8Cz8XhysezpmEy2x
L0zf0b4+mKMkm5d7WnlMU6ZUMvR8D/tFwv1YM+JMe5QqDYlzf6F87gb0m1V/
7l49tNWA2LqWG00JZhNwT/NVOtXRYSQka6Bz/SLMP1r6nR617r6AbB/V+Ie/
wfeOTXyqXeXMFuLcrq7/r68zwDVFU8NVKihRH0qR+S45WE/TRkds9/oxoLhn
ZdelfdBX//SewIFCbQ70mhluFLgOc4ticgXvhVLyoXuVrM6pWcB5SU06igs/
GIVR/k7NwJ5JqKfydYjVZ3ERQ0ODl8QjzsB5+Y1lDtpTdyVRE/GVwZUQOP8V
/eTUt++n5FA5s9tlxxIgv7La39CjJ3IOnU//HKxgAfODcPobAQKYCsoYx/gt
Jh3m+3gsofkG/Zrom3HhHJ1kdQK/AvnEIK8Y4CBXD+TsgXUf5MGAfBjQZwQ+
5sDXHPQZgf8m8OMEum7gGwV8pIB/FPA7AP4HwPcAzOmBuT0wrwf05UBvDnTm
QBcFdFJAHwX6eaC/B/p6oA4F6lKgHgX4E+BTgEdxsU70IY4lKNgyF+5+Xnm5
sT7kUQ3++c1IwjnaDJQ4YReneDw2zxrshi/c27L0VLXE4/8ef5dCpfuTC/uR
oKfftgdU6QnX5z/vFu6LHjqo2lXWbCaKywTfhp47zJUiN7XRH+TC/o+/XCf4
POhLhfqlGKmgA1Ms535q3iTgGftiP2GPZdEQoQzmqqQbBLzL8QjpnKMIuneB
vtl76xrBj6tsaszzBk6Pip++8Mv4hwXh//bNIaRbR5jxzhJXledWVwi4Fg9X
W3mDII5JLzPI0JkQeFcidZ+UNq8orsHiQZy2APlb5SndJDn/M7jkXh4idb6L
0M9NZMDM8ao4/qJZZYP8pRaBVxQppEUkfxHHvznFX6b2h3Uz+RfOc8PnxfF4
Vk8uEqtzBHz28AXr8bEzuFd51fJlCsi7ZPf/yDT+KoaXPlFXT2uB9S71FCo7
Zo9TuNGL1Udf22Gfcfqwp3bKPzytVnv/ScM/x2D9TSQ8/nvfUbz6jKZzhxXs
J37/85HdYpsHN2OP8/lDBetan7vwvHZWTnz3eQ7nXIg0fyoVGBzELUL2i0+r
Qb1WQO5goW4HPc4kfiHm2DjsG5rpnK6yZ6LAZRstv1rHQL2oGBLIv/17CyNd
EDYOfjlDwCUufRMp4P6Fzb1V0fz6AfKrlP6VotGtcay5Oun2v7pagHtZrhxn
utSDdbozGfRYwb7J25PW+bNaOHbioNvFa89gnac262tK3GIs9sra0zk1HOY7
G5rgaly1VBXCXtGr5WxqhOf8+8JAJ2XEAjkWGTf/sd2R8PxUVnu0HGZ6DXsq
i/nSNT8l4Gz3itI7XP+UL7M+MpWT5SesO9S3ouTZXf2RdXucoiQf+pl7MAcx
5samIpX/e15Bf3L3C+ERe/kLkYHLDAcvtkN+FZfIs8djshJ5WzpUsiwI6x4X
3tYKNIzWISYkDMVIAVxHzrnfsWrxb0K4gmId+q7COT5FQdv0b/YtyPP3la4W
0bAPVcjwVAFhb0EOZ3owSLpC3VG1g5N7R2gj4qtz8kTaXqgL0sPc8t7/rkEC
I0/YPPsMeU4rb2o+XUwpsssrIC9yklOnEeNP/8tzIN4UlCQTUuWOIa2fw6lp
IL4t0C3LI5WL3aB7Mf75Fdz/QE+WTlR9OaYnn9DyJBXywN3tBHJXtf7b3HE4
B7HLr2oRSn0X/Ww22G/6Oz+I2PO3fls7D/VygF8Vx/ZlkjtA/JbQJSVxwzLM
XSlisMEZ7ue1Xv4K1+E6LCGRpFhYAPaRfyocuy1u2IL5pJ6s1fsI9TbjgcYj
J607MTkdDiKZl9BvH+jbldtfs5Rpwn7cp+6g4D2nP/z9PORv9D6JL//dP+un
CRHK9DACnsNN6ywcVIcxH8zmba5zI+DEGU8Mcu0qsN3ve5KAr31UdC/2y8WW
N6gRHik7WN+7c+NJ+Hw0tnQndjSMEuaSv2OTND71z/1QmDVoV//P/QFwEZeX
4vToARnas/iTKqLNcoAjlMRNgz2MMtaS5dkSzGyE+6t2Yh+59icPpPnmLzGB
OEvCfqSaZlfucL1DUhNWl8Y3IM8MvjS7feFJE/JmalTELRLmTnL6ug93CA0j
nlRDIo+dYT6m2NTB2/b355BE0hQLsjTYr18dnpv3cl9HHgr0Zio+gHPBzAf7
TU78JkMPpPMqxh6B9ajTkgxl/KT70QnNwVzGTehfoULt+TSDjxVNdOVE2sPh
nCOxLRHzj6Yj6ESL/uuhOeib/SYu1HSf6FG0IP/jHMMk9BcK6D9fydt7Er3K
fFDOWQjqrIR7kgp1755GywImc62OQX7lsqpwhNFTEu2p9dyw9IF6m6SPrl5S
ArJok8JBs7pumPtjYmR7aD5QAbV1eYMySsKcxNc8kYt6mBJ6hZdKit3+PAEn
f13E3kWqilpOHP/KYKtF4FcgnxjkFQMc5OqBnD1CXs/fPBiQDwPWa+BjDnzN
wfoO/DeBHyeogwHfKOAjBepgwO8A+B8A/RKY0wNze2BeD+jLgd4c6MyBLgro
pIA+itDP+9vfA309UIcCdSlQjwL8CfApwKM+fDn6waHGEwXb7b98j4p7/pCD
pyKiaT//zoNbEa6P9De/uapaouzEgu5swW4o4F0fLZ9Zy5Mao32ilzW//nRF
Qb2rn6q5Ed9WRZd40dnfhU4o6DMm3z9sPWt5Gm0+hPjMFtkTfCG8T7gw7RB9
wU7ePJBpcOcRIVfRNObhTzHmEzip2aVH5K33CPOMl0Lrj2upS+It6RcK7z69
S/CRSODla+ERlsMHTdoz89QsCTyNJUFHwNtaAaew/yKh9Q3yNKJA5UXXJEW8
8OiAYdsJcwIfI/K/4XdvTRHv9ip+scJoTOBXDi8f+0RFKuJBjy+8pm2D9bFS
Z5HjrikK+N6DNZFFN2Ed7NF7PhZtOXmc591Sz34PyLsic64UCAjI4mEX7oVc
DoX1rhhv0h3Je9J4yMFkVMIH9hlLk8lHvwaK43nbr8v5vkF9V4XXOu/LCjFc
1H9RhGsE1rX0OQYfxhwUwYdnzzV7pkH9PHH2RwZiT0FcrC91ZPIx1Gs9bnWw
X0ziwaOwtcfekrBvSLNqfFFVhAMXltdo1m+G/OrWclHVzDgj7huONBd7QH5F
ucbvwhix9+9+YP2qNipyJ8SPGD/8sf8u/gzqS79c+Ol0IngFa/Wtu/U6A/YH
BYtVx12Vv2OyC4761yng+lvP4ZWvLtWPTRnXfLvFCes29cL6ntZa9RgVV4VA
Vg2s5+uOURR2S2Zhm3RfhR37XxPwxDn5rsh/3rf5/PYZ563cIeAVCqZ97Xkf
y/UYW5/yLx0krAvb91788ezqKL/If2env3+VsI78ED4skdv4FPng3H13wfga
5BU3LRtbBiOQoGume9VeO8H1QuKa/cXabETs4UEiEWvof56QUpIlWVeKnMr9
mOliHUPA4yWizeYKa5BsYv/Be9qwLldxct+37bVGJE75rn5DLfTb1DK18FSq
bkWKj5h1oF7wvZ4367Hyun07snUpdFDuPtSzbUsQn9nsa0M21nfs++kgXz3q
8uPwrYLmv98L9hOrmCjZPkrVIeXyZz31Z2AdbNefoRxR16JwSBeB/ZqS+9Jv
KvjTkEnHVIumbIiflggqmm0IxNJIImPLHSFudczGu2M4H9tdTyHfIz8X8Ziq
txLLVdTY+13+/5kfxJ4JUYpQVkBfAtAfjFZ/j1ifg7ogoG9HD9/w4D0C6xVA
356Z6UGt9h7ioH4VPp3ZXBsF8asaRs+uMNRjPt79m5PH4P4Bv1KeeHL30X14
POein9lhN9qw+yfk+rp/wzk+Ve+j1mhSO4YnMlW8V4A8bd/+rwqTH1r/Hg+c
42AWCb7+4GMjZkCz+oiqE/avyZ4IyRs21mBH11w6l6/Avpszo72swmQplv78
FIWnawwBZ7mqNObWlo2xXF9/I+YQQMCpG0kctAYiMJuPYZ1q/k4E3Me8YC3v
n/eKcP4GQ6/L1wi4b2TYAysRepkUr+2uS5ZMhPulMHZCz/T2AZlbujeeZGlt
EO4XsmEP2vDT7kjr+/hq0c078Pj3GBTvPZ2FlMgN/ESnXxPw+6ZPOiN065E/
jZP09mWQZ/bY/Kbyl+5Hfl5gXXzJCfWQRaKfpTbUvyOtN19rx/+B8780XW97
pENWEMp9hsPpUdAPv4Onyy/Knxh9ZvFKjdMF+uGbRpm324fsRb8kdZA9Pw/r
VINvNC9QjjOiXAzPeKleQT2VYkWoiTsPB3r9c8cTpiaYN9QQiS33RfGgxkvh
j0zkoc6Ka7rMvOy1IEqfpsJCYg3rV8vF7VdcGUTQiQSx/INZ/ARc4Mnw/soy
MXSqyqDN5SvMyy7deyLrhZ84Whzi2ec0A+fIVFnGvgVbS6O/z5Yt9AfAvmHR
opTzw2Oy6PAlb5QjENa1poOPnPtzTh7FKMrda16qEvBsLp/7k8kKqFGnvIbb
DW0CDvKJQV4xWAdBrh7I2QM4yIMB+TBgnQU+5sDXHKzLwH8T+HGCdRz4RgEf
KbDuA78D4H8AeAKY0wNze4BXAH050JsDHgJ0UUAnBXgL6OeB/h7gOaAOBepS
gBcB/gT4FDhvVdqCb25JvkTBFtTZTjy+oKVAm4F3je4zCH9UQ6h3hb92OEdZ
6o7PW9lx/sPrCH1GofloW26te7hvXsKO/Z5wgr7LqM73IZfDDVxuvn9zbcmP
oKs/f+Cuxiduc/xuLtX58m4PwjzjVa5k1juUJviL2OD3D3lcCD4SjglEwbGU
hngab+axN+5PIU8znEKzNvRxOdGXytkT9wm+qel6NGY7unp4Ar0v8XVdyMfe
21RJzLTp4iY9UhIRTbCedm/7l9aSig6e9M6zdjbdgsDHWgu1M8geauESyS1l
RBImBD7G4sI5mq2ogV8Vfmam3wp51/esdTUfIlX8PYnv3uwHWjBXKPm41SVc
Ce8rEp0cewD7jELvZdLkghXwm+yFXXrSUN8VfkZZrIRdFt8yT14m64d1rQKB
gs9LLpL4SJm56f9H1puH1fD/7+Ot2tOmKK0k0YZS6swoRBstSqiEUEmbikT7
IqFFG0p72vdNakb7pl2rNkWrolWp5PfyznOefp/vX3Nd93WuOXPmzDznnsfj
ftz3ykM4z9izZ0PnsY00/oZOv1tkN/QBXnX76iT4WRKPqT5DGygOfSH2T7RM
aYntxY0SCi+GfYP1q6dP4s6crhLEmW2Dk/h+wP7g3dAVjz+5F+ujCu5ZsdDf
PtWLGiExsOLfnOlO5Xybhc/HNbEo3jlqnI3iXR3GD/Xt2Q2lGx73V7G7MtRz
TyNg/0gnO13Fy3wGo+3pqAjqhjqTIH+5/hMHBrDGFW+e29ZBBB6QL1Cs6lr3
9/MOxHr4S916JHtnFlYee4rNY/EBgXuoqDjQ9nhjemJvPnfHmhH4vtOF9m9M
u0sSBmIy7T5vEM+FLLZ+Y92ZthLBV/cTrfi3E88Rt9sUbeSN95GHdRUyA6Qr
xH7Msr0C1EcikafavnKRO2zh84vHUe2MfzZyPiuPZ2ezNYFPmp2xZQguRcpa
zN85OsgQv+vReYHw5wlVSF3og6T6Gg8CZ5Rud0gxaEA2n6ew39H+TOZasX0z
IvUu+M3JHMgzo/dpZLzgaEXk/GmY3yjD+l4AXVNYxfEWxH96xMa/A+pbGpgT
dVoq/uO1bBUfFX2gXlr2YOU9Z94apPXa7Lq8AeRpZyN/5+/uLkUM2bCAqjuw
bvZI7f4FnoWkv78X6sE29e1hWAL33uCBHvj5vLwQaY+XBdisdyR99Gfo+xRh
EMIvHFiO+Rp6/xT8CXXmm9syTKa/Xu9f34y//UHsyzlX/dUPcA4O+DMYXeza
sO+Hz19QvzqjTGKs9IJ+HUB/VS2mfjtsN8QLDRls/+jet7xac6aehvunX87l
/nMckZloPUkB6roXPC3f06fUY0kvpnsXHCAfG7d4u6UvoQELQPmqop/DuVQ6
9Wjji/frMN8xHxUhJ1g3U1QoiP7D62Y122ipK+Hc31fdZ11eo++wKGUOzg0F
OJeq6yjv0yJSgKUWSPNEDEJ9IE0mGw97/GtMoJO8Umj/SwKXrT+85OoagBkz
Pb4VmAf7emls3arVVCSSWHInpXDXMeL6T821Ygw2MkEcJnbPY/+9ZwDc8eX5
DrJjVzAh22328Q33CZxPNWcKMT9BOquoKlwjL07UewUH9oex/ohCHle3f9YL
Dya+9zj3UU/PsziyeR5gfe/CQWeHJqMPSKlXp/ozUzgv/DWnWvnqr89IW2Zz
C/Nl6Dth8tq6XItvHnEaCvxR2TVE4DK0ewVGvv9CNv936Jfl06bebLeDBt0e
0BTtlgj9tYIe3B9z6GRBnZlIgSd7IL+yIhWcbVThQkv5OgOT1SG/UqPzPG0j
xI+yXwqYMZCA9avt50aY5zd2oV4NKM19VpgTtMB5/kvWp72oi+w77cWrUN+e
fCY+t/qnOCrD89H050+Yw2h/E1Wt8j6AGvUXfHzTDPuGsiTqwt9fDqEntsw9
/1UD61oCUWdSrw/LoB0CdUMSNFAv3cpvpuumJosmev0wu2N6gsALcnjs2gZk
UZb9r7/v8Ie8i1o9mUHXTBa9lqkcx+ulSeAgnxjkFYPnHcjVAzl7AAd5MCAf
BuDAxxz4moPnLPDfBH6cAAe+UcBHCjyvgd8B8D8Az3cwpwfm9gAO9OVAbw5w
oIsCOinwvaCfB/p74DyAOhSoSxF9wL/8CfApwKO0c+s1FyjeomBrlbaJC3tW
BkyJteNKpk8OPnEdIPRddVpfg9hZk3DeDT31t+/fELr6C8/puWrJg/CJL5bn
9t5LJOYZF8tLAi40uOPbrPIaukWeEz4SDwVnXFLD7+D6VzTkQzr8Cb63lZ46
66K4DZ4bcIXddJs34Zvq/SvdeInKHL/KMjn9lcqF8Kt/nSa+tOf0NXz2xIs3
ukMORE7QlosSjFqLl/GHJRI0T3bZEPWxJabwxoEqQ1zz6uWq4u+mRG7mo0xh
LsT/PF4lsPvSKgZ5Fx8Zw0P0uy7Orkjt/kXiIsG71p4ZxHRVaOPU+ZHyMbtg
n/ERb+Gnyo7TOO+UP/vZJHUCj3BL0NkoUcGlAtI9IhNhXatd79bvYwdP4PEz
AjsLbsB5RiMno6T2A4r45voM+4ZP8NM0K1ZH8B6xcunrzyC/auZIfHvZ9RDO
tqUh11Ea1q+EGkwGfnOJ4yUvrkZWfIb6K0WFspY/+UTeZ23yJoygvj1cI4fJ
TIcX76P7afInTwzg8SGzQXaB7LhGWT3XwE44pzNiaa5vXkqLzxx6VGt0EdYr
mpm5OXVlfmHD8rKcZy1gbotG/of0Vc/vWONattLrH/D9vUH9/vODgwNYP4u6
9PkzELf50L0s8asGu3hH47e7ANTVNEh7v/mjo30783uj9Qbcf+1xF5ulPrbS
3jWT6orrMsQ638+My8zHmCGq8Xdj3P7JKRZNfhB+/r/37baGjFmzw54E7peV
LeaeSFa6FsogHJYB+4w7+sp395GHISGlSbQpcjAf+cslEt1x6Szkq1G8Ga4D
dVw3GTQubnSWIrjzdERBdAx8r9/onNZ2qUZUE9y7ZPKhb8Ntu3f7eT68Rx4t
7pt0kIBziKRXIvs/HGlFPJUb2UJTQiB/UJp+zYi0IfpCJx/sYYD9zXNrCjbc
ba3Iqlifo5mqF/G7br0y9pFtb0Kcvei/9DyG+pzVi1evJtvUIjYcU4MKk1DX
rVFyrSa2HP/7eej3rrn9cXvQfDKifcXr9M0ZqK/++EP8F82O//6P/iOaqs2Q
7932qc38drwI+7+f9/5xOy1osAL7v/vf3JZhB9nc/b78hDwH6K/OnkyS8GqD
vAjwq05hCafrV6EPv5vfT/vmb1lYchhFxJsyiG/6MxRgMXQ/c1rVIE5viV2/
jpZjBh+yuW6dgr5qu9Lk3//xc9jiqZf2p44F8Be+pW3lITVYp/ROmboQyAPF
a2drB8dqMPf3uO1rTegHwiRvsSOmvAo7nepqoPEa1rv6bsi+ZJUsx0qe0dV1
VsG6zTh327Pnh4ox1hmV2CRd6J92ylwq5Z1kJlbFTWeykgz5ldFRmfaf7C+w
15XXTPRfwOvkcGURG2vQadKDUbkgrcO6xPWs5foxebXEGxmMdzaU9A4gzv97
pYh9oo9ckDyyiv7PA/A6Kf9awD3La4vl0tOL532CcwHI+s86c3k/bIr2dKos
WRj838/a+70+akDKahmdYumAcx+XyoKq393PREZVGYylfsPjJ/WZ1kzI1iPG
aYFdEiR4flI4oyuvZfUj3cINYYfIIL8KvScidE/8K5KzI9D1iS7kV3qKrWU3
yZYRHa1dh57nTUGemWZ8pHmAHP36M/1XSSSsX/FoBd3pkaZHHVyT5taKyAhe
ETzdInZLlA3dlnPZR5IW9gd/fI/5Qka3HS1Y+3rMZD/UXy17phTvzeRDx07k
UXhFwXzGj30hkvdahNAW/xMpsskwb3GbQGdn0fk9KGrpUz1XCXXvdQdcBRX9
RFFlqgS1a0awriXTEsO5fkAMzTkosXBKRZrAd5dp7hn5Lv7f73JUvYsdIXBG
v9TXx+0kUOGPobWvqSHvWjpnJdypKo5u8R0u2fsc1rs69Mys5fj2oS4rXrx3
/WCfMYLrnmOC3W50nY6F61CtOoGDfGKQVwxwkKsHcvYADvJgQD4MeD4CH3Pg
aw5w4L8J/DgBDnyjgI8UwIHfAfA/IPTef+f0wNweOB6gLwd6c4ADXRTQSRE6
pb/9PNDfA/UuUIcCdSlQjwL8CfApwKMWfVsZDvq1oWBb+HzTd4IeiS2ldB7F
LUd4520XptHLf3X42qYWEeeFi/Hry8eVFu9XET4S82t5Rhc1YvGn7KO8Gn5Z
hH/XJy3DqNaZQPzl1dPG7qQYwjd1WS0NxXm8cMHCW5GW6sGEX/1kcOfX7u9O
eNlOv3LObl8iJyjqo/57DS87/OTOMbUtFW5EPuOltowsoSpL/LPHg4NpR+/C
XOxc/4JQO1M8Xu8Thb+xDVEHo+wbyJLvuYrzxQ+6mx40JepgH+m5KotCLuE/
6aK3SFleJupg3qN3NWQ+nceFM05fSN2pT5z/+0K7Dw6K6eIvLb/KKWzVIviV
uiv5bSs5LdzBYVku/ocywWci6Y8Ver9XxaUXGZ2Tz8K+4VzT7hZ/6RN44M96
jajfkF9VMnB/TmU5itfOMFN+9oe6d6ZogVuPz8ni/TWStxwioX/pWc7f9Ac4
DuCbzxfoS+zL0/5dXnYvnj9H01XtB/3eXWaGOgx8BHD0gb2b7g9YjzpXHRr9
2W8bPhwgaNN5Cc7rhf2aLGy2o8d/f5XdU43/kxuoLKayk2ED+9YlEff2WieB
U4qHsOz1+4ZlqV/buOcM18lIXdTg90IvVvr09z2WQ7BfI9A0JRFzAcfCX+Z8
YVCDeXx5SKjKovHB0kj1aucZUR1i3e46ZHzIyuw5wpnEQBfABPtuGU+11gyo
nJHQ6LMNp3hhXl5sQUXp4ugTTA5raKw8DOfcJ63f91G9DMa+v7nlE/4d6o19
TCvMK3+zloqw4SM9VVBX/yVfXcjbPREJf+zAU6HyDy/ykU6VdypGxEwpQ8oG
oL6aVV8jNbu6ColS7HbxpIa/K+PL4pUUpkakhpyGkeEs1Jn4NrNdP1bSinCm
n5O7eQfi6ECqqxhNO2Kc/XL3YhPcTxXNTc6Lb9sQiatXMr3oYd1jQ0uXZyS9
BTkuFmKYPwp149sPF1bt4q9H5DMdJSTjYL9GX4v3gXt8GZK9i9Er5jCcL4tx
f4sszaYhJ+lczEm3YH601KmH+929wjCda54Jqodhf6qO70EYc3nRXx7ykMCP
2RdnH7KrxIRWLN9wMD8i8M1tGTLrcvmCp0zD/8HJ3M64Uncb8/zDf/76t+vb
GasKq0C+tNkfjMcYDKyyP5RA/ORW2Z/cC0XYrcMHGS3uQDx43lt+66t32P/d
v8qRLbq6P8qxvpKnYQgNPB7Dw3OdCg+rsOre9BVNLsivlJgu9XRHVGLhRVcV
vmbAfuK7t4E0XaNlWHzqJYwvDOrB4tTHWfsS3mKt9674MujC+tXTdOtvVNdy
MO+FA77sCrDO81R0crX5WzTG61Rel9MH5zUUJEVDQ/L0SG9kBh+zil0irs/l
102egq9CkFd1FYamVJAvnbHGv/ALv0RCKcXTbkRCfeAUuaGX/atAhEJOy1m1
AerPbzTZpt7eaoOdffA8Xdkf9q8T3WmkEK0XmORVhwySDLy/HvtkCBQci8Ya
M1cCLD1gfrc/7YGhL9TmpL0uL8Om0rWI+9c00YiRs6MI0eJlDK18A69npfVf
0qdr2xCzl087gszh+Xdhcax6njGC3P9UL/9aA/YHtzEtBrOGzyJX3XUUH7LC
3MbXKiaU5M6rSPmtRneFFuhX/+Vr39OGKErUrr94pHIn9J/XZ7hYQGvCgOqz
XLUNfAH17a3B9n1iXGxobbGiOCfrVgKXqCgNPv6JE2WPWskMz4N9Q+nKuSun
2/9bl0uKBba7wrrW5VceQbpHBFDUY09h+guYK3dh2t7ohbQQam++RZjNQpTA
bS5UTdV670IHD2VFmohDv6yEocwPx1Z2obVPR3w79kLeZZdtcUtAYBdaI+Ia
UvoK1rs4vxUIhwwLoGdjeAZX7GGfMT3oDd+l9ztQc9a0E++OQ31X2N193Um3
GFGLvq1J1+ohH9uvseMbvW0Ldn4k9mSVwEkCB/nEIK8Y4CBXD+TsARzkwYB8
GIADH3Pgaw5w4L8J/DgBDnyjgI8UwIHfAfA/ADiY0wNze8T1/1dfDvTm4LkP
dFFAJwX6jKCfB/p7oK8H6lCgLgXqUYA/AT4FeFTBr/jsiyc+oWDLUbK8+b3O
Tky9LvP4nFDolZrwH2jqX9+JLXVcyP6MKvxek4fnckkj4ZuKfRDszlNNw5/b
Vt16eiWf8Kvf6aLKGhL3Ao96IURHFxVP5ATljT7kMZN5ipO9e/7t8kYokc+Y
zvAuNOydB34ZU0zwHvAjcrGXTP33H6B2wg+zlcSlK7qjwJej6RKL2nYKO7yp
Hc1pbr+DAh+Pp+STfOxvbuHUOYc03yRaETqxcz9CP0TvuoFz9Do9dcu4RvCu
rOvZJZGKV/CRFI6K6w0GxPkXz2Ola/pxEX9bq6LUZ69D8C6rDxKU16n08ABy
YVcHKhWCd9G6+ohzHtXCO6m1PtYaQf8uHutrYsYNKrgwT4fKb0PIr7a8uZTy
8sUx3Mo1QLuxG+rbNxKWRmh0FXBq94yK1P1QZ3WGRtWL1u8QruZmUjtnDPVU
Qp5K0ZO0+/GHWcce7zkD/WRMv1DeFZwXxPPtqGrJJeD7IIfBtkcnIjjxMwNP
z08mQL/lELNpfYtAery7/PLARxuID63yHiw5so5p3i5gqlmEczqNpl+PVjtO
YhRRebZX9KCfzGDOCdOtpFbsnrLoi+rHkF8JO6yovOhXKV1z3EamEH+dWIfj
KkteflfNQ7J3S4RGGsA+lHSR5K5t+zOQdTKGhIB1WE9r2lD80FLvgPRalqy2
ukFdN+fBUAFtLAG7Zz9zwU8L6oJkRNnPmzzIxAb3WjHpaML9c+nssUv97337
1eCchK8jrM/k7lRt4LPdUSpwp0HVTAXOoZ896qfsjGcjB5WtN7wZ4Lzbi6xc
cuRtOWL/vGG0SxLqpd3TWEgRVg3I/VjNkCov+PwNTRksuOPTivw2vS0R8wH2
TZhZQ28/UWtHZnlM3L/5wD4Ua+osEmPUjtzxjE7JpIF4xv31Vc/oVuSQ4mqS
0xisDxxmpReJbmpARNkiRgc54ffG2+/m/cpYgVTyRi6RqKCOSK0pn4fhRDZy
e9q67tM/OhnjT+9Op6wHYpepSj/r1cA6ZOGD3K/DrEVY0VfhJhFdyA/j8sWp
rS5WYj+3Ygt5efB5urktQ35beXh8mYb9uL/+7RgV9XcHxrz/l3dZVtd3+FXC
utZmf/AFJkhmSKP4EeJE/eqjG32hGcRZGYJS/uiyWhLcTzbtg/vXZVcTq6ks
w4btts1lV0MeZXfjtFHQ9zKMMTnlyJ+6FMC9pKlS2K3fYUmXHhYvicL/K4i2
hv9PTlLdSvDl6h3Q5z8wjfrIOkcuZm5ok7N+A/JhKcEjcZbDsZhmevGOASFY
5/ztJUpDbXmRNL3MfP5u5lWYC7OD7/jzsUjkehMHfega9GfoN7Esyo9+jWw9
UGdoeBRet0VXrT/emnyNHMpWeNUiAvv1n3vJa6YfvEK09V6RasuhHhI9mEFt
73cSYedVPFb27B+9n+Lwi8zAGEyi6UfvUBfEpRViGp//917xyShko9UJ7mfs
Y9IjbcY0LPnCaG4zDnmaEkk8QGroNqlARKqzFzlP3O+lAzKXR0TKEP33J6TK
b8Dr0J9Z4UuYfhdSU2V9wkIPvt9xkLVkfWUZQzrZaCjFY6G+fTf5uYCIgHlE
6aTrs4dfoP/875cmJ7sl1xF7HcrX6EOYY+jyivHD2CQl+mAJM28PhX3Dt9LZ
UWF29GjjhfcaxadgXWvi0TRNXCYL6shfe+fMU5h/XZFXc5h6Bwfq5dZ5rT2H
i8DFDh40iODgQnH6XfG8e6FeS1730b1qrR0oZ0EzQyQZ7CcKSjRfj1fmRre+
0lVy5IK867B8m4me1w70e/6loS31MLdOAfNT/lbFiTp3rpgn2MM+Y3hJ1U+r
RFb0SfseRDsK6rsoGPdeFB2iRG8WrH1IK4J87AA+Ox6yOwdrN9ZTVHOG84za
ddcpr8rQ4c4D3LFoPORpAh+LuwOOcOOcpz8ca3oH/btAPjHIKwY4yNUDOXsA
B3kwIB8G4MDHHPiaAxz4bxJ+nH9x4BsFfKQADvwOgP8BeC6DOT0wtwee70Bf
DvTmQL8EdFFAJwX0UaCfB/p7oK8H6lCgLgXqUYA/AT4FeFT37j0XpqsnULA9
1z69uf/6DP/lrFVc7GvfYb3ADVTur89qyriEo+9UIx5f4WSQsdaGPvvry1pW
ezxVzzsX5y9NjQ6dKCLyGX0ezczwj8TgDFaaKbmliUQudr3WuJ9R4jNcWmXr
GRuBcBT4xBqcxEzJxR7ixw548w4O+qHAV/Z6UaSqyXZX3LZLxPuQpRsKfGij
Eu/vsJp3wOusAmSsk+1R4Fv7Q+ynNRuZDb6z99A7W/WbKPC5Pagp0Hu1yRRf
alC8IVh8megz/rphqZM7fAWPjYvriKLUI/qMha+QMaPJi/hPJvWwWVyV+B+3
hJz96Cemi5s4clMeOoYS+Jmk91Pa30/jO4ZbZw3CoF9WO1vsG6k+ZTxoKy1z
AzvUWbWd1h75ffQozvGocU//TRrYTzzGXN3wVgbPunSpxFsA6m3IDnC9Ztgt
jps4kXrHJheI9cQsZmvLywQh3MKJve/OJ5gvVutNF11kzIk74zeeTOn9hM+X
KcY5p3u0+MvW62vdEXA/x27yblQs/8C8rudavF+D+tK2M7+uvRkbxMRjj6AO
z2FuGr6WI91Ia1jKtXSsOi7FgVhXX9Eki2c+rkFkjuqsDStAPwcu/ERdy4Ea
5Et88hw2D/lh8arLdMi5QmRqQ2w6e3gA9jsGucUM1YKwRJuZXwMSEB+QSBtq
ZijG7EgeeZdIcD+dKY73X1uUY6K9htiw7gcCD7xSZmOFlGGnTCJM2uXgHFxn
c8yD3OI8DFnv9Tz9T97xzQolH9ftPKXbSVm5JzwcifudLdh0JPVlIfK1S7lg
IgjyCmpKZLiIoQY5rYQKRPDB5/JLJV5E2b8ZGcqLnmX8Jz9oMHiHUG5vG5Ko
fWTy0TDkIblXFZ3mXdoRZjYOFdp52F/T4/9Kc2lXG5IU+X3kVRXE11J/PJk+
1Ygc8DryZuszuJ+0a6iVcGAlUlt56UKQO+QVGcpi6w1LuYiDmddzvnaoO/qu
VqUylncX8/NoJnFqQb5R+URxr2Z7Pna2O5W98gvke9v0Bff98c0/3I94BGDw
925us5HqG29o52/B3wvycUIeG577V5e1Wb/yxMQXnxveTYTHD/qDs1fORrsu
QPwL1svxx5/zwNDD8Ccc/+CHzjDxLBRhV99+VjXxh9/7xOH+4uJsCeYveYwj
fxf8XTRqOfZ/5hCZsyL1jWYhX1Ukk+8XdivC7sdXM3LaQx71tDnb65d8DnZ9
PNHWfCvs98WN5m1b3R+HvfXdWxIhD/OSfut3lp/xMSTV854do/C4Rlw/SO3J
qkbOWARt4rRpH4G+DbEt/Q03j2Ui9VnzZ6/cgnOpCkI0Bq0muciosKNSixTk
OXuPaz25juYgySHOv7xGoY6OajxesuNCEmL/yKUouhDOpV430G8zpPVASl9i
cmPxcA5irnppQDo3Fuvdb9O61Q2+p4iS3zxYtj0PK1pvofOvgJ8XztzegR99
g03uD9kTUwTnL+pXb1CzBeRhwocv8sVEwDmOGrtKy0vk90hlvcliBt+hX71a
zUXe/XmVSNLaZXmt3fC6UnDSkzsU14ucc6Gdzn0P15kbo40DpJ/jyNGkktdq
mqPweu7liIuWXUBC/FgHLJ/MEfhW3cbtcvVr/3GQU63mPXA9XDZc1pspoEDl
U2W/Td2BedOaxtSkD/E06G3uybjkXVCvZXb9ZvUDOUZ0TDHxq58K7CcmcLMV
MS5vRTWT993xnYG8i95C+8zGDlY0aYe1FocNH4EX8bk5XOFiRc+V9fXEDwgR
uLrFdzlvza3orY8nvVLboX6+dXVYcvYoHRrmfi97fQDyED/RPd8USzeQPqGe
+Kg2yMcOK4jsYnnWiog0hjo07oXzjBYbQubehuuYW/WFbVr3IE9LsuDRW2dm
weXftdUVb4N5eQ0rVol2b7bj5PwXAmxz//H1uvBTBJPnx99LFl06uwDrbyCf
GOQVAxzk6oGcPeI6/JsHA/JhAA58zIGvOcCB/ybw4wQ48I0CPlLg+Qv8DoD/
AeBXYE4PzO2BOgzQlwO9OdCZA10U0EkBfRTo54H+HujrgToUqEuBehTgT4BP
AR5VKUGZvRI4i4Ltx5zNXOzXjmUShWzk7wZWrMceRlMcXf2bK4RZui6qMLfj
GaqyExbPOtC6vzlExtWm47khhXjKzMrBpZ5iFOQWyc+FB+lwJOC9iHdHrNpr
FOQcKR8yyWp5EYpP06bemXsYhoJcpCZRnq8t3H54RYZTrGqfLwpylBqctozw
krvjZO/ivrfXPUBB7pLGUf4v947fxRXwvBm/rbYoyGlaMji7HHDTBpe7U/Lh
4+lrKMh1EmXoXXkSZoqvXdcaFu7UR0EO1Ge3Vh8Pzis4V+p3pQYadaKuRU7B
fFOl5DxeTz2XvZxPIv7fc0mf4qmrtXHhsYZopwboe3+/5kym7B5V/HaXa6Xh
CainesgmUiN1Uwm30+mddBKA790BErwc5CayuF/9CTGJo3AdQKv3fe4RkMC5
Tdv69gfAnHp1xvPz3OpC+N5ljgSupi0EPln7XNrwMgd+L3B0G18CfI/zU5YM
3h1Fiee8l/5hGw71oo9iph6EnfuKXds15m+ZDHPNSHm0vGT6t0qrOY1f2Qd7
EuukQNzEL7IXXYiP3Ys62XHon3ydZmRu37lepHF6C9nyPei3LCelKufn2oZI
sBr+fOr3jcCXpiy5X3AVIfaPOVL/+OUA/DmzmMV4WgGWom0cPnYL+s/nKLJF
8FK8x0TkD9EXKsP9j/dkippeaMPm+jg/HKOAuWZ5oY7v18nbsM9Sry9HpPcT
OLtClxH9zQZszJB362IN9J3Q7qfu+f3f+/ZeKp/SKGHoWyVGt8/P9si20ob0
V4Ei0m7QL2hZJjbcowQpJd3e+4Qd1oUW7pfEzLDVI92GP9+YBEA+syzBTZLU
aEW675XqOdnDOsyj2hwN/Z42ZPH007PH6uHc+o6wSOunUm0IvWq0dTcDzCUZ
NpPHZMSakDNibZo3WSGep3v+nTF7NRIU+yYkbwruZ/zlWoPRxULE1oiG7lQk
7K8dT2WdXuh3QqhHZZ3SF+HxYKtUbwM+52DyaR6mf/ylAO78qrdahaMc+798
aXNL5pZ7/ptiHfp/5wfTEQml1wwu//A3oL9qIaMUrJ6EONC3q0WmPx76APF0
r2ERJqMczCEnpsR3AO5/058hHwu67Xc/jxU+r+/keD3gLC/AGPk9BE3EYX1P
xSZDbGtPHnZK2bfmRR2sQxaoNl3gW8/E9Hi7fL+ownrUysHaoHsHYzH1tH6O
K22wHjXL4M7HvseQlKNW4sMfCnlUhdqSIRkpDtkaf9hD/ADMSzLIMRdZf5CD
9PYMdbCyQ/+0iGu/RDsuFCECO9Umw5Ogz//7lqWUkqlihMazK4ZbB/KZDsXh
Y//xSeTveSPw8LsMHeYsOchFvw8lISvQN2PHjOx0IXc4Qi4UeWefCfRP2+b4
Ik1rMAprbz5/xbwbzgW3Hb1DcjhdgF1eNxDk3vFPTncjh9+fPmzew0j/yxZw
P+0rjPtShMqxrPwSnnEGWH/uOLR/v+OOYowmXvf6AXc4B/Fz/cK0C70LSVO9
+TvjyBViPdmsX9UgyyrZkx/44f2iMVJxj1WhDymq/mrnOAPr57LU7173HplA
BPY73d6RCPuJV2/bVj22nEfyl0MPdfyG/cR0DbWOT1d+IqpieWMWR2E+9cnt
H7tvHSRDc7Jil7fOw/XWWEPi8uA5SvRQZjwq8ZuewB0qOtc2nlKj2du8ZXvj
YL0rUMmkuOzyFtRbhUPmxxlOAreOeJdWfYcabev5VbTNBPqXFt8O7V04QoHW
Pednm9aFvhCy7C5y9GkryLjY1InACcjHLoV2abxrHEIeZGxxLZYRJvAMllcP
2WWnsL6HNaIpXyFPU9enGiWZUOAzS8JXjEqhTmxh671R6gkm/NJph0YPRYjn
SRxxKzjOjm95f6H5j84X4OxyreZqmhx4CV/zaHwCPM5rUutGLm7M+L465U6F
m+wEDvKJQV4xwEGuHsjZAzjIgwH5MAAHPubA1xzgwH8T+HGC5y/wjQI+UqBO
AvwOgP8B0HWDOT0wtwfm9YC+HOjNgc4c6KKATgroo0A/D/T3QF8P1KFAXQrU
owB/AnwK8Khfrdu+Pd62iIItfUjTZp2HfJ9uxxjlu71ju/Stu6mOghxt5wg9
gbxXHfjPJvPIE5Wd6KW/uduVXfkPqdBiPNJCvebx12IU5HSPxgVYP55PxLt8
Xws8PpSIglzv2a1vnvkxhONG0a0n3NVCUJADrh5/L/6uwGPcre4ivdlObxTk
hu/iVuLRFnPHk5pn+6M+30FBznigZLR7ae0dvLX7sNH5HeYoyCXXQrYsJnJa
45fTE5wK2A1QkGNeIz94LOHRdXyDMuO2cJk6wYddJLGHn5eMcJooeaWLpkcI
3nWBouoEUqKL97qL8TUYCxL/u6S0+sNWVQ18JfFX2uol2G9SvmdsYtp5DA9j
Pry+Ng31APWaaZjiQTmcewuZpWQ6nHORe6Y1/N5JHOfc/d1GWhNez+zbz8Xy
BQngX+X4DM+QMcM6MOeXzyFSLLgH8v2HkjZcN/T8LqkxsC1jbwcPXE1ohu99
nUt0LVGZTqXBwxwdT4MCiXXvgIS6JHvKF6Tnhc6+nfrQL8sk93TG5V8TyA2B
2tOry9Bfa0botYrzymeE8lOu7vEjMJ9af2rfHvK7nQgma9/7iwnOOV7N8NCR
7HqOmDpzsAjKQv95xdSzlI53mrEkfhXbRy4wX+x8cAOZVvBHzNmhIs8lHH5v
KGPn48meIeya7aeVq/zQr77o0+pDgbND2LZULQcOSXj804/49c9ofsQqN4KO
F2WMwLrBY4oOef127PupdwtNejA3TeODw4cH/71vB0REYbdyoS9BpWAajasB
WSmf325uU0tPYj2p6344l/wOR+Qf3HzaegIjzrNuw+FPOlcbkCLHAfaBaliH
CXUIlXITaEU0tcWn9eRaYB2pvezuU5dWpHii643WRah/Y9SufVBysAkRT3qk
fooc9lkUD2zZuY+iBnmYMqA1MQo/L7a6Ot7zuBhRLXC3YDKCeO5RprlC4RAk
Ssxx/1o45GnbbMpWBJbSMGVft3I/Rng8zQ3VN3Ztx7ET30zIdTGod9rcZiPj
nxX6zZfhnN1m/coTcWtNmg8zgvUisYuVIdwL4RiVjZvqSDLEt7ykbYwuT8Du
LL/ysj8N8U1/hnTM07w3gPUc3P+m/ioL+5FHNlRbCetOm/6iWdie4yHpCXmw
v6nwbcyvZCoFEw5pkapqg/qoJY2uHnrKKOxIyGGWT5JwrmFRl1PgWP0F0rNc
gRAzcRPoEzJZlnm+LhZ52nlqvI8X1qOUbp2MOE6ViwRFHJbw+ye/W03sNVUI
w1tEUKOXy3wZ1qPIWr45cg69Q1rUGzy+CEIeJS7uv3MtvAwp+i4yL0oB60sf
mXrv/Pf7kUlzTarcR7BvXr9YzP20rBCZd9W8lN0K+VL7SQ8LM9UEZNI5JHLJ
Bs4FW7/oNxhSDcXGDwQMKcrAOrMm47103+YCTHZ1QFO3EOIKBWKv07vLsWMC
HFEkT4hzqy98Y6evwfYMr7H4+cP9LyeLVzoFVWM4X3xaFxusG39zpp6eU8aw
nhPHRV5gsI/PdrDOem+MG+lmvx1rOK0JzAliL+dw/FqDjDMvfGwpgvXJpA8t
3yd7PyK879cKH5/qI3CDlkeod9YY8rHhnOawJqzDZ80/dXG7NIugB+wpf9DB
ur3Gp+t8z84sIZq04gOyz6Hfu/M1NerTt38iPTuLf7B+p4C6I73ngbLb1hFL
ur0Gvzrge247A2XaJbV1xFVm79bVq3A911Wv+S0U+hPhv7Cvt24nXLdX2NV4
qGwXEH/P0aNpLpCPbcwqFPdSf0aWBCu3H3gK9fYnQxf2Bys3YdO3pGVJU5Cn
mTiddnP4j0dKOSw+79sNdWKxjw+1xe4jx9llKSXlc3YS+K2BhZvNQjS4xuWE
DwF03FBvJsvZf2GCFj8w032XJg4+d9a56Q3Khijwp7O7EzK2wt/rxFWikEKV
S7LKuZ9KZ/+GuC/0PJkfXr3JjjZ/CuaycmcmeBHIJwZ5xQAHuXogZw/gIA8G
5MMAHPiYA19zwgfgr/8m8OMEz2XgGwV8pIBeCPgdAP8D0DcEc3pgbg/M6wF9
OdCbA5050EUBnRTQR4F+Hujvgb4eqEOBuhSoRwH+BPgU4FGRSvN3Aix/oGAb
yF/+P3zDo034xS3qd4xF4du9o6iPSptu/x/eMi42F1ndiV9zv3LG/2onmmq4
ybs8BJumWvnf4q/Gyvle875ByXI2jyfGtNPYSu413rSHpvh2dBw6OL+JG8/d
fPusOgy/yrjL7NTbQHTkL+96lJflbMPlh9OV3Jkr3++Gcvw9P6f6R9Ie07jh
llL7z5BR2qDZf/GKt5zmzIH2uPahN4d1OIzRkb94XC4y2UptgZMru/z3fqdO
9BN10j6+oft+BXfzuaxsQC5N/I+ntuxRosD08etafp2ZreTE/+4xI/nQfukM
/tMoIBiphPdRn6+PmGvMcVzCiqxi+Sp8L9gnzqh/vEIWbwtvOfrCCNZXdzN7
0pKy9uEPeTzRB8+3E3hh636GdTluvNuOruH8ELyvTx5J+vFtggKvq/n03iIQ
6j95irq7Un88LD2//di3ok8viXVMO6UcMW6eQyS76IwDWGGOodABe4qj//EY
tTSrcwejYN70w9MJfDXRC0hIglS2ghPMqZ/TNmrcc3cSGYpyGErzpyfw3dM2
bt+j2hHJqMRpO3uIDy7v6eck1WC3dx73sC2B+/Hg2IgkCQ5jI66jUl3zcF5y
qbztyWX7CWzoAdmG+jMKAl8OVxNisvuKXd7etLG2Bnmas2tN1XrBFBbZmcNR
uAb5WIxj34vUHeOYv3VMkmn4P/4VUxmjpgnDmEpIDPKWaQzyQLMCi1dNXZjX
eBt2LRH2JZcL3htJC1Rj+SV3bNm2wvd3Zo+4WfsASlJKinDsgIM3sf7IpJO/
+vTxHfJdaOYRmT+sqwjUZKd9r6tHehy2OuzRgvXM5+oTrmqBTYg+v+7FU5ch
/2FAhG5Prb9H6OrSz4nQQX7lM3yEbK9qDbJ5fiC+qW8vQa4XHti2Sx/iosx1
gc4/YxGV6luPT8VA3rXpfxWHnWsXcXKPh9+711hd1nbwDfY42Q9Jnob1sc0t
mdu5wUyGleCi/wfX97U47FMD60Wb/u2RWDkqbbC9DeLBxwW+s5yLwtp3m0xc
+yfveFN/lYi1tk4+U7GCfIlylUVUTCEJCwnW1eGrgnUnYwdls4K+eIz1VE/Y
LA793i829iyzNT/HlCUvPrN7BH3dT0RWxxSznyNllZsH6uddJv4v07Jg6TXB
GETwpNFhHy44N/HsaZrHnz5ddeBnqaEmqI8689Jlepv9W2R7ie4rJXvYdxY6
O/B6SbQcCfQbODRwBfb1Nq5bsy42VSIiK2nv9jlC3q4ur3LhnG0VYqx9Uodv
G6xH1ZNadKroK5BR2rolA0tYR1qzNbuSbVOK7GSisqO1hb7924SbHxpvZCKx
ivt2zvBDXkRBb3a6vckZu1b7pKfqIKzf3nlqVec6lYfdSe9KHCODOTWujYdL
FmwqsECqN8USWhB/ZJshnt5fh1FKbBce74P7sev2kVu5/B7bHv9ZbZcO/F7v
t1nlueV1WHaGyWc2M3j8Uqy0CRQB7zDvRJUwno/w/Fx1eWvqxuFOknFc3Hqq
/iqxXgXdS069z1ODdHMJcBnkQN4lcTw8e+uzHuSK5oP2unSon9/0v/qMyMa1
q96THf/n+qxuqEufQlYWdt8efAvfN4uNWHT388wiN15fCK9eXCHwol8GnaLp
c0jIZLhIYBCcW2TmmZM4fn4OYY4e/Vq0SEXg54pnfiXQzCCG5VU/KS2h7qt3
W9yziIAR5HFSrXKbL8zrKfapre//VYi8HXriNW7BQuB8djN0ARqfsD7RkzRr
12DdLDI+CY+Um8c6PpymENWG+AW9RwkvfVYxdhG/bTsL4HOBqfBS2nzeL6zw
QjR2ThUej1rJx+lDNMuY91z1yfev4PPCPHuS/kthIokvz0DsfVEmcV+wzj6y
Oc1CiyrZlxkND8F1uNFjT1xoggDa9UDY8okm9Bcqt8xotl+QQifNj2iMyMN5
eZBPDPKKAQ5y9UDOHsBBHgzIhwHPWeBjDnzNwXMZ+G8CP05QJwG+UcBHCszN
Ab8D4H8AfA/AnB6Y2wPzekBfDvTmQGcOdFFAJwX0UaCfB/p7oK8H6lCgLgXq
UYA/AT4FeFRbgUJLALKMgq3Yg9L/4SdYERux/z6XyTRZcbyH6qhVgsD/cLvB
QO8Yg078vbIlIuTyAf1Usrn/Qy2/G4N2FOMSQ+WZVjn56CC2eTxvKa0t+/sS
cHLTbN3Hva/Qt0ubuEhn2E3G9hBc/FpcaVW+L1r49/dKnTqF0e15iCdfrUrT
eeCAXvp7flJmE5U4793HO9PoJGKPXyX6iQllg++sZmzwIkw0j1dRnahrHfjm
ZxEnex3f5/Vi+0vNvUQdcn/9thLqFxfxR/62h3wPbifmTM0+Dn/INdHCw+uu
jQWehT7Aew8kxO27exx/cwf9nVoI8VlGBlumKBn87/VG4IuD+G0VYWH8/q+Y
Eo96+F6zU/+aZEIgMx53evYRHxV8vzBulVViGQ0pza3NMRU/mgj9zJ/8vtgR
8AuhmjNc+jEB7wvmt0y77mpRooo6+mfrJFmgDj/oqnFxHDkaYFytf/0yvF9w
N7q2Hxo/EcFnjE5WxpwELnfh7Njv0knE/HDf96FIiN9lub+TpSsB6X0+9K3A
F+r58yfrnMTZPmMmKbTdykHsBL6fuX8hbnYWm1Np1q9mgvnXSXn9jIxHljCF
6F30P18yEngVQt2cH/0D23weQT1b3vP3/jKhS5j82j3/9+NwXsBgxwufp23z
mG7847rd3rA+xmWXxMI+PoMdlf6greoP62AqIYciRbVGsaHWs/O0azC38eXd
Z8Ih072YUdnQkV65PgKPD95CivzvfduzEzn/cQLyrkCV7pvJzLykDGdjp+9k
PsR65arxRXktHUfiuOu/Fv0zp6b5ZUjKyaAWEVYtT7yxCvt0+W8tzutO1iG+
XCdnCj/B+tKZqnBWt5vVCENs1v+vTrXjRMelMVEMKd9TSbuaCfGquPAcUZdk
RFaaT2jyFMSp3jJl/unfje93GmO5CPkVm66rT5hrHvYzbFJ8+Mj/5VeByK05
n61Xi6Hf5mb9KhhTMGocJ1lD/sP/zre5ujIQE1QX4MnZD/FPIiXdf+paZWkn
q/PrYF7epv9VNNbm/OD9ne2wDrzuc216XvYVpsDmPZbLBucoJ847NjQsPcOy
9l+UExwOhfUrNVZaukxt0odQUZKTjAFx/tt8LmrTWkUgHmft9BPKYS4M3xPx
SsXSTMSOoe2KcBH0o+A4842bPu0NIkjWu0OkBfqV8RjaxCUMlSHysay2QmWw
3yfjz7UrprwKUaPrurdSB/vOoo8Y/aOu1yJ9VYt0o1yw33ed/DanVm0twhxF
HXf7GORXJ6ezswcLqxHV0zyUgzsgP6Fda2XePlWGNMpus3+cDPt6PG23ov7k
PDZON90m12j5P/Urb2SqRPnVvmbIf9wrjPYyfMnGFgUnuleLIF/qqZWeUtep
wJQrrYSYLkB+FRIYoRpL1oApnZ9GojwgfrupuOpHbjOmRfWj5UI/3M9Iu73q
n9yiiwVDDPlC8HsXjkmndWg3YLHr3QO69bDe1RTPLjsQ/A7bJbcrRyEd1ruW
qNgpNs64kTid99oly8I+Y5MIe75FTSXCb1d2npEZ9hmvWb73c3vTgWynSu4/
JtZD4NOvJjw1JgaRWQu+eXJvqIsYD89TOXjjM1Lhs1/uwNVvBH7ziMgRJqlR
JGTmbthQ1iKB79cSPNXE/AVRy/GI5jaHuq9jrPuYHlcPIk35kWlOU78J3AnN
bxbUbkSYn68pVqrB+piVlkWyIU85ti2l0P13B+w7BK09nounHMYatHYezeaH
/M1Nb+f2Sr1prMdjl5puHtzPI5MdWqLzs5jkvdRLvpLQ3/5G/8UJK9Wv2MmW
WES7G/JJPala8rW8FySq4HMNJYtxxH3R4dd/xPTVL0Tz5fV7vlvge7d96ofu
2hgO1O8oO4PRKHwvjhvjTF3fIozOrxzO23kSrufqPNNPbXMPosG16kK9xbA/
mJjtMuVRhqJbnIu76Y9wEzjIJwZ5xQAHuXogZw/gIA8G5MOA5y/wMQe+5uB5
Dfw3gR8nqGsB3yjgIwX8o4DfAfA/AL4HYE4PzO2BeT2gLwd6c6AzB7oooJMC
+ijQzwP9PdDXA3UoUJcC9SjAnwCfAjzKXWN6sejyDxRsH5hu1rumVV3qokcp
3x2pbkpgjaU4KnDi5Gb97X5g4ozVB1wwnvOHqUEr2ui0WU+bLOXftqFViHdR
MKs4785Gw1o3j+eS4kZfC3McziXM//LpyVB0989NvFOiXt3MMQi31JbzurTf
FX329zyIaHQXThV54Cf4e0QcLW4QfhFcT7yEs4864CPlkvGvv6sS84lsbI9l
BhvM8IW2MrF2qyUE6LXMf+03XiAzwrubbqoPbpUi/l/ZZuau32Fa+Lnf2/aU
fIe6QYrGk6p+c0p40LmedBVT6JeSvDgV/k3pAJ4of9P3cwmcQ7mNqDaovdmO
+6DeE97GsM4s7bba27YUW3obmZBhjMwm1hmawKoOFipa1Kh5+93FQFin9dT7
cYhuZOv/cz2XkgQ//lxlQl/qK3LuDoT122fF41UujVvQq/7m3ubqQgQ+w6wU
zt+8iqze7BjC4iHu9jn0w87pQUSoWiiubg7mLcpbHPZP/TaMubcO49S+cP+p
R8xPLC8vYQbofWoKXZgTFMhmF60bv4ElWznQ/9gD8xnPSU6mGj8ix0XWVqx9
RyDfk+LUnrH6RI4fazHnGGyE/DC/10K04i0Zvvf6TUt7UVg3I9toyz+y/Rd2
eOhQfcMrWJfLHRnvH/JexjgH75uRDsP+5lSvpHNgwBxWNnWP6pPMAoEzCNo0
3309jmU9SHt5UQb64cfaCaDSqn3YG4vWjakO6IevHd8avpJdg33MGWwZ3gl5
1/c9bUNmDXtIZVIn2lhXvIj1jYFjvu6rcQlyLPBwZ64x7DO+uoXXfbGrRFaF
2AIYKqEO6ldD8/nBHxWIGkXH/69/t8Wi+emUSSnSI64ncKblH11WVfu+Sr90
5NwKeybnF4iXx4jWXf5+C9M1u0PanQT1Wlvmjvdcd03H6pPuUrywgHqtzS2Z
20rF8TzOcugHsqm/eoCdsmfzQzyhb9Letiydjafe2Ib2k/bX6fDza5wLEWFG
gRgjj/03+19QN94rYVm1fOwZZj4m+57rnzxKg970o3tYHmPCFDMqJsLQXyJ2
blip01CN5M9dd+lLHPSP8q5w3Bs6GorMiBnNj63C/OhbWKfajvYUhCZ/XvMo
I/SDXW3RHtp4WoAEd7WdShaDPgbPZ7vWuZTeIaGdOsZZWnCOb/9DMvnlr5XI
7v2HcgvXIL/iufnKj7KsFhkOu3OgSBryq9D0ziDZ8w1I3tDdHQbDUJfeNI+Z
3xJrQLh4l63unoT9wfu2TtUfT9QhlAdMFr4+gbwr9sjeXNGKSuQuT+nrN/mQ
n2zODxYiZMdku//NRQpxOLq9/2Y4cq+kJ0UoCta7oh4Flc3LpmLz0k4PXHMg
HytzZKMTUS3DKkiVDueyIC+6+9Zy8Y9f6559+fUYP+RRbwxHv3mNtmACERap
4tIQz7sxr16s2YZZB24ta3SB+5HxcegxvNmKHbVaaA3zgseTlr18Q/JnPRbD
lHCUxwD+Xm/bjO7b/90Pz3iaQx5dhfoukfFfN8k+PCCdzOGinxU3ItbDudch
2a3HyxC+3ea7WuigTs8i2IJGLbYFwYsP7aCU6iDwhmKmT5+iO5HnNyZfsoZ/
IvBa94gzEfw9yOM294qP6bAOVh1X54VTd/33XlnT2NgJ+Vjclckqyo4mpPKJ
9l2GBKgH87zRq/3H75frbHXzJxro62Un2st01LUOkzWPV6+ngvrY4cIkX3/2
Piyfg9/CYAnyOvF9qoc4GEewnyYG3bGK//Alnbraxs5BjCm2VTM4D/KQlLVb
ot9vPSXt53g2ERAXBv2jJCrwxa45pI3tM+miCtRRZC/VHEZV6NBg7iQfgQLY
F+iS2LDopuVGh/hjwmME4fvsjdqIBU1EBPVd36ZCNviPv9CWYUVRzkOoPK3S
DXk2uD5zJiy92p6AoGEO1ld3yEPfbN+X47SRAidRGUdR9rYk2HcG+cQgrxjg
IFcP5OyB5y/IgwH5MKCuBXzMga85qGsB/03gxwn0WsA3CvhIAf8o4HcA/A+A
7wGY0wNze2BeD+jLgd4c6MyBLgropIA+CvTzQH8P9PVAHQrUpUA9CvAnwKcA
j2L+fE1x7+wCCrbbNZs3604UX8hGWcjfXcg2db4WsoGexB/8Dw+m8zXhPNmK
+wScP13zsQ59a7ip2xfyufFCUCwXb5zZ/UVX4TWa8HnzeOabDO1WrSPx0LP7
wjrcHqGH//4u6cOh/qqmfviTwdScLS8s0RN/z0/yQQHOX4NOuPzhILPI8VNo
O+BLNyiu9j25hZ8pp/2qL7mPyM2M03RQ5nS6hP9S+rOOKRD/49fKH/o0Rpr4
joXhNrU5OD+bpywXks6L4Fu3I59Ot8O5jH6G3xpnDHbjNZdbsjy8YX/QzeuL
MvY1s1R93PKLOPtbYt0YMo9hlDVmR/WpB0Vbi+B7gcMdlpDehh3olGQIGfMe
YQJvahCsEHq+HXU87inCngX1hFNP9V4c1mJHL0wkG6k+ECdw4WlyultetKhv
zamJsJ2wD55uvvXs2bkFxDfKzZQkBD//oOxKAs/5Xizn4ssYGRqYw/j7rnmT
9bM1bC/j+e9Nh2GfvZbq06uQy9S4rFJ/gxU9PE7UT9yQapkOX8+xbiFVQp5W
6FiTHVDPgG9rHtcrEYd8jOdHoYv/GQbcNtld+aQ+F4Hzfg/Ta6Glw+P/d9/B
+YLjXDa5bdHUeHqopyDpIswbotB2zXwSQo5rZeb43J+AvOuLs6JJTOcqZnm6
2Px0O/Qf0y5hoV5Zn8cU79+vTbeG9S7y3I/1NVoTmEbTE9VrGbDPKNAaFWWd
/hHbXB96CFx34lJEAVM1plX//LBUPewTJbxjmZgY2U8iq1FaqXfxINZDHd/d
utTWhQjfAYfhUnmoq0/r1i7apoIhxZeLL/RTQ314PJPj7497i5E778UT/3vO
E3jO/EfL8IcZCN2Drg+Us1APplvmI3K8yA15IskVH2UGcVINz7TwXBw29Jik
b5cA+zKbWzI3ubJS0ZNR0K91k1/dwkJqX63RyUB/8teMrw/YGHhhGSeZaFU5
od/spv7KC1tFIoT4FqFPl3XyeoniLzeMouaES2gr9DN/NNJ+RpvzGCm7JG+5
o1mDOD9Sv2qOLrAEIg0ZTpPjQzAfmWGys3xxJh6xuMya5/6P32b09NjCw7Ac
JMtcW/5lA/SVcolKH72Bv0Uek/t8nveB/GrTn6ECUV0dGSLfkk/gK94GM3O3
ahCElzbNXBLO/w4bkAX84VELo0pTZxYhH/Bo/RGfQdaIpGbeF5Uuhn2xA1H3
EBHmRkRd0eJEghXUZdHXpOpzuTcg5g07z4dMQz5mQ2dwP+5jNXL5UMPDKBdY
B2t22U7DKl6KOGP3I/zXIU/bM8z5eZQmFpl4JHNXTQfylgzh+4r6kq+xmwFd
q3ECkKfdtmY27WYow7oMArsu3YF1M81qbU9X8Trs86/dmdTusG6mu2UyKYes
FVOk3uJWzwX50rA9GpRM2Y7NV/wq+nUU4lIBeobOdO3Y5c6jKwYbkAcyPk4s
d/vUgr21ujrVPQb1ZgFCrY8Z8VrM5YZbT+0deL+4VH3YqEeKMUrPL46xlnCe
MWVsi5CE1l3SKe7ryVwR54j1Uy7Ys5V7+xuELVhWKnAP9JFgTzHzCpWuRkjK
6J6tDvC947aZ6ldllXqkw5R1WoIC1sEYqtLbW+JrkEcsj2wxJcjH2lneXibP
KUbiVv03Qt9D35tNfhWOkYmWnxMbgXORN9a1/UPGq7DSZTVdq1yI33yiny0r
0YZpapqmP7AYIfDFpt4Q+QOtmGz+hMDOJDh3OR2UeYJzyZV0pDpA5frrR8R9
Iet7o2Iw7wtS4kO/vr8TziVNiKA+rFIbiEn6bt/P81Av0RctXXcpdys6Rnaa
Kd8H1vmN2TnY/LN3oo+d5H957oZ9AeM0D4ztrQgadfit1kUj2B+RUx+b53I8
iFZpSZpVnYHvrYq9Y2O9Lgpo4FcBklMPnPs4lYmdcWk4jpb2CzTwhzISz0HK
sRfPJd6roykK78me34P1B5BPDPKKAb8CuXogZw/gIA8G5MOAuhbwMQe+5uD5
Dvw3gR8n6CcC3yjgIwX8o4DfAfA/AL4HYE4PzO2BeT2gLwd6c6AzB7oooJMC
+ijQzwP9PdDXA3UoUJcC9SjAnwCfAjxqT+ZM5wWlWRRsvVYG/4fzcbvVx6at
4rrsuLFC5A/ULDzvf7hVw7AdVWodXvKKNVHftwx9vmvze+XylfWavVPx34VP
VOX1XqBuf4+zziut4E5dMO5x5XOvyoYDevHv741Q+jh6T9EdN1jxOcm7Txkt
/Ht+FNUXxOx4bfC27xxX5mkU8dm/+I4U6afZMpfw/F4dL+wN5MnJd0/MWyBq
eMRAMycbJQleJ9UxPvUuB3Cx4zv3XjKB861iQk5W4+Ilpe22LfTJc1XEOnDx
2hezSm9+1Nu2oNTQAPajy36cMm8t3Y0WX7ex4TsGfUJOmfFyNeK70B8XA8LY
XsH5VmaNe5WtV/nRdbczPLcqZAn8pySVMH8GByr4NolX4wDM/XHt3LhdpEGJ
jk3naA6bwM9H8L1Erzx8i+k/mTytXwz3r6foo6egT47bJfe7//aFcx8P1Wt8
TAuZcKdO5xoJDnicvDr9squf2PBHTDQ/K9ggT1M6IXza+CsHvkX/VKDEIcjH
rI6QP8NI2/CfRkVLZXGwX2+906bF8QAHPvy/6xn2991KUrKpRNhwJf2tqwqM
kH+iLNufP6Dbir+Zpj2NbYO8iz2abKxXiQ5fG2IJ7rOD9a6iNnu+E3cpcevY
pOaWIrhuMKhn57ucXMeu8tQZbtz4Cd/7elg/fmNYwPLuCzHXXoHrlXZc4+c1
uXFML3ml0TES+upflvqkUibVg92KcrUWzO0g8FLsSRQPfQW2NtiTmnkM1j1m
XlA+9yoUI12JmLBN7neG/nuiTbt1nmYjJtkH+q/h0EdCzukXBZtUHjJodE/k
2xOoD9+nz3RO6m0q4iwZOxEfDf0WjFfG4j/k+CNX7+lMK45DvKpuKKbsRhiW
1MQoqPUe6s83t2Rujcdn+XTPQJ/8zf6gCTZiMzRevQfi49/2HStatMeUYpGz
IUOQL5H22Yc2LN3GRC+1jyqfdYLv44nxFQU6h0l7ujt7SZwwF+aYT9jlM++9
EQ2TJ5YZCu7E+en1jy8+i0Uil9tTn0VMwDrVEwWKaAqvVMQzK7GwWgfqqR68
ObItw7QAWR4kc+TZD301G3kfLku9xJHf5juWnyhDP9tV6bg7bZ8qkR/8h47+
Pgf9oNwidh3hWahFjLMXtsjlwucFwm3+5k/9aHP/sN6V6KN78nTPfzzje3Gn
7CDkA5P9WWOcVU0Iv9jV9WpzyNP0RQYM/+R2o+b0u3SXoE4e8Cs/sqC+6gOQ
v80NnbeK83+HBLOoHRn5An2uNucHMxHvBfbmJ+9g3y1gJknRXzEKeylCS2Xr
C683crX+jD+5jBLNcidrRCCvc9F5x1r0phbriT2v/TQa8hwt8WCfP/Orng6O
hrpckNcJ9Avf0/3Rhq3fGHidQgXrt/k9JnGdHu3YI6XKuBQjiG/ZcnxJwqQN
Y9G6dF7XBu6HLsp++SzWiPHQWAu4zsPjUQyV11HdUoWls3kOaSjDXCduPWNa
y3d52HHvGkryf3xW02YEj2BDNiS7tZfr82c0ifX29KMDofaLmYjYXatkv3vw
PlKo2B9krlOE6B3m8LbYCt9f3s+E2hooFSC7JKM0UlJhvbctxTNOMSQO0Yla
m2m9AXWPyhEzPX4WcdiD7TpaTQUfCNxfyMnwdetbzDnfwmwmFfbrRTi3FFyT
x7EMVh+1/Ej4XlNNt/BB5Lc1aV/H+d19zU7EffEk2cXzQnIXorakErYuBeuE
uirtqduOziE7b+jPK9LCuZ7b629fMeVRoDN6I0J9V6YJ3NBJ9/eYFitKphO/
11URvj9e4nfjG+DnRR0FtcdtliFO/dLB0XpqD7p5v08R+CjbUfcZkQOoZZPo
7afdUG/wrnL/vp2FcmjaKad3Kd9gP5Tn515s6wkl9NZotGJEP9TD3G84yxH4
+BR6dHV0wpsFPje96lXWtjzURBGpj0b3r0KfUpBPDPKKAb8CuXogZw88r0Ee
DMiHIXJh/vqYA19z0E8E/pvAjxP0uYBvFOEj9RcHfgfA/wD4HoA5PTC3B+b1
gL4c6M2BzpzQRf3VSQF9FOjngf4e6OuBOhSoS4F6FOBPgE8BHkXHFmxHXjSO
gm3PrW//w099i4ywcprHDXb8vvVpbRqN9N30l+hjfJLveL4Mr1oe8346nIPK
p2x+byl2yWTtWQy+Y2p820SXJ6q7tolnrd0Zr6/zwQN29bK2ViuhLn/Pg6nZ
0yDW57Z4PE3+pJSZBlE/XH5n1ZfWeREvF9C12n1Dhfgfb3yTOVmsr4hvIdMN
s7WA/3tqQUez+4760tsLOM/x/Dbivp6SWj5/wWQfqmxLcabVBfIQB/Z+AfN2
KdTsyqcqJj7oG3/f5LOEtKkkmji453rvHMxJtE7Zyr1YvBdVzej9lXUX5vvk
yI/sijMWQF0qayz7oyH+gPK8rsjsVtTz+8cJlq5jBB6iKDDtJNCA3OHm4KS9
Cffv+c3xWoURDR4sUnlbX+kogS9YrejGyG3DJ9LOmE1qw/wgWv7FgspYHlx4
+BDd67OQp9le+nCqSJEf15gUHZ59APlY2+JZTZKEAN72Ey9r/ATzsg2lKd/n
2PHjiVGfX2g9FCXwD5oHLHfT8uIXeXu9SzYg7zqfWp+dk7gDP6dXu3sklo/A
H1HaBKunb8ON6CIjRT9Dndg5O+7I4wGsOI97W7pCDqxjC5PTdJDvZsBnRGaz
ZpNhPfxhoYpm03dKPOHDx3sZUmTwd90+W7Hj5RrmFS45UXQa5hbdpa5e0imc
wy7wdXHrJsH1R4Th5ei09xdsdeZulvc3+F6ZJOhn/FCiA3PZ+VhGNRr2a2LP
Inbj/71vK2TJk53jhM/fw+M/RLftEyVxpy8HTT9zINZbZ/2nI4f3JCLahbal
gxZQvyTgLhz8SjwBEVqymZe1zidw9+b5ik8ZgYhc8i+JGV/oOzr6iBRlvdMH
2xtNlSHqCnXmm1tFTOM1+5RiE8yd3ORXZ7F5wUCn7672BH45lmmI0egKRlKo
1plNvUngByLv2vGki5D+P7KuPJyq9u0aQ0VCJBQlklmUaW+kFJJZMivzFAlR
mck8lLHILFNmMu1tVpKxkiIpCiVjKKHv7dWzn/f6fn+d61rXsZ1pn73Oute9
lvlv3frFgGOw54h97/ZQby+khWTU9qKsK/F8t/oH7yIHFU+GB7XCHiVc98UC
OpKJcK6JbrPuhf2Y+V69eEp/CfLgg0h1MjnMRdeRCph3YK1BisivPO0STSfw
F9wFCh6sTYiTtEzRxyOwh+hv/yASGftm+CEO+RjFCRFvzXtPkaaUQd4RO9hH
APiVSe8M051tef/Dr9ZJycnOZkI8Obo9RtG1539woF8dtGuS5umFOtvkN6Ec
Edon/3N8wK92VZvvf1wDHw/gV8nirHMbCPSVVS1d8aXhj8M2VRhvWyXAXqSG
J1n9F6dqMPXxlJscdyE/2b5GhRkbdGAHuEqrqIYhn9w36/VLKaUbGymwGPDf
CXmj+uOA9zhjPxZ/m/TIpeuQHyZFrlTtch/AdmoZjEhNQn6Ypq+Z6J3ej6Xc
4rvGLgb50hXba9GTvT3YBbx7h+cVyBvPaTwjz698grHvyBno4oTHt5fQkeQL
xbGk1J07HohBv5yNqedrO5tCTGsNnTrGC9/H95pC7+PHLWTDXdIiPQJhT1DB
kbzU9uo0JH6lu+1NBJx39188l1l/PAP5WlbIq2cMz4uIi2O6X54FIqpFzYaF
w/UE7iQUxcaP3MMqR9Mu8NJB3eymxcyNXdO5mPbd8JuzppDXcZc5uoixGMmy
3bu2phJnQ5wXF3ZtUtmmdSC2UXWOXAjkydfCp05qOHxE6n63V5wQgvNZIVpl
l4rl74hNyIcZZQ7oF02j/sS/wkWB0n/k6tDZDntA3itxbORd2o3G3/CS4FQZ
I/CzyKel89/Y0K8JlXarPlCHrG2oP8967DB62Zz2QO8szLv+xR43TvdSCPVq
CSB7+wz6wZikyz4LPJBAi5kkK7bnQn++QjeratK1f35G6I6oWI/D/S8X0Y5L
bYmKqOGdy/5V8oIEPumdbrI9WhmtPvkwOfs9vM7uZGm5V22lgdb6iAj45Zwk
cNBPDPqKwfUa9OqBnj3Au0AfDOiHIXqu/+aYg1xzwLtA/ibI4wQ5nCA3CuRI
Ab83yDsA+Qcg9wDs6YG9PbCvB/zlwG8OfObAFwV8UsAfBeZ5YL4H5npAhwK6
FNCjAH8CfArwKHV+nvNv496h4HaM7+cWz1mQVVd2+4TvtWfZTRP5Dp23WP4X
/+j/9Mr52DLcRLZ1bKdOMnr8y9bxfVwWG++XR+MFTh1DHzNk0G1/n1dUcBO7
6agLHmxyID1/ShcHOVpCgvjrEyRauKHewPmA42eI98uXbY1RMOlNQ7cAD7IU
Pkacp4+WKkhc7U+gMeOXTR5fgDn/1JYP64fJZNG9BgleaogKgX8fUr/aviCJ
UnM02h80VifwquPFT67Ni6E7i3MffUnQIPCByf16DtpH0PUCvemflyHe87EK
K+5gRh+4yWhdWDlP4Od+Uu9wOpiOsMw1OdUonYN84/YV+Z8KDPj4wNqJ0zzK
BH789KznFwZOHO2XLnYbgf1BnBy3zbr6uXHjbVdZjt6HPE22UdtGKp4Xd14q
1tPeAfkYmpvL9/3uEdyeW6Qz10mKwKnO28Vr8B3B0wy/NVx3ECfw68ucuywK
ePC28MuGHqwwx7Xk5kEGL0tuPGKbzpfQD1Dv+r6PTXf8IRfeIanBmNsNfWIC
Zv0N1Dc5cO6356986oH9RCpXRNy/lrHgPO9jrD8yQX/XJ5XOnDllBnzfv+cj
9NW/Fclcj9jYjqs6PVc3V4PzxMYXv6jPfCPDv8fuLyn2gbpWooYx78+lH1hI
i8H5X1xQ16qZrCbzt5jF7CIPfVK6DHWtBsr50ZGEMaxQJlwbTX8FdYxfmQkr
rj2Y4mGrIpvj8Hf9iYeOsbz//N7Wenmh2XEZ7rVJ+1TXSKAHZRdGzxQl5tkR
389tft240JV4RLCueQVZgD1B+9ePfr56OgyhChg+H6kCryO/HxSwiJU5Y8hR
Xo/9ZyG+dSuCbRh5pS+u6xN43ZlLN460KGJGCUY5bY3aUAf7QHHSyZZR1jO8
Pww7y0k8npGIcjHvBTtkR0X3Q0Euc+Lxh72+fzzzbRAyKoXV31K8RuBb+aKJ
SG3qs035DV8C38q/ykFmvWx+xwuEEPgt5bky3jNlyIGZByf5QqMgLzUm18k/
XItgNGINZH2Qj3mQrg4lGDchg8Fx/cq2UAdjGwxSKNFoR9zt3qyU5sP7B+15
L0c38PR/jg/4FUXE5QtsS7cJ/BlyifIhWzdyPEv9H/4GeeMHjehJbez53/tb
E69b6Yri28GBZ0hq4hvS35FQ94si66NU4u1AOHi+JdyPhnNVhZD1mKq0JuQx
kyyLEm8C1EM+P6PpnS1B+mMfCEQ2Qbwt+iKJ00FfLHCfx8zj77AP0f20/fKf
/Pxq0csKPkehz03I5rbwnxx8e99vRSf0od64TT20mIP5OcCJ59XWGDnrFtUH
jk/gbiUOSLJ7PxYzKbPzx0mYG5bg7VyZp9KPWeTtF6ss/w9vnM64cHOyB5sK
umrwJgDywMYmqyexi08x8tqQ837BsCdoI/Cf3+Epzdh9OtV9FDUFBC5avREz
71iJKZnVN8wJQt+ds/SXHWLLaZh4gl/siFM8gXcyCPo9mtKWRat583ReixDf
57rPFnbqHw1EHs1JMGwuw9e/SEIVo182Qor3zla+OptK4OVxUo+v+wZh/g8n
C9E0OB+fWQ9akLFUlL2lo+eYVa9JnBe9dlnasmYVCIvo6sLoZ8irUZfrS6X5
/Qhz88GxqBfQ7zecptaqUfkJUXl+0KuMBH4/fA9BfN9sW0HyY1v35lyB89bl
13IZWq/IUeNv7h9s6eE8emrhEN8zR3rUpE/9sQgt3OdliL5zRiuWFZ0nX/0c
QwbnniM+itaWXw+iN+Jcf04/gnuXv0J9WhjHjqLDr15aDEjCvUV0KBE3vCaG
hnenDX7tgfv1Lp9td1Q/kEQtb/yUPn8A7nkZ6Ma1GJHLo848Z29aXoc5q+ms
wZzktqdQhUCfb+/OQH51qGTpxe4gZdSt8vBeDXnYH1RJHrnzkas6Ol24phJG
okxcr0E/MegrBjjo1QM9e4B3gT4Y0A8DeBfIMQe55mDOCPI3QR4n4A8gNwrk
SIH8KJB3APIPQO4B2NMDe3tgXw/4y4HfHPjMgS8K+KSAPwrM88B8D8z1gA4F
dCmgRwH+BPgU4FF2ty6zo9bPUXCb7rClj+1CXzp85BrAM885XF4KakGvmm/h
O+7v7iH3ScI9vz9Ir84WQ/P+8sPyzQfXmUkccRV+8eJxfSNiPuhJxd2zm26+
YeV5UarPjiXivLOMevXQ+/gZVHpo5KgciRaxTyrKpY7aWJ1FF+ZMvpW+MiBw
2rkcGY0aRZSkoTfcVsKEyH+gMNdIRsJk0FPLLb+3e0Gc2XdHy0UGEZQ7v+VX
PakxcZwzD3uY5ET3oiK0S/kfkuDx1yp2j1HUkuLUM6MXJbELBL7dyrif4iIX
zhx1O3ywXofA6Zn4hJKHj+I1ub/CGlo1Cf7gasIqVBArgofs5P18dk6NwNOH
x9z5jMXwFSXVxmudZwncyy/Nff2HGM4nFRswc+wUgdOQfbyVlS6Gp52m81L+
T58UThFy7k2YKO4aJvKCPgDyrm+GPGPdo8K4JxY8+qQW6l1ZSTf46jf48Z8/
YpXPLMI5o7zG+XXZbl58oyJuJFGNB/oqKT9oXk48hLvnSRkXnoB+e4WJ/uty
/AdwpYm1ubXd0Mc1P/fsreUXFvzwNOP59Z+7CHyfsN+P+YzdeGWAUKd4KMyR
MKd797v1JTW+J89m+wQ99BtQcVx7ahVDgtt/F2JkLlog8LqKG1fw4u/Ypbv9
pYkin+Dv+u3L1z8+msTkqnZLDbBBv1ZtiPnZp6RDmLWUgG+7BvTJdN0yZCan
b8OO072iUVSB+QBPRISLhiNzMRMjOk2tWtjDgvHM5G9+ZJRdn7C3rjC6SHyf
911VLhq29kKChvJFhXnCie/JGsvsxWgrdeyuymSTzHj0/+NXJL7HPvbZSzfy
Engig6hCfeiCDO8hIZuQhQ0ZgFsc5eLia9FGHmktOOtVnSQeD5+LGltI1DXk
EPWCl/UufQIXXjDW914IQ36E4jRfnlhAPvOBsm5y3z2Ebn/2keREBwJvfVak
4BaZi7SoVD5RWnL6H37V+rXsldu87f/wqy38IuRRo4rO1RlNyLyky8VGPzPi
eVmmT2zsGmxDBoRUTq153oL8s+Gah0n9E4TjlERzwd5YAgf+Kw4y6Zxz+2Eu
BPBfydhf/qOPQR3vr//q4sLd0K8ysHeSWfx971B4JxJsaDD+8BXcr9y7f334
8fc2xNnm6gAvOdQ98qWyvmljDYhWutKbpmWoq2zlMzxCiqp78hIPwevmln4V
iHnUNvprKUM8g1abj2t/JeZTuF2hKALqmVqD2zI/HmnFoqLTMVNGeHyJ+Yl3
f3KTfc5Rqw+Hwv1QC4pcz71IL/aBYazpEQns91y+e1W9o7UP23r88HXIqadx
nHfswwacT5vpX7tL4IaXtQRnK7sxj70t1w6dcyDwgf2jm6smT7HbqDatRDfk
26S/BT47jTVjUWo5GaSssBfb6cyv/raAamyPUXqUaFEM5LfCo29oVHOxnWL0
8ganoX/P2qH+Zc4/54NNxNKksCXkjaasXCPv+8Vlj3keOf3rCT3x/S8yY/b2
+OpeJPaZm835Alvicaqfjt7tOMshu3j3ebBxigBx3u31j4nNSk9CelRlQ7v8
oR5buV0z+MWuBqRi98BEpvw9Ap/l6xNtqHqBVMmZT8tFQl7adTfgc9X4J2S7
0s0Lf35/APypmlu67vZlZOv9fUg8nsgnR2QTVcnQrdcT7sWcu35QkTGUFl1J
PcpV6AZ9X+pi9I/8/ZnRjl3h58WsYJ6YfdzTAT49TlQsJL/xDS/cZ8Rj7uys
fsGDNvZHTSVrwrwIBWnekbFOIZQzaA/92wQ4B+QXD7nGySOOTtbGZa/OQn4V
oRP1yq5GCmUMkTy+vAL1q5D6pmUTKnl0Zv95h/GPsD8o8bxLvEmCInqv2LSC
l1eOwF9Xi3366HoGPZEtYKuHnyZwji9RjNoPVdFQjuqx1pdqBL8C/cSgrxjg
oFcP9OyB6zLogwH9MGDOCHLMQa452I8D+ZsgjxPkFYDcKJAjBfKjQN4ByD8A
OhjY0wN7e2BfD/jLgd8c+MyBLwr4pIA/CszzwHwPzPWADgV0KaBHAf4E+BTg
USMcixSCXx+h4JZ6Yuv+xxzkQ2k+5eGmbq+osrjZUK2VLdzScUa62n43VvyQ
Z9rvBwPxuWJXqReZ0jdCT9kxvtxL4ogC3hWXI5GQMKWLHq85bWU+6kLkxn/q
VbraZHMOPTgRtrw3yQUFc0b3945r1DTy6E2a0G23OZyJ42gE3nK+K3AUPWHh
PTYY4UDkcZmXtey1TFjGSHxK0ym7bIj8+fcfaK8InDuCn/x1/waDpCWRI2F4
urUtmlwc32D4jLHNmRM8jaRf7pKEtRROkxvYlL9iTOCf4qilrR/J4qsC7C9r
G/QJ3lW6l2Xd/BSKW97TMSzlh3ysKP9oyD90DictzXLmkoO62Zca4cxhDQSX
9hP2PdUDdTDbgj5NbnMZ/MO2Z9cFxCDvQsgsrvK+lsT7PzHyhLNDvSv6oUOm
zbQE3sVzrByNhXNG5fIYptxuMXxX9hr7SgCcqxqdW1UwvCyMRy7dWk73g/PE
3PbXnYHOfHivvF7aPhGoa62PDh+8TsaNk6vraWuegnuLmStjndRX9uMLxxIY
1ZlhXsRaSewars6Mj9XUMKnZbiNwOZ9GUn2jXfi75LoPJKaQXx0dWOW0XqHA
79/O1Hx5BvIrLld+lePWa1h5Q5B3ORPMn2ceX6Qe7pvFEq8aFNgwwbxTUqo9
bhEnx7C2W/sZdAqhX+WRdpLqRF43ZrWkmi9/Bvp8HBwc1r1NqrDj2womVsRh
Hmanc4FF4ModbKcXM8lPnkAC//Wpkp7VZFUm/3TfWLOnNPH9f4Da/I6yGwOm
bZ5ieuD7pf/yKzMWG2epxH0KF298OlELcOsxo6aBi7yIxaxTz+/ZDuK6E/Uo
TJDyjT5yvchnOO4SNXEcyWj7ecHvbghtYhbjBysRAu+ifdvzNjsM6ZGgWHL8
rULgXmlXDE/o30Pc6RfjaCIg/+l83CMo9D0HqRm2TFOrciHwb9fWxTpaS/8e
35fAk2/HV+FyNX+PD31ixjF1OiUFjYgv0oyzisKcB1sLkdh/eAWSr+t8oHcW
6n4eD4v4JSQ6kLhf/V3F2VDfO9upmaZy8SnSnt2ya1oE5pqa7EsmpeN7hjxP
dv+HX0Fe5PLiYPw1zU4k1cBAy9ME8pyt/PYniDzd8JrZKJw3gf1BJHvb7hh2
6Itbao3k7EmpR1IOO7+LuQV9dFv7gw+Ry5xH+OvIYR4+4FcpEYwlf3q8AY5y
Gjo2JVViU+oOTmlmEB+9pa4W+qwZO1op+1A+Du7lBYtaq/7J92dZ4b9XyAn/
7zEzmuU/vilj/mtRTTugD3Cmdv2zfEMPxnqnduz4KsxDo3y4s1VUsAerPUnj
Ml8AX5/FhFUKUdcuTNnxsh9/EuRpk44Z+rcedGAl475f/uxhAJztRNfXc3gT
tut5ZEjnGajXufCcHHQIqMKSPE7ltmwLJnCOsPufTBVzsdFQeeY/ei3AL+Tv
r3k+Fo19rZXXdz6oTuD8NIw+Xf+cD+4e8VZFfvC6cH4+QLae1U9qc/2ZfryS
jhTAXdc5+R4W2CKNS5ZNM9/2Evf3pjX4Ha2SiuwMojz0oMOIwKU+uV4Me1OP
9KLa9tG9gQS+g2ObymHLAaScq+61cCZ8vtejvp6Uez6OaDTZe+RWwf2Xz95Z
0iezFpHPg0eLap9Bn1i9+zpXxfRvpOmIhsSrnlECp+VPtPluQ4OW5F3fo7IT
9j/uoqJ4P8fBiHZqzSo9fgj71yIvpNdN2bCh23Zm/giwgv3a+Matr3XvD6LY
hSFPcxY4B4w/1BP6Zj8fithuylSegHmnr4rq5HyOiqCanXVzT4Igv1pWT+dB
lcRRu7QujnVRAQKv9VBVffhMEpXb/aXAYAz2/sSzZKOSYQiaGkrxW8oF9iRa
sVf168gooFufWzg3FIku8k/JUUTv+2ZrbdbDnms3t1XJrJXTqKoP6VUnSQ0C
B/3EoK8YXAdBrx7o2QM46IMB/TDgOgtyzEGuOdDBQP4myOME132QGwVypAAf
A3kHIP8A+MHAnh7Y2wP7esBfDvzmwGcOfFHAJwX8UWCeB+Z7YK4HdCigSwE9
CvAnwKcAj3qZwzK6W3pYBtyC19PRj39A/hAbrhts57zzUx7Bu7btb7/2IVsM
98nRXaXwSSL0LunhmSbFDBk8ycjOMbk8mpgzbtvGaVzZoYB7H74d0fM0mPB3
3VG2fH37yGlcKn5NOEDej/DVv/FkKm6YOIObHPk4IP7ei9hnLGj9YHB2Xhnn
nvN7aSnnRuRIZMzf+F0ip4rzXzVOVP7mTOR3LQQ7dF0eVMXj1OWl2bbZEzyN
gmNIWbhBFR8jeZO+K9SSyKtX+JDZaEWpim8odU182wP52HVPW/plTBk/F6Tl
VPoV6mO1hbspXKnP4otlTG9ukeoS+OXnmRZuy6fxj1bMa03SkHeRRvz2qs1V
xEVtat9q4FDvesQS7RIqpYA339cUvpsA54waZJ/sK2IRPEepr8DeHvq7WkdJ
O5OfSuJ/zy8CF40KvmGjLI7/PR8JvOJkKv2QsAgeyXDzQp839GvxzrObsrDx
4SScyMtCFOZXqPKxzP3z/YDzOrcu0O2B/KrmuWumhzUb/qxlLOaGI9Sv3qDq
zezsjPjf7x+Ct5AZdIxYO9DgJ5hXTkvtg70//rlv/EOmf2PfVj1Pe72A/qvV
Al8sOnMRu8c4MKP2DvocZieiB+52j2NXKu/xOD6APpOu9uwTCpYD2M4m2h+e
hfD3bBWld+qxkXos8wqf4R8/CMCVHzhHzKumYuWfy8h0MCMC/1bPpnnin9/b
lroM6ZkTewncStCtaZHxRu1Ar4aE5ycPgkdt3f6QbZ28fPWaPTdxf83rA+45
rzdlkhU1hLlEluoBPv9GKMskQBORv8xM9pzrJPH9PGX8nEtnxQXJrL/4evCY
IdRJHmQpT7sGI9J+r+lDtzkS+Fa+aCJSsx6aPtYA51Mj3uKL+keykbWuJaWj
5+F189LpS06+Do+QR1+036MJUF9SzXK2yHxbhai3umwMU8I9x8WFWntXUgzx
t1k6xx8Ir1+OR25yV91oRh6U6byQPQrzS52d72Y8/dyGrA8dr0qrgzlg37ZP
uzXwPEGU6wbZw69CnSdoQO8d11AHcoU7iFUpCebP18bNfA28/wRJiDrGTIrD
PDSQf2Wy7kwz6gL5zPwlO1edlWYkKa928WsC9F1v9eM8Rl7okI38rP9P/vm4
s7vBjTyk81iVpYYs3A/NvRBMknMsCWvheM0cJgvz1oB+pdUzxt0YBHGymZ7G
LtEm7OIE7hoUBI9z9Y7b5oJDB3bbJUrwJgvcV/UNk5GfPPgMW6r2YXvUBh/n
Hbrs2iTkObb4eBpdkYbPy1k+anpOvAtLL/GNKEAgH0Op3J4IJD3FeNS+VH2f
hvwzkt/3a9buNkzpOIpSTUDdLLIm93qVPIZlNLSuHSjII/CPpAzfi5FyLEdu
scqg5QGB8+QOh7PPZGAXF+0pT9nAeWiNhZ/DjZwg7KPxKRntr9cJ/K0PkyWq
t1v2KqsIrsJzkPg9wsvzwfwfvoUISVjo/lq6RJwX6znBExl8ErKhzPtXv/fT
Eb87ftpX9QWt3EE2f1wNXeWFPGpDXOg0n2kVIrizxIZCAvY04T9nLrnldyPv
3NS1smTg56pQ6El8sfwYcuz4vPxKIXzfWWdac0f7ZxHSNLYAS3q4b3j3uz+1
quMaQimy2muyA+Y5SG+3WLn2gwINrt57O1kB5j9M+N+PeGm0C/2219wMNYZ9
Q263TB5XnGNGs4I+izVfgn1tu8fNTuIe+1GBPC2TIUbIrwxP9V2Mp+BG1bcd
obdWhPpV3ojU7UxnPlQr+XXW4lHYE/TcYJWe21gYfc2m2U0dAvuyLwb+cBvr
FkNVc2icmYNgD2PZZkT94UkJtDZ724exWDg33DDLXqZ8I4kmSSgdq2GHulbW
N072KisZdEDX4fdJsVMELv595608bQRN2X6yOqhLGfJASo23T4xRlNonWJBZ
DvIu0E8M+orBdRD06oGePSKn628fDOiHAddZkGMOcs0BDvI3QR4n0E9AbhTI
kQJ6C8g7APkH4LoP9vTA3h7Qc4C/HPjNgf4DfFHAJwX0IjDPA/M9cBygQwFd
Crw+gD8BPgV4FP/mRfI3g8UouD37cQuPU/7kNRfUgh/2s1ue4BpAnf/qY4HK
37N26yTjFy6P65yPLSP8XdceaXSODAbgmWcOZ2/cSSd89fIcI9QWm2641R3f
o/ZP7xL7jMd7yyuSkxzxiQLufFPrMCJHYlLbOSLA3gr/qWRtx1DjT+R33eCz
xINOXcJNJh5sbve8QeSm7lR8/DKbyRRPLDoXfTP6GpFX34JadLQzGOLst5Wv
32G5QvCxQQ95E7lXF/BbVge2JSdaE/rYp3MJX66R6+KNU93x2AdzQh/T/4At
U1zVwsPnaHlmfxgQfOxR8DhPBIMG3nig0JidD+pdYr/GovflqeIq1z6mcQ+o
EfjTohnuUbcz+Dhl8w3tJujvohvdRsJzRxH/6RWTOSYIdS1prVOuMdvlcTP2
R+8k3sN9RvHoK9q69VJ43LlJnsYVODd0fNHt7nhUHD+Zc2mBdhryq6XiJN6L
z4TwsWrR/SkRUL+yFWvXNOzlwTvSKQfadOB8kHb7TyOlC5y48uaKlikP3Cu8
5sYUU+LLjMvuWXhibAHzsoZuNeevhdLizmJihRQ34P7OvhcnDT1UyPCVCoWy
fnO45+4wI0aiRbOMBf77+kN/cl7PV7UjHz5hZmspLapBicTnNsz2or1C1QvM
OlHTwMUd8oG1G42x5bQNWLnDXg8RScgfSr7pu86nJWEdD+I8X/tCP8/EpFKf
ZL9ow2988Vp3liTx/b+K7qZ9+WUvtl5LyjxTAOdrW7ckvutjTNNdjloEfvvO
IH1bmAwm9DP33cxNNQJn+DBgxDvJIdtc7S0+octAHD+JsnCJMc8C8cYD6eIb
4e93secsGtdSfZHUQE6p5rGrBD5mYfE169gd5PlClIzlPn/4u/u7Yk/PbBqy
vzfYRfBOFNRzAhy7tufnIydPF3aPXYOvm+tB3tA/OZx348XlhudhP04x78yK
Z2MNErAcenQ6GM5TjmbN8jsfbEQqrlYGZUbBOd0lMvPIOeUWZPOnxWtnQ7gv
8MyA4+yaYStSj7+VYqaHPOr7qs8+4cw2RIRhtSvWDvKoBcTt1K6hVkSP8YlN
YjDkG/TWk/f/6Ga9ESsvn3PB/EwFnis6j+sbkbP/9khAPhPSkCg5a1v19//C
XoAt/1UawrWcrDo5AHPMGpotmup57mDikttzVQvhnEi0VYw1+1j5/+CNO3Vq
3WJw7DPl8UskNBCfcN1f8IqqDSMXEd8ubwf/r2qArOGA4xOsn9fESZwP8rHa
M5oPOHZ2YpXLpPu+mMHnVU73sniC5SlWlHyA1vw//ZLN4j9k3WXaMemfgayO
S9AfXrRPNeDG2yZM0J5M5N5TyDfmfjn+/tPfrb1xZXKREeqHR2v9UmPbCrCr
jSP1yaTwfCGlX/DKvhuH3Z8fu/T+NpyDc3tn/Eyf5ZOlf7F4hclFluBR2M+5
ubuz15HqrmKqrw/hXE+W92cMhYQ68tFc+hjNRziX1JX0nMEsvTDBsAz6ycPh
BP46odjgU6yOrOLzFtoFCwE4Z5QdXrWIyEVU7TxGdGugXiqvHm07uKsNKVCb
chdUhTyzQvdAM0I+hJAVs5ve0oB8mDWifc2oaBJJUmPjcGSF+RL9Px/qTxd+
R1gZXRDm4zAX4rDlY9Ed8SQow/OSp0XpkF8t9igNiL2mRneJK6ScZoL8So/G
lUc/ezd6Qq/xxVog1K98KmQGLb+woKftQvA9G3A+ODNVLkcvcgB9c+NjT/lu
2Je996b81FDsIZSiwu/BbVnob1dOS30s08uL/pBlrXupBPsWWzV2C+uv8qNT
+4M1cv4zNxSLnhfhHBVGG0LWuG83QF1rtM7M6MdtUbSCt2JoyVcK6lHo/ra0
JDHU2Mv44YCoPIHH/Ow89+C3GLrQzd0bJQ5512G2l2d/G4mhbFcsBEyfQb2L
9UPfvGGCCHr+YdcXzTk1eP+//cSgrxjgoFcP9OyB6yDogwH9MAAHOeYg1xzg
IH8T5HECHORGgRwpcF0GeQcg/wDgYE8P7O2B4wB/OfCbAxz4ooBPCjwvMM8D
8z3Au4AOBXQpoEcB/gT4FOBRr1Ymw8sFe1Bwmym5haMlr0zII9/h/j9OjJ5z
+4TO/vWD6ZB5PIr4UIZrRJZne+k3EfuMCTI/TKR0k/GKG4e0eoMKiByJxo8i
r+d8Q/H97fHc61dSiPyuSN1TkjL8Pvh1KSHWS9djidzUhF4GS5KbbviVm336
p3huE3n13OsPJnjJnXH7Yj3KW1S+RE/QGi1bG/0+W7yH/ecffx3Rz6ioc+uh
n5oFfql/TpDS3pmYbx652nVjtcYM32ziMPTqsSZ0MFrvPF39TkPcFW27eUTB
nNDBHovWBR7YdwG36/JKnx7TJ3jX0NftVDt5tHHfeOtP+xo1CX7l/Uix+IOL
Ot6PJ5Qxb5wl8PWofLvUYGUcT56x4lKE+4zmo9PH1KxP4Zke5+xnzsK5IfuZ
1QO/KOXxe06dj9mdYH6XQofSpY00STzgG7/36AHIr2j2o7JCbmJ4K53IqV3t
cK+QmaLkUf+Ho7h1V7h//mGYgxfXUepx7ctBvCinaNdC4Q+o8yy1j1tFseIK
iBrXIC30qx8g/91T7USPu5Sz9gUWw70qxpDSVoaX5Pir04wp42RwnsJuxsLN
SLmCPZHNePbCAV6PNhS3O05VfMLOCUixNWxAHeDWguyBioJ+7MrEs6ioHngd
b5W/pMlvVoG1eW6rj56Cc6ux5jsGRlV6DbP2NvH/sHHivGimCKxl8QtC8N1m
QoppMM9c0Ay9d/CxEeaWf01fQiX1//ErDSRL+LFaeIo9gb/5OdzFunQBozpc
wS5HbQd1tm3rv4RpL2CXGCZ6X1hAH3sm96HGzV5hWVJhH08nqUMwp+gKRe/t
BBfk0gE05v4B6LcpmTYRzz8ciqiXPMrxVfMj8E32KyfzDycjrEUM2ao34PXx
A+9JEqqKbGR1v+JhSS6Y0xUoTpHPeKUEOXPzeh+dL7zOljPXlDZSViHnG2U+
/+mdBvhXble+2/F1iLCrhnHgYaiT6GlGrEezNyGvRD2XzjBCnxLjqOryu5Um
xCw3nrOlHM71NE96BTv4NiNI0uDu/Odwrifquj/FiK0ZMQ1KV0x+C+dx4mWB
FLzKTQiJ/7J20lmoS1jHHXjkvVCHPO/paJv8Cj8nL44+5oi7UIo4drG9+nwR
8qgt/1Uqcn/d7zprL+RFQL8qJFu8wlkN50fdr6SNFYvLMem9304f34D4ucoU
C3YxDIt8/av1Oy/E+14KGBf5tWDrY8yF6+nw/6bQ92+rpm7HROJOSz/agI8z
/8uhAubmdszFYe2WPyl8XjqlR+cqrNuw8eqfBspOkF81vE/sfG3TjAW0jhSm
74O5uzuszNDuo3UYnZy0RCU75Ff1j4f5U26WYqrMzBy726GfTXL/x/ni9ynY
xxWK5eht8PPgrm//K8BfQtb13qSBd8NZgkdxT2g0PL8djaykaseLxUN//jVB
9k8/L8cg3E+u7pX6CufvMj3ZWh2tzohO/ukcUyXoS2dU+6UsrBSG6TmpFVYq
Q/yXiXAqj2M89uMWz1r8AvRJypyk0Ds4bylbxfb5anS2LMxNfdl/RtirAhlk
8h2SWYK8kTKVNelP32S3Fyed/HHIVxsl0Zd3E8aQZ7a1LldSXhG4k8uLaXuH
WWSzL8Qu+xL0q0cUjhrOrvxAKvRVRmsOzhP4y7huZ+9ZMjT2rDFjphucDwrO
xUw0/d6OTuepSK+fgXkLclJIg+hZBvRogcwNHkWYZ7VNJ6W8q4oFjTYVKL3L
DHsP390+cuHkDQ70hv64EdNL2LfInrrLUquQCx1mCyjv6Ya6VrOEmk+vLTfa
IJKUPv0a9qG8mznVGfyQB9XlGL6WygJzJmtoLrzm5T6CDvFsaoU7ixP4kECz
uOWdI2gErkb1wwnyriff6MjHo3jR1h37xgvood7l5BOt+fw1N7qtxiT/XjKc
M8buoqZ7xsiJDjBk1IgMQ3/X1UGfVqNTDOiNjvPFJ3igDgb6iUFfMcBBrx7o
2QM46IMB/TAABznmINcc4CB/E+RxAhzkRoEcKeJ9+Zt3APIPAA729MDeHsCB
vxz4zcH1GviigE8K8AcwzwPzPTDXAzoU0KWAHgX4E+BTgEd9KdHbtv3YGApu
c5+v/ou/GPZ9+/bXDH7gQWG6i9cieu/v/uP9d3nTF0KacP2AkGiKgqdEfldH
tcKBszK5uFNByIN9AuVEbmpGRl9hllI8zuUYcqGfLpPIqx/xJnfrqAzB1XjZ
eXYMxBE9Qek9od3a/L54cRzX3QSWMKKfUVYqbtBzwh3/TBqmPcnvR/RiN/xK
2WO/ywVfOxx3JVXRg9DBqA0eN7uo2uFmpRruQyTOKNg/DY8XuO9ZaIFTkJ5D
fLitULCvmqJU6TDoYIb7h+QKz8WbELzrWGj/i6OCBjijuB/DwoIOwbt26NB/
cu/WwT13BnYkIeeI9yvB42w7rZUGbrnUzVCdDeeGqXsO0BRFKuPKlvnHON5D
fuXPHMtZmqSIr5cma9KdgfrVUvHlY9evI/j3wJwhiRHob+fuP+AjkCaBz156
nRaXB+eAsq8dVoRfCOH+d021yptgP7WD4HZunmOH8S66AROhwPcEvvhS8vSb
r2x4x7nNIVsKeN1xcb0ykGGxGw8QMx0+qQFzCGfHrc9Xc1LgjlcveWdRfyBw
W2NzvScr37HYvWO1FWywx/ZZ2dJavf1HjIaqEknnhzk5N4qqf+amdGBJjwQm
GP8zTykIHTrZIeTckOqWGnHA1Y04L1iqX3i5TuUishtkudxmcG9ddXuiH73s
PeT3xcZ9g7Rw/53KY8boy7NATLA+k2V1BO7Rb92S+AZlek37ON0kcJDPECNn
tXdIHeKi44ODx/XtsIO6IWUoyXUC3+rHscayXExOR405EvhI+puEbDppWZ/8
gSJBGmHi8acF38pN9/NEiqb8KHhnYC7EUfocbemCGCTywxlp+fVQAo+rDN/j
fDANedNzL3v3APThHOKuk7sUkYe0PmetkoqE8xeLxHcPlvnKkLSrHXfTySC/
Kspd5XlAXY14PP94J+Q5nAPS8j8MP6Ffh4g9XmV7MQKv74NFLHnloRgi6pPx
aM0E8ivDvVJPkzUbkchtdfOS0ZBfSR29J/uFCUP81bLCvjtBfnU5fverC8J1
iP4Jxkf8COQh2vSf5//kzBvGi4a3xkDeUsgxlObTlYdwSRl7aTVDHWmLX0Ui
QwmnjkvpQH4F8q+4E2/of2GCn1uj8H1qHa2l2NRIiO2HBXj/rX6cOqzPNZPd
khLio6/Mz3e0NmEO24MendCH/3damlzrD0+aP+G3EIlDnW0X80sWseMtGMdT
g4m3/vD3Qnfw6Z7aO02Yv21P89gj+Poc1DqTyH+3DnO/bv6tdRf0F2Vfan95
a6kMK4/5FbjdHb4vzFalh3byZWAU5mJpJ35B/efkkVubP+plZKsYSgw8GjQI
HnXq0/WyT6TJiA6ex8b0DubQbprVfisly0RKJ1mrmZ7BPcS2t9Ltz189QEYW
s3f+OAlzKrTePSDNOBiMlFzqYi30hn7IlbWJf3hXDJal4DygGwh/Z9HwKzuM
82Rj/SQXK52uwtzaguK7bI08OZgaN02Kpx3MYRtUKnhvT35V1m6sddpHVIk4
L1IrwwL2HGlAHqDch5L2QD/bNP/9rpOCL5H7Pw3JQjNhr5avuhW9/+0JRMf2
7OLHb9B/9eTDmSM5NQtIH6mk5HD2FwIXdj340ST5F5KSifR7n4f582Lkp3bb
/SRHrYMfmI4JwX7GwoHpysbDO1BFAVX0TDYVgXOxSnFhEbvRH0clkvjKYN9i
5I1R4Yd5e9D7F8gLOz7BvUJKmcOPEzJY0TmXeGu5jP0EbsyeFrZKw4FOr75k
N9+Efq1jr3NHP7kfQMkevWQkC4bzxPT289Qxgpzomu9XL65x2J/CsO1Z+XXx
A2gPU06dmQ/Uu0Y6hB3cUthQ2jROh3A9OGek9HvUUsC/B93MXv5IpQP9XUyh
z3lG7KjQfjXNj7/lIB9z1Xoz/Wfv4zYDb4eIHdxnTKA7vv5rZhd+2tP0svUr
yNNAPzHoKwY46NUDPXsAB30woB8G4CDHHOSaAxzkb4I8ToCD3CiQIwVwkHcA
8g8ADvb0wN4euF4Dfznwm4M5I/BFET6pvziY54H5HpjrAR0K6FJAjwL8CfAp
wKP6fCurjTq+oOB2JGn6X7zfgv3QiZQVnH3E0TS3cA21+pv39WZ7AFX726c4
TVj3A2alPiKv/lTyOpMXdymemDkcTqpZTfQELZn60Aa9ScXP59tUjwxnE/2M
+7A4uZN1MfizDa714vYEohebVurs5XPsQfiJPfPPqzjDUZBvFsusRdreeRNn
23Se7CXxQ0Eeml38y1Paedfw9FevbdMX3FCQn3bnt6mZao4TnqHNvipZ60D4
wVRJq+bUxaxxVHeK127oEsG73NKfp1Hj5vjYi2eVXpH6xJzxmmakeN5xQ/x5
TNFrzF2d4F17ImpX5/7hXcc619WV4hXhvmRudFlgoDou7/n8uLc5fN/vvs4q
HA0/gxehzWVttDCvnquC+95DRQU82fuYbdI7OAfsr5BS2ngsiZ+4eePCriGY
t9B2gXrT6IgovnUdhHl9t2j2PKCZ4cHPP9pxvEIJfv88/xFjm3+QA0ec6fxZ
NmAvxqbLq8x9WrvxhSuvTa1kIW69sCk1VEGGl6S8jzYynyHwYbecbUJyC5h0
oEEIzXa4v3Nqp2rEaO4g5pNoT3JBFOb1/aKVc8zl8W+Yqh21V4m6TZwX1YKB
DwNRHKEZ0BBAU6EfvnsW9ykeqEN6La5e0i2EOTkLLKfIqz0zkbXmEJttVS/g
9eL39INv+ZnYGRbOyikL2De3deuLdOU21sf0wfwBkN8eanTqe84emJOQEXBn
TnvFBXvjalymohFM4LaBPUwNPB5YSfHBvmQqf6iD/duPcxWj2JWtPxjuBo+T
1KxVJ39SViImdfy6gwTxfF/TGGYe9PBFJD2TNkwS4X5ft/mm3lvyOCReTCus
d89//FelcWY6KxnIBc06GVsyuEc/7u7wlYWpAHH+MiPN9AL2+Px+e1eb1rgM
0T2jUCKiDXWDq4IL3Cf1qhBmoX11ia+gH3urH+cx0pmiJKzPBflAXkilT3NJ
DWJkVSWfFQ35cDMn7dczmTXIuISnEPki1DOlvW9KchRVI1e/Wz459x8eYhTE
1XjQoxSxbf7NbjsJeddW/2AWIhDhY1BT+595nGbmy6FwT+Qcb5vo8iScH93V
yTSzRlMx00DOz+dSIS/aym8vxS5aFum8NYN40XuB9FnFx5hZVPLVoHPwOFv5
DA2Y++9JufNmkEe93Vka0vsYxyxEFUy6yuDj/+ZPveO+Hoaxntz5glocPt+Z
yP5Xf3K34nZ4nKq+DfXYoIN3mMO+lGES9FWBb+egfkh1vobhmnQm9n535/az
HyBPPnqW+fObQVTWyprKrD1Cm+BRdXco7nz7lob48na/eX0I6k58H3GSgNYC
5Pz5NA86d5j3dXHQQj6fvBj5JEATddcF7ufKp+lZ/eHnJSp2hypkYU5X3sX1
pp30CQizm/Oj1GaY16pzqfQQWh2FvW0TEA39CvMQZFy917tLCrDpUkSDLgPi
iXofM7gFK7C/nxMCH87ibPoeVYpRJ3MkX8Lh76NdF34aiZ/zlJWSVJvZ1FUj
zotOLfLU39QtiH1v0eOnJyFfTaYquu4rNITInDpU8b4c9gQJyJJp0EpPIg4G
QjfdU6GuxTmMRJbuWEIKWxj9LptCXYv14UfxWPl1RIBKkYn9EtS11BPWy2W8
ydFivs+hGyVwr7DH+KHutDwN6l4Te+7ste0EfsmoXJZ9zy40OSv1QOYeBgJf
qXVKkeNlQPvbj6mR08J+HKNjwYcuHmFCh/rxsm5W2HtyH/vpHiq1B3Xv8vKc
z4K8yzi72iBhlgnln+r9oiEA9a765EspLeMM6MFnl9/9ZoFzxrwEsvs1TbSo
NvPv7aJMkIeo+F5+smBKip6nUg6kDoN8rMTEpD6IswaJOEnX/qwO7jOGdZ4S
EJIjx6OFOJhIL0Oetm8biaNwERPeqV6IyYvBnpf+xF65ZOMD+FHBnRcUW+D9
QT8x6CsGOOjVAz17AAd9MKAfBuAgxxzkmgMc5G+CPE6Ag9wokCMFcJB3APIP
wPUa7OmBvT0wHwT+cuA3Bz5z4IsCPingjwLzPDDfA3M9oEMBXQroUYA/AT4F
eFRuRuSJsK+LKLhdl3/xL95miZWZxG3iErMXJifpSeVO/s231+fvmbU37MPP
HlUY+ur0guhnpFt/8NKprBLvpvEzucdaS/Ri55wtXzRPy8TVPYskzSRzUZC3
f9+Xe5NfJQ6fkIiXvLMjEQX5/EYdBvaHhkNwF07vkeV9YSjI8x85EmgY5eiL
FxeuUeWw+KAg/3/jnW7LyIA7Xk+efoaPzBUFfQG/lMtbPEyccX3Lkoi+a9Yo
6BfoyO2mjp6zxk+LKRWstBsRc8a+/Y5BG3nmeE13YmeFiibBux6zkzddZDLA
PZvJdE1/QX6FWtaF7+LVxt9yBT/6EiFB4IfOmE6EPFXFd0rGuvt5wNx7r4Oy
P4SeKeK18ktWnf/piba60ySq5SODxyTtk/spAn//5ia7Tq9cF8MPqacfSrkC
/QY5nCpylXW8uLADxaMuQ/i98aNTZG9UKTs+clVXkO8IKYELP9/jYlW1C7ff
fzH5WQjsgY03+t64ILiJXatvcMpdgN9XZl0kSE3FBCZTMF5z+xX8XXkj4XNe
xkhsQ+S1m1TR5QnEeXHLIz9MX6QPobpALpmTC/cN3dJ+HucV7Ed2k+2IfWwP
fV86PCk023+1IRcnstgtq2AuxNP9NxPomhORMRa60IsTEJd16Dji+KAWM0mk
YVx+DueeW7e+SGreSN0yH8yD+pvfjpxLs6QQzIC4gEFr3L4lD+x+0S6a0RW4
F19tY7vR3uqL2WV2FNKc/k9+FMOC2v1ofyzAarSjtgDytzbH8AWawuuYJivF
+4DgGwR+OHDILPGjkuzQtHtUn4c08fqsHLyz9ykagHg9VrCXoYR+LZOR2uvT
rgnILjtswUYF5j4lfza+e9c7E5l/xHlo8BP0ZRnokJ5KepePSMYoMGw+gX7p
xKbLxk6SpcjpElGk5yX8/KT8sjlW0VKOtGt4kf2OhLqWhsIz23KmSmRpxttU
PRzyB4Vw03t//GBuYXGDiR7Ql3VEUSPCEi1DNBJ/WxtRwXnZ1nywALl0hdTg
T345wM3vfnOgnElG2M/r99CVwjnRVj+OJtZbZ65D+hDysa38q3RsQHzP++wl
iF+NW8dEBYsx7oarTj/jIR7hf+ncrqEKrGWww8NQAR7/bfMTq1brx1hpo2Zy
ngTU3+65P2prlKjBElbZxozs4PVdj2Zkou1eFXayvspD+iXkn8a/r0Ye8yrF
rtdfqz00AHnU0oJJFVlfBrab2z3vvQic5zqRrQa8+oLKsiV8pIpKgb2T9xde
ZStNZiBivwxe75SFex9xLK6X6H1Kkd4araBj38sIXDq6pWcHRRVyJW7/oj8/
zJWatEltcm6sQvZFz0nNDUK+ZJPot6NppgyRjBJTFNkD+4k6VaSn3GWykL+v
M4Gb+4okV6X5YuJJD4t7zGEOlXmUAC1dxiNMSu3+a/VZiFfMsCdmMNViwpbd
Rc31sM8o4tRu7wkFDFMzNRu6SAX/L9WPU3zjztWY1uu58Y9ScP/laLyi2PEu
H1kutlxdVjVNmJtqQaWYTtuOSDD51EQ8he+Xr9VjNd2it0gXxcjXq5HQr+US
9GPmwvkpxNJO9rl20Wf4uZVxvzXxexGxTZNWu+EAfz8uppmtJI6sIZuMTe5Z
z34R+JT2D7r8JFKUy79tF984nCfON/Ue2sigRNU5Tgg6aO8gcHvrHS07KWlQ
zT2f5ac4Ie8yj999YkplB0qitnC64gL0cQkqnOvU7dyB7vhhoK0swkHgdC53
H+5foUEjIzLPq7VxEXiQtnPFlDElKi/T1DtGdZjAKxeoBtvDfiEhbANz0icg
H7tdcjKc5/wb5GCAQto0NT/0t3vJvvk8vYSRiLLk7uCGPG2fdf8wfzQ1jrYf
HR/ihPldzNxzzuLqjLjkHY0PXV7w/rfZAtCbSXtxbroAatkSmFd/YyO93r+T
Ff8+il89exg+TtBPDPqKAQ569UDPHvF8//bBgH4Y4vP8N8cc5JoDHORvgjxO
gIPcKJAjBfgVyDsA+Qfg+g729MDeHtjXA/5y4DcHPnPgiwI+KeCPAvM8MN8D
cz2gQwFdCuhRgD8BPgV4VOdD72MbM6souJ1wqfkXj3jgV0qXQdZ4Wd5dO+sT
udzev32ON1ITUR7vF/jg+d3uaYavUND/KCbRK5LNUYMb0bKQtB+oQ0FfZCJD
yWLQsRx8tt2+NHcxBwX9kj5fPNvLbifgZ24Y+A4mx6Ogj1JSiFq8cjQM97uv
c0Rb4DYK+isXdWrv5ij44Wym8d/yKLxQ0HeZZ/ObbEjOA798LuSqYKsjCvox
j167nml1yBnPbSgN6142I/TDiB+LZ6ieWuEDkz8l9bu1iHliuP7Ae3shM3yE
OWPmZi7kyQZ1yswL3/TwvsoDJ1R5xQh+ZTXn8DWDSQOXYI66bXAD9uM8PGwl
dYNLCTevbhe7exrOQdZIkrPRLAS/o6Sk66EIc/Bsk1tuL+w5hr9wGvrWTAt1
bKG9ldUxcrx47DMn1doRWgInkfLgdaXZh+vE5t27yAn18PtdLqXUyjT4/fhP
Su+rNoj/Gx76+5L16wWMafFsyl3lrwReMzq3Vno8vUG8VtoKE8gmzot9ZnOn
RV6NIsOJ9BmXK2CeAz/bQaoymo/IktWZe3JyMP/BnL+85R77MBIv2z89tPKd
wKcOWDsaOT1F7BrFwnHKFQIXihlx+eX2ENv6noH58032U1ISb7uxPYYBP15m
wV6MrVsS38wvQjc72BP+B9esHbeIeAXxQ2dT6D8eccUqUwQrDO9AfGnsg6ax
QTB2M1iULkUU5joq7Trxc9/SbSyDw/mt/3WY87mVL3obCxzN9b54NILAXZuX
FHfreWNvT/N9Z6WFOUirpkJDuxVVZE+2mlYGfEOI1/OQ6KgMU14gUsNDNnSY
H+5tvSvlp45sSkDmf9C8MkHhPPGgCYfNH73LR2ft7QwLvL5v5V89RIroHWtf
/oLzRK/ZYm/uC0WIn4ddchQCecLsUuNDpaVixObfnBXIu7byRYuQvWrHs5yW
IN+4Qq6kxiqdjyivfdipPA59R1v7gxnIBV23TcFMyFsGlPztbZTjEHnjBBXd
D1AX+qtfYcwVNaaTBZCn7ebK6fNqTMXum15/dO4pxLf3P3TNP5yPbT1fiMsm
HbX7MVaKnUU3JQQfw/+75b8qx/o6d7Nq8MDHye7ZupeiuQybYsmcDraBfmy2
4I4L7reKsJiBVzTM/5nrTW0XMWw5no59vCHZf/Ig1KN09jwwcYySlbVpMzhs
uAPyKDWOtgPzopmI+OH7SVd6oB71ZvQI8/B8GRKr8q2WehjyKFlejkmzXzWI
4hV+tDfqP/mcl2kdVVkxxCdp1t/V8j/6kvLcaER+A1LBzUxuKwhzO38LMvyM
F6hBxo5LbxbfgbyopODyrz/v4wMX2owON9ir2KPw9VZm1BXEXe6MlWo23Au+
Y+clLKVThC1tT3s69BX2GhcgFD4CNg2Yk8l7L9ceiLd/lrkusNqCaQ4r/+Cs
hXsxngqUvVGerdj08sP41mbIxy7S2ARdv1yP1VOmd3uZQJ2N/hbZ9cPK/rJz
dM2cex5oQX/XHh/JkPIOZFjvzrtzHJBXs+Sb9jmdHkZIPTQVL755C78/hfZq
UxdMItn7tQLFxKcI3KF90DMmegFpbfsapCsG87K+2KT9YgteRVgy38U1isHf
rZQrWnnp+zYQSs/+oVP3IO+qfG/jFtBEgrre3Vk8wwv1rj0nzqfyj5OiMaXD
VVq9/5kzJiGdj4NIUevl6qav49Dftf5Jxq8kYxPxiP/hn38Y7i0O0/y8LPR9
GUk8V0ZrowX5GHrzmq/OygfE+9v7l4bB0G9f6UrxhFToPWY9Qe7BtQh5mr0X
47D72Bpmk76r91429IkdWWXKZunehqvu1F/cpwrxr5L7jc6T0OGMe/Uy9sfC
4792pXmm/34XXt3Hv2NdEuZXZKrNh+6noMbZL1gIZ8fQwbkeMiWxM6W0Qdx3
7U3/cgbxPoJ+YtBXDHDQqwd69gAO+mBAPwzAQY45yDUHOMjfBHmc4PoLcqNA
jhTYjwN5ByD/AMy5wJ4e2NsD+3rAXw785sBnDnxRwCcF/FFgngfme2CuB3Qo
oEsBPQrwJ8CnAI+qiP9hz1j6CwW3BgLp/+IMPYrrckMUjbGlgbUiDpRyNtmc
WzoYTbhczKVX+NILs/X77a/QAqMt3pUcq/c0/GstHqPk0k2D1qIixVuPZ0Uy
1KJQJRf/EG/AeoIpG53/y7taxSI/KnMm4s/u3/oZlHMHjfrLu3wE624bvwvD
7e4rJH5u9Ee//30dbj4p4HJr8cW5nNsnYgJciT3Hjm+Lmcbv3fAjGfJ3TqlZ
oCN/cRrTQT0ZTUf8U8X0wVhtHWKeePfe+rt3ny/jh/MLUXKnk4SuZXT488G9
tIb4eGR3W0MvH/H+ntOrvz1zQgtn67jg7XQP8pDgPnr/erqzuPD7OjaBAEbi
8/n7EO7zCUfxe/u83tb85/Mcm30z1qVcDH93AZ+8Wwd/F3TGB5zs3nYY713/
fELmNDwO1z03h/2ZTLi905rX4c/UBF7AHCDXnrqB6bhb8k5sW4U6xpHPicLz
hQ1zRnaHPSjLiPPiIj6yJ/vsV2TRc8RD+jXkS/RaXyjol+YRr7c9L98LQT/Y
07f5sUbmM4jL9gimJ+Vwn3EzN9Xl1bYPyDalt28PcFIQ+EXVt3ULe5oRvwKW
E+yDcB6q9/H25x9azzHrFppDJqrwOPzUSSzh7aPYLHXFEtvs7//hUQIl1rf8
eGD+4ZZ+5YqROoaYetPdJ3AJhy97tbGb2DI9d3qHBsQBv+Lxq0rNOQOPk2cW
9+7KwWhsJ8UD3xB26LfH1kYr+x5GYeWjNntrU6HfWM5IWziBOxxToX54pG4e
6mBb+Ve+WMzpcB2xU7Cv8OCTqMaBCVVZo1JL2gJNOeL1r+9qU4tJC0S4V1nM
VaYg79rKb49H9AR+rA9GQd7F/LHyfhlJOiLgoXPn8zbIu6ZPyRfytWQhA+f9
KkwvQN7lusq7U2smB6m/bXdVwgjyClK96pPxn3IQdalVbzUSuIfYSlmVcDko
ExHd24WX6EJ+slCiGjCPJyNbrz/UwbbmgwGIVsj4Rb1dcM9uS7/yw3LqWE6l
/IY4u16cyLbae9ixTJtf26sgfkTWWrtEIwfb1C25Qn8A+sfOCpJYveAowJ6J
1e9cOQJ9PrlPmvYY0xZig4vxemODcE7qz23q/245F/PvLRHStYK5VUFqrq8u
Bd7HYunLk8zZYE7Cg/2/S6ciJWWrIlW47vBrETyKeZNcTpw9A7m7TDpZJAz7
jNz7pn4tvClD3NKK6SQ84VyvfPrX5ankOoS3wKsjaBL2SdUaq+/7WtGElJ98
n/k1EupRpocfvQ8wakHW3m3Y8zpDXeglh7rCn/5F9Ve+3/fRQx6l8KPsyzFm
HHENOpG36yLkUa49I0d2nK9A7Cl/ubtKQ17Uu//Dwz+9Tterb29m2kC/QSr/
PgVu5jzs/LW8sTQNOK8PjaJWChfHsHXhEGyyBOLPxhK+Odxqx55P1U9N6UPc
Wyowiu7dU8zbeLDv2yjs1SoLZUJfXnyCXSte75v7AXOJydcPkd8owbH7FXz5
lvGwZ3z0ftvKA48AWWOSMM5kT8i7Hpfd93V83IHcWjnX7jYNeddrgadRZ769
QZJjZjs3pKBfdIaZP5xa8xMitks3031jksB75Q4Je818QwI1Qhcdw/7jl9CP
D4vvW0Te2p0x6AyCOr9rqgsak7GMMDwlFSkdh3MBuSc2Yw6pK4ixpniT557/
/J79dz64jFD/5PFlSoa++tlbNGfKZueRgkBKRHYHzIs419TJ8o59HMmKm491
jYHf5x+iuZxfmeRgeu3xaeNhewj8/LtI/ensaYzJcE/oqfvQJ3YLt4r4ovsT
exJEk/bYFOKeMZ/27M8mxaefJIkbmUG+54/MrShokuOazBPjcSKQHz7tGOuy
j9nAlKQersxOwflI+ZMya0G5nAbTvhMK9J/iiPfFuGevx/cYOpQqpu0lPQU1
8b39RTiOhI7nMOrmTh/35hn0w4B+YtBXDHDQqwd69gAO+mBAPwzAQY45yDUH
11+QvwnyOMH1GuRGgRwpkFcA8g5A/gHwe4M9PbC3B/b1gL8c+M2Bzxz4ooBP
CvijwDwPzPfAXA/oUECXAnoU4E+ATwEeterVtdyfu4GC2x977/yLB5qTcPk9
oGxkbWR7n/LP30la7/0XPxMaW3qq9RVeF+YzVJb6EjW5tXX8w7QOIj+HanHV
3By9grhq1Kx66/F4WV4uLG/IwW25KP3EPqajR79v4ZTHOMf1N+NxsRvV7EkS
kejZv8+Xj+PKSPpgCI4kcXnrzHuhkn9fn43FuMVyCm9cy/h3wRMKWxQHuuJ3
vhKHiav4gm1KBLamS8wTqQT4quVUbPDfwb/bs4TkUdgDxcpmZmuKTyr8ust1
iJnQtTqpUm9vHNLBLSwCVQq+7iX2Se98Fxp8LKOM7xXXPJXGA+fRKTFtB2I0
UPwobj0u1grn9Q41BVFFSyL4temXYx3ScL5vdzd78kM2J84kNXtV9jw8X5x8
JR8N7aLGJfViu1Pew/MicvwIVY3K44Yo+iuT/F1w3i1V/FptYdsq8l1Mtbon
dYP4fkuzDX9hWrWBPNoxqmN4Fu4tmld+yyoNXkOEXBZWFitgXgTbTpVbEfKL
iKPmo4PlWtCf/+TZEep+jTGk3EW39elliLMtzb/PnK7GDgSx6JpcgX2LnwPV
tjHYfcT4dax3hUTREnirU9g7KqZv2BzTI0oKO/h4tm7TsYRNO7KMFOgH3rol
8V0m7d450wL3Dbf0q8vYHnJFesrDsGe52ynOeCg8FAvX894e7Afv76Y6La2z
Eot9Xpe6dYMGHt+jL0iqKSkOu3+gOjtNC/YJfrTXG90dfRczR/fIO5yCOtiW
vz0aawj2Nxy8DPfl92i02E4o+2Gk1NRGd5Qg73JdP0YaF6oqG5rPLsLijhLv
12DZ3kthZwKQ3PZ0SmZ2yLssGnF629o7SNBmgNk//AvqSJ+d3h04fA+5z1bu
rlcC54wqyPbVTssHCAW5kRPjG7jXudXvnIrU8o20+rZDHvJ0oOjZxakkZMwl
7uceUqiDeXonKHe0xiA31SbPPeeGfCbwu+DLBDVHZP1zQ+3dGMjTjPkLN8yk
ArGVOx3INnKom9nr+9h8n0/A3tSr/qiwhve3vsX0tsc6HWN6fpdasKCcwP0u
XxPZV5mJYWy+dVJnYE7FvXimAbljGVh8EpN6wDf4vJBdjvdWJuOx793pk2Et
sBemWOaKgV3tMVnmCWu+qv7zBI+KPyDtX8j0ANmdm3K9JBjy8MK3fatUt0oR
bOrlWMEV2I+TUXHs2o/eWoThlSL3ch30kx/k3+zjPdOMcBYKU3PKQ92GlVN4
X/w//AkZ+5G9oQh7ouXupsg9oO5AjseXn5J8AnUqUatWvT991XTKK2MXpyC/
arh8lerHyRZkp1buOtdPyK8Cl3IMTdlrkZ1BmoOlfZBfCaogb42oM5GU0pJX
tXf+4+dc3dQKfZaBRY0+OTBUCvnSLbpEieX5eiyf8/S2JzbQ9xj7WLbk9KkO
TIqLJORFMsTXx3/ueEr+HAs70EtWvA3idG3FbeWh3dhWDy38v1y7W27f6+jE
oj52qXHpPCNw9W+d74zeNWIBsh9mCsIg7/opSWF4WjFA9ie7ffzp/yPrysOp
+P+vLVERQiEhW8qSZDdjSwhZskVSKYSEUvZdyi5rEiJklzUxk33ftagskRYS
iQjh9+nDe97fX5/+uc9zHs809965d849r/M655cO8bnQJ70jlbivEblYot2v
RQ95V3qf+GOl1lfIBG/pzNWsNwR+I22aVOjhKGJ0iC+rdAecM7JGUzWL7P6M
ZJxrf9AWC/0SboeSP9A8m0TYvZ5Yja0tEDjFjJBJTNBXRAyJ4lubh3OBfS/e
XME9viD19xPXY8Ph9zAD2fMWjOOf35srgsnsszBH4pvYnWYzkyZk7Mplo8vV
8Hfx+ldJvka8D4tbnSjvugZ1s9e154beOkxgMdZTRraREE/subTy+v4cdm1y
x6ybKzzOk/ajC47xC1iwikg0TzLU5Z4Ni1541DWLGQSfPbGdAf7uNt6jNF3x
PrGareL1q5wF6KelmD3zc+ELGbotdN3kRQS8X1B6Vr7eJs2K+hssiFGPwfuC
i7I//67Cg2hnG1fd/gQ4x/ntc5LNrk4SpdV0re+5AOeDoJ8Y9BUDHPTqgZ49
gIM+GNAPQ+RCbOaYg1xzcF8G+ZsgjxPMDUFuFMiRAvlRIO8A5B+A3AOwpwf2
9sC+HvCXA7858JkDXxTwSQF/FJjngfkemOsBHQroUkCPAvwJ8CnAo74LaMkW
+q2i4PEoT/SGvuTnFWT7muI5XzPZzoFP5PJ2Fof/xadlTgTa3H2B54vUPVan
7UNbGDb0NBJKgSOxXypwp4Y4Jd3AYvRV08b5cFPq2TAkp+O/31FVZKTdQ+0W
N/B3HjFdRhrROP8Y+/EGtgD0wKauNUNS2XOHKRAf0eJ06BVyQP02X59tTRN0
S/4uOMXDtdRASmN0YBO/M3nn10mXK7jzTgvNK+rShK6lVv++Dpk8j19rUlks
fE5HvI8r5RbLJQkGeMhJbZnIe4LE+x7JOKDyAFXHneQ9hQ5Xwjl4uqVcWFul
LG7VRzqSOgHn7CbkKhVmPw7iKW9zon1OQ/02loaWxMFmF35jxJ3itA/UaR0E
Rj+8Y6yvpnRADEM1YW65c+Phq/0jZCjKb8DASgd/X4jn0/UEfKRC33ga2T15
CHsPyzwk29u4tqLFd3j5Kalh3unFBXP1K3ykKHc1k/ftwr0ErpjcqaX48wfC
Ekmf4sTJTuDasjas9w07kS9RkoPDU7Bv0cHRbNsC2QfsYcargolw+Lsmuqz8
pe7FOUz3tcghfm/4OeI5kx2d/GgJO4/EzN9j2/UXv/qHR3G8qBpa/S+/in9g
X/N85G9+5Y+pUs99OfMQ8ivWUyLH//ldj+kvDu7Y4wvxWEuqIAfTGCzXT+uG
cSE8zmb/IOZnMVW6LRfef7GhYINqvnisLbf70bUYqHedkZh9KRsUg1G9nqX1
s4B6F23vAbGKqgis2FWJSiIljMDj/DGurhc+WEK2c5soJZwzzsbX5bXKqst9
+94x4eEtS7y/Tw29tFm9fJCW5+3sZsswL2I+Tmb72EwYEsgiY1N2H/bTOf96
fWCHcTQyt2NaMcU6icAf5Czb//HhC7p/uCUxAHUwYTcbtT88SoZEePDrFOQt
g4cYmh1MAxDu0A8WPfwwfwA9kr/lerAhci6S+135Cuz11sBcU/68/sdLtaMV
5CB/8zS1oDryKQorpypoexoDj/M5ImSLh0s85lpXdHP+O/x/vfSe01c8jceW
fwRmVUnA+Z38GN3DIO5IDJ1+VuS9DJ/vvFv/D/MQITkH+cLrJNYw94AxsHaX
2/MExO3tS+38EciH1+quNYy55oHnC/VMH94HyZcqkOQxfqlvjXDep2S9rzLT
uwZZsvNL8+OGOlVoWLcJ4+MGZPhyh9W4NfSHkx2srO5raUasD/o8JlGF/Krj
8No9afpWRBZ3IKFlh/yqb9sJ+jDPFoRNQcPjVR+cu93x0KWIGG1AAo8ynbJ1
gPxE82PIloRPGMI+GcW/8wGc38W8ERLuSspFeCUO7qT+AXmXX4/dU1vhe9gR
dvH6xQuQ/3wlGVarVK3EmvI+pu+7BHnXI9Yi+1XSJqy7vKZQZhLi+6MS1fPO
dmJb/U5WXlqDeOCJPeh4QA82RZHkT2IE8apCJx0Sjh6sI77/ULAw1LvkTO6q
R55vwy4N3LUYbYZ8MpdiiZ4Rx7Hm3bwBN1QgX126dF51uchXzv24bap/hybx
ubhoQtLjwVOH6F130d9aDP1dJiRTk1ZGfUjLgwN3Co1h3qnjPe4EqZNvkWR/
Sr7BfLjX4z08ErVHZwSxFJKoXBWEPopveWpa77tGECnDz4dL9kMdrD2swSo0
+y0ycnLWSzgG8rGb4ltmw+53IUVt1Wt+7lAfG5WRZD5lm4B10bIy64tDnjb9
Sjjt2cWXWJmKoNre7bCfWtupjKZp/gM2ssx+pEoazjcDLhXbtq98wZRs2Nfq
FuH/e5H7U/iVx+PYndRJjzhDeP7Ro4wvwqIiq1/+pO5OLnAjXjeRV9TmEfSL
iG52LWLeBecXCnpGp1pE6FDaZzTcN3Xg3CHRSIGZJ5ITrZbjeru0DH8Xn/7y
2EzdQwidDDO4J6EDv7e5nmWxa4pKoUsiFLwc+fC+4z/z9gvdKyXUg9xYn/87
5Gmgnxj0FQMc9OqBnj1wnwV9MKAfBtyXQY45yDUHOgnI3wR5nEDXArlRIEcK
5EeBvAOQfwByD8CeHtjbA/t6wF8O/ObAZw58UcAnBfxRYJ4H5ntgrgd0KKBL
AT0K8CfApwCPqsoOYO1RXEHBYyZX+r94L/324wEpZM8NmZ0iKxlI5Unszv2L
C6ovV+au9OJNH0ivB052oDFfN3jXt+1PWm6fL8WZpV4yPVfPRa3fbpwP82Sx
gqdcKs61fXG5+Vsk2rC8gX+U0UlxeBGOy45XRS7E30B/bL4O7sf2Lilw++Av
zk+7i20zRasB76V89epiuyMewaJrfIhBmPBrnXu88P3JqgXuURKXVuBxmNAh
Y50LGSjFDfHlgCw3WQZJ4n1vyiGVrghQxR+97Lm63Ar3PvYHRxZaq0vgc8sy
s8mm0E/Y73PoomISBz58IoPn7GM4H1R+SSX5QrC7mj9C8DzT617ic+GYkt77
zocWvR0UW+BlA6/nhzoFiotajGgb+/Khhkfwd8H8s9M1bcd2oTrMJ46nbuUl
cO9yHka2QRr0u3i5HJs8P4FfH33jXnSWDPWoCqHnq4b40a/M/T8kJxGLxcGH
1l9h3yKG0asrvxzBno3asz8Thccf+nlf9VvqL0zlY6GS2STsCQqIp3NT4CXD
b77K+z5kCM8zcY/C0AWbLfi00L7bblZsf/GrVOSOiHWQKgfkORvzQX8shVM1
Qmbt7/lgKMay5+tgqifkYz7BS9e7piOwMnq+eKH/2Yvnm9+dvxYWi53Zy1L+
DYH4JTbl5Fd9iZhRXuA4jTY8/qzSIRtJ40QsoieU9b4o1LUmUttvXNe9h5k2
OepcooG+r/xOsqY/fcb07Te95LZBf1cYy/KlutwwrKmeLKL0+x0Cv1+v/VV8
3RMLcV13fucCffXHmo1UP2upyN0cM+BOHZaAuayniyzL212RqbjL9LZecJ+R
a29nSXRGIHKq/qDMwdIwAmcqDarxuHEbqX18PzhyAupgGT9EJ70nAxBThdJa
cTLIx+TfhB1jm7uJXMkeoT53DOpjl0yNes9Q7cdoJNUfMhpB/rOkp70vWsUT
a3HTHTHigPioYViCwY07mFqx08uFYjink7k6JT4nGYbdqHwicgaDuayBk3Qi
Fi2BWE59x1LUKOwV2p77WJvnJo/c8OvVBfSLIsGjjrbTm34iiUYicm/cuMUD
9xo4cn5+/tNbHHtHTklJFPqmVuT71DVaSpCbfRVnPOZgHoLuOUUPR34MCalj
60i7A/MQfnX9eh0vX4+05ZlJJ4TA/T7J2dqLKYHNyMF7ErtKr8C8Ec/zBZI+
fm1IyaXX7Xs94Hxw51P/7j993O6KPbER9yDvCrCjC3Y41oYEci1Kad+Ec0Pp
t8eeHKZpRs56yUq/DIA+9qNXTRN+29QiriP5DI/1ID95Z247x+LyBClXqjB+
SAL5mKXzc5GS425Yzf7hlXPDUAc7PcdzxjO5HFsN/KxoEgr9WlY/60NJWBsx
O7v+g2HbIC9SF3PmJqHtxIryaT7kUUCelvVSfLlXtPc/eAYbbdKhD72YpCh/
yoc6yPd+q+wq5dHswWZbTXPGnOD53Dbl3x5P34o9P0uR9DsC8k/jvnFJRp8q
LPyCCefzXdBX72WQqpv93VPuTMH6M9OLMEfClTbHV9C6GgnxfCDQxAP9ezIv
TVQkrNqQG/JX8ZAWmD/DZb+H3m2tB3k1mE5pWTBI4K216TY0Zr1IxpuF8tFV
uOcoP+NucHFrOyJQof7B9/gEgVMNvKiLel2G6BXlqQVchr0/HStFipkL5Zhm
aX/esv8MgRdqXFxz9ezFyIVi6A4ETxM4WXKJ43mDN1iH1Vf5Rhd4fKGH0qhz
wius9+Tqxaef4F5SI7P5g+vR/tVyJVTsJEZ2xOswcE/v4F6jr4iosIbIrmzo
YzmRa294JJkc3S96nUw+HvpjI8wbjS6dY0TXoi6YV6aREt/DF8IvB17W2I/e
rfzc4NUB+9puN6l+idsrjPJOkVLbBcDf9Z+mnmiPWkii3i/XnCo0IU+7wcrI
TGWjiMYocE65ccLr80PfsqQKnzpqGHRVYUkR7heAfmLQVwxw0KsHevYIXWuz
Dwb0wwDeBXLMQa458GuB/E2QxwlytEBuFMiRAvNEkHcA8g9A7gHY0wN7e2Bf
D/jLgd8c+MyBLwr4pIA/CszzwHwPzPWADgV0KaBHAf4E+BTgUeQDlaRnRBdR
8LhWV/0vLn25YV07cg1/YF3S9rtwGZVhvfcvbuVrX7hU1YF3qnkrHchvQMub
Nnz7e5ryRE8GF+IVrlHhZpoP0ZavG+ezy2Po9Tf+BPzLitcj9TZf1GZznsjM
98YisS8QtzNcvvxl/zn01ubrs6aXSXPI1hl/N15XQOk2ggBfHM1pj/WX6Zfw
/TSzattuyhN82Je0gHu7jQFeKdDqGWMvT7y/H3mz3C7oK+Pf+UZ20CbB/dYH
FHcOmXsdxG/nBISrnIBzw5mdlDxyfW+qM25oUmfNDsKcmXaRTLvHe9Bc5iJF
sySor/6wU3bfd5oTjfzUJbA2C/dbKWPMZhxkONAy9oeloXNwL+M3dbav2LM9
aAcL17EnxdA3GJjVeXmOjg49cD7Nc4kJ9v7wRftrOp38jXTbxiZV3oB/b6TD
7uGb3oMJkzXTaR2APYzl07JNIoNrmE2kvcTLLpizujY490zrCDXeIRZ3LmYE
nmfy472TD4x24iff6C+69kCedvP0Xc6XTPR4oYcHl/To/r/4FYnPfa4hkuhF
yFs2+FU0Nh9dJGjkDHtmwd/TJl1wtdeF+hLgV49cjAJGHCAO+FWPqGJibSHE
Ab8aG3OxCGWA+Ia/PRnjWXa59OsxPB+Zyrds/LRJ2PcJxo7W71C/qlniH9Z0
uodd38PU85Ad8qsu8eEg0f5ozGdXhsgeWahrbewP3sFc6ooOi6TBviGVzK0j
IuUu2COVBYFr12GOxPa9Px3ltRXk3j/yZ+pDRYnr520h/dU/fUAFVJWfVppg
fperuXKMpLEbIrTvbvgAL8zV76JuvvXsigsSaRzzPLMB8rEN/9VlhPSI6r7g
SZg7sZF/pYY9TWBV38MO+5EF6IJ/FX64jvWScpMFcUN9ieZZTtHDWi/MX1+W
5b4hPL6Vl3t2mI4blsd2ZjIehbrcOc+h8uE2FrlJiXMSsnOSBI96/twsIOJD
MGL57sWJpj6YZ37Xt5O/SvYhwqmVqCRdCq8HneA7X7QuFCJLyn30am/hft/b
NzvpCuSeImvPXc5NHob86vCZ0zpN9TVIhQhTH00p9FldX6WIjTnXiAxaROg9
1YD5UfOKydImVq3IxnUIeddZ5S35oowdCM+ieHqTFPS3Ty7vRuckOxHcs4m2
cRDysbih0/vYODoQDZK1/goGOC+bP5JxqLS4BbGrTdQ0eAR5Wm+2f5pCTB2y
+r3o6NZu6JNnajmg/CdXP4KzeW/lEuRvx04edL4Z4IiQ3teMjTkF+Rv1MYtR
/zPFWGpXFbfeFOQzzeMUJ+K76rGzFVVcnwygnoaxbHmywtaB/Z48WJT+P3uI
ptWqM+cYerHZKo5nw3XQf0V62i1X1acP66OMOEH1A+KyIkNI+j+8a9+oLvXq
W3icl3F3Gp0juzCJ3CLh+u2QT+aFqgYsUTVhKx9xq/2c8PkWiCcZsd4vx9q2
r72IiIA5EkLHVwxKft2Q03WXYjtqDn2P9hS7Z9afliA0jxgSuV9Cn+G7/KZP
v6VrkFMnzkx3SsM8kB5/JqP+y7XIbesFQSbDfgL/ZFL32YqjEmlkv12sIQPn
kh2/AtmcrkYhUeFSg8dEhwh8kE7jqPHJf85Twz3hyDDEq8PWXenEmrAkfdR0
fQ4ex1VF4F5jSBM2/OSY1U45mJOz+6dSY1q2czW+8uRoB9UZ4nndunavRfLz
MMKZ9mWV5B7c77bkbNZaXlxALIq18s+tfiHwmEeHi2TdqNAgrUf7mlJgDwjX
3R1u9ubMKO5D3bugCfvXlm1ejGDp+9FvtIrxHF3LkA8n+1jJ7RdC8y7vPHVq
Fh7HKHRCy6hSHL2/LxE9/z/5J9H89U5GivKo/7TLxToz6GdDe2UKnAdVUAmV
addJBjjHub2D/5PajBZ67SyLcE4UzHEF/cSgr5jwRW/26oGePYCDPhjQDwN0
EpBjDnLNwTwR5G+CPE6Qwwlyo0COFMiPAnkHIP8A5B6APT2wtwf29YC/HPjN
gc8c+KKATwr4o8A8D8z3wFwP6FBAlwJ6FOBPgE8BHlU6/GLt+PgsCh7P/X69
oZtJ9gTVxS/gnQwkVYNeP9C8irZ/8a0xFn1z7g04/ZecWWPeSjTm6sb/q4SM
sHG4ZuB8bMW0g6RRaM7mPHHq9n7533PheOvjO4zWbpfQbZuvg2HaK5XBcldc
0kWXpNLqKA7mhtlBTHRlWpa47jCjxqHTagS/+hJpflTQTA9vD1cIVTBTIt5H
7yv6JYYxkjgXD/NWbmuYEyLGHv7bVvhT9X42p1Uhky/E5+Jx01CQxgketFTD
jczGC/IQcr1D7YamB1HD01lcpuoSBK7TnGW27+sB1FOpcGfeM9iTyDu/y+xT
DTd669i714e1UQL/0l2/Mi7LipbQWb3Lq4H4fNG9U1QK1CjzS1VBmUcIgX+c
K2xzCnqCVFqNXV/xgsfnkQnaIzxPjqdMu0XylMP92ceUc2XqufT4fTd/TfFk
2B/EefuVk0kPM77AHi7B6Ax52v7zu6ljo1hwxsvrP1bbIB97qXv+5Gk5Vtxy
7kPchz0Cf/GrIuwkScWDGlKoS2w8kvi09fp6Hr8B8xk29Ksk7G8c8Ktd2bYq
XvSQ52zsD8Zjn6ZPf8wJgzj99qjsP8f53X4hNkYb4oBf/X2cjf7BB1iRfpRj
CjX8fwMVD2Q0Bt/Htusl5tJ3Qj/8YY6+/qSxOIz2qvjRkPBgqA9k/NhpPxaJ
SWcu17AKQP7wZMSGLIssEDuS1EPaquNJ4FeTSvfZCThh00frlPPLYG4q77j3
raUZcblGy4LYhgE+2EPXGqvcN3wRYSykmNoybvsXv7JGPB+brrT5uRK4YJp4
gqSxCTLfvD/AIgL2Vm/kM6hjhnRu5Il5kBc9EDRWZZuzwnbIxJDVLnrB39fd
0SF9qTZYVRxJ8RH5awS+5zldxu60HXIKoReinI8LEjyqpDq4k1/VF/n5BvWO
1nSD+p6BvJ5KTzySqdLXx6MCeSmFYWRxIF0Wcr0oGVXKh/yKawuL/reyYsT7
4KOtRYFw7rDRP1iFFEgufOFVyyDw1g/k271465Bt3VoDnR+yCbyYMWSOwbEJ
yTQbcHdmzSdwJ/kz0uz2bUh9VHFjOyfkY4U7viq59HUgvJ9C7+UcgHPGU/LU
W/QoupAgGasrdw5DfSzJ2Gn5FNaB9NDrite2Q5xuOtI9m7cVEWlSzv+TqwFw
l6c0GVHDdUi4mwQvxS2IUwclL/7phbQmmffINYI+sQ1+FYV0zZflqW6DPPC8
HRlPkGwRtlXE0oPuf/IWXmt8uuQ6VIsdDKVJmsmAeb8FMV7zEUttWFxNsj9l
AZyHDvT0+9SE9mALIdFDLMuQByZRjc9q6PVhZQ127lXUkO+9vs/cG2TUh93Z
Zsr2JRDiQ83UA1WBPdjyLufIW//DG5PolbpdLduw1mfe9/WDIP98ialvP1tZ
i/VrhtDsEodz20IV7EwOXoS1raRzNVPB3FSfpG/G0ov2cl+ySK+QCIgRn4st
bVQSvCRZyDvNW/78rjB3Tni33ykLjwIkT8SueEob5shRc1bz59Y9QhqFDG7Z
acP8kA39yhmLKOWsVPeGuXAmNzTXfTnzMYf+14vCq9A/Fp/4ZHz7iRKMs3NS
OPU0PP6KCxOJbPqlal7nX2r3BtWI8xSX11sZle1BHmx9LFQQAvlnxxQlyaLr
BHJp69jsQcM3BE7+vlhfWfo38m1/pprnL5h7M5LsPJIbvg2d1TXr4Ls5QeCX
Jd7NjCQxo1KnT31ar4b4/sb9aS2zXKjPh9j+vVOwx/aJSWKq+NZDqEfN+Uds
xpAfXns86Lt+Www1ULhlIGsE9wW+5J60ntCVRefsf+mnSkE/vxml0+6D95VQ
Tvagc+29UH9YOK7x/HqrGpr67v0NAbMjBE5alO7AJa+D5mUfvJ1gghI46CcG
fcXgvgx69UDPHtC1QB8M6IcB93eQYw5yzYFfCORvgjxOoMOA3CiQIwXyo0De
Acg/ALkHYE8P7O2BfT3gLwd+c+AzB74o4JMC/igwzwPzPTDXAzoU0KWAHgX4
E+BTgEcN5iu4oPJfUPCYmfrtX9zZ+Pptu7kp3CqFtGSr50f0QtHXf/FtPTvj
qtqf4h7vdsrR0mehSr2br8+E5qg7aQJOZr3Thk3bES3YPH9R9WdTY2Ve+JMJ
x0zmdXW8YfN10G71S7EduYgP5qLfOS11iNe/lcqdNTRKFffw9zpyRATm/B8I
EhAk8Z6vlp1s9ti3bYH4XLB8aDLfbS2KWis6HVONgTml585u6VZMEkfPR9V2
mOorQ3312Lc77q1i6F5PzYy0AFUCR57Nrww8FUa1TD5Gj6HqBC5Td5op4SAP
ejqhbFEEgbijRhz6zmUXWvXl+3QLDey55pTW0M7O6URGRV+TXOc6TuCvHlG0
5EbswE9kTH0cb4Pno1zdzlDUw4IvjraUdRyD/UESwj2X945x4uc9tn/Jvw55
2hv2SBZeHm4cN/IoHXgA+Rgmv871YpIbPyrBUbF24CjU3zq+yxb6ceM/PB1I
Tosc/otf9SBC0SvWygUwFxToV3/jG48kPtRyK+Jc+6D+A/xXf+OAX9Wq9Zwr
1IF8BvCrU5VuE99UYE4p4Fd/4ynxQjaUbin/wfNKnnX+OU7B8rOIrUfg8S/Z
67XISCZg+WWRnG8D/OF9cJ1E7IhlNPbTIurWvgzoy9rIbw/GsvYXzssehHyD
YkdH9dJ+L0zxdT/ncLgjgQvc2RGefMkK64grz6qSgD1BlS/FBtdlD8hNlk2O
n3u3h7g+aT6NjXQU6CIsP7J2OZnDfkYHalP3tLcqSNhwVvEWeisCZ/dgvOgv
poANvLr9pv2eNYE3rPvXZlSewupnDj234j9P4LVUp9Y9BJZl+SRXHi7fYYP9
epP1dySkriF9hUzljZmw58gkRSzis1kYMngpmtq90At+//Me/vmxJhnBH14n
W3SFc9VtfqKihx/nIC2XKG0fb4G8N9y6bjTnZCmSmWDCPNoN9UanivKFU1g1
oiwzfqlLGM5/dS0/z126X4dMIF3CYzPQj/dV87TBVrpmZCcHt4L5W9gvs7E/
2IZ4FLhUcH6Evr7FhPRiIblOxP3ySbU5SXgcASMlv7vFnchne+3RP/sEAAf8
auP6hPqnC5MwpZZTKzJuksnzSAw+L/vx3LwArB45IrpEro/B/BDAr2rDlrsH
V+F1uCOh24KyLBrZofPox6s+yOedBJQ7GcXzsBvtOvl/9g4BXjP1nmzKoQb7
+/zjzifvDGJqxU5d13GrSXhE4PVeP8m/FXZjhreXJG5oQT7D5N21TpnWi+lO
rtz/k68G8OiI2Y66HX3YeEpPdO97yA/3yCgcFyrrwQYRB9b/zaUvL81g/EXe
sfk5hbgX34H5GzUNWFr/nrFLlPA4sTTrv3vcKjGLg6tG9G/hnkJI2x0bA78M
7HHcLbMKdfg+3tmHtDPxnJdTYXONoN8B+7NC7G55ZyZEI/W57zNSvsO59m/a
90Lub0IRvbGtZX3S0H9Y+1CVwW/eA1vVuDpWtBfuZTz7tr7WY5mAtR0NfHqY
BvaNJmk0en4T0KsuQWLV5s2PEP9vEY9wbJIpjqTVVyXOqMPnNZ7+eBb78QbZ
jR9r6RaF/EqY/sxSWPA0InVYXSrYG/rfMMnrb1Zp1hCjyYN8pDdfErhIcsbU
tevbUJ4pB5+ZZLin8CZhZLrsNhN6k859L90r+P769oziW25zojK2EuE507AH
5MAO45lOiQPo+s3LnVfvwvwxt5eeTcKMomiQRtMtq3KYL8Q7KkadeUoSpeKY
L6t/CPuJHOYKDE9tl0flnp+ylo7lJ3AB6Sj/KbFjqJtvyo3fvyC/kvEV8TnW
pY5OPhVJe6cDc+PHLJmXa2R0UIuOtIvOP2F/EOgnBn3FgHeBXj3Qswd4F+iD
Af0w4L4PcsxBrjngXSB/E+Rxgr05kBsFcqRAfhTIOwD5ByD3AOzpgb09sK8H
/OXAbw585sAXBXxSwB8F5nlgvgfmekCHAroU0KMAfwJ8CvCoQfOc5tWVtyh4
LNZe/he3dTjaHuQ9hHMMGctNC/ahftor/+KvyOkb99zJxAfTJM9QVvqjRZs8
8P0s38WhWV+cXmKkT4LCBC/YfF6Spwy2M2w9i58R/3V0PlCXeP3T9rdYXhja
gqEk2hSKW7cS19W70K+7j4oooHsGxtG4KMiLSntmsubPKKE7n/Cq7zfTI/ZM
r7MeEF+9Io86acmdHb9sAPdPyXfQZu6SRFMZuLkPihsSeAZNo9Sx+4Ko3X7q
7TYJ8O8N476Fcc3tQY9kHJt35YE9161V+pHXxcax4dM0+JykHnE+D75hplTh
e/BnprRl+C4dAjcpqStvc+HB1WrYTge2ahC4ldhi9oUdB3Fv5rYXjGHwee2S
r5Z0UhbCTUy1fb7dg3xsddLArfmmMD509MFQMbkC9GXtMm7hXhDCG+4WcYlW
SkN/l4wI529RQbxflPQoon70L35VhLkn8fXqT8F+543+wQqsuSom5kjZcQLf
8LdH/wff2B90xXa9IzOm8zIh8CAV56g//Md82YFt+vhZyH8254MKp/g/D4TA
vunNfmfs04XhFlUH2If4IcpkWMQuFSPbEuNVwOTwH371mFHjHPsy5D+JWF/1
QMi9zeflBH+Pdzvt+ef++p+/f3Dz9vlOwTBMil40eZj1KoEvGHouLir5YaQ1
X49mi1gTuNqL4IgsfSds7Nfu+9ah5gReVVGaKz5khFWHUeI5q5rwftp0Xa7B
hkEu+nzyW8NEMuJ7XveWNulQ4wHE8Evr5NFiReI6DzrhaT5wgR+r2Xo3OeWl
EoGrTnDkabm8l5W6d+WcQRAZwaOmbEeKCw6fRypCmdaN808R/69RRYjZ3l3e
yFbtnuMX6OH5P9yiEXNr113kyOmQL9PO1wk8HUl+qMP7EHnAofx+dAn2Ih1K
PHa0RC8PSQ+0PHlxD+TbtAHV3Z6kZcgNGqXn97dBHluvJVz5iRJDNl5nuNfZ
/4mxerm4Dtl4310JXFORma8lqAn5+zrpZ+o8+cfn9DL06szHrY7E62Dpc6S/
zrpj8ziwRwnMB7c7aNiOqEP/W5ey7Hb90+2bx4G+tTc3K9/h8i0IiZ6f6pVb
MOcf6Fcajt+3/fNLicD9Ld/oss1VIA1U/mazvHC/4OXodb3Yj7GIGj7cT10D
9ZkdRW98TdwfY/GRZ7sO7MkncJYfZ0jjunFs31K7u58i3Ed4u7iUGFXcjEl9
ubqcZfSIwD+KDzuL7O7a/HzBnnfTzm+HG972YFx5Q8X1PXAfduftMNoxpd7N
v4e/F7j2zEbicj2YUFvmK/EYyDNP4XfSRd+0Y0gqU1H8b8hjbY2/Job4N2KV
tb9i1VKgvy4utvntoZfV2Cdpdl76fKhbuv78PmMvWoiZHuhzFdGF/smDffjW
RtI4rKbAd4xfAvJPodtJv6rYTsgZm+InOOupic8Fb/hOkycLtkjaN8XeRAl/
4nkZCD798PqhNeanpuZMNQDn729WLBrrLolXNyt7Ofx8B3vnmbO2U0fQZCGv
xMzF7K0h3/5Nsv1RxO8m5GiFCDfTIaiXTq4JThWNDiGVy15TMYaw/+h6CGPO
sv8M8nPyCuu93VCftPJkpOOSXEUu5PvpibyCx3faq+znWEWFDi/yDTLLQT3N
IpvqtUrULrR0osVNiAH6zUxR9y1k+uxojvTlY4uLsLdIUnGwzX4bL9pM8f5B
zDm4L3mHZutSHYMQyq43KLn8HvqpNCcERr97iKGOZ/tVKxTgvrwtz+HWTHtp
FM3MFJiPhvtfKSq0bur/3E+pycY801MhvxqlbHMRPHIMvZzTo8tzHvYHiVpX
vtXB1VDS0HW3ykzY73Pi+lgKT58WemTlfQTrYw2CX4F+YtBXDHDQqwd69gj/
/GYfDOiHAXNGkGMOcs3BnBHkb4I8TuDrBrlRIEcK5EeBvAOQfwByD8CeHtjb
A/t6wF8O/ObAZw58UcAnBfxRYJ4H5ntgrgd0KKBLAT0K8CfApwCPMiqp/Po7
qwEFjzkHN/nMAbHJWOc6HI1myFKjyUbJHm7gnG4SFWwxfriUV0esv7o1nrp5
/sr5aZShezkxyXil12+TOaE+rHy/5VugLlq39OD8P/yLyG2YED/FIWSpg75a
OEJrP3KRyHmwq7Rn9z+thn6+a7n6TsuSwHV3lS243ZBHy96UvS1Ov0Tg3Q5v
0RH3w+gZg1TOrFULIo9rIvbmhYVqOvTSdECnz+R54v81mIhnfbuPGedwfsSb
ftmcwEPrSoUT2wTwH42a/NY0pgTv2vv2owkn3xFc6UWSXP405G8PtM3vM9wV
xxdKhV27eU8R+I5bAZOu5pL4o71RI68CtAn+0xR+0yRsSBLX2UZtiIVB3Uw+
+E3BruOSOOlkZoOE9TG4n6g+yTf+XhynObCIem6FvCt6Xnfr51Ex/ErPR4a1
Zqm/+BWJz4zow+hRag94H9/Ur1SKlvSSWd0JfINfpWPfyuMNcl/D+dQGv7r3
n78H+lVStqlOlNlNAgf8Si1zR/c2b+hfehOeXvmHL20c357AgX41m5fTu1vu
MoEnuDlW7uBJwjbOH+pC1Bop5ibuCZjqIfKoF5pqBF5oo/zszz6jsvh3Rusv
NAS+z1CSO/hiGHZfWI/B9JAM8T3JUy66Q37QD+MYu5w/dkAZ8o3g6hzj3utY
aop9x2qtItSFchczk8fPYVkmDcZsc5IELjYkP69LgWJPGTMHhr24CXxCsf/X
8Lv3shLMpx+1NvRUAVzduRZLJ8mWjf7a0W/B1yULcKHAqAOu3UqIn6ju3gcn
+YnjOO++zacbYI10HtBfezUuT+Dfcg9QmCX6Ik1X1hwrS9QJXO8VZdofPYXV
UWtO/q4Ggd/9FkwmovgQ2Xh9hAicX3Ks/wJ7HnKCi5lG8Yke8bqlGm3dZ9lV
ioQgD6om4hwIvDe42VH4YDWy8frA+eaxC+7Fz4drkXIPdTY1jkjIZwaro/b1
NW6eJ+xrFld+XvnrQwvCJEqaYRwN9zHVQz1lvJjbN/8e8p8ta73TBjfaES6z
a1/3mMJcMpUQ5to12zak1YJ+mncPzK8A/nZ62ekDU8IwB+yd58dErbJaZON6
hrlhU33Puzu4yhAX3i2eOpRw3rS5P4gIGTM1sYfA3P6TtL1zSWOZ2AW1g8KU
2RBPyQpA/uSXPW3y+1ZXCY9T18BSfrurcfN6hjlmGfsNIyf82rEn24XOZ9yG
5xkcKP3zuXk3VvCV8pkoNXxeJEZLq527e7APW0S0uJQg31tEV7kWbbuwyqSr
dVXJkL9J7LKuNjZvw/ruOTx1dYd7EJKvDkcnPGrAJmf1VZa3QZ7z9aim2qOw
aiyZ51J4c8RRAs9HI6c5Q4owyo/WFTya8HeQwFX0gdhoEnZ94JdfHQv8XXMo
MWX6Rac7VloW5XUcgTqwPmO7C9/cbrlqpTOvO5+8ID4Xj4ZSC659WKs6qFV+
/anVa/h5Sb+Z6vMqEBmkxcV/pMLfEbEpp9pU2QuR/DCdFVMKOPd/c6Vqucen
BelcU+jvboV+ywyHb6tDwkNI+zCr4JkT0A+ZrWse/8nuG5JAK2j7ORfmomRx
qDne8VpGFHJOkbvc6CLwMe+Ph1/92IL6Ma4lyXFBPWpWrcuokYYePUQ7OJf2
HeZXPLZ33rbAx4JGMlxL0U+He46/n1ztlqvnQtFgoTMUizA3m9JINVJY7ACq
eIxXy/wrzBfqXcJrOt6LoL3zp7TlhKHPKsX0W7WL3VF060mbWB0ByK+uBR/u
p/OXRnGK25pvgqHfpvfjLr6QvfIoQnbRif817P2pva8rEh2nhObvjnC8Iw17
Ej9sqXU/VaOCtuRN8Qw7q8Lj4HFPmFfVUK985YJRR22CX4F+YtBXDHDQqwd6
9sB9FvTBgH4YcL8GOeYg1xzc30H+JsjjBDoYyI0COVJABwN5ByD/APiXwJ4e
2NsD+3rAXw785sBnDnxRwCcF/FFgngfme2CuB3QooEsBPQrwJ8CnAI/6Je/a
Lb09GgWPgpvHERJejrtYrYc5XEDyzk3D7+dvLrJzPurWaMeXF92sMX4o4F0i
pRlB0hQmqMyjUKvhWV8U6F3VVEX46po6OkG3XXa8zAsFc0aa4Nl/eMZRtLD4
uMViuSuRCzEwIll1Eh3B0voNL2jaOhO9iibZ1wZ2MArjyPbTkQLtjsQ+4/d2
Sk3VE9K4fdHDcAWXK0SORI6lnFKioAKODPpuWzhhTfA0/ttxrNevKOGdI159
A58gTxuXCOTOS1fGI9Xmv5cInyP42Ja2dJGlRWX8B5f/1kEmE4JfdTw4XuVw
Xxk/QeKgvN4B9TFzA6OFnxlK+EIwW2mzJdTBIm+1uB5WUsRvbBl5OXgL8i4W
BZvnfYfk8bNczh/MYqDetb/biFTGURZPv/hksCAc+Y9+tc3wa5RlSQj2/3ES
nwxpYR6BUOiX3sxnQHCfB96/mCAO5oN/40C/mqX1kIgXCCVwWrmsoMHVuH84
RFC50vRtAn8kQJ7xh6fJ5e5/t0/gFoHzzcU5LZ+9j8UE6V/0lYP9OMB/9XFr
wvO0Esj3aqO2iP7Jf5h5+aKlKATyuvBW85m7X+9iYZ9pf0QfgXoI44UapkeZ
IVh5VlEKjz2c05nzc1/RX/DF9sTduKHYbEbgucGMleJB17BMYS8ti2odAl+a
/z6e1GuO8b0iNd37Tp7Af0woWsXYymFDZrFdFkU8BB5dufDy7MAjWb05ldJk
qnaCR3lHH5/f8uO97KUjWwT8EyDv8pWh+FqUrYiIGgcxWL84QBxHT8rH/QSL
FULCdMVgd6sKgZ8PiI9ui/VBriu1P000NyHwYU9trTttUcikvURDNgf0iR2x
rLtsL5WKVKsu0DO4uBD4mvE2OnmqHOS2j8O30CaokzQ1Px6OJCtBgndPST3I
h3wp2d6P8xD/M2RIOHekazvkS8Dfnt9V/1ynCepIHWJ6doo/65EFZ1bZ5FjY
W+TyY2wcIWtGbqm2emcegHwpRulgEpLUsnk+kFeAfAadkDnRz8dhfr7jStPP
xsstSCPnh9mPHJDPRN/Eex1MG5DICtHc4AqYkx8pjDIImTxHaAPGDgT5wlyC
E2tsZKqkpcie+RP6tnTQF3Qu+/WqiF0kUrjVVkjyItQrpI4JcA/aZGFbtLhs
70RCnNcszzVNpAq7+31gj6MBxM9oBbAPhDRg9tKkdzE5eHyRrAtT6rmt2AsD
fH3ZAp7Py0LXT1kdHdjjuJ05w2twj2/iSpx9k0MnlnzvyxNZP8jTmtbJ2Or7
2zfPp5zAI5L19NnmmjE93dN2oX3wdTabEeC7XFmHbQt86bNiBOduribKwTWN
ldjG9wPs/YwObXsX2ZCPDSm02ErcgNfDy+VD5Nlv72GGapRbyULg59RFHguj
bXXBjp9w/hl/xoLAT/HZrr9586tqzTFg8VZvN3H9cz1wz7Dn2CNXyDBorv+t
l8B72/K/W0v4IwKPPeKNf8PrWQpr66iXyEUeltVVz3+E3z+u17+dDtZpRJiP
xHLqYpBnXpPzKzkr92bzuoXXD7+M2LZylQnkiQLDfXaydgL3dK4r8YpfQIyj
20h0omEe/ogHyZrGXTL0Z21v6LnrMA9fNoV721LiDjSrZHDHDmmoU/Gv/Lp6
e4wRNRSZyDG/A/1UTF2fDaqE2NFyl6aiiFbYN7RkVvGzJo0b3bhOoM8qI/nD
PZ0gAfTMUfL2J9egftUQYmF6k+Uw6vKTc+fFHD4Cd8VuDTdXiqHfTPnedw7D
vux2PrFiNEoSjciyS7Oe+J+exOM9Oba2sqgO2Ufbkig4N1xyi0x7LySP0g5T
kvDdhboWfm/KkktZEf0dnm3z4JY69M/PdTKUP1JC426qNdJY6kAf9WY/Megr
JvjYZq8e6NkDOOiDAf0w4D4LcsxBrjm4L4P8TZDHCe7jIDcK5EiB+z7IOwD5
B4AngD09sLcHeAXwlwO/OeAhwBcFfFKAt4B5HpjvAZ4DdCigSwFeBPgT4FPE
571rm3f+8WgUPLJu8q7Lt1WfIzTZeMKA7qkE5zpC7woQ6PEnrfTHW2RvXWO5
k0nMGb9+sSlh0XbEKzkT3v3DAwl/V+k8l/klt0t4HBXfnvm5cMJXb7zYfHgP
9zncIzdRJrwvkNhnnFli+S1IbYoLnXZltuT2IXIktI9+kw7Zaoy/DRM9+8zf
heBpoybK024rBviH0VcT4uNORG7q3M1U9b2n9PG4NWGxVV3Ix2bsfLsud+rh
7Crh9wZboJ6mXEl+M1dNF3dITYlreHye4GP6wZaUX69p419+TlEmSJkSfKzh
iWFanKIm7vrUj+JhO+Rd66EBzGdX1fAvDM8uNzppEzh/9/el/hoVfObkvlt1
TnDOmH36mrtbtBIexvjQ7IOM4t/8Ctm3euXTcQu4p7ahX6UjmSlHoq4xwF4/
kH8VXNCdby0B5y8gX1REaVE2tRb+vdVBQ5U/eQtfv8d8oraB+AXN0x7mu2Ix
XWrVT/5n4B4c0K+65K6SHbaD38+rljs5H5IkYjSozd0QNfg9KWFGrp/New/b
V3P4M1Mg5GmfL0llmJnEYRpiJhy5D+Dv7rthuX6X0CjM4oUB4r4G8xYoJA97
6SbexpR/LMxf+h89TdTWp1eh2gvzOywS8EPajsA3+nHsMccCaxHrVXMCb9mS
JN1Jq4+9Zsl9mYueIPCAc/p12bv6ZQ/+OtbLWbZM8KiSTxP2X2N4kHsaGak8
RnLE7+jxQH/7Hf7cmNtM++l8NpTAb/YHnC4uYZCjjSlEPKngnHFa8QHvdf0z
SBrDAj/7M13i/10fzv+U6uuKRBf/HPC4AX1cvfXRP5gbwpDT0rvOtXpCHsWh
yseuM3Uf+WGWbO5zGc5fGqcft71hz0Lae38l1++Av+stavhJhxeKkJu1d386
JkIeNcGc3fLTvAIpfB9b9fR/egbTeDmKt3PgiKsg9enhJcijnlU4ubKI1CGn
T+TQtbrB+3v1r6BLho4NiOBrnwGxC1A3MDGpsSldbESCHe8WSBr/z/6UxUEV
9rwm5FOqEFf3NNSLegwVZMPIG5FtWvZCvhmwJ4iqh1spc2/d5vEhn9ma9OYX
2bVqZH7+Gf2+HNhzvdE/WIS8SBhty7SHe3Ab+e23kU9DNpwknbBH++KAS4OZ
SSbWYeSVel4H3pcTCs8tfH9YiSVz3bVaZYJ46oeRx2MH6rFHi17Cr17A49sx
+CLSpc3YW/uuKG8h6OtOYEkSV/jdisXc0g7WiIXnz37mkCtVTBvmLS/G8SUO
Pt9Cp7kdo0UtWECzhkSkG+SZ+MksmY9jDZg32QJHxVO49zd+pqXedvk5tl2S
7daXozAXN4apNE7yUBk2e22WkuUtzFVzaVyxiXyQib3gDtk3xwfnmMXdSPjx
gAjsDHlYi04pvK5+sjifUZDnq2ZzLH/c7btI8KUu774rMyYWyKTQPqmiZhfi
+g9qqRMfkjuP+TiR9ZJ2wHyVldjtvHH5J+SCC4sEfTNIiM/FzFO7W/EzycjE
1fZ3FInw+234gD2NnjaOiAvsMrbwgPqewJsz2Kh+P/Iy28U90xby7dl3zP1K
ZOPI54ECAavTMHfiouP7Xxc4fiCxO16GTAyMQL69p3NtZWUVWYw/sZ/mGszL
Mtc9rrePaSvagGzpKk2B+VpK3ZcZhzvo0MPMut/s30N+5fjYV+W40W6UbaHc
K/wk5FejFUnqFns40Kt7HbpdRKF+ZcL+JrBqjRvt1xa9wkMFe4JCKfUn74we
QAs99jO4XYL+9qVfUeqqP4TQ9AR3gapV2MO489Hy3gV/UVS9OJIxsxPODeXp
J3NM3ouh9cOkrfdaoK51bm/+kPiIOCqjd+xa5Dbol067qWk7pSaJnh+eENOy
Okbg6peyxdhHJNEHTBzUeWGQdym4dkh4nZdEVTMjngQEaBM46CcGfcXgfgd6
9UDPHsBBHwzohwE4yDEHueaED38zfxPkcRI915u5USBHCtyvQd4ByD8g5mWb
e3pgbw/gwF8O/OYAB74o4JMi+h8353lgvgdeB6BDAV0K8C7AnwCfAjzqzvG7
ma9sG1HweJd1A49ued3yRbAP77t55kWo9xDh7zrW1/+Rhj4Lv25Dl1vd/pTw
1XvbP1NpIY3CZfVXyPe7ZhD7jPu926sk2nxxUi++b3P8CUSOhFbs94e18Tfw
1WbyxyEvwon8LrPISqxIyAFPO13Ado0pkMhNNRrazdNLcRkfxAy70ym8iLx6
L/9+jmKti/iB2Rsx2iPORE9QrbS5OfnPc7jiRx+OK9wOhD4mzKl91L3xDJ6v
1Tg0MWMFezO9OCUTwoxx+msPz33GIe9iIKP4eOq7Pn6wT2KoTciE4F09+X3K
MXW6+NXWSu/5/XDO6KKiZ63xUgunzX7/czFLg8DzJG1tz1er4fc79p8uzVL+
i1/VIBE6Th+XcuBcYOORxMcigNKoPQrmdW/6r5DTUbYl3u0QB/uD/buT//iK
/9KvPLD1D9QOt0khDvQrhbhclZNZsKfGoeFC5B9elMdYma1kCflY/kkS92nl
eOy7+AfkfDq8v7+Qj51W4Y/DbApYH63XQN0sQlR3oW78LhZg9lqxYDwI/i7u
uMz+Jw9q/qZd0VsZqIN9e3HrzF35AOweMy1i6Qj3+7o4mxjCam5gjkeE7vyY
gfPKKyEJJ0kTzmNcFFwel1NNob5xN9ujgfSjLPl7i6n8sZ2EPypstKKsWfkE
knPt+vdAVn3ivlC40+mqEIUC8ju85dbJcujjQmruCp71l8Jqr2jcaus4R+DR
70dSbb9rYj+0D+7ymTEi8OrUkMb6wQNy7TdNWN7d203cXyKeMp593m2LdGYJ
ajCOXCTOc9/upNUJ+kCExYc2/oajG4GX9dW5uazGIg+bOeylUiFfvdodN6aI
pyF7LJtrjXjh+/Jo9cvPPz19Bi3jZ6yPQn8yOWuJINe+UgQPsTziawp9TXo0
8QJ8JZVISNDX8LFd0I+UlX9tPMLyOfKtycSbagfMsR8VGNK501aLzH+375CT
hXOxz+a/mBLu1iPf+b848z6CPYktl5Mz/+EnyCcltUSmIXh/XNAYiGazqEOG
L0qyXyyAPdqJH66T9erUIGdI5h0HLkAelRyY2LI+XY7s77vou2UK8pxVFcY8
7/bHSAD5m+yZcciLQD5DSxtFpvZ+2IsK/FdCtqRhd4sh3jvw7Oied08xqbNJ
h4ddID6SRpu671ItJvr2jsZX9Q7Ie3nPftmr3YjN11/1MZOF/K22X//f3hxd
mtNdoUnw/CU+ucbKCDRjPSK7tqbowOfLeavYgeJ3AzaCi5ftL4B6Vx3b405T
vVrsZtKvhKY+qNskXRXwzuatxKQCf/7U0IP5/3FISBa1SgHmoPJxvTgd8quP
R042kVLew+4bFbz+EQevk+CYqK3qx6WqS5qemOi7UhDX57IrvvVpcSCyzeq+
4l5f2MsQbXFmx4lQL8TL0rq57R30cYXp3pZKYnHErIsCIjTGYJ5eTHUWVbZU
MMbyrpbnHSncs+BnwMcGGs7L3bKqu1y/Tg/zeYZnhW+7FCC79fiu5azD81e1
uG/RJ9WKRJ6vcbBH4Ovz4XDmuft5g0hJrEv7b1LIr5hydJwZRb4iFe+XgzhP
QX6V9PIJY/nKAuLp3dTwu2ySwGVWXMPbP5OiJQnt4eKxUL86cMnmynWBbWjp
G1uBumckBK9I3/ZaRoeHAWWfiTPopoLzQUWjncuyO/agPlXZRRT80H9laNDM
M/ZwH2qc01r0JAP2MzZJ6ezK7NyPzrOyGXzIgn2LqyUxg/FafKiCzsnfcp3Q
9x425/kz1fcffqK5qGhqAXUtm5R29t+igqho+C13a/WjBB6j+Znv+YIQejTi
6imDKmkCT7RvrdhrL4zuVV3kWNkCedfvonu6tKpCqB9zFGdRAtS78tDaJw00
B9Ho1+m5wyFwzrhDKuqG700elFvVfPx2iwaBg35i0FcMcNCrB3r2AA76YEA/
DLH/uJljDnLNAQ7yN0EeJ8BBbhTIkQI4yDsA+QcAB3t6YG8PnA/wlwO/OcCB
Lwr4pMB9H8zzwHwP6F1AhwK6FNCjAH8CfArwqLNuakFY7iAKHn9FL23wwPrK
DFLPj3jwUou/09wUsc8Yt0893oi3Ejcud66cd28gciTKetKoL2g+xKesdSo0
gguJ/C53zcHmrm+ROANab+0jl0rkpooHsLNWswXgTfEF23U1oom8es4JBlvO
7254h3dG8+ir20RPkOlcTfC6/zVc5L3+5SN1PkQ/Y9piheiF+iu46tYTL6/L
3yR6sVe7Dih9vWaFx14sO8Zl7kDoYEcbXNoeDFzA43UdmHaKWRE6WJeHyHXD
mLO4vnOqr+OVc4QO9sAktDds2Bivs2tzsmU3Il5/tbMuscaH9HGDjAGOTzt1
CH71ImhncK+UDh61r3wydkHlL36ViunfCEMcheDvTZAvuvD6hUjSift/61dI
5Xkld04riAP9ipf/STllNTwOyL+KmuL4MUUHcaBfvZCze5SyE/IuI7p3I67P
E7A9YU8N9Wj/h3f9Pur9Ry975o4xv52BetdLzcrJRaW7WG5+l3fx4QgCJ72y
deoP3wsqPq58Mw/yhE7Vd7PuLkHYYPqHq2Iz0BfEMui+Nz7QA5O9ZE+lUXwD
3u9+5QpMZ1hjt3drYtzKl+Dv3/amBOqGGVlRJXK/yGOsBI8SMp7AGoNNkbYK
qt2SD6CfhI30NXn3tDlynu7WA9539gSOhuYd9T6og9QPnWQh8btG4MGpHZMs
LoqYd9mzZ6tF0H9+6SkF+rzDHOvWd5521Ia+/dsG5rszBc9jk0w8HpJXrQjc
7qrqk8ZqCbmODnN3IXle4v5iXL+YxVzrjDAa6C7V/4BzUtKFoVDGpjCk1FWj
8Ucm1BlEVjNjyG8nIRQslEuWKlAHAPmiqFTPV0FJyK/Ej0oK2hgUIeOpV3/l
TUJ+Rb3YUBudUYYcr2NRIl+E/Mp5TxhVWuAz5LD7FlKJbMivQrY96qRNwZGZ
4IH12jnIr0Y1n4/SmdQgS5Lz799GQx3mEZ3wrsypGsSiAqeUOwB1myNbW36z
fsaREXJyLicpqPPsLkk7/O7RM+SkQBRN/CvITzia47P+5DU4PXm1W4QD8hku
6pJw3sp0RCupX16GAfKfTX6FOdMvtFyx/i+/el6A5i5jEPfSb50Ju1X+n7//
8jjhE+r/HBM5H3zJgxMev09SNppksm7zcwTPx7laVr2TtgF7Nr2u5nkInv+n
jpzR+371GINCNZ9LBZwnGvLLWpbvrsXUnLIT0+5Dfa+dRIzJ4MkzjEr3iuHP
c1C/4iLpOTLv+ARjqJuvDJSDOs/UhyTaU4sp2CGv+yuawzAv10pFsZXDRqna
jdFx0PruVuJ60xSgi+KJi0EOVxysoaSEfOn5VoYZv0OJSCBzNGNRMsz5F7u+
m+SwXSQSI2Xheqoe+s+NC0vY9nZdxbaxuZw4GQ7zOr6apVvjevew8bNy1MpH
Cwk8PsSZrU4tBRsv1dgf6AtzQjhvtKlbqznIFe9Vb9vnyEKcJ/L7jb/Wywrk
ZVeqR3ElvA4/nWHfOd/Ui+ySfWW2zQa+/vVrUcoV+WPI1B0Oo5PacD4YfjU1
yyr+O5Lq8u5eDgvsbdRPD2nhCVxGTFnu3QrrhXn1EiNirW0PyFGStd5S6T0w
fz4v1p9LzmQ7qrzbobg3Bfrbn05RaWFMDChKtyfBg3onzGGgTkoS+MCM3iF3
iNbIg3NDnrcnr37sYkMFz/VWU3lAXevGY2mzXElOlHnLqK5FPOyV61YwTGE9
vB/NbHzdGuAgAHkXg4dRjxc3WqL0gG5ABOZlKWVcmKWZ4Eav9HfeuHIQ8i7/
b4e8hjm4UcWm4xdWU6DeNR+QMSA+yInOFViIubjAOeM9L7HLCUMsKFcJT2KW
MvR3VSrMWbYm7kDd9sv9Em6DfOx8eeORaJVOLIvXUtqd6ziBg35i0FcMcNCr
B3r2AA76YEA/DMBBjjnINQc4yN8EeZwAB7lRIEcK4CDvAOQfEOezuacH9vYA
DvzlwG8O7vvAFwV8UmDOCOZ5YL4H5npAhwK6FNCjAH8CfArwqMWwCzkKlyZR
8CglM7nBD1m+f3vt9QNXjaXka45fQHM2cyfW9paP8+U34DZCugrLVR1EburB
O1M2Veq5uN7Fga8h50uJvPqxH7MvQtLu4R8ulMZyJqcTPUG1L+6+dxQPw698
6+p3XYsl+hkVb0Zfa3juh3/vmPGwGAomerGl3p/LTtzihvu+M6vYreiLglyO
3qhg5kaya7ik4c3p3r4bKMjxOHFi4oPHUzt8+53ChE8Z9oRP7E4GbTIjjyXe
Mlq/ypx3keBdxYy9/l0K53Glr8Eof6sp8fqXN6Qon1k0wW9aqPpcua5H8C7+
tBRXMQoDvJH0rWY5pRrsSf/3Xyqy11T/l+mV//Kr54vc1CMn/8OvMI8+RxGH
9L/5lSt2RaDah30YHmfD3x6EueIBn//4qgAeql+8wLkvBoty2nH6j08K4NMq
ieV/5oXDaZE/XRXg/FHNIV9w50A0tnN76sAaLeRX9Fsqub0PRmK/6Ck4zxpD
/WrD334byx5N+HXzBeQJ0Vd1O7qsfDCZH8/4P3tCPz/nrthM8hdXsC/DRp3y
QdC/scuTn5Q9d0723Hr3bvp+LoJH8fUfE7khewnpu30rxS0R+mkfvDSgy1iw
R+brksetc28QuLzGdbtdO68gvg4GbP1NMA9B36yZ5L6hGVKh/arEjgLu5d2u
jpeavqyCvThzXF6QGu7lsfS2F64UWGHMyOrxMmH4910nL+BtZY6YU3OKnQ8p
PL6f97UoNP0K1lgSGflGGfIxmgcy1lSMinJyEs2evjYixOf9EBqeaO3jiez2
PDiT+BrqeLZ2R/1mb99F7hf0Hx6VDidwupER2dCeVMTch7KvbQ983/eKTbMs
XchGDI7JL1P0pRO45Nmdjiz7nyD6h6WRn9/h3v2Gv70MOdjPeHcgDOokpfFr
tBGylYh1yEDMs2fwvt95MKazSaEK6T7YY7rKAfWr73fshW5oVSGufcGPvthB
/apOa9upsb3PkMX7u6TThKCe4+U7LpFvVYYwuzjL7GqAPqiMV6Tkqkn5iNnC
TuH1HVC/+lS/zkgvlIQcU7pdXZ0B77Mb+Qz+2LvnCXVPO6GutdGPk411pr6p
EGWEfEn/rk6n2pkyrHjg4ppRLPz7p0oDe4WqqrCYW0upxdvg8Y9vb0xTl6jB
9pDZDQ93Qx4lbWap5tBeg2UZpenntcDnZcLpUWWs8A9Pk/AJHmKDr8PXm00q
VD8qsY33C85Vy2cY9C8zF2Om5WOBLBfhHFAt9Z111qeH2CSXtGA4L/TLrTdt
Kzx+ULV6396lbNksqEcFWXbJZg4nIfbZIsfPL8F8hvv0/V9X8jKRucsPDK4d
KyDwt2d37T7VmYn4n0y4t4MP5kKIFr3I8bF7gDzMeJor3QBzw2q6Lz93cRZH
JqxPOm6PhvmxuOfU/bKUVMxmu6bJ2kuIC1qRx9QM5WFyt47myLjB4xxRuboW
uD0XOyUfrOKJQ562R66w+Jifi5xNneIt7z1sxPM6QHGrOpm3BtEd3DKwbgn9
bDOqz+c6DV4hsiFkL2SM+uDrFpOKPKP5hFBO5n+0egT97fJH+3XVw38gu69l
0e36DPPnmYfdreUkfiPFY58HRwJhj6FOwZNb7l/IUTJd74LQGDg3XBmhi353
bRu6K4Xk0xtFqGux+fbmyT6hQw2vsSYpR8D+a76RSKsxRkb0xNXDN74+2U3g
x8eXZ5bpd6OK470u8oegX4tc2/CU7jEW9Pfwu/0uZHCeSMKJvMhFWVH+73vN
d7NB3vW+XHRfUijLP3wpgf90G+ytq6c9fGxnIzNKvQ+VE3aGc8bpC69TYh7T
ozy9HN6CKdDfJenhbrRzgBztLZE+vloB+VhkAqv80uEizPJujaieN9xnvHv8
uMFNZWp8meTeIzQd8rREVre3T6VY8XVu3PsjDvO7QD8x6CsGOOjVAz17AAd9
MKAfBuAgxxzkmgMc5G+CPE6Ag9wokCMFcJB3APIPiDnm5p4e2NsD93fgLwd+
c+BfAr4o4JMC/igwzwPzPTDXAzoU0KWAHgX4E+BTgEeperPoNc7PoeCRWapr
g79xCZkvFC7jQdINvoaRa6jEZs6qNAndp8DJDlyIbzQ8b6WX6AmiZGAN0Aos
xk3XAmOTvlQQ/YzH9gvuFxxLxVnn+3gLqzOIXuxk2iT5Yxl38YEkk99RnPEo
yIlN4pR5sVswCKcdtukfGw5GQa7s7mNG5K93e+Pv7avapK/4oCCHVkgzcceL
WWe8+c6ves3H11GQWxtig1ZdIHH4B3/pP6Zhg4Kc248/VljPdlnhz4TO9608
PUfMGS8gAqqdo+fxfhWf9wrkBsSc8dBeVHly0gSfbz517zuu/he/KkIyPq6d
o+2DOhLgV6Ftb0KSKOB9c4NfXUMkJj5Ykz6BfAnMB/UeT2Yec4X4lje/zv3h
Y2mK7L/kXkMetZF/FYpVPD13cSgb8qiHgk6zPJFRGEXBE00KGqiTbOSLhmFz
/+4rQJ1q51eHQ2z/8DfRbadnGZbhHPCK5qRsU70PFl8m4ilEAXM7h9SGPrgZ
O2Ap0l8zezKvErhr9qHRQ9o/Zeu7XZgOavMSPEo44zVlgZEtYp9M2m7/EeaL
jrI9FMw4cQN5skMrJ8UL5hg0Wj6wyeZ1RZg/Ffv+H1lXHk/V+n4lcyVTGqgk
Q5JokundlBAqkhIpQ0VFkZIoGUOGEJkJSck8j/uYx8iYVIiikSKlqPjdOt79
3O/93X/Ox2rf9+yzz977rP0861lr/wLwAfvhey3VhNce9TXv2q6Z4EPhjV+L
VwRUWCCjqlVSuiN+UNf6mz8oS7b3nE095Qo+n6ukc54HWtiQbAZXxD9zAR53
I7jiy3YnUvDX3pdiFjD/HnLmwwnt5c7kgDx/yZYfsD+Ko416rqftSf6V1ZZy
maBv2cPjaltyQ11p16ndKtMWW6n7gy7jBpeUKTeUMdz6utULjmf4z/6zR3bc
Rkxqjl90HgPvvb95s5P+ZALifv6WNbPqDoU/D3Ti4ZR4iE75WJyN9AW9NPen
ct266izEfmhD/wIh0F+tbP3h9Hx+Hsp3LjxYMQo6dp7HrD9nAvLRq53h+h7L
gSdc+1zngTwK0EnXrYJSRlCf4ZRTYJp9kYfSprXsGZT+Vdcqe+ogxZSFIkaU
j/M9AH5iqPSu9MyVe8htYU1MeRjwLl/7yIVP3wahvZsjbnDMAx3UdzaORe33
b5I6Z3dEiJOACzu56QlM3Cf7tzkH/34JON/5Do1LtTlk73Sn+8BawGUrty24
t6WI3BDK0tXjBu/b61u5T7WuhKSfV7Cfeo+uMnlUl5A2sTlufl+hn/U2OTHX
8UohqVGUphplC8fHKHF26WOtbHJ4MEhbcQHw2H3vne6Mbk4k6ccH9HK5kkdt
D3RolvXUD93M7p2m9FF7isMqZ9cmoKr0lOXRr8G34ZBsQcwm6QyknlvT7moJ
flwFthJGvRo5aHTzk0IpYeA5acW9Rd8kstGdxLXzrg+Dr2k6Y+CL87r3Ubxc
zNHRfPBHbbh99X5jnTu6cVgoPCIJfPI1k9y6t+UlkMwzT0b2XwOf/DiVp9c8
mHNJboM9D7NqYfuLEU3D3dJFZGRmzjxUAj6rH7vV8t8F55I8IZavHkaBP0NT
WmyQ+FZXpQ3s633Pyy+B/nt0HGmdU432dNp3XhWB88rzbTt54t4zZH4q3yq2
BfIZX7Yd+ML28y3aHbolRkJ3mMIrPjgyDWybQB+eSTsHBY7DfWxv8em9HT/R
kLPK8fgnkLdok3D/cWshI1HYfnHVLgfImx4VH8sce8BKiM5j7ZonAnqtFa6r
B9NVFxLDWo33PmtCP1H0Pe++X1OLibHPTc9PfgDeNb4ljFeHn5tInBxoZLNZ
ReHittXjnEu4CW2JpZ9LXgpD/zGeuaNGfzFxenPt/iOtoJ+3fOTnniLKTvAz
Zaa3DwIPcQ8x0cupmEFKT60npTuBjwWwlIzJBbahGgO2GeN1MM+4Vid+bYzN
LzI58sL7ycvA0zrP9YxWLuKinY6s8h5fAnl5fQa0tyEly2jBSVeDz+fA9hff
dw3UKaymWRc9vJk2AfU3nE+M84oxjnP1cM4exnEeDM6HwTj2Mce+5hjH/pvY
jxPj2DcK+0jh32Xsd4D9DzC/wnN6eG4P12GwvhzrzbHOHOuisE4K66NwPw/3
93BfD9ehcF0K16Mwf8J8CvMoxjX70wPcpgn8WiD1gL6faGJXPs+8crIo9qjP
HUblGSt6rtDUeSJOg7ODJv/w2Z8cIqJpLofI80meZHZoAe0Dv5fUr55iAucW
3ds2vVqPL4kWJ/fl9H2tZALnHKnMC1yYFXmblmyYllrvHUbgXKTMNce8qlf4
0gKrQpZYvfAhcI5SvJ3Z9JJ5brQtjJtv7W28SuDcpRFrlTeOqg60qsP3P/su
Pk/gnKZso2fi2WdsaYd7m08U7z1B4Fyn0vps7sfhljT+M8F+n54YEDgH6qKP
ynY5fjNaSti0/0kWbaquRf+eg9CRdu1q2w3Qj6PzqwtkYnDWbv1RwFeX+zyu
rQ4iRUbHC21FgC/R+ZULKegyMj2jAdvT9e2+ZLOue1HKQ9Bj0PVXXuSSYo+F
ckbwu0zXX3mR+4UnLm//AnUSi+Uh6zv6PUnnvsxVAUug3+e5lSmF18aFFPj0
k/n8FfjdF+hXtS1IsCUriergrizwDSjjkvt4qP2r4hffdW8G14lTPCp1uMQ+
udEG8SfeazG3gblyp08Z10QMrqLkBcGR+v/KiS63mEgu73dDeZXs6wNWelO4
/CwRvVrYHQU3xD+Y2Qv8582VRZ87TJ2RwllP2dlN4D9P7w/aoqvCyy7pLwL/
Sforg2tYxSW+2eXgUyQdIc0jGnSebIicfWarBLhb1dF1C4ZcyZakttWza2Ad
t+0n3Vk3XyctA31Xyr0Bf/7ajbRJRW9Pcnq+Y6itJPAxK+nfp96eu0L2+DBv
fMUJdbD+2L2k7A8tJa5X8YJ3WeSo+0nGoKrY5BpPdOboRwV1ZZgjOPWCr6o6
Ogzxcr9FAVbAn33WjibnLk9EgcnltFd5UA+J+FbtNDTyADnfMCvcHgd+C1bb
9OUkbmTMHTeoq2Q43Bzi/JSFtp+PZJh9BLr3jKaXE0vmZaNux9Wr9AOBV/zD
gY3quLMQ/byCfiLdvz0FjSbsswrw++/84B20UvxGY4os9Nce7/jonHjTBU3Z
+dx5dQx4zpx/O0l7mpqf8g7w694Xf88E3CN/Syy4JtACON1fNIscWWuoG9AD
6zN47k6v4cgjd764MWHLCb/Xy4qCsrIt8sm8LiYmge3AG3tVn+d0NuaSscZy
OgLN0D9tndQ+Lfoyg/T9rDSQog7Hbal6mt5VkQRSV9900rYNjn9dxMbelL1a
ZRHuEoH2+oMUj1oqmHPPUy4RDRa3ri/fBPlHRkGnzSXMs9H0mHPJK27www8X
Dtiy/kAhesndfNP2PuQWjWRabS1uKEZPRe/sV9cBPnNkPm8hyi1E+9KqxesG
gf/cUT978A/fLpNe/HZmCvKD1k25tn0zCUcLt3bYpxyBfL0bX9e/t994h7S7
UC4p0Al5i3XzWBcuOJBPpg99NUtZBDndVxJ0Qms8y0m3VC6l6HOwzt4dhFD0
qkqSeT4aLPxXflCZkt06f95isur7toRwd/DbX+UrssLyrIdS9ZpUVpcjoKvP
K710nmdxHfqe/+joViHoRx+teCn/TO4FinK4JRo6An7smf/8QBpte4cWrLF9
7JAM/USVK1fq02y+oP2lXMw/fkE/0VygwXjGYgot0M7Ku6YO+dRJnc8d02UY
CO+C3Totn4F3aZ9r1jHbO594LpP4y/83B4XneWxs3HqDmVgh7fZjLAHqXQNF
RXx7T7MQ05nB0zQdfgpvqhoIunKWmShqvpDoYAn+pZozk3omYozEIo4pY3UD
8IVIu5e2eDz1Bwqty3K4+AH42CPOjmMbPV8iaykOEbEtohS+L32BbK76B9KZ
fUkc+wjwNGlrpvRHRxhp94S0lPNKQCcW3HROu7h3EW3jsryCIGXAW3+92a6o
xktrvO2xs4UF1ueT/2SntI+PdiYk6e1gEuznpZdXmAxdOWm3F3Ey2J7hBT45
l0+M84oxjnP1cM4exnEeDM6HwTj2Mce+5hjH/pvYjxPzK+wbhX2kcJ0E+x1g
/wOs68ZzenhuD8/rYX051ptjnTnWRWGdFNZH4X4e7u/hvh6uQ+G6FK5HYf6E
+RTmUaw6PH3mH2cJ/JqX5PoXvxsUeqnzzfzy+mEOKdunTMpn5nK0V7g3XsiJ
7aJxO/mJqFc/IXDuNrPGIWVuopjW3FQy4vuxmMA53avq1Zx8vtyjuSa/Mw7d
co/Aud5vpV8g9wXhtMMma7XNtEIJnAN+T8y2y1zIj3aRlBmxEbxO4Nxw6/ln
vbZucKN9yjN8Wv76EoFzxu8HVD2pqr9Eu1DVwiO1/DSBc8lHTVYezee3oe1Q
nNR15z1C4BzzlQ0ZE4Y3TtJuTFZP7CnXpvgw/XsOQlcZrU6rZgDPsartEtcj
/RHBX/3Hd5rC6fk4V8l1L2KqdgoAjvuDJZ94RJO2wDr22u8V/vgbCNWfT1UP
gHnAAuMF5//UtVjyFxzu8oJ5wN3yLPp/ts/lv2zuHPdff4YrpFr5T/KOjwuF
S6Y/aHXKPEcqxYpLdsoDj+rasyH6eOQXRfkfvewlysCjznEIn1t1zxZtY4wI
exMFPIr/VV50NoMr4vDXrkh2AR6VJXs38x++h5g6ftz/YAF1J/50qXg+zhvo
nsXOPumLoMvlPvddRWDCG72TWD/v+BfwA69mzg87ft0dPWeUliq3u03hON95
zXxGBkGv/5/zqNhAThY/B99COZ3dO04ssyPfxn/WKdYAHct28bNckyke5PAL
ES2FJNi+n61C2fu2L8k+n3vx7y7Q/TLsn+e2TyeA1Ol2eFWcDnzMIGiBIO3d
DfK28VbDxC7gh9F8SexPF7uSEuLNajmtcHyUeXLtNpTtVerkL7N4w6VA3X/M
vl+pvvjOE6XXL93PkAd+Dh3y5Zzq4mHok3eG5ZJo4OFTWUGC3cPxSKj7NsNV
baifRNlvE20qvocueOzVZvsCvCvaxaDq8dgDJLiH4ZszE/CHb8tqBf/0JTeu
/91Zzgy8693OxFTbq/dR7bDuyI1B4CEifotvRQcmIsU3zAkiBtD3eWD4q2Ih
VxjaWM7R4voU+BidX5mgFd7bPs+YQr1ozr+djH6/wo6WA3hHU/nTNdl3SaY9
i5lMDgAuV7Fa3mj0IWmdmuMzaAzr8wnH65uFZJKSvd8FwwuBH8qL5R0d3JFJ
li480sqZBZ9r/ehrN5umFJK+n6CP0v789uGuJXGkYsAypcqNkBtOJJ9Q2tK3
u6yT8ZFqvdMgNcdaMnszfFVrAvohOtsYLgT1qPS1ynyFnDkoq3HUs3gv1KNu
h+jyLOMrQWufjhm1vYV61NS2pjWlIeVoaPptC/sq4FFOO5d2lxRUzH0vUF8S
ColzempOQ7s8rE43BUJOYuGao62ETwHSMTbzUqsEviRTHlKknp2EOm5tO1F8
EfKsPdSaeW6nhM7dByD/mj/tkNyZS/mkz2OekztLAZ+1tNsY31lJ3k7pz7/k
BfjL3DtjC9nqyKgdK5HaTVj/qfFU0fHAWnLiSmn8KA/kPCpcPRPQtoskG556
jz8ohzyjlBTRhD7760qc7oljFwPnU/cfjyfo8PN3dehuCItSTCHUJ4us2mY+
dD1HCReEiK2aLyh8T4u/5on0N2hezvPGOl3weci9IsxZbzaGsnq4n39aMAHP
m+HS7wr3fkPn7Q5ULY8Cv/evwasyM1ymUHnnTzaNUUbwf3hwimOI6xcy4+yb
re5ig/pPZMkgg8kvpOxSPu+wMei7GvU+qRfen0LPCJ1KQUHgIUpLxuuPnphA
F+35gjJdgY/tQHvXdC96jSwmal9b3PyX3n7PTM9pphbyS5ec2rOPwNOQLaf7
0t9fyOYfQadThEEn1mt3UEpi3Tzaj0aZZTezBClcP/hBlKEQK41B3kH8AvsK
Crc6N+0k+oaNtibK3npVIsxXyh0Kbol5yUg75yqX3rMYPi+LLTrkv6euzFZi
8PULvmrqPubjfTvj2hle4vydu+0vXDkpXoTziXFeMcZxrh7O2cM4zoPB+TAY
xz7m2Ncc8yvsv4n9OHE9BPtGYR8prBfCfgfY/wD3DfGcHp7bw/N6WF+O9eZY
Z451UVgnhfVRuJ+H+3u4r4frULguhetRmD9hPoV5FEdwm19r3jzq9RhxnM5P
sl/Uh1szl38Y5l3pFcesLGe57C/ecqrQPbr2Cc2zcTw40PwJ8dCYzrtc43v0
Hq0uoa2UEOWKW1lEMGTT98djkXjlZblkmtx6eVfjO4lE/xc6Pm0Tw+ZXG0a7
PhnnpVwSRLya411fuAUvRy31pZm9bmdIlXQl+OaOT9umcoerrK604WvbXN4w
2hJZc3iR18l1SYEXaSonPW0neU2IV3N4ybf+S4wsVrSpl5uOq/ZoU/1E+vfs
Sq7Qseu74A36JYa5fygtUK/ewgl1JDq/sia3H3dZxmoC22N+dWqIQ74rE3y0
HpiG9tkIu5AZHXzKLxz/5Z/AKCd9K8eZnM8gMNlTDXWP7PkazlqGl0mhzWdE
h/hAH8UjdaCxJfMMKfHshxO6cJbCXyjr32vz/aQ4q+/snl4AfT2Hed97wo7a
olc+az9VqoAf+zxSPvaSlytK1mzomwp1gftt2UWHY6XeSPfzMbmGUKhH0etX
/mhC4qOolATwqCPL5Bsi9weiWyeMVxZPAY8a1A18e+AfXnquaNDLhwH4zEDG
ktI/eSo+5vOj/51zvdyq7+M/fBWtLD7K9DgzCupaf/uDhxDPg9feKyRgTkqb
dLzzat0FMt4gM7qlCfBsf3tTGanrZOva2gdnvQHnvM/E+KdvFZElpH7RGnJq
NAqXeY0y3SLNvoxP3h+G/RE9GXBZfzKYXDI/I6+ID3jgrpFbl27fCiCz7jWr
u3rDcWD1KPRzU3UjpfycmbzPgE/7qt93j689t09p1DopiE0ZeJd05vy73HKe
6IXExp8G2cC73unIx5buCkX7k7q0v60D3sV5wnLt6vcxKHR5h8ybAKi3zKhc
dDqYloCa3qxxOrcffB4uRnIlHL+eiOblna+e5IP8lA8H779IEUtAFcs3BRUW
Q18s0485efvhKNRxLfDJggvAW86YZX+iafqhY47DT4JdQfel+vmIht9CbdI/
6HorUwrwtIL4Tplorluk1b5Jk409/5pzPLbhsMPyeHK9y97QjCZYp1+VI11E
8R75NI2bQ8ca3vd1VIBJXEMyeS6lwr+5GnhjR8JBue6FSaRaoNbsvirgmU+r
EgS30CJIFk+5HUXXQQ/Z255++uo3tbJrxbmGg4smKR61npHzXdyWeJRttNMo
XQB82iVWmW16qJGNJBRr5uW8AH3Uh82VHPwXS9CZkfXPim3AtxxdG6oSXVuJ
2t8eKTh0GPp6MktcoiUzqtG21+djVzhXU/gC5gGDfVtr0IOd9R5rl0E9yjmv
3M0spgqpStg8eOsIdaTfh8JeqNiVIZHUS+rTji3wfHGTlbNILQPdWb8nPZIP
eJGBsPpVsQWXyZYdI8kLEeTXmGRFiXxtySWJvocuG1ghp2ZM4LjbJ68qkpP7
tp2/FuD39su/vzHYQPaHLBfOeQbrPHUsO+h08RH5feMKJek98L6Fl/t4+2ob
SP0m2QE9c9j/z8KjNxhulpPb0ubFDjz/V9/T2cTpM4OXUtDup2cecK6k7lfP
s/tbBwXr0P67beE/soB37dx22NrcvwcJtcXF2aSBfv7ggx/Nl2Neo/2Jza9/
ykG9y3BV9wr9+x+QA3PtN70C6DP6VBnt+7lmDIXrHhWfmvgBz9FfN/Lyp40j
1pUXGyyCYG4x2jtxf5fGOFrf8V3IcpIJ9FH8k2ryK0YRo1Fdr6U16L5sN29O
ZbryCvU4V6ZM34C8nvM5y9s8MwrQ6vmzjwvOcYHufbPJi526A+T5CzYdCSeg
bjZu89TEQukLOXP+SeIKPcCtVhlGNvlMk9LNS85b5APfi749rP4y/zcZ/eh8
Fpsm7I/+pZPiQyzfyYf8Hsq1sTAvcJPL5q3ko9KygNfrWIu0Cqn7EiF+kGcF
FxthXytj0/mSkeI/TSunJWuShIgE3Ywd3/fyUXj+yoQ8/wkZgiX06GdbhdUU
jvOJcV4x9b3M5erhnD2M4zwYnA+D+RX2Mce+5phfYf9N7MeJ6yTYNwr7SOG5
Oex3gP0PsO8BntPDc3t4Xg/ry7HeHOvMsS4K66SwPgr383B/D/f1cB0K16Vw
PQrzJ8ynMI/S65US01dkpF5lWwz/4mY7DvRJ/rOdbIhKwa4eJuUzSUJ03sji
yn/nyBOah7JNmOi1TmKglL6+J1PEy9vLi2mXtk8G2mTnEf0kfX96Xtg/7niR
REvNc2kJehZLlHyj4wHTxpEcHaG0rFa1vZF5PkTB3Oednj1UNi3qTVvlYnxW
56o9cWzu+OwfmD2u7niFdl3qQgDzLnOqn/gorjlCc9SWdmrNrFu7sjZV16J/
zwyugl/Of3zoCjpwen/wOCkzHlRz5wfgdP3VcfJkbI5RjgzgdH51mrzw7k2x
vzTwJfr8oD3pe/8oixQ79O8eDWzfqJphRzZti+PdoAz+n/T+oAU5P+zhWsMx
8GtCTJ6M/rNvFE33lryXHhKm7kuaN9ZZE3fPolAL++urjSFPhz4/6IKSG1Rf
m68EfZR87krHkrM+6JPgzvo0a8grpPcHA5H60M6k+T6QN0f3Fw1GHPxGHFm5
0Ndr2yF8ObDpFkrfPdFYPAB9uht7JMa/2AWjr20bdtQPQz2K3h8MQMohrJl/
fs8xPmZ+5oL+pBuizWPKLWEEXnTyiEG7MZs5OvfK9dCoA+TTiQ3yv/6TE3N7
gMb21BJ+HzG/OnmOOC0eC7ix34q9ddVB5KIZl6U3X8E64Qm6p5h+hZL04wPv
m+Se+eLQ8jAyYIlC0IENUB8LepsyXHMqlFyzgffVok/webcpC/7yPhhIVi6L
y15bC/najJEd83fJuZELWGTermiGeldFhK78zPgeJac+H5uHgdBn/FG+a7qA
xx2V933Z6b8Vzp9XrseSjQWCEW1U0GKNIPSXR+w2aa1+FIZGdZ2NbIVB30X3
F41EG6a1Fpoxw9ziSeYwpC8VjryJ3auU2SCPZpRP7ktWSjBy2aWTJyMP9Z/w
rVtuFu1wRcGKX+VX5oIejM6vrEi9yijHwuPAf2gm26TLzW6S9xR4eXkkAT8/
wer8x59NrVIxjb0P+F4Bi2+8hHUcKfWpj6dNEHT+0fsMrC61xJBaHL/3tnCC
72UCK5fC/d+3SNG1hlF7BqHfmizQtmyf8M4yKYG8u5G3flM8aqr6bh2bdzQq
+FkU0FcB/Nl67ZmZZ00ZKO1VUEh0KeRr77O6lYmeFqFYD/u34t2Qx9exU/5N
yGgFioznv+reCP0+4QPjUrYNNaicS+SYQD3kTYvL6c13l6tHg1/5TJuXQb/v
dLdWX65zPYoxPfdZShL41aqH13nl3WpRPu/lnUgQ+MnP6VnHZ5yVaEaOcduv
p9DXuznyyvZmVy4KZG8Jq1JtpfDpDS8un9L0RId+KtquaAf+s9HcLMOTI5us
YT3Db1QCfOmSx52UDNYqkvvhGIo/CvyKk4dvN9uXRjLHXMXpyzXAv+4NOLCz
8TF5oz57j0EPrKOzX2rkoFwredv+toyrELxvj/1iezHdJlKoLiv1cwPUuxJX
NH4sDCsnXfYMqf1Mg3pXhcyudu4fnkqfxdpfnmoSo+5vuo0RsjKN1Uj/3bHo
/EXQZ7SOc7FZk9OFTGUGdlfI9FD49KhD5vVP/Uh8QdTwyPUheF4IWDusfvw1
KnpbwOh+4hOFm4e0Z4XLDKOS3Cs2tIyvFJ5Tdv1aDt8QWnNBUkvWEnRfo98d
1Zw6+5F78jN3n/ezFD6ZuyO73awZrejcecRBC+pjT9R4Y14zVpK8PlnVPF3Q
rzxrZ37tLtsg+em15b4CIeBvmTEvA43NRkjL8Rn5nlxY52Jp2bnk8THytvHX
8nEp8Lfn+7I7JkTzI+l3Y9bc8inwyc/GZ0QdmLPLdNe9CZceS6XuM183axc8
jv2N5DOe7h1n+U4d/2fOBtbZCXzEtnSuNs9hNor/6PJrqcezihJfSwwrmnbx
Unjz8jW7snM2E7/YU9y2lEB/MJfL8kVaBUG8a63+OaS4gsJxPjHOK8Y4ztXD
OXsYx3kwOB8G8y7sY459zXHfEPtvYj9OXNfCvlHYRwr7R2G/A+x/gH0P8Jwe
ntvD83pYX4715lhnjnVRWCeF9VG4n4f7e7ivh+tQuC6F61GYP2E+hXnUmlPc
lvZ286jXuGbLv3hq1NvOuOH55czrpl7xJDAqr9ql/hfXjxNcOnKukxaxpmiB
1ZE2otmJXk9jdKDRGPYX0ISHm9qviGQRYW30/ZF7vPZTG2cibfa9ul6Q+m1C
ZIqOny75YWN/OZhmVJbz/ISkC3Fr7jgEXrQ0elLoTtvlxHSyycqC8otYlI7c
Xijb03gutHCnfdak5hPp36cPOetezr1xB/ht0vnVATJC+52LVhDgG4yqQ1dM
WJJNnPf0WqsgB2dAvPTpH1zz1KDexmzgSwVu4p3+FRakV5bSUFgl+ABw3WS7
Ta42IzeWfvumdQV8m2+ub57Z5PhSsaqyRcHceRV1n3lJSgj3T51C4ov81+Qq
WVDXBT0f5yo6qZiU7qHgQOGXe6wYe894I433n4zjp6CuIiZ8+qeYZhDy7frR
IuIJ/b7T8k5LjSNC0PtbtZEz4cAT9C8reLWK30aCihbHAxShTmUmOKXgznAb
KZZ7PSzjgjrPOLLftbgnBGXfKRriNgd+9WJwpfebqCA0MhntFVYBvKVXkqfe
9ognYomY+HAnH+pLS9nnK/zzO45eNm/pynkK/Kd4f2LXHx5Lzw8HvvSQ5ip0
bZM3WTTvIlk7Bfim6s3L//Rr6d8j4Be2tH+rDA0jDV62MemTsP5sVrPenzkH
qeO58wJCgAeeeOIbm5ceQZqU32vdHgSfi2ld6OoLF2+TIXktEWwG0Ge0GFfT
thUOJC9vvIW+jYFuX7XohwrzIlfytIlpOPdvyCvxX71jQ90VTaUrpQSyU9tG
3Q+3SX2IfentjHjsu2J3/EtftzhwOdfY6xuIPFQVuaML+s5rGz7eWhwbiO5x
eknpq8KcxejDfANb25uouqPCIeAa9MtWrTY0U4zyQr3PXw3YpsCco79p++1U
ofMo2N08sawKeBq9P2hDcl5uyPfwAd+kE+5qx3navMnD23mnuO/B9hW+S8or
HgWTETLNl/Tnwfo6Ed8M2LpvkXdVhxVfDYG/weixCzrGg76kJ9s+O1Mx+Fyr
T7IV8AwolvGKxl09sHKW4lHXvWymZYduo6ajl5vf/6uO+q22MmSMloLkV5AF
ZcyQIxxj+iCLvzIf9Uc19Fmogo/B6pkixxyZctTpnbnsmQnM8Ym52L2IkqtB
3EFjyds5QHdk3Lc/RLGpHt3p36Y9ogz8qv2q1byP041ILEpKZLYWdOl3OJXT
hIgmpB21R9NJDfqDAfulN95f2IAqna55tIYB76L7i1ajda4fVlnmAj9h4Kl6
ruJVhOj3H+gbOntyDPX4RSLrWBOv7R1Q71LdEGqcN/yQnNHVF3iVBnxsi8r0
fac3FWT6lV/THneAF92P+fwqtqaRPLj6I+uxtcCjODTv2Dxd0EYuD4uxCZAB
vPhdd5GuUTtJP6/+VU9brW+kYdo2d93B/ohqVt6zmG4kdYZeyjgdgc+7M0j2
SY4JSS7g+9Lw0QSOM0Pdjh+N19yVksq53r17JUndD3/29zzM2FmBykj/OAEO
0OldE/TbpnmnFd1f42vivbGLwlMV/Q4Q8U9QGfNYf2/YAIUr53PLdwj0oAiO
b5dfpUMdLNzO6OEpvm7E//oL24s24GNRvB0je/ta0PeHrmRgIujBPC1Ws0SG
30fWI5sZ9NjB16teKaGp07qBFDRdKsLLDH6qwcsGinMFXpCnj5odqp8EXqfg
aeTDzvGKfGF/j2WjMvAlxYevi7yf9JOmjxhQUS7wkK3FChbkhqSyov7P01my
8dR944tjr4PC03FkSOtdkrT7I3U80xf06x/ZzU7cOe3XaZL/m8JzboiKs7Cv
IPKvbn/UtIaV4j9j2wqUBJTFCZcCET6B3kUUvs4s0XlqyRbi+v2W0xNcXBTO
/0Rjg0ISIr5mRR5gU2Gn8MFNTxkurlEn6PdtOB9wPjHOK6bOh7lcPZyzh/kV
zoPB+TC4roV9zLGvOa5rYf9N7MeJ9VrYNwr7SGH/KOx3gP0PsO8BntPDc3t4
Xg/ry7HeHOvMsS4K66SwPgr383B/j+rrzdWhcF0K16Mwf8J8CvMopbtCBeff
zhD4lSnO5y/eOXl19xDXvPK6fmlZi9AZQp12lV4PdJgc41dvo1l4yHysf95A
lBjTdfvF6ouNBTfk0EZ2xKzRUUwmkl7T9yfTQ05qyiaGxnw+8NKA6w1Cdu5z
/TRq1Dps6Uu7+968SCXyLLFr7vh8m2zXnP/SiZZkJPyO9kaD6PhP/erdid8a
tzOA/2CcvGrrs/gB4HR9uym5+MOxxa61MH8Xoir0mevQMfL4zqh99wKh7qQX
d1fz/YVDpLFkwmRWKfhwSo43ulzY2qkYm9ST+jiIn7pvFJ3KZvayP44YZK2j
JO6Cr2bhpsRWz2gHdHplkpdYFeSX/aJp83rZe6CxNxXh5qng57xvydmuP306
hmMFmY84wd/g9AmZ4D/+qPT9BH7leIIjMyMpDPElZX4VfgC6o/UvNyoJTIQj
77b0zlkmqF+ZCmiuaggNR+kz7//o0yg8Ycz3k6J3KHqs5RfgOgN1Hrr+6hba
OfnjHGsJ9A0LSLNzKaI3UGGChe5Ne6gzdKi7W53SvIjErOS3t70CPmYT2Xvk
peZJcpO0zQYjF+A/yQZeDPe2+JCvs5FowVvAMb/6L65Tu9/DRSqCdEmL3zLD
D/iXzHCzr4FR5HmHlZX7D8D78u6eHG/jiSa1NAffnJMGfiV2kUV3m3IkebZA
cflHffi8+lnrP+dahpIdvcFH3exBVz8/htbNYOJPFs9wVr+0gD7s8vk+W61c
rpA314tzSobBPOMnnTrFrz67lFqX+exi6pWh7p+7t3dwavTZo2UVbFoLS8BH
oicn+dITPTd08d0Z4qIT5D53rdTZUSfujvKRlIDjKdAHPlIf/7bhkRNSs1Qf
kRiEviShSgax+5uiwvwFR0xSgaeRj8MSPg9ZkQwnNewC18NcbcdP1+IDP1zJ
57ILItJYYA6X4bZWI2fWddLk+8k1hybhfQ8GBO5+r+hGmj9JnrzZDXXgQc/U
l935W8oe7uGM4cv9SfGo+Jm9K4PFglB6YMu3my9hHsF6YLnOD44kVMvz7FX6
c+DJ5D9njUNjNqrJuJMe0QK+UgH2X0Nya0sQB1sNn6ID8CuPsXtNPTxV6FaZ
VL/kojwKXxtsH1EeVoeOmc4eMN1RBPzqW/g7A+kmdO9576JBBfBD0JA6xrlA
rhn5VZw50OwLfbHPk/NYf+g3o8C1YdqWTqDLCo7aeO5qTyPSJ92z874CHyvd
Iet18GMNqljCJtClAHWwthNjvxSOlKHtm6sdnVeC/tyW70O/4vu7aNrI3PyB
LfAWhYzLG6UTk8hlsgU1a1cDT5PgiR7u5y8nZbk5xO+0QN1sk6d80eJbDeTP
h5P+IxpQN9u3oV3nDHcbOXhKgdy2AX4fpe7f0NaY10Eu3F9/tXQz4OwNaYfE
2TvIBUjY7sMv4IE+S9VHCwZaybwSq8P670FvNi3ME7igup6MtaY1DF2Avuqq
TfaDZQrFpJ6PiD6zDcwzmkW/O/+g11lpNHJ+hGfBBur+qZipwHCIvwglHEAX
3oqBnlBV1CLtlGwtMviZGDZ5AXISLeU3uNbqNqJiH7PdDfOgDlbjvIpHP7UO
zWNdYu+/E/iYTV6U2Nm4YvRpKLAjpAXyqU2nY6q0r4eTDx5/3LtuEOYi92yQ
Fyj7XUP+VuU4+y4XcHbWPBQv2U42ZU9Ml1q9onCXcCsGg01t5K6F2v79yTB3
GXDxKmtgTljZlbA3DxJ6g6n7wItwroTjuUNohelnNZkn/dTxcXr+uOvlxhnE
pfeBiWtijMI3nh+f/JK7mDDLG72b5TUN53nZEhefTEHixKSJ5lmxeRQvulrq
xy1WJk5cHHx2JesY9A1brW7HFF/aTIiFeOyx2/cL+Lblq4s/rykSwxOZTXbe
oFfUujcyPNSkSnQnMTWkBi6keNTuCgHD643ahFFuVUHTZfDBwPnEOK8Y8yuc
q4dz9jCO82BwPgyua2Efc+xrjnVB2H8T+3HifiL2jcI+Utg/CvsdYP8D7HuA
5/Tw3B6e18P6cqw3xzpzrIvCOimsj8L9PNzfw309XIfCdSlcj8L8CfMpzKNc
2OR/31o4ReDXQ8HZf/Efw0O34lOnaUvTd91TipkkzoTn/sXtKvIz5z1soEVP
nCg67FNBRKylvy/h7uvcdv0hTeGKwBbiYCThOrefBlNpV881hNB2vxqWdJ+x
J4zmPq/jltQLV1TcaPnSdz4Mr1MjCv7DrxYp3kat982p85lev1IlbQM2J2gI
Ab7pdXe37GEtcuByOvfnWsjjmzn+3c2CpkWyWnSKhsdCPsv30H3bjkrVKD6v
7Nyzd2IRdR/Y1H6g9gSzMfokecIfeRyizsNoZV1mawk7dJe/d6+fN/hK/TCI
8zYWcENqYUaX+gvAh3POnwHVqC6o8fMGflWUe5YMtAhEk451aU/9oH6loph/
x4T3NkryuOuS6AT9Qe8OpWrvHZHIe6zI/GXBDbi/yagfDBOJRgdiZvNEnkLf
cPzb6sGSpkh0/OoWg8g+0CNVCi36qJEYgZi1r4yEigAfW6eq63+SCEbnuEcW
OpYDTtdf+aPNLcs4PY2Bp9HrV1cQn2TmTXZJ4C24P/jdR21x4BTguH5lqlMg
fSEU6mmn3+1M+DOf8OzNi0C+BsCv6ZVzFxaFk4ICjS9VMwAfyjC3fb43hpQc
cV49TwNwRbHH+V/FY8n/7s+Ry40Df/K1UbLKn7kG2J+tE484q8LJD0OLvn9P
geOz76T/cSXrW+R9ztOX1mnCcbYTOKt7qMSbTPjR5yOYBt+Xx8fIplvO9mRI
ncKnW5Lg3yUex/RLJA4pWbMYG0t+EKfut90mW34V8Vkj198/rsu1w3OBwoMP
cnXP7FDb2529wk+hDsbu/lxLU+YsspyXLqv+FuYpBHfFvhfM10I8+4UkX+zy
hd+dvkPGqc9OkJ8vs8gbrwHc5cPl1et3XCTNN3xcxdkHfIlp9W63czsvkGMF
Eh7V+8EnX8wlN/0cl0TZLatbtCfLvlE8ysBt5Whk93V0M8j3yk15OA7b9Vx4
ZX/FoKZdj7az/mtu4qNqf9RVtlR0xH85i4kR9IWdmO9mBTnkIxshKxsZKfDV
JDhS/LkP0VAnX8V8TaFUuO78tM/96qxGY8wTn61Ogx/Uiz2u+VOcDei4XM23
w+9gTjDHd2ziT442/TwEPsawxNjt9q0WdEq5zTV9Kei1xtKefu0zbEF5x5+u
WeoGPG2PTtn5MJFH6JFIcg5nLOjktXVYnR7I1M3t57/qZjxkYM0l2tz1CLyO
Xr9KQXtKT9QlVELfLWvtQs942TjSQHflVbe7UGerXhnzTYmpjLx7UWTlx4XA
6+qrjxkGu9WTqSeIc6JBwHOCE4pCcz88JnP1D5eb8EL9zTulT/fdcDupsolF
cD0j8D16/mAH6TUoz7BOE/AFCZlWi462k/tqwrldz8A6Woxd8/TJZvJ30+PD
/ZOwP8WmxYa9zDVk6tP9hUt2kxR+PGtT7wlaLrlTokVELwC+rxVp34NHbtkr
yb6dlFiyXoK63+p1GVSe/ZaBtt8/GyzuCL6pspxP2FW1CtEj5yP887lgvtVi
QjtFRSMfpR+I0B568C+/3IpFPxxTE9Gj2qTtO06C35dl+H6j85cSSd/ThlY7
8juBjw013bz5uIR0HldanfsQfO8j0jcM8SIaeSWtYCo5BvRm74r7rbRuepf9
XKR8NlnMnbquWQ3my91L7kbODim+h2WgTjhhoRGlrDyOJAWEWbPZX1H4eQ5/
vvocRqLheUqwsdkIhZ/dny6co8dNCCzUcvZX+QL34SDuO3ZCK4kdcS17d3wD
/Pj33oRTH8WIrR/5O79s/wA8jbGea++6TQT9vGqj9v/OJ6cgkQI5QkTBe9nG
r9AP/T7YkN+8awehWvaIJ6sNdP4u/E1dfAEahOWW7ynmC8EXIkkw+GW3pw6x
0Mvzg6MJ+JTifGKcV4z5Fc7Vwzl7uK6F82BwPgzmXdjHHPua434i9t/Efpy4
z4V9o7CPFPaPwn4H2P8A+x7gOT08t4fn9bC+HOvNsc4c66KwTgrro3A/D/f3
cF8P16FwXQrXozB/wnwK8yhn49LMDZJfCPz6uKz7L25jGDt81ukLbeaEQsGr
nyNElE/fX9y/MibJ8XAFzXDTy7qAwWxCIYX+vrlvagx+34qnVbwdVnrf7UHo
/6TjKbWZbXUNXrQFru0mn+t2ENf+h1/pIpLk1lR9okOdJ/T5wQ1kB5qUeqK5
l8If3i6+4F8hSz5sy+J+T+6k8GnvF+uiWLMVfdxtBm6xzqOu6+lbq4+Xyu5H
Am3BQs1mWtT5OVXo1HTlsiVCG4TvEXePUviJD6uKPvo7oG9y99s89wC/Wl9f
v3FPuzsKiJBz09CF+hU939kPtXpFbwyoAD/Pj/pMJnfjb6F4txL0bQx4l3lv
xBnkEYZ0O5p3uqwHXRDmV28dBD3+6KEwfoTJX+DbWDTS/Zbq63MT/KMwv5rJ
OGK58SvwNLePx0Omj0XP7Y8XhadK7EkesAlFdrICpJYh1M02JG6L2H7YF22Y
nn7b4wd8g65vv4TekM95LGlQr6DzKzPyxlmjhD+6e4znT9i4skt6kvTPC/24
licKR//MhdoZTjPpk7A9rl8J8T4cnBKGfijdnyGa3C7Oca2pDOp4xsRgkUNH
HGmh01RgNQbruBw6YOixNpZM9uo4cfopvO/Gt5kvkzijSIJd9eg2ZfhcrhcH
e1Klb5MBpUsbdfPguD0+bX7AWPkmeTS5ZISFA45/Nk1EXWOeO5l2asGuLkPo
/7LwzszoDJ8l538KTc8kwK9+/ti1Mvldm5X0RtrGxuatpO7Px69zLotOMkZa
YyHH+R5ATtDbeX1qwsQRxPdtlVQukx2F0/0ZpJGs7E0T+1bIo/z8USSCo9WA
vPBjxdrgaxcpnDF6d92ffjdHpWaqTcYZCg8RWpc+YCpQ1rXzN19q/geKR3k9
ar/zSccJSRUJdNopwPMC6lP1Nxu5hUZKtu5yL4Tjc3lXzrLiqUSk53Z6z7k6
4OeRLPbyJs8z0S7OI54polBvZBFs/bj5SSHi615lemhpPIXfPdh5WutQBbq9
qdlk+shdOK8OKn82ratBTHkXbiY+Bz7WeE3VmLOjAd0/PiFoeuE+PKd4VQxd
FG+eO58fwO/abFg2Sm9BFhs+njP3B1zEUejdNa7H6IhwqZBTOeDXTbSe1Po+
QtdUtBdsEQN8+EqyWUN6HSqyU7xVJgbvS/dvL0c3tK4YCkwAvt/Mc++Z0TSk
s8yvI/gLrKPOfu30Hz5Pvy6AT9qN2DQMrC4mtVryBBbsAn5if8ozYlVHLZmu
tuFX0zfgk+ePsrJrxLSQb6N+Nh01gjqSZr7bX75Ev36BH54s2LRkrUHH3PsC
P6wUq2abzmgnl+/qOvZGAvhSj9RBoX2tj0kWq8cBH44Db7z0SOre/Ip68u6i
y7PP18H6/UcdxT/500g5p9+MPDKgl9tfcL6s3yqVdDYIeCUrBt/jeL9GWviD
M0oKLgVF2wjQrx4z5tyvV3wH1ctIp70IgH63LMvDocmtCcja2vrXtWMwf5Fo
I3HkQ5Mnyme+Frult5TCc6yXOcjIRZHTV8qDcxZB3azGkaU08F0yWa1ivl/S
FHhdrH2s/+oL9mUPb/TsrNtoS12n7B26G4jYOlQg5XnfkwCezM24ILjQ6hWy
vzMlKy4F/dnbSu3veya/IjPJnKoowRdw/qs/f75aiImYSY49/4RlEJ4Lzh+s
bjjOTdQ3rWNr1x2g8HfB23v7RwQIHcUzK6IP/at/N3huZckmUYL++wj5R2eC
zsk+ebyRKPikWCfdC3qwaCePPdvithEPWCbyNVNBn292dcG79IuIkN3Ydlrw
FfhCGB3RcR2NVCV4lcu226lKUbguB/shMkCTqLvpYBTQB/xq0lcgr95ClzA5
aDD57d5OCsf5xDivGPMunKuHc/Yw78J5MDgfBvcTsY859jXHvAv7b2I/TuzD
iX2jsI8U1ntjvwPsf4B9D/CcHp7bw/N6WF+O9eZYZ451UVgnhfVRuJ+H+3u4
r4frULguhetRmD9hPoV51KTmkMajG28I/ConNPYXX8zbdHO3/TDtpMKNiAUB
fcTYiW9/8SPi4Wz7grNpJ1uixjj1IwnZD/T1jWm/9sXmBNLOm4brHEhQJFj+
h19xoQHn7Da1ks1wHZn0TG07vIKUlJg2PLRQisKV+3zCnuWHKGpUxTXeeDlK
/V58v/JhcuqIKvrZd9321EM56vzUXeicFHXoKNqX3Ljkxq89FE5O9+e13T+H
ii83+5VkHaZwf/srX7/+w4fkWy5rJqVDvgw9H+c6mr4YeO6gG/yepuWWtPyp
/zxlFraL6bam8K2ccQF/+nb6BV/FFaSBjy3lUcjo/R2G2IIsVssEQz0E86v/
4phf5SgvGi8QhZwa97bJu+kMMcj4c24VKrGncLPSwbBPquEo5uOlez2+sD19
fjAMNYTcVbpdAb+njtfCNOuqg9B5VS1OwYOwDuZX/8Wx/uq/eE2gIcM5YVfy
s1bN7je5wEN+xAoH/8mzPqdHeGTxOFG4kNzQV43ECJJ+3ED/v+5z5ohpfzQZ
xm4SOI/lXz7zlwV/dFvGkVZmm3/sagP87ta+9inhOPLgopg0i20wj2mrcvP9
563RpL3f75V5sbD9yt9v1gZUhJGLepZLNzwD3hvaJ6Dj9yuIND/kZfjHr4I6
PponFLgPeJGuMpzVgoXwvZwqF6K181wmNy2/KH2/G3i46YykiYS5GZnnNDb5
OR7yGQd2schOH16jtCu5LGc9/wLqfv7tokOugthOZDrdY/r2FNRdZUZMn8t+
Z0OGpqOG62YOU/hJYjp4c+VOsmL5aTtZ2gEKP55RcePjKtayF7tEv7nfeEZd
F8c18+Ui48+gZW+EulUF4XwOkjusHtRzHX1aPLgzXQ7Ok9yDqyvR/AgUr+a4
2WDyXz4hH6zrQu7dQ0cr4+uOL/yXT0hBdya3dDaiH2fgyaZX9EOPvSpCEpwN
Qc5TwMe+8LPJhSZXIE7RPTlvHaAO5qt9xFR8vAatGvp1hnMD4O4b9/yULmhA
9PMB1lfZ5xL/JO0RUo9e6WCyGp4jVqu8EVI72vL/zv8bTQK/3MabUeT0mRVn
d5+mjht61BPBseDR3HUBcw3350fFlV6pQ1vlQgpG6iBvNGnFupC+Htrc+0I/
l6FXXkfzcQZ6Pin1m3U59Gf1TngkacoGkTIa3pJunrC9KVPZ64N1BaTJQPne
lF+gc/N1f6zEr1uDryMKZx7e7pT29RGp+pB7ZKIXrqO4DZclf4a3kfT7A9R1
d9da+2nEt5P04w9+F9u3rhJ+r9FO1iSGZ0tcAx546AdvBv/QY/JtTcf6at80
Cme/2t05f6yBzP7y/Gy4N+QEOUsnvLt7p5Jcb7DokEzJQwoX/mb7ZbtNHink
JhoSKwW6O6mSykk0foescWuhbbSBuvSvISvLXGNDJVJsJGXmFS/FuxY68TNM
iXmiRtuHJzz/1dfOeZPNqE8aI804W/8x7VgKr4sLdXzqep3MHD18YewOHP9P
Vqdum9OOlQ1U3jIyzj9EXXdKvxmTRUxz0dKCTqcL76B/3XrCzvxgajtq+URz
yeiAeQrDobuCJ/OHkb5YDDvHT+gXnynf7EdjnkTvVlueNT4H/Va3h0u3C3bP
Jwy1n5eML4F+9OrrSw8es+EiBCbGXia+L6D2M+Fed8b7m8sJ2/NHOSYZoe+p
Npy58+gHYaLvW7TGaDzMXTZvCTMNfbmemOmdKNm7GeYWJ1felOWz30wI+XTb
GbWBTwXN4GpeT6wc8Wxl0HJREcgh6tsa25czX4X4/eGgU70D+KzO+5BcI3tq
F6Hs+yyDVx341SXml096vTSJIK8GR5mdkB/0jqfkdK2dDjHr78l/7Pduil/h
fGKcV4xxnKuHc/Yw78J5MDgfBvMu7GOOfc1xnxH7b2I/TuzDiX2jsI8U9o/C
fgfY/wD7HuA5PTy3h+f1sL4c682xzhzrorBOCuujcD8P9/dwXw/XoXBdCtej
MH/CfArzqPqnB6OQ1xMCv54yo+vBXruli7xa00GbUdTmnrxeRdiZ0etmJwvW
jDO7RNBO/W5YS0vaTDz4/W9+NaDUfsx0YZMWI3X+ZE+vujP82Fxx6+eh+uTm
Zur3olDmq/zgZymUOWOycquKIHXe0vVX+1CS7lfbDfqb4XmcZ3xvdKA5Erqr
0S+4RgXO8/H3wnXVtmhjUO/5n/Ya/49f5dQ7d4UU7oXndJ+y9spQL1Sy6S2j
jLUuhZePzH8VdSgAbVbjvqHZBjiuX4UsERud0tChcHr+YPj/e98wFZun//AK
tLjf09eMRZ7CB48wBP6Z96Ovo0wdH8UTiibn9kegh4cVFx/fCr/La7zklBMY
otDenVsNbw8fpHBcv/JLfi3eWAP9VtwftP7qpyJ9EOoq4y8Pn/vjY0lfB3IP
cf1qTFLqbn0Y1EnSRa+oGEh7kf9dB/OrdscnpVLixhQu722vfXv4Nvnf/cT1
K/p+Qn1yT47BdtnfsXM4fL9GmWRZzg2M6wGv1tli9etk9Nx+GsHvkTPfyJqe
MPLTPrE9hxiBb7i6JC0VDQomo10CBcJ+AS4bpbK4easP2ZtmnCBxAPR48beC
Jg9KXCXZu9HIejFY/8BdpvnvVpwhf97NGGNtgvMh90yry3bHvaRC3oF9TgcQ
8Iocr0uDvIxKB84uSpkt/0j5aqqFijzSla9X0hc2+J1PE6eOw7rltJD3bsOl
6xU0hFPOllDXRb2DJSlRdQC58Y6uF83fSa2fLVAT5+p8ER1PFyhdsxCeI+ze
Ozq4ifkiFg/JkzvjT1D466zl4uWro9AS24ofQt9gHvbCkq1tjx2T0QIJ3Qu8
aeA3cpXl7OlFR7PR5WXzV2ZsPkPhqSlqGy7VFM2dz4YUbuwrPittXYHmjjP1
uerP3anU0a+Zu46gfzrz9efwO8GGuesOeIhK/6+l4YVNc+8LOrTunWv7zVc2
o6st27f+8gc9vw+fOmfMyCOk+rO60zsG/CVOcnq+7vFrRDPiHcprFWBO89ab
QRn3qFp0WvLcjdY+8NMYux7Dcec1iXJzQ7e6R0FdBdev7LzqMz6pgg/Gk62C
2xpCvcmGVVfDOCsBL/wo2iKun08WXM35OMgN+IGnD3mrh6rIan+VdTodkBeg
kOpuGdHXSJLTTCWBr2E+VM3HtdJ3YStJ/75gDvRQh7jTn74Rff/Bz+2tpNMb
LqM2kqlkUca/fQX1T11SErnfQlbGSzSYframcH/ppXfjTjWQ+hVe4qqFwLfN
HfVGVN5WkiY/3tztzAbeK/fg98ZRnwLS7fGXqoF00D2yerzYF6CVTK76tf6N
nRrUw6/3pGySFvMj2+w0015YAm9MUWsbqHRUUPo5nMe1/Nh36jw/eZAnPnFo
GRotFdi//SHw5Fnal4std+XKht6qt8m1b6J4FI3bdKPqnQhUyeRZvNQN6rGz
huUruheVIW2OcDcuJdB/Tlf6nGLJ70TjS3fNL3AEP9uBpZw3DIeGEf17BP2n
imJF6wDrt7n7OeRBWFaxrz2mzUgceuX95oce5FJJ6lsu9rm5iHjjuZeF5wzo
vvY/lZYUd+EnQvILnuw/AX5iDt1pY32HhAjPcC4nFVGYZ9z3TP+7Y5sYEfdA
8EOsAfhF8J2e/fK7aSMhbLaU/XYw9AG3yq4unFm3lSCVZ9d0fQB+VXMra82m
Ynmij/dww9pJqF8tWvedcGZVIU5ofhAbGoD8oGNr7F8fDVUllqucKe+QVKbw
z/tWeVXZaRDirWNTnRVqFM6ZMvDt+31t4rKa3intJ3spfoXziXFeMcZxrh7O
2cO8C+fB4HwY3GfEPubY1xz7mWP/TezHif0KsG8U9pHC/lHY7wD7H+A6GJ7T
w3N7eF4P68ux3hzrzLEuCuuksD4K9/Nwfw/39XAdCtelcD0K8yfMpzCPima7
o9cTUEDg1zMV9O31xAuXLhh+QGtsDDzLJS5A6E1ifuXqRNx4KjcxqsEuuJtL
Hn8vdP3VfBR0b36nrnw4db3Q/Rm2IP9EM+lrs08pnO7froMsPBc9UiVnKTzN
c1B80VEz5Bz2LH7LMgHqvOU4S548SZxH53z387yX2UjhysYHpMNEriDp8qEd
rUkqFG4sO/5E0dsT2QfdNryZtIfCMb+i76cBheP61cOS83t4H8PvyKTtodcz
AbeRz51yv9Ra0OHj+hX9fcGnNMm7pOHPXNKSh5caFnJB7vP1jkN9//AE9D3Y
ItVhB/h04foV/TiADyqX5dvoP/sjUjBzyOC7+//jVyuzShbneIAfFN2fwR1F
Z7wnG94ATn9lcKXvD+iFyipPVJSKuZP/xbH/1Z1sP7NoIVjnhXXURrHWMHJY
9u3so1rYH8yvMkjesWFWyL+WjNq1NVcvhqR/jzA3mvT73bcDZAwZnqqxYjIN
+mitvHdONCVEkf89nrzTT+y4toSRPPe7RBS6LSh88ILZu2HWYPLrzRrWe6yg
6wu3zRbRrfcm313vF5Qygv61hevmzqpTV0n6+aBE4YuLPFprfa1I+vEUoXCD
I0cyX13SIy3livbnm8NzxPdPpVdaT4vMHZ8a6rwNf7Qge3yhXvHGzHXjX3kV
i6ntkZueZ6U4ahURWN97pp7avve8/Y+SkcOIJe6TfNU6dmp9gdWSiVGN9nPn
lQyF0/uDvsgt8souFj0tCl+ZNDhalhyJbIhfEUbdphSu68vPN9h8D3H8HI7f
mw+6MpZt0VZ2eVkouyI/pGgH8KK5fBzkGLL9t2k/+NExZmltJ5jL0eENMtVn
roDPg+2D7ytSDlSj5Pmiwq2fwO+C4f2UZZtPHdpyapPwez/oHz2u9MqNnN+I
xvyET3S0QE73h7oZx0DUhI5v4/+HP0A/iO7f3og4kza7WcYAn9HfkdDkkFyP
nnem7o+uhX5Tluqehe93VCOWXZGX2LvBr97H+PrUmqlSFH0kdLVoEPjtY/3V
9Um71OB+mKcT/nG2iI/zBrnzYnHWlgvgkz+1mJzIzc0lE/OkmM8ZAS7bi9wD
yUpyicGa9aeLYZ1QP+NDAhP1pHPss9rdfPC+uz4d/6ubetxUa7F2GfjE+j3w
RQ9GHpPrTLS3n+8HP7SpsPdSg/KPSR59F68wFzg+jfcdGCOtHpEs46o9J13S
KPyln5LBhaQ6UqlOYER0HHja/ZaFa3QfVZA1DS/jKyygLrfuDlO6hEs+OXxD
Kc5GEO4DaL24w6rdyeRs3MOlm7PhegzReluh+DqQLDqZ9CXQAq6vA2YxJqu/
mpOr2cxuadrzUHhHq+42x2GHYgsp+4ovvFeo6+JX8Tz+kYen0XeCe1HXh2XU
9vYpFw9v04pFUqZElHAhPN9JlSYu/d5bilgdRow/NMF9SWOpUN67Ex1Ib/Z9
3GgKfN5j4ey835pfIyXrunVn44opfMkRjx9dd7+gCqt38tueg07sE1vuhMCn
WSTJFrHUr7afwj/zpTMznWEnqs/59rHyQf6jGQr9GinAS4gYp4TEJU3BOlKr
fJwsBYioZSp95mcgXzvz6tU18oPChIPhLaEnS6APaDHxOuz1MgniyX6zfYZK
4Hf6xdmWwVBahmBpHlPMdAd+1blp3lakuZXYqiAt9GvTBvCvaBvmmamXI0K+
7md9Owi5P3dPZPdm3ESEcKvBPIXzkJMYwJdw9LXCDiLF8MIVpxDoG0Y3Cxvm
3Vcl0rZbWZmVQc518KqCD7cn1Ygu78W+7XK6FI7ziXFeMeZdOFcP5+xhHOfB
4HwYzMewjzn2Ncd1MOy/if04cR0M+0ZhHynMx7DfAfY/wHowPKeH5/bwvB7W
l2O9OdaZY10U1klhfRTu5+H+Hu7r4ToUrkvhehTFn+b4FOZRB9+4iNam/lTE
r/h4Wq5U1xIvWUngV4xL/0MsCx8XETd9Lj8V/ryJ8H1GX+eyVKzpTvY0Rde9
d5a4bt9MrUPnK4fLDIJ/b4gM7KDqzHg7/P9hnP7K4Kr35pRo3dd26NfEckXL
DYQR+PXDHM9M8Omuih3bRGMbzB3MeFxEw/uD9w/vL8b/d10GV7w+3j+8vxjH
6+L3wesIuzzneNk9jvAr3v584SJF5yg/xV7l2cx91szU58J/43/HeJ8r49PT
vy4R+BX7vCmHzLo8W9RA+MXOzrbWnST05nI2r5Hth29WJvy//ae/JirR+eRS
av9zT71ialrUQFsyMG29u+4kTX9uHbwufh+8/v/+/4lK/7s+g+v/vv8/97G5
dfH74PX16kpj1qjvpv3pZs8+daRyBCaqR2oNdlrTCvLKFth/8yEOz+Eazmbu
Iks0afP/LCtkSPnp1bn2Do/y6tO6PAJ9FDVMiZ9zuLW6W+2svCyN68/2XJCL
Kl5dvkL5mhLNIveqv7zYZgr3HOdS47u7kMb09++31Pelmj7+wbyEi7bv73PD
awqX6YgucZBNIJf93ZFjFM7VteCJ4/I4srh8mjS1gVzL7+FbbB/+LEARf/cP
9Hiyta/yd0sXIeKBGtcxD+hnabJO7Du69xFS+bs+8G2dk/m1meotiP4cAzqo
q5bfgpVTKsgVjH/+hn7HFwWFi2skqsjbDW921FaDTnu781GdbaiGvPx3e+hP
3ZKb3axzoZZsVzP89IkGPlfd1m6iAtbYFxj/98/zyGRTirRNAFlqNuhlcwTq
n7P2CqGuJfro1dM/+7+YWsc9+erHMN796Kpwxc7+x1DXbXR/cIy9Jgqdnfjf
zzsd/KwpsjQabWz8o+uE+kzPzp+Cw0sc0GaOP3+DHonYoBj1dcclVGH0R6cA
fmW7azW/HD8YRe7+m9sB/ehO7eTvanujSZybinEvgwKvbU9cyF9/TigXwIUD
2uWU1riS65r68vwqDlG404+cTOYkb9pD8VXpH8yjiLK5voPeSPqL5QdNaOjJ
1IVinZPEt7nzU0ylT/bLyA6a0LOZZYIknIfLhzIv1uTz0G7us5GI+peeJ2ua
OavS5AIp9FW8sO4NPF886G4Xvr+nAEmiLbnaM+B7xm/9ZAfSaUUveufTrq0H
X5G4w/fKgl5VkUF//Z5hbnReX0KnNV8d6fJ3e6g37lN5xrFV4gZ5ZImOxS9r
6HtOzU/Y/ujEGvSSUWOCd9FS4JktkkrdzDGI0/iPHw9sH9L0XOjxSwekVPJn
jhz4/Hq2Ae0O/2jSfxPdH5E6n5dLHPT7527ym/nXT+lFlsC3g1fQTnEm0djs
ngtI2WcRTe/ox9NYu/9mt8wp2nix+LNJbWviI/4djFH46LZFneZq4Miu2gXH
WZbv0fJRNj6aiyjjCquxXmr9sDORd6uc7qFLVhZsWzeDjk7d/CqzYnwmEl6+
YVRDBepd3WitlVZEG9qdfqO20xD4/2DZj8xkuWpS9W/9APzrtpe0BVeurCPz
WId21fpC3VL4+eaVl/55zmlort/mWA/Pm037Fw9FTxiRMQdVum4dPU7tz8aC
t0Ur+aPRcs/HfGVicJ9p+G4kluntiH4VnX19WwSejwLYfnzVb48iF3MeqhAJ
guffI7RFp5vOO5HnhztNacpQNxCtUvu+K7+WVtrrXXTqRjMRTaPXYVTXaTPe
emBH+74n0Uxg1QWia+44a4Yy0Ow5tGmSAaciTp2H+218Ie+lDjU+mnpq7Db/
PeDL0fWOnfsBcykKURPIvqMAurhFKnskhSs80MV1MVFqvnCejOx5MF67qh21
7pHyNfkOfm6+taXRnaNV5EjhSataX3jOev/58FjxxlrSh//zuJgU1I3fyfiG
BrQdJNtGh54p/tal8MyzXIw5IXak14WbmvuFoN47MK9WuXZpJBqYbJ/n8q/r
Ii/7g4G31hVkod5RGrLgX3X4z9esKshI8srxP/7okHecbNt1pdT2Imm0zHEk
Oxj6R9nxkyXPY6ZoT55JGKQk/SKG/o+s6w7Hsn3/9ojsPTISolAppPu2S2RG
RfbILHsVERnJyih7k5nMhPu2904yEik7yt7q937fuK/3OH5/OY7zeI77eZ7P
czmvc3zOz1mZ8S+e2/drD1pYvNDA21ylzi8ewimHOGsqs+iTXFRHxWLmdx34
hOA/h3YGyeSVMGpa9MtTrf3CQLD3ipPzW5JqZzNElMZT/dhhGvtefG+mIgNp
y5Eiilb+5ylgbmjzeC2Xuno/xGR5unCCCMwLKxeetUVT6hHHPn+JulgwzyKs
Q2Sb596IeB1rZC9SB32B1D/Lq3b8j6H+W28rp6iBDkPZF5HVl8d9EXUGjc2X
I4B/4irkWb3aEQOlUl/UPJEFcK57c5lZLusx5LyavF4zA3SwHxiob3QdvEJS
V/osmR4CfcsWnAt2X55bImw/bC6f/AHuI1IZk6xa10H0voHbeMbpb3AL2c7f
OCFhQNNFPhCdXI2p2NX1g1kP8UyWa1/toL2J0ooGqs9+4sVwDjFDSI4fUKIF
QV9Pf/sJdJUvrOBEDEAdUH+MRculqQ3se5l/5BYSK+1G1p71Lin0Al3E6uCm
jE9zfRDrNO8nng9gzkXxHWVvylgtsiIraC12pwOzV1iN6DTg1SO7Pbh45G+B
n0nhXkoOkIiEZvYs8lr5gE7X55AirdrUMITndYDLFd8UzM69Kjdh9CMCWnuf
G7nDDfT/KaridSUpvSGTIVeRKRJQJ/kQ/4c5PzQGaYmkIUqtBziLExM0SJXJ
IuTnTu00N4J6pt8tI7Lr1jhSlE62sHLLAapw2f9f3E5W85fteEWhHuwJI9Ta
YXDyYd4xxy3uFEZ/C61sP/baZpoRw5mUBPl1zpYQvffO5vG5aqDz/HCu2SjJ
qgm6Zl94hnIYH+xpnZfhVcz6ghBrrO61h4A4TQrfXDSGrBeiYMmgY0gEOH/4
pDpkL16NsHyNfUmRAs65aZIUJU9qNRKdKdTI+hWc5+BTFy558SRDI2/1vksX
g7iopoFHLjv8FRLTUxWWpwPs7nTXb7F2PYXuy6Xm298FdQB+G8I/tOQ+kIkj
T202KbiX7el/UGqYRiJkCv97PcC5/NbPRg1qE+hOH7UPgTLoVy4qx383Qufg
H1ccmJxDZ1H2pqV/cRMPg/OelKehycjdkU/R8fDt7cO8r/jL5DNaHdQ4rrPo
utUqchQ/142S1klQzSEnpJyiCCZBX0b6/MfdTw9ykdmlx6faw4COUAO0P2XT
MI+whY+Wkf8B8/W/hO3T8VLaoeuerGEpIqDv40ggNNVWVo40XO/WObEPcE7c
osKj4ytD3he/lav4DfzzvWUldTLDLKjVgNIhaAnMP04MKLr3kKYhFz+MHXSt
gHt5g9LINvyqMWTYPCo0cR3UwwUuDdwtL/eG/vJAgY5ZGvlyoxdpGKLEqfOg
YA34mWv2sStn7V3+ibd7RWIzPbDnMww8eojb2gBvh56J3OmrR33u/MVNkJaY
ji+lBCXh2yMW28iH2cf/2lnfZilwDNxFnX8fSz/dcBI9OMTZ2KFXK0RtH2q/
PUfwnQzoCST85L9w7vokYhPFVl9SwozZCZuZi/XL15E4fhZlS0+gV8BcWE+z
1lkHpbaufrK1AHU8q9NKhOuP3iK/V97bOOGCehGThWFW9LPXSLczH3HkK1Dn
FDnILnvfnQ/ldCuXvzsB+Opb1Aq84q9fI/MzQZrjfuBeiLzpSWav5428HVxT
1/kFeJuWpSd9Rq88hiYjlL5LdQF+lyVVfJnbdAAycecqXfZVEIeUuPVFREFP
oFF1Jv5LhIAf6NTruKB1Ix8eN6Z+fmk1D8Wf/4tbQdz17ckbHWhT7vytR2lN
cP7c3zhEV4adiGRfH2UbLR6fEhLFcIbV1TNFyWlhylMFxUmfQF2C5GKIp53L
FsLgSh8oRgX0251TlTdOBfxBHi34ZufJA39C7jQis6KVAoVEvXjsJwn2U1yU
PudLVpWNcOizumoztGP2CFkNTqn2AOQy9Fl4swLUJ91Zr0dNdL2FSjJ+9tx6
DeZe30ngz1tWFSFpP1oS0kYA/iKSD35nPIhCNtwsEGdzwLd0sHl6TvjVQ8i2
w+RdXgXoXxtF1ZIzynojpVzmVZQUIE+JfVFxA/0VCNVYSKs5koE5cT2Wj7kd
tHHwNHyw0ZAXj+03fGlpboDntI4ypPP+ZspegcPMP/xrPyhSah7aNUBlV77R
pNhJYXUwlgeWBoZxHDB64ewnczoRDDdGqncocxQJOlYKqX/kEsTspwWCPFzw
iFFJfiETR75jmP2tG0G2AWM1Uplatmo2C87bZbiAmZ86EfnWxfpVthDUsbsk
OYxS8OMgwV57iic0YG5IBXaVHDcuhSpj8yhvNQAdGB2I9/pP1zLE693NaGY+
MP/7Y6R3RFY4FVEkqC00KwJ5UKI0ZJvu7wKJ1EgwS8SAc7s8pkXLye6APD2G
9OgQgPmpD9TI8z+iYVD4ANuDkhnwe62T2xGc6X8GSzN2X2n1CUMdDvuhpCJG
pr9xP6Nb49FVm2qTcIXb9r/2mMzgeu9hfZS8qC2pe08ew5kqWylRg+wUXPNb
kvBjHoTh9vidW0b3AwYUNzMzrDYf5DUu0kG+ZjAVmm01XOK6Dfw27Yzu/aSv
/QhDqfqN+/kgrxyjwd2jrwtFug3clXcEQPwcP191jcXhDWTvEFi6awL4pVdw
rs/IEFRARnhX1pzMgL4N/f2r29ICVYiw3LJvzkVwzsd9Vcz0z75GzlGfuCLH
AHgFYW70i1HaDyBCCaP33G4gzmd7uvWhZEoNsZSgf+DoqYnZadZLv9FyR0JJ
TAEOQWGgXhFMQfKNhtcT1qtaPYNL7Yc6H+IWe6FJLzFpDp5swD+bgy6gvHd/
/K0XNd7p8Z26g7qcOTWMOF3D/IZeZvhyeAcv/F4TuZEhdR3DLb67PThylxu9
UvFslXZVHLPLjVY/Ir/FgLqd0g59MgX2R/TWphHHSE0gvwZKOX6yfMI+Z76i
XaD2kDtCH3Bvfdv5P/tr2pNHGZrfQUrlESHcbeC+e8h33ujVzjuouZdEUycJ
/F7zTo79XqG1yEii1AqNPeC7anZfIo6RfoPMy/xp3YQAv9dpTc7eJ8YIuujv
0y15AexX+hCAP81cbwBNksx/uBkMeFzbTDacNcQxEPGAfYXZS4AzRyvdzz/+
djB/FaOB9hkPtP0QtzGvL76xZB/hm9ZaFSrsY2jT7b1/7Wq2hmy8V5XQL9Id
M0Z5h2XLf+xsvVnRdAGcsLLHd3d3Py0s3nMqR+1itYTQtz9O4wgrSGN4JnIY
557tZUeJbhjLZ2cAvWiI78Fzb6FZhOY9y6je4ij2Oc26V7+YH7+LnIor23Yy
A/lCpnei8am3tZC8hDJXZATQT1B6t6xyqfI9tE33bOVOKMBZL885YCihAfHs
/8UsXwDOc91ymdhCbAnSUzPeU8IDcLajs51d0ZeA3nH0hD6flMfeV35U9HuC
uwPka9oPnXkK5hEIrChmGh++gq7hDK0zmwN9kiDZWi7NBGOYlNellUvMAZ0/
xGeYS911fikB9uiUW5HFe4suL/61G8htHW+vkIMry8uk8abUMTw7ChyeX/pE
gv4mpPm5KGuE7XGL3DSaKr0lhjb9YXbTr5TH8KyYi69473QS/YU3eEX3Kytm
X91/XP6d/xfC71ukpecF5tSoum5KMRJxIYLwZq6DMtDfiC1SUY3Wa4RurAx4
pI8CvVYTtbdlPQ7VEM/nS568VMBvkHnOhEiINiOLkg7fZnaBf75i56XyrK4c
kTfUX6DHBTz5yNvaw0Y/1JBkvAqv11NymJ0zMPm3LqEHpHrgs36eF+CszSOC
EnyJg3qCz9H9ggEvKysmzUKf6ibseM3bn4nAEt06xOdywO8lNQtrONV0WqKt
IBKNO/TbtfqvVqVXjOE2uKllQNwXzjl8fablxfMnY2E0LS1HNzXGCj7i4Tim
vufv0JNBw/lNcMR2gT+pZzuhNdHAj1amfvDjvHwCsz+hHzhX77GGEDYqCEq/
AH6Da53dUqVvX9IyNHzwihg1Vm8f33EX2L7ZAl3ad/yQ0QD2OnE8oG4Q/VED
2ZPefZQ+CnQw3tMYxS33tiJ+Z3fbae2APpv9q2vn6O5VIi5m4+unfAC/a4VU
Z5/rgz7ye4DypBQujNkNnK8vXPvkBe3dgKKp7gFe5XS+6zJdUwLUXm7i9mgO
5PvoTuJnRUM5+Kyx9ca9fzKWo3NY+2iu4CenNDpnUfwk6eUjtP/Q3q5zWj/D
LQHtbhyQcvOqgB2+/LUL96S+++Z5C22Rcf385IYzPH34ekn8C1QTotdRMgvP
pAoicP7/BH5nWZsRQil64+y/7ACcFcr4fp3t3USEkDtpGpagTs40M9mrIktw
xf+mEwVbCph38Ht19aT5qzYIZWKTKygF93sD+ifWqhWF4gfsZey5AZ62vWFy
pTwdyIfS+ZdtTOD8v/86UpwlXIVc9aIz87sA6ktuc1ZSdZ2GSKTrw1NRt8Ww
/6NnG+wun0K9IecXNgnwLznMTiiT3oVsJEIEQyYBDXetsOdoPbn3avLCOVh3
/vVwRultrI+ZZyckKuivjH43wOs2bQL9yp9NdYm29g0oZU3BYFdsP6zr8jeu
vst74mLdqDU6Nd7RrhLgAxcfvj5Vfkbg3ZYGGsqW3E4RcxPrv8RQCYgPTZxH
m/cKf7m9A/G2/mgGlzHeDrLQYEZylQ/kHepGjvf15gSQla8dpOtPQR8km5XK
jH2sHZII15Fm4/nP3lhbynkGgzrIkueZpt9JEIf4u1g+yPvWiYRXEsC1XaC+
4evg1+CKU42YrlXnyn8Edc7rrWKuWjduIkP7k3qjIlcxu88zfs2zsV4Qu7zP
6fpGUC/KnqP6xtWTBMm4Lxq/5LEB+an3yBnJ+3Rwz2N91cRHoL8spv64/uVz
GdS7RsUT7lTD7juWGLmcPN8+mCpsUprXtBj1G/uLs2Prnx0K2ceo+pq4kuvV
EPjPoZ95MH7DdEVSB3UquhDK8f425revmOg/mo24hGrdo/rsiw/2I2gqv4nm
tt9Bhj2/iqNyQFc5ZKz6V9xHW6Rkiuv2FQGA24UrOLoUPe0Qn61m7n4i4NnS
b0zKuiXUQxRf7vCcxgP4t5blrG5XdyFpo/e0ggPBvM99q7TL5WlVCCVjOIrb
CnQyvV1meorEZKCX2fVC5+lVsfelSRbI7zjlBk2loBV7UaCPI7qZe9ySKRna
yHwcUtQH8qZ0VtwGxoQVRLg00HXV+yqG84n9aDXihlPoz7FXJC0egLf5lpw9
li5zEp6JmLKOthtBLyb+javJvT9L/dJ7gV7pTpz/rBIPcxz2ZUKDDWhdwo3R
Xm1qj9BkPWwvuVtvklnG7cto3kJDdkg62DchmMK888F4C7GswxtoypsE93tw
ewc/cSQSOVJssT4F9IjeLDA/EC1thaLxLmnMqCHY6w3r5O7EnWuEhvSmVm4i
YN6c5R6JunVdF6Ih73RcVRLwru84z8UM4b5H1kJoLroxgP5Oj7bFRWt/KwjV
tGHYswC6qfYdEi69H+9BBLMUx4gCwLwDG6J15l1KEuQp/tM37yfoMzZXE8Sz
HRxHX3dcHJQagjA8aRT5nzoXccE0BhdT7rKB8zbJVQRvItWw9kbR8nnct+hU
7V/c9mXqdoQXs9Bm/AinDZkCmOAwPlEcWikQ0bBE9dxEYlk0jeG1Q5zfpKNa
KjQw6pHj4j6bSwD6MqeqG3AvriK3Km5as1YAPe0QdXVPc+9ChPx3tZPwBRCH
yPP0znq/bYB+4vtKGhQAnMfPrurVVDdBE6krHOqtrSDeNtHM+cXShdx8RcIT
8RDwmsytx+pSiCuQF5JJTOZyYO9kyiRHtcqlh9DILT7cdQEQPxDw37DmX9RF
RE+z5g6og/mIPeuAnlspidAg43WbE4qAv8RepnZrKYsaDZ4myK/CA7yXFlwi
q62WS3CEdh+9zvczGA6v1pLYnhK9htGe6yOSuq/Ql4e6PZ4buMe/P65Hh8+J
TcbtNsJv1f7arz4n8yEftkffiGaU3TtjDh/pOr511Rd2LJVGWQynfz6dBjoA
OH57ome7viG+cfs6rBag/yXtXOTzYroBCSJ317xsCPTJjx/87umfK4H8R7M5
fWVAvW6VbwHHlLEFUiat9n52vBez7+rKfsz36kCoddXonX6B/J3o2EDeMFqM
sNYMNg2+BDjfULbXlc9/Csk1561F8QLdD4KX7533zvkgU8Uc5pYm4L4wzbS9
cl49HhoRc1u0UQN1J0a6q/udHpQocRjpqtdHXgzn2EdL2VWRUnA61WJYhYYw
hnPoXKxsEF4cTGfVYvZxPxD9c+gf6oNQhZ20Hyiys+mQi7MEcy/N/GvXSHS4
Y+fjhiaXLD4MM7OGBw5x9oacQjx+y6A/sufmSJPAPkTolHb7xYF26Fx+2AUi
JtDnEnhhrJO18BGJvq1ibBKyjdnzOouOmxdmI5dMYz22U8Ac6Kwj7mm6xRZI
4hf//u8toPcVkMy29+hSG6LetRHjcw2c87XNLSlq8xzE7TfdhtkGmAeRpSzT
JT0XApmMPfNtNwG6IuH2mftsBRGIkBnH9VhFoFN9U45lrZf6FcSQQ5Xf+vUV
9pzq6V8bWQHE6Gw5Wcx7YsC3b+h7oxXNKQunL/h4vGMA9Z+Ip1rC8UthcKFD
fqpvqRemW2VNFegZ2HKAkts9TaM1x5WKWfmr53ljsSowKccHffrwCnMbsQOc
e4gz06AwGVOOLHqG0WBw8BrQozhzfGjWR2UNshe6frqXA+iyZhIMt4z3TSF+
7NobUzLAz1D7Cj0919yFRCG05HjnwP6FOx8dl2qpWyFPyvS4PCegw0brJZO6
Zt2MCDhSCN8fasPslKe+rQdFv0S8aPTJlTJA3f6JtdUb6T8RkPfHidOziSCv
/3mqJEE4MwFhJbe88oMJ8DeM1ru1zsdFQu6EytfTDcBzOD9U2Kza7SOrSoZi
ZZrE2PcNqtQMcV+RhbUp7vLxzIJ6plDIrxLNZ0/hood29GdTnf9VR/0fbpQj
ItsJmqvwQ5vd2cRX7eh7o4W/9Sg6mkwu1SD0utDptuLLbrDy4eu9CMJdrpvI
op14ZAufGPix9832VbI17sSDbd+82nnjTY29b7e79uc2rjVkP6Ax9bsqJWZn
MZ516+eZQL4SChKfGwW6Jcwfkzt4Jpqhrwdl3P2i4Dy7Sx68EGZsQBg8RtIn
x8B5fozb9rUk4BFEuf81p4AO1J8Te40CjklEQWdIOwWffgH6M7oWL3bkEjKR
M4oGGj/Ywdw0UbOhCvnoM8hH9etBYEAI8EuGsoaZojOIE/q7RvjPIrhnH+gL
LKfJwuIPfiUwFzJi36tonGF/x9oTnnl3b1hj6AFae4hbWjh+xlUVHKnPwZ0z
qrU4tfUObv/akz96eK2kR6IMhqPPB+SfYPqxgWxFV463SaMWx75G/KECc768
TBWsZjVkcNh2pX4GCxf2vj/n/Sff2eCg2T1W3+8QgM9Ttj7Of1XiByKkt2zx
LA/o8lFecBAjwW+E1Chwjtmwg77MZ5c8za8bNQgi3KB94zfo554udjUvkMqA
blsLCubTAh2en5qJa5fTo6BA1Udk77JAnn7X4rj35dICRMT9pprFAOjLXLiu
hpus7w69E5n7zEcP6gPmf9RY9Zo6oMbLDSEELqB+JZxvqqMRJgPrWJ54n+2N
g30vjSh+qTcnnWFicrLjrvyW6PghzutSu+WunH2wlzvNm7LsflS/6a8+sCmU
W7d+IQVlXpm+s+oWCuse8gDfWhjbsNddRnGZ4uptLYUxnFt9JMJwWahhYprV
cPOis6Av00+DtzN6DE2bmZ7UPsuJ2Wk8Q9d9nTYQ+ZHu5HO6oM+rLl3keNu6
BnJ4/LVVjxncdx5z2n2fkXLEy5b0okByHYjrFmnpstqLIY+gvTinIaCDxD02
wNCCRkKzW/lvbT6CePIWTVEC63YJkrOmNG4XA+pXdfGBFZ969BC2qqJ+Nra7
mP3M7rvu25yLUFP6yrv1SaDfqLj8a8aUUBpO8D1ZF1oI9pu83DNX/PLdFh6T
jlCm9jRFlw5xNjs1aUA5Ugx/nG4VVIgvR5d6/tqLNeagH8RFaCFZRykDXiq8
fhjvDbkLem0nCaHQj7yNJgY+DOf505ECdpeo4eAGT4ozv8RAn2ugoliMlh6V
ZRfIXZs5hdmld7zwl2L+IIpFhbO/ecA+lGQ1nLdPtgsgsuOl4t7XQBxyyrCj
g2CiEBEfFjVZogT98e352VsFB+8hCgLPC3ivgH9wvEfse4wkHKK7/05p5BbQ
gbd6vq3HLlKJRGR4bo5LA/0r2DPwU/HPp8hqTPBLFytfzL4t1Py6lmID2uu/
2kV2APrOQptxG1GmV+C+c77xkZ1gTm3vAYOUbI8ZbHTPIvPSmiE2t6W8aCBf
/CIexj/4ThjrlY7Obh36k5skTgIRbaiV3s0npjK1MNuZw3zQWZLP2HQXOpYe
9H7sMdAtLwvtWvpgTwQLiLY6bZvIAr9hJdnl85UD3TTCjbArBnGmFi5/Yfg5
IrQhmW9ozB/0JakWgmZe8IYg7hb3znMzAV2RVNbWlLLcNMSnSGRP4Q+YJ13I
NT9pv1cHralci6fPALoKq+RiXQ3F/pDmiW/LbyaArv5mEXLfPh9BLtF3zZPc
APy9Y5bT+gu+UUiq5mybQQzQ8Xsh7NWb9XIbGuOtKu27P4bZH1qIRH17KQ43
1dfXE+YyYjhL4+fzVi7pw9m0Ce8rDXWxubnjIbct3F8EwF2F+Fz9XyNR9kM/
nFlXtSpX+B0NupFkFRczBl9u2PzXnnugYqTyWwymSreLl4mWwfBhw1No6n2+
ibwe37SxUVXG7LfiQoqlbfjQ7ObKY9bSoC9T3Hc7uWX/OBpM1z9hyE6E2fGu
LLMlva5E5ocMTZiGgf8sMt+8aRweiqQYTp61VgL9vtdkguk/mpugRzi5bsHX
QF0ap1tIyq/dEfrSY/dx0RPUsW0VDeb5SuuRnIxW65l6gLM/eVx7pWUigusc
zkn6HPBwOEQPivQVdiBS4zHuLySgjxa/tmmk0C4KH8gPBL8KZ8Nwfh4bQehv
pA0XnnkcaNKkjfVTJC6suqazO8MiNiN24Qb+qMuh/aadW7zvqzpYyExv4Qr3
G/h3wV/79yui+Kl91+Abfy43t8ncxepLd/1uji0p8qA593CHtXtvYvU9Qc2R
t1qICPpLLCLOKvUShmfdANOecDwtap185+pAD9hHyU3m2ksa1orkZA2PnK0C
+iHmqh+lJGK0oBNucN+HQKBXIHA+uUjgahuUJlzQkvsd3Hf2dNzMZUW2SJFU
B240FzjP9KbHRd6+aPoHz+LId3PAb0SI77YYKKYjbb/O2p2tAPkjr8W2CDfu
NlTj5UaBfwzUYVjP6v0UEzwHW4aoVDRNncBw9mLPGUsQUIVNu9r0Ob4BvY7U
5aCQ8hhjeHxEWxSq9cDmBWxjJO5JRtTDkGKgG+nVftQ36G/d6U6itlnjZyV4
geTa02pLB/jIzx93k9abvX8ZdZur2qnQ1IOPfkeVRdV4LkMx9MPyUNyEriSG
p0heapLaCBP6gNPCvpEG9HM7PGbvM5P1I54mFNsnZUE/dzhEPelyWxCkhicu
kOsO9J2CxW9CdE86ofv56Bp3Caijpo/MRfGee4LkUSUMCC2COm3paEougWAr
8uXjc+dkA3APPhAJHDbLzEJknZbiVveBv5KO5Kg7R7cBzZe4xgt+B3HmhsV3
6eIxQThn8dTt+D8AZ+Q1HYPetjy8e2uG0I5eBavjPWscvlpqqQyX5WmZa9HY
o8uHdke9cg7dixfgWy5257PXX6ENh7ymGS4vYvtzsqgHbcF8B2MAHHD4+jPG
LDdogpRR/KUPLvU8ZvDOoR2nRyyhDkcaHTovco2NB/S/Cr4Q38pKPoGG9Pj1
ytuDvV33FybUxsgHkYoq45ntwv/o5FAVyNdVvYB+7CRVdvYDXQj5rL4ePKMe
6BRj+MXUepCPkATPUclzhiBqxbd0du8Cf1LoWXWq36kdMX3cLixoD3QmDdLz
JcxWXiOI1vEUEXyg4/SlIcgi4/EKtGGtTdLmPoLhTN0sT3mTgRf23hlU+fSA
HcOZhx25S+t2BY55Xrojp3MN6OGo4chwSpyB81/ffPXe3Aw9wkdmSGF2auUu
WlEicuGbzX0M/x9ZKZd+VPuiClzEbnoPU+COw3ivCTXGtabURfs2bIljam3h
lcPXF0PXa9j8FVDqHtbYwFxwPz7/0hkjpseNzkUYXytWB/6Znmu7OvndJ2TK
a+m8chLggci3WXdsEIZD98hXNvlIwJzsQZlGGb9THxT0kNhm+D97NgX4tBi7
T0cipYpMEyYe4NxCT5u6bYQ6EQ9qWlu/C6DuwbB4o1/tYw4SZfz2JFzxAOSD
dQ3Hbb8sQIWaxk99Qz9j9otuzaM3/skTnCiMqm5FgfmsFZtdSqPe87DjRV+x
d85gfio73rXlMS4V6ihwr/bnNx3Mn/RVOVnfuESMLsf6VQjg0IDn5FLxENq/
RdkG2CIvyaHw1/JDP/zjC31BnAW6QqXbGtLhDH85fI7w5to5m0c30EQqW5Ep
HgXMbxdsBfDKmp9CPTeMI1sMQJyvf2CvLvjtI3LJwLvM9S2oi6ozaGZHrhhC
LFKWWrT3gV7KoKr9cqFlP3TBMMof8gP9BftsnlM1elEI+ZzYonwe6F8Xo3uZ
NRZdiNCd0rb1C2C+gG4wwFiBKAf57enbbkIG9kYF91zzHYe+Q2NGp5VVBsB+
nOfxCZdEvjHDm7Oaqkx7QMfpJIH4nB0+P+wXWONhFXMFnPO+JRsD9lNo0Hvv
E5ICoF+wnLsTKfpVHd6Nub+63QDwEUzkP5n5dR713Lwr2Bm6DC9ZTv1rv5ao
ZrlK7YJqv3CKuzr5GKuH2GprcUTEaaJ3GOteqTlew54TxB3E4nCJH6VOkbl9
jOcnhgPLriXj2O8uZDFUcY/ZH8x7/mEe8e+rSUICC1TQ5JMg76O3fRfOMd4P
ZQst1md9B7+L7VOBe4p6oUgvgcKNgSgwZ3E1gIP2S2kX4mFyBaXfA/W9CfZ+
+wDrLCTxT4lJ4hkQz5BpbiXS8w5Do5LHKz9lgnrL5v0Q0zNstDCPZVLRFhEt
hpu+I3smy0V2WCEwmjwyF+gzlIYz271P4UVldVbqvJ/IYfbyCivai/k6sHiW
v7RFwjUsrlgf5Dt7d7ED1qtZZKA4/h0mSvnLBw6XFDESw/dD/Up2w75uBsIM
h68fy/fSrMW7g1JE8CXiB17H7kd79ksMTx8JoE3Fj3rpx8E85nCL4nnm19nI
8uvpj+LnQD+FtgN6TNdTgTTOi3rlWQN/27YZEnEytx+yvIVz4mQR4Lcvqsep
mvM9RALKBk9+3gHzwtKqdwV85LsQ9c9QFXcX4KnKNIz/MPmQiqw+eBEjhAfm
oB0fFJuzoK2QwJefx3F3QL5P+KdpFPYng2eW2c0LaCgw3NhSxk5eSqaCTf3U
hElXQL6co6HMnlHFjX7Lk+Ye5L2E2fHNV7N+n9SHh5qcCuz15DB8ZrTsYMn4
bdiPWVkp++kqitY0/a17NJPkXx98gZIRDFMSLkbBFw/vTQlmjjik2ADNxP/e
JaaojPW/iC5yS2t+EUQTnL6Wv6HBBfobLjcuV2l3QUr6pKaqAwMYnlw/yINH
KNqR5bM9L164DmF2RICgSN6lD+rJ+N88OuDvWQZ9k3jp6QI9cXpZIPkQ1Pe+
DBcpjX/oQOKsfNou8IL+QrvqCd3qzGhkQsqijFYT8Eh3RbY6l8NToDnXC6tM
BUAHj63TBhLgxIcXK7ivmhUSYZ+/pPENuxwNLkxpyr8+8gHUq5e3xKl+P2JG
Pxxjj/0ZCOxjw/VN8aH6cB1NYTeDiSSGc2zuxlNIdQIeZhPCmzk9itp6/z3P
xGvvPmUypaNb9TEP2l3T4fDDPsJdajU0+JEp2tVOQ9efdgM+yo8UEdpjP+cF
UW2D9YbJWHAekri6o56XTUL3LJIn7U0A7zdU2Fw2aWUIcWDUt8SRBHNz/ilv
fj7N64QKGasnOqcBnuN+t4cOOKIgBrVOepYDwAfWfdh7Sj6nDTHSW7nyRgL4
JX76R7o7lvaIFtlovpfnf/R5Hjc0JclUIB1cu0KGX8B9qqJeQOqYvgPdniqP
GzkL+PmZ/KwSQ9xL0JTq665OOw5QZwsmSy7aJUXPy9GNuBCA+04Jf5C06LIe
/LGkPPWRlAjmN0JqGQ70YAQeVrlbkq1Sgbrm/7VvSpw1i1YpR5/7WEhPeJXB
5u1/7T33RvQ+J1iiw9WE8reCVTB+yEs7l8AVHgGU6vfID5FtOjDXfCk89Q7N
EnTG2wKvUArk42zhspwTTNPIWQZb7jCtdez7bsR/c6S43wA14p5odF4DuA2d
/TGrx5EG3T93o3lECcS9OfYKb6sKmxEb4wr+UgLAH3ZTJ/3F+ikMesxzLcK2
HeSD+Ao5A0+7mxEBvmaGQWoQh3+6ew7ivL8M+SkWrMgEg726qAqhjHdxDzRw
X8EuKA98r8VHT5wpIr4gvlnIKN084JlbDhOzpa/rwEqbVOMqCDOGc/K4yqnW
gBzY++f0nQDJdNTycE9rR59k8fm9PvSd32UJuq+9cNrk37rfkIUDUQmpHSo9
qrBPSa0KH8WHeRdE2uVJedEuGkhhvBLUB+4EiTcrXF+DtkWXyJa5QB1715k0
uDtoBXky9XDF4SaIT17hCVHmBadAMvI/I7S/gPkIn68s+X29ryHTriwP+zKA
89UqBn8xhgbEf+iSMAM9+F1S9xqY0Zfp0KX2AqUub6AD/8WRfkQgrwtJqDo2
HRoG+hFTrjVCUNZ3SK792fsyyQXsOQ+C3vWwZlcg/MXtPTalQGdSotKkvFFv
H5Kx+qNmeWYTe464sCKp5uXbcGUCF01n7h7G/6fhpeWbexgHF/MYTK0rRaH4
h/2vaDf6r1lyv1HdX1EK/i37cCNO1L/2y/SeyoSpTii96u9pu9uq8Ozhc+7t
PNpUFjmBpjuZTTCVgd+9P7G8PWNyHRpOWr2yRg34ISEbJaZ3F/aQVknhkNfu
IE+f/+KixyRcjyyPPbkfSQrqSPvNJfKLbwog5YSlT54+YI5jJkEO+Xy6Bsmz
Utw+Tgr8syXfeO2yxBuovs5kYiYc5DtX+fq5qIP7EKOfTzQf/QH7bsQDBsvF
rw1CFO8M3K/ugLj6i8GFtSL3dkTXrChv8C2YQ2Fop2BWEiSDcwLqZjYrwDnx
sCPlD7+pBZ++S2heL86J5Y/vg12evPIOhdcdE9hjnweiiYd1J4XBvUe+r96i
9WYDeT8VNmDi7O//2nNe4uVOkHig9wYd1P50qsLDh8+RrkkUWqnHR2/I7T2N
+AD0223VU0+rkCxDV64wTpoS8GGfJ5yMf0HAmBANNRLJpzIB59x1aow65+wQ
oirHt9pGD/hmelR2j4ga3kDL7qflZFY6sefDxQzrP9JLEZOtxzVP/jPn1Zrt
PEHMUA4F1fdHLf4B9aUZciHta+r9CIuW+YODRnCemwuHt3ybGiCzrDnfYRvQ
30FwnAnV8tuQck1izsJNsNeb4uI7OZMaalj3+67ZOQqA8xnt6ioxBw14d/KT
KmH1aey8ke6K+gjy+MKqgvZULhbeqP0hbh13ORn3k/ZgeaYqDWa3DTQp6O/+
GnrKuMZj8j6otXMq9+R5dRg5fH0LZfIC6ToVHCVV+eF9NT32vj7uiTvnXvsi
+LtOvasaYM4xLPlmh2s9JXqjKyFaNgL0ZSQ1KraILkwj3uQWyM9BUId3bN42
/MZWCEEh7Ae99CDem/E2xBWkyEZarma1piiA+JmzdPYN/e8q6HqjW+izeBA3
ktNTn90V6kdUfTOzxv+zj3717Negg5gkyNbsbXXpOMhbgyNQQe5b9Ygh3Elo
lAvOOY3RpenMj7TwKOMJe4nJLew5YgMn+/itVWC9PXxLZioRDOcu4UklhMEN
/qzCZfVNyBWtO8RtUQj3QCl7Gj7DQ89RoTiPUrz9+a+9mfz8g8JZf/TTpJKC
yZImHHj4eic7OUYaV364t+6jn4jrBQy32DHV4/v6uGgcb+PkBUoJzK7OsjWG
840BFfWZ3LSpBLy+5w2dx6xyl5E3zJ++Z4+AfVJV56tljANeQzltROid1Srw
/3Imqf19tj9y3i3xvPcOmJ9lC2o4oaBTBy03qNlPS4D652J5Cdsnuz7ERNC4
IfIk8EvqFzkU361nIkrv3TZ9p0H+bkoh3N16uRhR4mXiWX4F7lnRGXYlu2t0
cBdLg+u1N/PY6/cqmDsyrRXhZ/1V5xbHzmE4T7P8XPT4eh++eFpbiVfOHtNt
21DQx41RqYA9xxdfPduuRYnT/tqfKJIpLr0JR2mkX1oiJ/RgvMPX/1bqW2i/
Kwr/ply2Srt4FcPty8bZQR1rJnQm/G74l//Ut1tKfFoNGTnRzUoX2xh50F++
ZsWf3066jVjQ93Pe+s/81+nXs/N7BYkQ4+JM9DIK+gL+Go6tY3tRkHsi9xs+
MsCfNNmzTPEnbIQe1bZouLmCc6t79+OilWEfIu6116f6AvDWgumdeBW3ShGr
K6e5OKfAvdlRyh9CoO+PjJ4/pxwkCPrmUQ+9zAXtaGHf7c5s8xBQ77UkM2s3
/yEHb7p2FGYEnMdw9tM4sRhhaworrV+NrjS1RI/qRS9xvqSdd3oJJ/0M1Osg
yEK5Dvsy+59yRCMJE1Dv+RviHu72MP2Rjgrn6PvZIgmYsC1wKXZDG4tnmNK/
Cebon0bPhI1N+dEqAj/2OUVHnpIXTat15j6wBX7bMWDLPlUJB9XeV/xxP2IN
+/yiJx9FmPxyhconSw+eyYB5nzXjYJ35hNfQ4vJLVXkSMGfR+ctx+3lqM5Qi
56BAXgVwVtbnXMht6UU8FmkMKxcBr6NqBc/7+Nw7RFS6vXRUD+w9nO1tdVNZ
iIOep82NLjmAfUkELnv3aBqoYV5lc3c2Q8AvKklRTbdal4JFrTLK2yQBzvfi
ZCovM+jAuZvsz6/5m2D1PY+N4zR12Q/hTtaIm66nItHnh/eji0CF2VByKerT
pSpZEPQKbp3+a4+zjlVQFbgIVz5Rr3/4xAzLXzRFnhHR8YuhUxLr92uE1TE8
baUDY95nnkXzKOkzvR8DXoq7+Q5dNQUhKqQVfYHAAsTVqbQrH3QsXiCzJhJE
NWRgTm24cfR7kEsxpPpI6pHnf/Q3Pl9TYfxI2QZVPxF+5hsJ/AYLe9YOHNGJ
PL+UeOIrIdDLCpaYIl7be4cUxDtrx0xrY6+3Xgp79GI6A5KdjO3yeQv2OESw
0r5RwKeEB0/QxAc0AH2ni0TPjgWJSsB8T7Xfs18AfgO1PbBjGVGD1fR+hPBc
1sN410p92la9BXqw17jycZKFJ2jhod3fN4LIs8EVHpTUwPnf39oj+4/yCy37
PCgRZ/8gx5IjfKTjbW+5ruSaLYcKxN3NF3AB51wtcvuZuO8FtGXQJb5CCfCs
Sr/hf3VmOIbGP9ucQXfBHkC+nHfO3tZpSCP6ukj9OuCNB+AwlMgVlUNt77qt
TUJiMfvtNQpaOaUO6CkRq3r+IujLFPvpPq+r6kCEHFVWZnaBv4WLmFbTmsuR
Ex8TWVuTAU/seXRCG7FFGrR7W3xDXBP8H7kiNRAe3TGYjq+wMI0Q6JFKPqq5
pOxzASbxLr8soALqIV/CfT5KZMnBVbcqc5ndgK7Ui37zVzM7PLApj/I3kSVH
TP+cOl+jyVLCDa5fiej439+jeGMG13wlLF8PvSWq03B54Ql89LuMGZxsqx9S
Q2n3NT9KSuph9RCy4dvqS8IS6A8Lbfp4ERCHrAbQNnIdp0Qp/iB6O4VLIB7w
P2/b9D0D6XnJZLb8Hz3DZVLUV566ErqkMH7pso8WZjcPs/21b90Fnb88d+9X
JsivXVcGycQV2pA3SoZsUhUgfpsg21Z0cStGgq+/cBG7APhmfQTzgtbWL6C0
bacB6WOA38s/jpygpSaEd0qNRyptAQ9BLAHVFs05C5Ped2d45iMI6iGmHV3X
zojBl31oLr0XAnVUm4BbSKrgRfSTXjxVwRMzrM/r8liWcjS5FF4/OSySF/QK
PfIbQ0ZM55DshyisZWIacCoSPvIzFaMDZ6npdVDN3B9K55+aYH2Z71zyD3XX
pdDnZr4rORdAP3cxyXj4eyM1GtueovfKdQLDJ5Pt09Cnn3GIPmuTVb4TmB/c
/SQQ/HziHSQ5wWOddzUZs3cKyROLPeuBlOiTCHxzAO8ul8BJT662GdFrEmiO
HAB1qlqIP+3li9eIa0xQ6l0ioCP3TmO2imnNFVntDSMTkQb/R45tXPiWV3Fg
91PZBDgh4DwPszr8OMnJC5upNZy8ZAJ4Guv3g5enLU/DdboViRQ0QFetRpCR
PrdIAl1dzWhFN8A559lqPf/PPQjr/Flg8HG3R4/uQc9Nu1kxp5fo2c6xqj6C
LPjo3lTYjKLKtjFFS6Z0aX6bWmJ9mR4NZYnOeTl0s5/ehzXkP7pM0aFhma60
aPojeRHtBhC/fX4kx2J01x+a/WD/dOw/e5Oz8HtTC9dLoXL+nPorc0CnpZBb
tfbMuT5obz7xRjQMdAhrFE1qvB0aENcXayQyDwHOsXDiqPRGFMLnZ2+pSgp4
73emzF6n5iQiBtDEmZw6MO9f6xHI54+/DVWnmT5LOlgG9Rbch6UadJzw/mx7
/rEbQB8P5dUarrnDBJflbS07RYN9DdG41aEseqJo2c26oLyLgPfufLn48tab
cDg69trZmBN66FFctxTJPRyhUoGWLG4vPt+uhY/iwISd8O6Xk/dRyL3HfVTW
Hj6KG3npRKc0LRTR47cGKpa+AL9xI7K73+cqHerysuH99Kt57PNXUtTcw5cs
hurb30/KxgJ/6xTNF8n2MxPqyUjdOz8L6tt58sHXTq/9k1dD1y3L2EDdY6Hk
ocJ+Zx2SCxX3LIkCv6GxNSq7XuAPRUh9KCnZDwT3b6HtrdVHr5H4B+GPGddA
/PbZ6CHXh8JlyEQi7efbAVAPUX74Y3tyigEWOA//qnwL+rk2zHtxHJq4cONC
QJohlQRmT4kJOuHjwo+OVXXc5HYFfOzn0D5n5aw/LLhBOou3pIke5SkSJRNn
/8lrUC+/tpFKxXmY/DCvMW7zrj3D6IbKufGJvBFyhY/yoJzfOUOUD1RQYTpR
3+jjYD46vcGSfucTLRrtxztnPruFff6zTibOGwb10KXnslKK+YDfHv3ia+fz
l0nI6W9Ux/cnwBzcOba7X56Z9UMljjODXN3g3JqG+ttqZFYjLnzf+2iDAQ/t
1rFaIn7ibOi4PIE/uRTgFVe2ftDplShE7lBX9LnSg3kx9btmx0WFpyGx7lDd
nx9Bve5Oyta7k9WU8JSGb5J41H/4NnGiIaMmztAd5bD5MU0Qh3xuPb/au0aF
Cn77yIZU02P2Fw6kYRfkfeD2/q1O7fPq6NE9eLbQoN32xir6ugQ3OqftN6w5
XPSv/SL16ZNaPL5oL+3x3eB73vBRXu9FS08866CBDostfN4oOo3hnOc9/J60
hhq1bznfS0AB6sDpZiwHmTVtUGhLQUDhFuiLdZ8p+bTW2oBwd56WqbIF8dvD
cKrr+Or9EIP2cf/dYcBvh7RD2M3Ny5FLV52MvHZB3SmUzpi/u6gUIisJZGtS
AvNffXFhz5rfvUEcYnW79fbB/GMF6Y0X1kJDkNkX3o90DJ+w5zAps66GWBPC
vZO4DFlGQIfTvzumaZZqGUlzKXlbSwj89j3ucoFf9fiwi/6X8b0Pv7HnN3ZJ
/doi8YDPl354da5TFT2qIxkGDZ30d9yBNTOHSleZ2mHn+b97e8mcK28qe4ei
HrFyuo+eB8JHdSpdtpL1IQ0tVGYvOYRRkRPrM/atc9VyCpKhf/I8CFsqAM4i
jk6Tr560Qzdv6cocFAH+3oLN2VOyWoMITEEouLAFzrlkseXugm0fZDOmmZlL
BOqo9346nPvN9w9ui50iqf6AJ3PdSmZ56nINZBn0h+o4Hag7sdlxJvuKFCJR
vtU9n71Afc/CnlozXqQeEv8Gb30mBX5p0PX7LMmPPegty2RmsisJ9vll30TI
Cy+sI9YqFTYWDIC3sKistE4jcgJ22bfh5i0Dc993avj9plKcYCui84aOd1XR
o7roJUeGgFy53zA0vpr9pGUfbTisoxb+pNnbexiHbrkYnf6sFAUf1V3XT6nU
fxG/jZ555m3jXrEHHd2z5MKbXvf095FFtfY19TOb4J4i1ftK5FABZfqzjPuW
An6IKo7UvNHb78he8RUe7sugHrI8ye4+P9oFrb6q5n/0HJznpw3rgoMu6YiA
kKI6kQ+4N8+zfKRw4WuA7lTS82exgrqHHmWlDDVpDnLlDtHYu2ww1+C8cPvK
flgKcmbfaoB5FMzlVcldW2KOWoEuiY9osKuDc7I9YvpIT3YNaarWy9DmBuc8
eDz7qxopL/yr4rMs43tQT1uaWGIlOmYHay1sn4RoVDEeyIDp05vn9/rgYJVk
aZqvvehRX+ADC+7N5oAcdOk1khokmQ4f9RHIn6eHvN3QQdvJibv73zNj8YwB
Ims0EP4Fqmq7t7kxB+p1V6XHNcsdepBbEQ5TzgXgdydDC4k77y0jtIZ3kj8H
Az6wtprcp+DRZujyVGtmNDXof8nq/jph1RuGtHzkL1j4z/4yVdsLzzlqm6Gk
8EnhF0Tgni3U0edwL0hFVOhl0CINgPPZB84cczYNiITo97gfq+B30f7DEWxH
Ow3td/Tzrt0GcXXHSQ7SGOJ/8saq9qvfpMA+hQy1jEItHgE4wGMp5tou+F6v
5SuSRhIt4Q6esmW5ZyoYT5W5KMg4TqUcTqYjJ+jzKkOP+lxl/PKntGEE5S5m
jE9TqYCP+mJ2gvG8Wv/kn+U+9MxjkAjgreG8WAzbI4Vf5L8ySSagwd7XJX9U
WVxtCbm5eVKn9T4HZq8vnAitT9xBfpxmWTxxBtSBg7MsYn5BFZDZtE1v3RfA
+8283Pb8vK099PtZZbeJO9j/SOSneZzxfRt0lsYtx/kiwO3tJnGPiHQU0hZ+
8ytRew9mTwp03qF+24l0TG+dfDgN+l83skpep2wNQQtKJCKPJWex98UN1vP4
+W4SuY97v7/FFMSBIghxHc6cINzQ4FZMEE2Bff45r+C2kkem8HjFd5GC5BtY
/uJHeWBUyJQO40qzqLe5pqNHfVu200Sx4qoTaMC3KJz506PwUZ93pfgLq36o
Piq/NMkrZCyJ8TBzO6MnBB8zw7LrakpqQbzY+07kDbnas+KiLd+N1cwGgH3t
n8CxhQkfFbxXV3eyFPCgRFBEMiI6BVHUthjsLUzCcOCYfmKLGxgNFTPdD6LQ
BvzGxNaxT6ZbHZDoi61JHgPgn7VIC/FL2J4iB2zSMnq3AJ4rbqUp4a59iFnb
yFJlAahTPdX7PHWMuB2KlPN1LXMZwvCMpw4y473VhRCKn/IT/zAA8pom5tG9
UUFYwLq11ZMc8KK/On0jtCw1gPObTzEWKChj9ZBHscFGnoMvYOH2+HqOxSj0
iIfguhyvjae6gQ51hQhN9G3A3d+a/7Un+a19l+bRRz1ONl1R0pfDcGYXbz7t
VM0Ny/LUblnyAj7qa/47L6uSqNDqbOnF+Z+gHqJv3T5XYUuGbsLFF98xgfNg
5MAb8riqFWmjS3Xe3QbzEaJfLj/Jy0qFhj9befiRgz1930zSQoctuqAdeV7W
qz0g3ojOCT95f98PerZ2xzCbCOi+llx+nsqU34/YhWzl5eaDeM8xsiFx5mMF
hN4j4pax/o9u/Iij3N2cbMjt19zTPyKgvl2hEEvL9VAAXhbg/bFWPI7Zr4WG
nCTGuwNbJ3+PUw+8juHjOBTuOYfnB8tnE77K3wxEj3g1gleY2UUsFuBjC8FZ
DgJj8AW81X/tk0/nZynyddAyb64y9oRrmN+IVH2aaJjBC39Y/chc/UQO9AU6
mhVUxdjRC/5FrRVZFzE7QfBoLC8LLcrugsys44N5XgL8qgEipmGkCu91z4Ms
oMtXkCgbJK2UBT1rPhcocjrq/+Gswz2osikN4mf3tJ5H6VrhkMBkTFMlB5in
G8/aHf822I9UllzsMZ0AcwcnPkTf16lOgqCL3GfJebIwnAmiHUkycbuhiBNr
ITcCgF/q05U6fu8iP0y3BjtPiIO+GDc3xz5hnCZc9ed1wCvna1ifUeX92fQ7
1C7wjWuNiYTfHqNHPLGIH8/YXn+dh+kldkfaQpfRX4e8spc9n++KflVHXwmT
nGBtVMCe4/VDhcmC8RRMYqeo03Ia1FHPEMyx5RPwozEercOtL6+AvmdHgX3F
F2bU6oR7cMYuA2a31swatDn7HTF275G4PzSMfa/659N8L/hyIP63eIkr+s9A
nTPw6kUWri5IgHfpZUI4mLNI1HEXv2rxCqoyCBKfRgCvqSe46FOmdj9ydjuL
v5nhP3veQ1uNOTYMEaoa0pThB6C+6tU5Rhg++RFSZHttcv09+F1I5Fq+f7Y4
BX+DZM8G64P4RE1H2t7Q8wZ8TCTi3H1OgA/3dWnu+jgL+LyXxcvkDmf0iPeY
5u36mtD+LbzkdJ1LRA5Fj3iSeUwQl9slYrh8WKDsMg6476yjz1kkfaaEhQh/
am9NAl3rpriuZ9ofzqOcvyyEpx0AT/XjjgvddQYu9B7F3N2DaDCXvfmY3rb3
9wLy8qDg7UAQiKvVOBn4k7tzoJXhm/G1eA/+n38u6w+bi9MAfIbRkITbBxbR
EKx4r7FPHNyn71cyps39+pAxxfvnPjGBOiqbzOzSAVE48kbH9VwQMdgXTH5M
7NTqu08Q3lhBWnsVyFuvlQ5lmutzw+eFHbqm5QEPKhNPE+H0V4AzoQdcGzmA
pyp9qyqen0oX1mUPOpWM2mJ9GVfu9tRf1b7wL8mEpqsPU9Aj3q/2Mg3j95W7
MMdCvNN3m/sYD+TZsYKL85fPoH5PhLo+moN+QT83kd2e2xXUmm1tf0fnGoan
4q2HkzVkvGhqxsvOlgeAt/BmIPj0BfcVZCr7885t9xHsewml3Rru5ciBzrJ+
df/+DOiDvQk8M3Xhn/uLVyVuMCkZ7FmrpBf50JkeCsmG6vk/kAX+tjafJGRD
vQeJurVBjvcb5Ds2fbhrne9fIJc8fgo5NAFdLDPIxyGCbBA60ZP08GY14MF2
7noOrGecgE+kMLxmNAf8EPJoP3dxHGnY3NNw4AGvNGafGHJYCwpQhv2WmStz
TwHetd74g0qd87Iwq5ncbC1jAHrEY+eLC4x7LXoBrUlWdspdfwUf8d55GdxX
9cyV0XmOntgqGnv411E8Y2QjhL8mj6ppHvPQo1fB8DxHOve676Mg2iEnl32N
CMR7unpPTMY5NhA2iSsxYfMg7mWk89LhnM6C0FDzpZF3Qdj3bblY4ilL2grR
cMdKFhuBcys9qqf/TNIbMr12Z8S+C8ThO6VR7CxunUip4SBJdSfgVUaIvR0W
aAlCFOl+kBS5gn1Akh7vcdSO9UOMMTLuZ6RAH0cc6sXjG2WC//CsHr9BdQzD
s70odpjeSAwmuM8bfOM22GcRnXzSOcHuMkzr4EoRdVMPux+XT6YynR5TQgt4
dpsQSwds/q5q5nG2eEQ9GmxnMUF2tR9+cjjH0dhqMr8dY4yy3u4weY16wEdz
H3vmJUpWQqroVmfuFuMXDcyf5M4szvEIn0PvUM0TF8yAvvlnBxMT77UtJMd2
o0v+MuDJTJ1cJq1oS4O4J98k3ugH/Mb32niMqp8aITyDrAgCGsAHNqr3qQuk
fwCNsnigKTfAnOm6XunCqlYbUiRyR11uGvRlOEV27dOitBDOOxPHPwSC/Syw
ZBZ5flgrtGj3gWO2HNR7/VHj+1fiaeHHZ05Afh0gTxd9Ynv5abUIzDb86TGS
DPioYbhvrnJp8MCdG57flHtuYn47bov2hVvfNVTV67VDgcxdLK7gVFDbuhTX
Bo8c11Oh/9gHB6n8xVnh84Z8B7szmkG66hdp4A8fzTFl+yEHtwy10RqzdCGO
Bm2Mh0ls8GRBslkUzTyAraii2DCcqUXLX2bf3EGuJM3Ub5KA+mcAAy1vzblE
qEowU0bDB+SDeXKIjZNAPcTzEOUSnwf1pbrQ+m5mI1kED6fY9LgG0Plc+D2X
RI42IYpT7zMYbwJ/wsGksqcWHgo9yNBzn1AG8Ywi3ngT7+tK6Cq/9PndIaA3
IjHXXrK2fxxW34l54MEA/LPcnor6kDkfjJe+aEonD/q5w58LX8zDm1Cbhmfj
W1VlzH5w1zTb/LcYyl33LsHuP/XtU15Vb/m5puHeKyfm+gtH0EbHv3N2RbSn
Oq0iA9Ax9R2hR18j4aO5PHXPzc0LP/XRLtEZPBEDXcxvP1R4/y0nQhxdaDS5
6v8G1Adi6V7ebIneRkhxbG7VWgFdCxw1HMsmoyhoyJmuuyo/FLPzXuTRyhVF
IVNnKuPWAIAz+b0JoujfTxHcQL+RxDpwnpMFcr++2qtDBJ44KHFkgDoST6QV
eUxeGiQdHkOmRwD2bl9fIDVn5w+B8qVHdOLogb869tHio7wYEQw/FPWP8AP5
+MVz6Vt48xzwVwaj1hdlYG+Ou8VmRrgLEco2AmnOmIL7MfYgmNjEdBd5OkM4
0/EY8KJv2aIdghFtsEvwpJqxTC16NDc6UkmgW/YiHv1cq2mZ4JUOH82Zptyu
rbHvNUPlT/xm1V8xxPYUCMV6/6k2v4Iq9kdNS3aDuf6c47yPWog2kOCHjcxW
u2Av9lu9ZwTwt6fQ5aYp64L7YP9aOH1AywJzJXSXv0+77D86k6lsF8YT1Z4j
WazigZsqQO9aSJnj5AJ+FYJaTbB1ewM/w+5mPZbdWwgdC0+/8hkX9CVrbpD8
ENwtQD6ZZ8IvrxZj9k9vJXiuJ/yBfv9kb3LgAvy9A5HhOUo6erha51QJ59wp
UPdrHO2XEqdGDaffDHuugP3a/PZkjxeThOB7veR8PxkAT0P93nefNeIi+FPk
z3ESvFT0aA5a/1m3/p/hYtRVd7NbKr4cPpqbVg/9pkr/3RblJzSRx/cyxebv
IqvTbyTgS6P8drXqZz8AHkKsaoiO9MlFJPhqRoj+f/SZv5XO2V8c14Okl8Wf
jBPfxeyoS/eso0wppEGmd+rAFtyDCcbxpGtJkYh90T1N9g8tmP2LjMr32w3F
yP09AqvcD2Bvl2q1t0NVaTn0MXhSfywe5I/jVW43myxqkEr1qE5yFsBDq34o
FTXmvAGN3hQdndUBfGDeETvxqolj8GUC/n1xIaDXkc15MPuBjRoVaZhaKXoD
dJzE8ymHcesuw1ctKEWiLUG+HBfxkxRfNAX+AYVNlriFokdz/bl9v1dcOfvQ
2Zdhc6XZ/fCRDkC8QZPlvZPOKM8fZq+bpy3hI90AH47NthfhMujPYE+SLg8Q
5/PoJBieaOxAoqVVes67gfkIxvQMq6Usd8QoYPfDdXqwp9VPnV61WKMQuhAq
SDoxDvznzYzkLpzAKITrqfNd+2pw31XmauvaKWYgl64OciF0IO+bEuhvDXpb
A23l0+bPL4N8/wQNfaM7cSMSlryhfJEFzJmWfr5KmPoPCpR9+UJ3MoBORV/z
UtM1Gxz4bvNQWgcB6MswaiXIqtSRoa5l2Q8hVi7MnkryjKOuVRqW3xCumKUW
wnDmMgnhrkiPhGVZRsWYFJ5gezyvOEh5y6vg1NJKMtpo1OJIoYe6FqtWAoin
rSdKYaGL2z/4AOONVFUVkwilyaLapqs0mWXg82i0rh4QCM5Ami5ZiegB0KkY
p8IXsTv/DGkemHxrZBSC2T/zverdfpEJkbzDmWlkBX3bAAec5u76SGTmysXn
eYPAP+iZd70xfvoIcc8LEDFgfYzZb/wWZaURbIAms7arWT+B/s6v52VcxvPN
yNP+4pwqQRBnngnledZyagJye8mjzvP5K/ackSRcQ3a6NYgOl9mr5T/7Zw3F
Eut4O/HQ3VC2s37eoI7dYxvI9/x/c/jGxczhLPwYzjzbRO5cqkGwCpXJ2ZHL
buiR7srSwHjv+88zsOsduvVyDxypoZ2/PNVBBsq0+mdP0flGXVHJVGf4SNfF
7JjU7otfsqijUm3goznQXzYo92DJd96H/JzJXsZoEGPvG6OeT+TRG/l/TF13
OJfv98+mgSJFJXtHiITnscnIyMxM2bJlZZeRHaJsIntm63nskVH2iozISvYm
v+/1i/f96R/Xda7neuS87/e5z3md13kdRNkr4/ymAOibCzETZRog8ZBu7xvV
o7+AV0BFJlVCofYG2XEt3s7MBfUIFrZxmXd4DDT06+owTgZ4z5k95S0zpmZo
6AJPq0w5wPfu6vXv8x22IFhY2kPWAQBvie0/Luxr6IRInl5xDr4D+hFClgrX
4K8zkFrHz68jIriYv2u7zT7F6MEGcjuYOhm+CfZc5PQ2pBJkicOXAhOXRmWB
XgeBLm+SZ5Y3vCqJP2lAaIfBQ0yIfoV11OOIMHpOTF++sIdqcP87z3eOK8i4
/oShmY0rNvc/ecCnOkVOC6rSQbTiKNN12wSnK4CXQslPk+fhRABH/qKW/IgH
9Nu1iZOg/qwYZJasXEu6A8yBqin08RzER0DN0Teuhf5HHyyGiM/m+6sQ5Euj
Iw+uItgLM4b9Tf2RQxbkLHQj/OMy4JvdfjAw0urfBmG/C910zQTnOdr8glzU
cgvCb7tOWvcbnGfN55bEyfkfIZeDNpfXSYBX7BZNX5R90A+VnR9ChwN2Mfas
CVqDoN4vCNt3e01qCtCP6z4fF/r0rxjcSRBAWfafvQCa7XLpiLcznD6du/7X
yAI91cWSwVOo209dghMbvslmnFlGGU90tCoH04L9sN+jyUTHC+hhAHyqu0Ua
92LY4o0Iiu+VylarDHhWgy+8CNPcSeAPKz6cpf0Arw5Xez22zhSHZKCZuD1x
gCeWiv/qad0tb0ibUEz+4n/2L/wetVVrq3qFTM7VjJ+j+Y/OpLGuGvmnYkj4
DOXgsi/A9wRTTX8MaLVDgZ+aYIdHID5L34jz8r7agihZCKMmbIDffohVrXxh
vgQxthDRioJAHrJyyyE+Zq8ByuE9uIyjtYT5vetOKZI/O6ahkSNlJTczoGuR
UqbAgvdJFD6zryC4XA3wVTqKsyVhw7aw4Y2qlRg2Y/RU521Lc6J0xrMe3m7r
Ko3cb0RPdeHCPrLiBOJnogOOBrqs2rHwqY5cPPe7960t/CibfDW200+QZ1p3
SFsXFl2Ey+lH13VwAB97nsRG9+18IkJ1tzzLRgPwlKh19GtfrmlD+Lc3pGB1
sNc1zeb6aoCtG/LuDGHRLy5QP+aS35DtpCyH9mm+dYrpAD+b16qnZN3uhJgD
czK1VoAeftDSzKDEcBMykvi67ygQnHOK96lZpgUNyMwEn9j5bNBfmBz5YC35
Ih+6qvFYpo0P8NvLpxnsQu6sQ/aNPUlU5TOY5xM3mK01SWHY25zF9U0IiDMa
+3xN+Spm8C8uNpqbDw3RU93CF0Ikvoq/M2BdkuT33WJ56KnOYftaG9UaUoOG
5wRT8mMVwae6iCsRSjNihbSo+HCeHf91MJct/1AjzV2bGHYoupEfPgJ03W+7
zV+TZktCRKtKPHAnwRzW44t0N1s+mSBFzZL1wW+eYOx6lVV6vY7miByn2Naq
gQvm741buy3JdbkKMixNtQ28AnSq8VqvfW/s6YT0HHsrLzQAvRFK9aq7h2ca
keaSY5d1fICLWjrj0hkWtSIWWvQ3UyDg5wU/w5VKgkjo2lr1TZ05kE+aEwtP
P3uyA00HIkMKRVPg91p6s3dqCcL6TcXHxx/BPK9gdee8Xrgh/DXgEw5Pmi5G
n1Y63d+lQfcNPMPsM9HxIA491e3kiN1VvJg+hXYe5NvG2ozA/Cc6n/nRTWLX
GxjhLd3LF7RcgY5Tu9nflL3ENcgd13250QPw3uPfUwt9C0lCVKvcFpalAL9X
YSq1e0HAGSmUWia4bgr6hrld76JsxcWQXsmRpA1cRXCuPrgWZ6dWQ6M9WJfI
rsSB/FBrZTqzsxO65VVU12QB7kfveBcjL796JLpq+IihAvCrxV08qyfQLwjz
Jr+5y3uAw7h4ucg6os+gy7E1HWLsYB+xzX2nUkmbPQj/cf9B7r1+zPMPb47T
VATzwzTHqRVrhOC8ffG32rsn/AjOo8DTvlquiel/HdFm+dCKe8KHkYkh6dIh
6KkOrQ+LbE0cVxp8+ahy34R2CO7++S+vXuX/Y9cZLAY/+43Li9OhhOGBtMr+
9ot/Ro5+Zkc/BrqBfoF3jPuRwoUURJgnr0FHFfjz8efbHY6fPJBPg8z6NwiN
MXaSxPTYJg1V6G1UbgouvTTGrvq9xzMErwYa6yXcFYZBX0CYxPwv5NwBvV3p
DS5PBfH87MJOH71dHTLvlMIu8wrMI7jCw3VWP74gyezGfXEsoJ8lSl1T0vGR
DcK7JvVBJQDcF+7yqbN+2HtQffLUpsEu0Nkovv520/MHD8zp3p9RWwr4Iaxc
9+7fX1eBadWHNjxiVDH4En+ekovnqAXcSMUUzhjgjZ7qKg8V4Oeede+C2Q7d
buwztqFT0f9wpzeJP79EvZKH2QU+Ndo3GWP0aaNKhNBdVm5Uojfxvm2pJgbf
87JFBMtEE5ELUt/zvNqBzn/YkCRJt6EXwp19bkQhTRzz/2dZEeiESgygd5Ri
D5aI7mLs2J5DusKq1VAXHEpb0QbyZxvxdd5093bI5OXcDfUxUCdee6X9U64P
RciipRtangI9VcZu/8LD6DbkdWHalzhqMO9/7QddqKzgGeFfMkRMjecHa07t
F90C/bC7t6FIE8JcRTWA0+LhFe1fXeKE5aKdHdX//IfXFzXbS80tC/8vQxC4
d1YZg++93Cl9U+ihAd+cf9+qpOCInuqEv166qZvtHA9bvHnEYO9Rjp7qiqPe
F6Ru04jC9Rq370TEvIC7T/Pw58OpPuYSaLAU/F1wCujnW02EHVj/fI+E4I6p
1T/zw/w/ZTL68hNbPBBtG0pmzp9aGHsv+yPPyBE9KO0hC27xKoSx/8I9H4Gr
Xwnhmx88F98EeWCz9dnbkGMb5MI8g6fRC/Ao8tkh7vTfn5HsvaNMbR4Qb7/O
zWaQqbQghq+h/ONnBRi7RW8K4+48lnAX47flc0vdGD+7Fd8KPfdiA5qjbkmJ
9wB8s7sU+hloOwtssjkt0ccB/AwV5hQLPhKDrXCzFLb2ZTF2YpKrh8rvYJhR
p96/8a05Rj//SHj4UGvNEDVFPLKGBXzRU538ZHO8tF5TC1RsdaaqPS8SPtXV
FxOJlXpBoYoemumWR2KbwafvMWgdEl6/l4DYFphxmR2BPXrtokYNUjiuyKWb
PtdqPoC9kKE5DEU4E0qQmthtecM1oJcuXd82WNhcBhXVPekYHgLx4f3ODyEK
6mZIeiAlKtkN1OlNkZ0+S3drkEefbbyHlwEelaG2aE2t04gspE2F+xeC+UfR
Zo+6N6s0EJNyBO6ILMAHcOvYd8fYV6DJa6xdpCogD1lsqpC1sKWHp1lc9xSX
r2H8aSfd66z08C5sxQ3RfqqSxNilCDSejPYTwtjTU25k4kA//9ztnZDScgkU
K3eF4OAnOP/iFhuxc8vxKHO5kaEYdhF8uieCgfA5ffpbQ9Se0OZtJr8dfLpX
Qlfx8WcW/xhkft/buHIKfE8/WbtYDL+yQ/RtsfXOvQJ7IV0G8jg1H95D4pM2
TMPWJDF/L5+DxGOJghJoyMd87VYH4P/35uPiudg0QE32hHxKPgBXiWNiHjy8
Wo2UXNjvO34IcGwiylc8OPm1CHcGgXSKG8CvUpizMnVmtSGjYCf2cwZgzx3Z
s3pNDfY5qJLlkl7zyCjmeW51W4Nb327AF/KaScfKrmL8OWRv0pOrwwl3/Dxj
yyQC+l+fnP0WGz1pUPtPigzsPmoYf35eYJHmkpaDmes93+rnwJj7jm94dSnm
XD961fGr7sMbY3Djyd4T3EGrBBFvG7TsoKPfkMMVPt2TEv+7JrHl8jtk0LWq
Pd4F9K/JVyUSzL/pIwHVOCS/o7QxdtuscvG5xMdI1rbbr0t3rDB/b7+A8uHg
vQKoqLZLc44f6IF33TckgSlqIepa/VprAjBPyiPygZjhYwViGh+YYCMC/BxF
6vjVv6sCwTdxjbjRCer6q3/F9oZnXCDJClaCXZtCzO+NXEwVI4QmoBDmcLcr
d0Hc8M7IvuQuSwHXvXy5+GgOzH0zB/RtfDiggy2jtUj8lgUw9lm+BE+JDib0
jTAlj50wiCerq9fD7Ge0YFmF8bZNBxlMPyXW/Zoqu90o6kFTFzt8cQPWCfpX
Pw7gbqs5c7ijRoLmv42JX8Kne38mxpGx/A+RiKk//SRPJpgHtOqCs7lHlCA5
YTrdcQegi0XQdIX3kqw1MlIdb/XdCOxloEiymNaDMyE5idXLiTQAD/F9UxSx
xFUNGZN0JMdggfPsHiimychSjphZVzzEMQJz07m5+gyzTgWIytsFPwMpkL8F
aPWGajSEQgIBL8PS2IFeXJgdofGPyf/V7eaS44RZ4PNq1DdbVREnhaM4d1pc
1oC+9LNXi+9lHCjgA4FnNF8zQV+mUlzxydfzjKiBP13Njxyg696x+qPl5bAe
3KCueWB/IIm5144zUrB+rW3CeREmZtmMg7BrzvT/280aZDc7e16j4b1mZ5V8
wuDTPVZN+37EcgRvEMO48QkLMzAfcfbrxEOjOVtIwOSBFycB0AdLHmLBnU98
jiz2TXn+iADzg9Z+hl8WaVKg9jsh4rF+YE+fLw7vb/vtUujsytDgRTIQn29/
h2mEHT4hxw/2Q5JXQB/tUc/gAT7+e8RH4/EH70tgH0Evi7UUA3YCFHxff188
H+DV+CmNTBqXayBsT4t09nXQz+2jaI3qPEsAN1Wr3bDgBP3ci+e33dVeE8J7
k4KRczQA/xG//tx+4N1NlDx3nvbCZTAfLU1guNm5rw+rtw7cK7UTwfj5Yz5b
J57DJjysIPL1ysc1NPBkz1oyIc+gB/l7lH2aH0clJw4+3cum3y9vxUvmj5j5
4QcOZYG+Ffn00xD/G17QjBL6jagQ5MOiD/SbEwrdkCMuqamIRNDvq6PRirno
GgW5VLaXRbqAz0v/0yW1GpoiqHdOSoIoD+RvlRO3rjLPFCHfBGubZJNBPxHR
aMtPb/GHBBler3OioG566Bf6pTH+IzRSbMvZzwb4e536G6/MtJIRBpz1+iRu
wAN5ujX0mMT3GCJNz4kQ4sfB+G2c4ValePIO1K/rFHlMDPBMiLnBqfIsGTpl
6Pb9Tw/It+ewlVdHDvRgQjUTMhHuO5i4IcTf+2dKoR2WUe8W80htQk/3BtaS
U+qoK+SiO9ck0oXXc+DTPYPqfDjH51h9EAOOnpFodZDXkdMPyTboBUDV5pvx
M+fAuY22Pls4SeSJXInMH6tfArhTnMY1siJdL+iS1NzUGWKgMyZlW8ozEpcJ
keV0yHV9AOctsDP8+jXfXMRRRUhIYB7ke3QtI46xAZkQJ+Hmg8MYUHdMe/dd
trMtgl45yz8/pgI6n4cBFqNOnXXIfVkx9U5TwB+u21juvFe0CVXB8sZqgfuY
98vZ91+ZM5uClGjHieBSoN/+2RT9Zal0iIj0Ql+nz4G+JKM9kfbvXh34PI6r
VF4dPcbPTyL99giSS+DfmxduXNvKRalP9mDa7+Qt4rY2oNfXZC/87a6HvU72
Zgp4ZXcTyDoh5InLtK1Rrpj/Dwcq7kb6PBT6Rjfm/3IU8Ejt6hi+6FJ5Iy/i
zn2YSwd7+qwnSYdeSBgipUh02CsLQ4ydZvHI+a1wKtT+Vrar0R/0ZZoLtH/2
PctAtENMq+EdcN9lMSjNBjOWQoI/XCRt/gC8ToHkgV1YexnE4B3QHdMD+MAc
rA4C1glfkBLCci9+VdCX4bKhKt5tXoAiOWXVr24A3i8ZeQ/bNn8OdPEsv9dl
TxC3Kc7IOl8hnYf0PbhEeyYAz7wm7MdezaVH8EJPZ/cFqzUM/3/pg7ZSelkq
HFDU++pzdBx6uteVf5A/4BE6j/4gmOqyD52DGU72wGqon8F6xvoEoT2reOe+
BNhrI9sj/mZRKhLCfc1bEjUD5vFDRH8cy0l7Idop+CL9fgCXiMKexXpb+wpB
gjoo9eTA/oWrgbpRkfKxkIIFC3SxEtTXeYU/76kKJCGRPWLVJEJAFy7E4d2w
U1YNVDA2x3cHuxzzHn87uxKavWpIKHXOeOIC8DOs/KIz+fI3RFxJ33wjG8xx
2Px0Yd77OA7JdTo+EHIBfedLOYtiP+40IR1HOodjwyCe2KwECOI/w4PTKSye
7FSAORT8q5R5Gpc1YE5K3Guzh1cw+R5NLOPsuEcUbKE7uu+pEYae7im+lTp2
kb99DxWRHdNRN8MWcav0+X97hUhTp0mNOPQLZ9budb4o5v0jW1hBlyjfQhnP
LlF7/Yd3cUmLXFWqwAvZYhV/wDoEeNSvJW/O4J99gzB7RAsKp4Rh7Oh5c3nB
l2EQ+XaRWK0oqF+uX/tzUY81EiHULcG+9ADsubtqYIlana2HzEbpMygYQX/8
0mve7yRJtZBNa6vAtRqgd93sv9XTvtaNDHjxPb9VDvw833dnpuxTF5SZ5XNL
6wvQ5atg5cXzkG1H8M8Im3Jugj7vnty9qNZ9EniPkS7N6Tfg58cU6pIGkKnC
if4a2YpfmDB+Lj+YzSqXCIA33U1m4nVfoqd7tx2I0j/fO39GhIk8qX81Yw0u
Zcr7F7d33Eu+ZptBS05bIo9vgT3ItWW7pJ+/xUJ9hq9mHXsBXtr7tNBdfNoL
KdV6On+hGuBycqmGMtGJbxFBVfdOHSvwPFNs+h1nKl+Itd6KvfkCuB89Z0xM
hlk8kQtfKCiQa2BOvLx3e5HUvRFqFDkWd9cDvGseQU1f15B6aP2DcTsLB+BX
l56ZFH5o0oN43l8qKr4N4va3rN8vgsnKIFjk7MuzaeBe0KMUNlTra0auf5/P
MPaaBXX6roGwHgkZXCGWdlPIBey5iBYmlxbgVoaz5uoUG55yYvz8nGhoO+aK
B+zsFSS3Gu6GJp/YKZ8mk44l7MF6ecv4H9MP0aWTvfMF0RzOi+zPofr29PjS
h5aY9yuOVhDNpMVBGqR9dhF7QJdb/9mW0Jtmb+TN7ivDQmXAS3/XzKISNvoO
MTPYwvv4DMTz2ndQ4rcQe0jJp8BeUAvs/VQyV+GKHVSHzngZNofdU8E8f4Yw
JNqSqRkqM27CouAG8Vn/9/pjvPIGKHjYYKz8AOTPn6CBlhq6HkR+jGQiqAL4
v+3eoqUO+hIhfzHp/jAU5PnIGdoZJ7waRHaYgnFZEvS5VgxaxOikyeGoVYvi
KiugV8DO4lPlSiQPt3mZUoiFgjlHfJHrd+Wz7GErjoT1GkoHtP8Ud/JuOMtZ
1gyL29s/8njdicah//IQeiKGK4e33SDPK0dV0sIWmPdveX6QSqaLh1ZHrZCP
5H4YO+0G2z6DhRsy5KK8l30D9MdxGq96jvXFIe/nmQzEZwGP+t6rpEKVUW1o
Pvs7e5TeU3AP1h22kcLekIJtMxGemBPmebY0ZVqCsy3QXNxBu542yDcWWOvu
Wso1Qon637eWQgC/ml71oapRRDciw7Fk/SQE6DxvD9dbJ6UWIjfOH/g7PgDP
n1cVXsR3y0A8Z9zyWNjAvVy+GypLjE8Oa7kGrZxnAP0v+thuq3d3pGECEbGd
2VxQ12wshHFvc5nBXT6qjDiKz9ClEz9LxOH1dRGnw0ONN1MFnxehX+b/2Tk5
tfg5szyhgvNW3urNoG+ySFqqOLodD0XU53qZI6BOsZWY51RFnJG0Oc5vVjnA
P55HqU/tV+ORZfaM+pRGsH8kwrz+GuUTWmTVIUTyZ8oVjF2XYCD/AfVrKFqE
3vTWCtDxcI1sIa2mboFUyzeZBblA/EkivHLn8mYDlGU+TMG0AXCYitJtMZvQ
bwjTnlqW4S+wx1mQXv7PPdlyRMLdd4nrGPR3/nx5anfjsQO0pNg9YDZvgrFr
KwSwi1VcgsVbNKmj4kB9GupQHJm3IgaHqM+Va9UBP4dEWHlmPzSA43/Ii99/
ZIyZ/5qRH+hvTQ+AOUM+u0YYxqHISV8GxZYvC2f3guZmPt+ofgD2vuF5UdzI
e/seYjcPNG7LB3v3lILv2h8WuCNN7iVLUxcBjqc69/Z44U88Et2ujXs/DeyX
pPsqi8tFroJk0cZlNBWJgL/3qsqlVPNQqI0m6e6PINBHqNI6TDj2bYby9M9H
dPeCfH6W/Op3FukGyMcGa4JFGOSBf3kM8SasupBLFjJedSYAR1WO5GlK5q5E
6Gd6Z8RegjgmNcnq23Q1CVL5QK0YaAvm1tNKI7uFy0hhJ/e3NuU+YC6sI/qc
YJWnMNwjaTCVeAziRsSqRULxBTU4rpr5vY/QY/TgxM8RvPWB1aLPYO+/5YjN
diCqdWLX4ipwsq3zgKx/qVM0zohj3l9D//y2Y+A7CDc1Yjz6CegDJj2yE4iy
dEQu5zi1nScF+htSYWtteSzxiLzb0c7wLzuMXeu6BtxVp4aYPQ72dtLDx9hf
HygRpNiEQkLSFm3r9oCvm6RL+FRKrQnqY31G3I0HcBIy1wBcKLkOavW0XY5G
wN4TOHlNng7uQHD/KvVK6QHe9RORTK+r2BXIrd95vW/WAU8yAcdyxpQ/FbJX
D/wWmQX22dEtB/9VSjwPvxD5G5ujvIaxp/P7vS0W5YfT6MQOf6aAevzJjY+f
Ryll4eD8tArjUi2g02KzbmB5/z7MxsLfz97jig6e2OetEse2bjxEse2rwgRG
3eGOEzvPQ20vveUHqHHXmemwfW1MHeQrIsfUcv8eev7y3PmoFqCr4FHRU/yz
jgQlbl/5+rcF5PmkluQ56LkkRLpH6Qb3RcCTPEre7pOXqYCsTfBq1M18MM+b
IROV0WgHVOn9qiUBC/RfcF063tlZ1SNy7/clc2KBzi32co3ck70mZFTmyQuW
BqCjJV/6sMxTNhQxaP0l1twI+vWLm5TEOwFqUN/37x2UG1cw9pc4YrQJF07x
1tN///scOYTiNv93f/zq+lae7lcF4nxAx5j6dBzShLVj33II+MxCyDVl9Kw3
0sHQo25NB87PunrHkuqEHeqW9TaP+kwIzHLiz5dmVJvSUZoo7rFVTHaZIUaP
xbmS9eccriiK5Ab032MCOiEdWT5CBlsXUTfzDkhbbADUg+MRhuEk7oho6xqO
4hrAV6loc36lXK+E/Pzr2AXjQP+lRWSIBRntgvBfZ6rZ6IC+rUj6pXcesQ3I
74rt4qNQkO/JHRZcLBprRkSZhzTnWVQx72l9jMjMFL1G/o49cd+iBfMgpMHN
OKp/laAzTG1fn74VwdgFLlWco+mPh3J+H6k3N9qC78uJn2NZ75RPsYB7wWMz
ppDGNx6x/aHRP8UC8lJ21zHdVx2eCIPKyDjXBRBXtwU0OdRKQtDtNVkyrulE
uOyEPzlqIcdPwvcEVXd5fRGlM8XsZ3xqd77k5poE2q/8YlL8OfCzYPVMxog1
GXpdgDdNFQG8aMnWRtM24g/Q++8sG4duIE/L7Gviya4og9Z4oquM5cB8Spj0
Trrcz2/QNP98hi89wEV7kvi86DkakUWdhhfT//l755y3D/XxWhAcsTRzDRLQ
X1jQDR88E+SDGLFyKS3nA12jtEKTuk+xZJ9dzj430MaiwezzpU+rdtsei4c4
cRDRLVawH7ZtR5upMMAVsh2dUtHTNgHxzbMgyfNiPDKp4zI5GnwPY5+m0/YT
4HmB0OgZ89z+j5+Hw7BUwm5koRTv+v5srpfArpP//GlK3UXPvWKJ/uGUIhNu
ssbsL9Ze4Wn4YXkffb497to+DOJGwRc5uYM9MlQgMTj2SBfofXUHo4qbtFWQ
tfxFPyp/UK/VbR8MOf3Og9QahenNMoCf7SDRCdGBbkhKwk1tYhDwJEd0gsOf
/s/PbOjNyeR6cA9+DWybNnZsRjoJSx7ILoN5pds7yC2qzScIy9TqQlw90InS
uZPOFe6sj2BPKxc8jQD372JyzOVrlXHQ9Qs/qFZRoKtPgVNjmrnmCq0t3Rjq
ewR0534Z811ePHqPqJON/jUMAfH/3CKzwc3k50jan2tHOdLAz4xDeLduqLWj
1gFKf0rHu2GI/19eDR0WWP90fo52+bxrrBp3xPRfKH4+suC1fYCOJlQ/QwoB
r7i66jbFr1tkqJuE98adTMB/qzKs0ZOObYKOD62eraQDvtCWZne3haTB556K
32qPDi0x50rSbnwxXqwHslYZSuvyBf1rIgrVshm+BiTjtm84chPMC6Dpsmqx
642IRgZ1xMxFEM9LnRlo5EpdIGZqXA/hdVCnYHNLChqPOSAGkG7SDiO4F3rO
pssSW7yDflxxxaLqAzyr8RW3Wt03HhC/2rOLR3cAHp5a57Aui75DEmyvXiPP
Av2RO8uJecTfLRG1jePXRMfGwA9Udy7v9h+jfZbhDW3vsET4xR3+358u76eG
nWu9UZt23amftzxgvxM/Z14LXZG2UUFL3tqLe8azYvpllJYfevQzSVGHyZdr
wd+Bbi3VJV7nluM2KCkwQESNBegn5Ilp3b3DUIUoiOUXltMB3pFPyexkjloP
xFlT4izvCviiJaPuDPiNdUhqh/VtDiHQF7g9G09F2VSPKOY0LlTYlmPsa/IM
UGBwBJT8zE8tm/E95v1GHFfSHFZ9kSGSAdGmNICPhW6rThu3RkNvBcxrSp4A
PxNXx2kLkXhBscrJr/fogK4X7hHdFRbFGKRuvp6GwhDEsflqLV8DGxVkdZcz
0ghPAWP//n46W2CtDj79+cL2n9+iGgxoXX8EoUOypekivn7w8En/BXdpqy1b
Wg2Vmtno4sgCeizxPL9k6WkJUaWP4Rvu44AfGxPFy18V1Ai1Y2WxXIJwAN8s
hzejzLIbUe++5UVeBnhE2h6oXl5ZN3Rgg+WEfQnUxSFYwwJH+gjyZkXVal8f
1BHrF5ilBFMQBOq9cTBoAPxs/8HM05I/ARp5Qu315g7g+3k3USRzd4Ujfoef
HtNKAB7O9zk9Pp8L4dCq3VTWeQawn5HFEu+Y7Lw3xKjb9o7MBsyrmgsvMKNh
UQhB6A+uoQLQV9UIpc/2adOG/PUKVy9Rgf28Gob6dcOcuCI8xZIRFudwar+5
i/y/3+5tDyzFf4pB8fl+t2zTvIGHTuqaala2MC92TdRIptVUy/4Mhm/TnWMx
WpC6iWyuPv3068885vdOtgsxFOVlIeFCpMRHlIAfqzd/SHywPYGYWHuNq/8G
8STbXsNUGf8r1Lyt4PD0PNC1HnWl1N81qkRiB63Jv0HgnN+lG3AkcC1HZnbV
G4WmQR1dPczNUKeaDj2cKERj9sA+QdPkibjoB++QwD/SjyzxwFwSh5OFRruk
D5SzlF/3YBbgMM+djEXPO3lDsFqNlIsMOM/paoE84VIRSJQvwcdtYoCPwaWW
lMET9hABQ7+W3Diol78ZlahG2AzAZ6mv0hwP96HROYf/7zddc80f5GvpqNjz
P24LFUmw0wkfNe/e2lL4zCPUnru8QiyMApOfl3IbR1jKrEKKMY7sopn74Hs6
rEBMVz2JTFmpZQsQAd61XI5TPLvJEhJqs1IVv7qGeT5axnH7SmsrRJ5Lpzyy
APSyfAlNgqOWS5CCC6zNaxfBPgI5SNXfuy0PeXRnHOrwBTh2ibl3Mmd5DjRD
QTZUswd4kr4EGZTBbqlIJHeKTpE08D9iTabRTCXy2Yt8lwTnqzzmvvic8v7r
IIk39ExAfTtfE+C3wSQPli5ovkYUgr5aPjwG539XICBYpsULSn9JVOhqAXD4
HwxkBSZbVfDhLV8JPsdK9GXRP78d0CX4cMSUo91koVnXi4vg0pP5I4Z3F3+e
ZddFpUWT8XPe38LMn7YUF3suORPDQ0z84UcHVwF/z4E/br16Gxl68DwwI4EO
zH/11kq3Dm4h/fAmXsGHA8z/Bz+Za0Vhoway+1pNc7YZ9LMqP+E7ZZLlItFY
0e6CuCBuOBbAROJRMUgQj2BRzWvw/SW47ucXJlkETVWwlCeSgr5t1dNgenbe
LEQvlrx9dAzgTiNsgnJQ2SvEqHmkN0wW+OdaViM83esBhbx/HCzyDOT5nKvp
W7gsvsivIr5ha0FQF9f5ZXHcDPOHVv1zUfHnAOfsCCRduPI+A96hUiDvMM1A
w050hG4/PZB5mdKNVmNVt4T0fYE7JP/lIS/aOqtxg/TQvYiKnr0ZAYyf9V8w
2iZB12CaxUs+r0aADq1dqu+g3RgBel4oSKQ0kA1jFwiHB3J9z6B6wVYDlCsg
bkeISX2stzP9LFeaepddyRVzrj4Uu24evk9FCr1NZlrDAU9sMpzefR8Khn5n
+RgRWoM+ZtH7i+LFYyUQ2/jNR5p3Ab/6KctMPilHEXJeop7lOy/Yy4ZF+/3y
A5EYpIBUrWz8P/uV3BT/En34X/6sb4HPJisP6r5uXopXOReckBBSB8qk32AP
rPiSgvjERAh0l8JakZwf3LPuue/wy86+hWvX6hwn0mNQqZM47MsMsVyPOkAl
sQqQkMQdmC85///tXxZGHN5J6KFnCMqCKPnEMH7utH942fUXHfy99hOV2DVB
jN/WWkmvtH67jHJsRx8tyYC65smGr7z0PgFaZVxC+mQK7LPTqyi4yfO/us/5
xx0txRkwB3cPt0lhyy4KiR80UpprAPiG5BC0JDCaBZlf8TkaPQfuu+UWQzgj
uAwyMyUQOTcH+i/cuLtLs92liEDRhAN6B/RtLSYtg7GLUxHzC0uPHwaBfpzs
FX6EE9sRkp/or176Cs5tITN5dAWeISJI1CrMbQTytyY1VgF6jzeQJT6lgOh/
dDJTz9lQ/tTwh7V3YTvT/+UX307yCrem5C3H2kb49CcO9M/+mxBbbptBG2W8
kEhg0QB0b54NTYhoajHCJpHBs2SmgF9N+dzqG68bHdqskMPU7iAA5ghIh3Vs
RkjRhx23lDU1wT4Ch8hj2x/z/Ui3Byvljc+grvmy98W/sdIbuX/rwYxLLuDd
Vfn+UsmmLoOqJV5/V6kCPHa2P3KV+94V0FUsi3A5M9BnEZ113s0OrEbMWHGe
icEgntw4vJvWWZGFdLxQ8dJKArrZl6K+t9hmWkD0fsdtZbsAT6u88mPdPfEB
9Oo4+27DNdDvW9f3VJCziYb+HD1Of28N/My7lV/P0OYCc1I/Vmlk90EjTvw2
dXUh2+HWCrzyWvbYI2QD1Vke/n+7pnOHRpjEQ/QA76IFe4kwpo/TkiavbnyB
Fr7K8CLum+RDTL4X9tH9cWboLTS7h2A6ZkUEnNsXCZ1Gl6+gJLdMh1p4wf6C
Za5W3SXVKWSmPPqngALAixzzKZmVcnSR661NhvJ4QP/Nuv0JQaM4Ak17BpfW
B4O+7Q9dvIZPqlWQeI0Wmh0M/ExWnDsktFKLrEy8X683B/MyFoMxukU1hcjM
1oZxHSvAq7m/w06kZY+grzFOyyGGAN97TR39TELjGRTCcJOfWfspqL+SPhn0
LMRAngWMigEZoK+6T9Ie8hDrGbzg8+Re4pETZv4Idud/73u2FJ7UECDOcahH
G+L+2YW8hx++hthQagubya/2QF/ldp8Cd6/FNOJM7q46tA32YNYLfPcfbeBH
3dqJf0xoSWKev1b3JZ+kmBq11fna2TEL7k0sC7KJtI155EihpcmOCOixJJgs
9ysaP4BI6RbcfCNAnGQZ/D2vqdwAXbhiNarKD/xc8Lux8OGlGki0fNWlTQzo
Rm7tuTpXNDQgVnxOdTTJ4DzXBiQleol+Qlp19NmFXoN5scz8GG/WC5c+J5RR
jFBl02LuiyA8Uyn0tROkZGV0107VFPO8583Y7HDT/9VF+Ge+mzUC3Pt5hohQ
mZUB/K30hXFgpQ1Gp4I3m8+bxicQ/pXPdAf7dypqfMJfMpYLbXkq+QCOOmz+
cv62I/zr9Nwq0f6dE7iLYiV5tTCVmGDwPZIfvHoWa6KokDjUfstfFuPPOBmb
IZJtenTHkC7ADQfoKsCDeVVXTFeRpUGOcDyJUYA/PKG+3gKpQL+dnCm5uyxB
PU6MEDY6NUP8OykebdQApyohY+Iv8f8MyWLNUtjZgL3bHyI2XlrrNyOly29M
J7tAfF5mfDjtJFuOiLE938TfAzqHnhkWaG6/KnJ3DydLLg7MLxTgqP9JUnSH
aISWfQqU9DH2XxoVBtcd46HHCm84Hc4DPtULrxUZ/21lOHjj25O3oiaYuZgM
fTdpvV11+Pu7t6GBVK9RwxO7xuamPdGkLdrFGGKRY5EIh57cm2eeHg6QXnyI
Ro4zVieO2sGn/bLbvrsvNuPuozuipNexfMAcB1N8j1SMGis65uD2Lo8b6ISU
aTguNN3cRKJziY8sSUGdCDW92eHLOqixJ+GX5le7hDlXRNPTVCJHrdCDGY7H
vm7g/iLWJYteNkUhX4kSg5rX4D59+MQ4qHu7FanNxKF93gzmv/KO3M/j11ci
TXxUlKn3QFxFu/NUpy7qI4+Jfj7XdOHF2J1evdW6e90LqpMfRDQZcTGfe8bg
/oOmwgQomGFE0KXKDvP89ac8g8F0YvDgpBjL4hMDDL9agM7543K+OCrquT+q
dOiA0fNMaUH0D7la0Q8j+LIuqf3w9rd/czHnHmXe92gyRrNjK4clPrjDLSfP
lyX3pqJBKuiVedPfV0VUMfWjdOr1icZXXGijamNPfhnwM/bfejdp+h2EgO9J
tZ0J0AFT+fNnnvtQBxmPunX33R0HjF1SMctIOfYLhI5KbAWagroskeedlQFv
HUTHt205iw/O+ROeZit84XbkzLREkn8QmDPKkx97KK5QjVTkdll/SLHH2Jke
TJLh5esg88drMRv3eDDvvx7WgNa7e0IzYdM1ybagjzB4P4OUKTUR2nN92Uz8
2BBjD3rANvZx4BYcUj/BQnJOA1PfPXHTc42Uk0JbfLorBJkAvz3c6bp6gU0J
fPrz1cA/+6jmmoG8iAtaQu9DevZXAPzg5HkC3q9cIalaqJRnKBm/oiaGbxlg
4ED59DYvut97tXruLtBxmhd+ejFjdBehUOOdwEmpwvw/yzPGGZ7XOSEl7la6
RWoAl9iSuzQvTdQOPSwRGbtqDvbOy/Zb8eQZ1kO9vF3Hvvygvuh/PjFOtdaB
FA0yfsl8Bnhr7TUM3Gkj1Yhwb0SSCQxwTiri1bCDx1KIFiJ7pPuGC/P851Gl
o+okV+hOQ7xsKiXYfxd9LvLAjDgJikRKCDZtwbxSC6P/gAY3KVyQHDvTkaEI
5r/+GLV82OBHiRoJGj9sAl3xYIaQwsHPv+AU/8xHTKST6PzPjX943Rn35+Ur
Qeghnrpqsspb+NUJDyqUiOnFMq0h+kgoftb8ii4mbu9316uGT/CjztZF4irw
f+age68F/s7YRcaqHjlufQa88eESk8hDqjfI31Cer6VUAN87n3C9OeljG/Tw
WSFa/gnohKD+nWNT+I0QlT1LiOoNoAtEZUKobFHXiWQw5X+fLAT1Y5bVJ09V
nmqk0NP1Yh4MeMXlxN1b/CTqEM3s/ZXK24DfcsZUvPFVkg30Zzn3afM2mHeQ
t89a+tSQCPmKvxrnbgG43+6rlSxRwm1E7IyiLtUPMK8REoYqacudQXUPq1kT
LIHexZMzHiby63Wws0YOTs3tT+jtE512Ktu55NyaZBSH/VsUG18GfPYED9HD
iaG2+2SKfj10m8/aeQxvnvi5Vc3i7kiiIJpbZUri9B7oyKU1N8/OdW8hObkD
eIvCU+B7x3Wua6I5E+lWKJOMrwFz9y2Pbq5EFDdBrCGUwtH0oA/r+f7Yx9St
CcrhM79+rRHUjzQPF+5SfOpETAwXEoN/Atzpih9ZMK9oJSLqn3M2KBvMI0SQ
bNB429tCETXeV2cFAI+Fx2ryUCyO/bPF+ab0/gkIc1/IlanMK24mQNvrnC2R
HuBzbBVblWMOuoCGrITUWMYAHa2bPLmZVMcccPD2jtfmHTDvP+aavtxLlwsr
B5i+RH7FobmnewPDzW4PRJShZDoDaQu6VXB19T97ziyp4sBTW3TdMHboZqER
Zr8JvbrO9WQZGC0YUHXmYQB7GN2akdGNtyvIYBPcK8cJ/Ew8l0kRzowgNoed
0cWrPzF/b/djpmOHvSqofUpPREAfzLP8xS/wD8JtgZaO2fAvkAHcKYWsickb
uxM5b2K08GEH8LHN9603zA5LEeg+ng/nT5Cfa8l4ExCuekCiu0X5JBJAZ+D3
+b2H7VNOyO7XtxPZ78BckpPT32vG43GQs9WA029KoOOnPGj8424qKVou0Dfm
7wr4CVmMFUPGS/dghGiNetYf4BXHJt2SuQMJcM21pouE/UHohZN8I+4F5/2R
vT5UhE3IgNR5AOZP/4f76Refq6T55oRuRQRfeJFjDg+c+NnJqajXuE4UJbB9
Wea5BvT8Fzl2yBoLhpFd9gOV20ngHH7KnKQqw+5GfhvqSgpnAl5WKd8w/Tca
w89za+1N6c7umHPF+QI77cJcCyQr9pc6pQLg2E+k+cadVNuR+MSFwp9XwByH
5iuLFWWrIuTevaQPuATAz0+dCvqkRfyhhyF9ZDZnwX5kn/feba3YwYi2YXtH
NRvg83SF1+N4jMdC9mXcRD+5gZ/jK18SrC+eR4fPDZu49zJg/Hx9f3Qr0VoU
tizV+d5zCPys29jHE/PuDVzvklYiIOaNvj6p04kf+eGwnsOr7Y4tfln7DE9E
/jX1/9vxEg3pJim9UTaJ8QpfW1u48MTP6OZVyyc7YqhJTOTS4gbQJzH43qJk
LzwGOQU88O/ym8f8/3Wfp1C5EE8i7y7dx3/ccwzwIu+5BkHuJuRP/lnfZFXA
r7sRacG4ea8V4uEQObNqD/ii0r81larw25DpPbYUfFXQlxFn5WmqVchAnLIW
r5gIgP104VTkCVjxIZC+ceW7zUKwdz5B6+Njv9exCN7zmLSiCpBvi9cExTz6
EAXVC1U6iouDuCF5OKSkgo2HltIZuvWFgD3dalMV4Wa04rBOAMfwGC3QcWKK
Re8WcwfAr2qdWTsEnVCdE79RClDt2tf+hE9/cnb/ux/ZQtnuaqkHoL3qYfff
szrBj06e53blORj1E0dn2p0+FnwB8X/EpfMNl9QOxCpZrLOVg4v5vdY7hswK
w8sI5UgCeb8k0G+Xq3WsWlwfRiqKlfEUakBdc91HW+GyeAvEp8nYsOsMzjO2
/UXiOu5mJOWHPs5QPeg/MvR8zqo2Dke+rpB4wcJBGDuj0QeijP/VdVXxWKRS
NwGOGh6dFBh/IQ0xOL4tY+MI8KsJC7UNxCUEwqOx/ozLAeYxr/DZ3sC5uYtk
z+qVjwcD/QQG8lrhl57isDTXl8Pvh0DX0T4l1w7/wAvWs61Reudgi56eT0GP
Gsc+IjwRDxzfd/ef4dUqJvw7zxpDSlxwwRtU+bHqBjuzN+x/cv5ZXGSzw66L
o9xfhrRi+Vkwv3dPhPhw0gQXfteLXW4dDnRoa6oW3MmI9pEt49uvYjfAvdmX
+rX3/uIvREJnIzOLEZx/M8f8e2eLG6HhmuqIKlowh+Xon4dFM1KPyCp4T27k
gfNcGLEYnWcTAkmEuYkReoB6OaDoXW/y5UiIIDBPKVQC1DuZ763o4wqyES1F
uEJzAJxzI+UiQ5YcT+h9pA8erdR/+LF55mk3CSYQyPap1toU4JXlvrzwmnZO
DG7voa63rQb9JpHBCfvUDCd4oaA4ZSHZHMNrcin5e09kpw9ejkkep3YaQFtP
4rORInFI82ICGluMPY4dGQSfP4nnUZKRL1s0RFHv8QaqHjug00XpaaMlc/88
zJbZ033zKwPm9+p3cp2Dg/BQnqfEFjEM1zD2kLchAk3B60ixb+lecR6I2/7t
JffU3VCITsaqSswDxOE7iqLBWE6fEdmyaxKXq4Cd6PFTEWGsTOioX9ecHgH7
d+Ab5MhEzhsoefb7QvdDgDtNDRXv7PAXI2a/al9a1APejllaXovuT77Po/il
Bau0cpj7ol61IIQ7YxDan0IKg6zAHNP2r1eRhIWisHfojR2sR6B/p3yVUBRX
yhaeHV+zEkwwwuz5isIi9HkVUga36ZlQculUoZ0n+YabAZXHCl0uqk6VIPAs
IA6uPclPkvKeiRu53UOdCVvxSG2Bnye8fI8lpUlhOUlX5Iod4IfAv6fGGa5f
RL/jTuAZloC+zI/wYhGhbwcI2UoJJQcd6JepSllc2pIthh79vJUpYAP4HgNb
i5fviZchz2Se51UqAxybeoq4ayXnEyRdZGVMRADwqLzIn1a7FyIgu80XJXKP
gL5TtZH5OMudcuQWYTSHRgXggzGzticcH3kjfRdYFC2aAW/WVUQo4bDrD/TR
mHtEcATohCSQ8dCmMsGwkGW+qcIBmD9apU16x/vSFI5H7xqszTzG6LHYL7a9
J/+UDJtHJtOs8mSgxCf587YgP3nUeB3qqElp6tlfAtekneBOERH1YSrs6LR1
HyFpBR3m/WaVT5gN/pyH84Jk8l77CmH8WZhH/DKYhQrtbcz6YTQB9Lt2QouM
ojtw0EFI4vjVAZh3+GQXIbHsp/yZPRTW6Mi3w5yrt0ypAvP7echqhqBO2gvQ
H4+11mL+8K0GWvIgH65kB7jHmXjphbfRAZBJx4dNUyOA+8GKqpSm4TUI7824
LtpXoP8Yp0oWUWP3Btnic+l47gD6O89bk+Tsk7YgEp/FyJdjwM9/Bu04R14K
wr+wsgONR8He8z3VBbbZM4bwGM9T8+VNHYwOcI3f/Zn0n0EwQenFIFGlt6jf
ST3ILO5ZL271C906G2XySXUCblXc/H/7rV+C00o45+Ft9sl9MwjoVN9xW2jl
WtyEwu+13qL/CnBUXF1G1w4LerQm3a426i/g5xA+3vOIPnsOdfSdmlksAPcm
W7zpI/bwUmSfWkNnOxTEzwcDK5TeUykIt9Ke9/2rYC6pm0KtAx6rh6Jz0n5e
IQI43pmXv00S3N2h3pcfb6oJAhy7OhTXrj25DsmJKPXbVgX1KfGzzeesenEI
Pul77pkbIN+zcquz6Xq+CzlMKV8mzgS4uqfb4Gu+Bn5YM6DT+ro+mLP7GT/2
N8BBC/6sEZzPzQL0WCKJ/xzZ8LjAgfZvusqnA9BTfMOH32VMTgWBT39GRP+z
X1dithqxvAdDvKSvV0akMP75a0QYhJ1Piv6pDbq8FKKIsedmJcFbeBzorYy6
n4TkdzD2u/TfalMGL6If+PrlpD8AvbivLvf2buo2IxrPaerEysD32s+BkKrm
MAipcjPoYlcEuJPSrhDRnbBmSKnM/ujuOYBLe+ckaPX7KyB/YS7OgFwwN7fR
zPsr3rIREfh7HzsIB/h5vjqOfkAzFRF28bGdJwV+/ovLgRVRvAsdcs5ekicG
z9PJhzrdouKFO+RlR0qZwHxoX9x6u7KFCnz4Jopg/ybQY7FpGnx1pdQY7lC/
Pnsx2R09xesU6ril7pA0w6XdMVZWBX1o84V//dz9VHH7z9oy8HoW3cevrw0w
+JKCxdubuwO30PfOoYFXDsEezKI8/4WNal70o6+AiUIQ6H+9krZceNlNgTbP
ZrtUGoB8T7qJ+MfE1jdkNpjPU2wJ5GMdlz9ZCS8ZQqzbl1YOnyqDPPBOULnu
2S+Q/MpQSSQnOM+VFb11ny55IiNOWMiTFtBnlAlZ7C7nakEIBygNnXbA+xN/
GIfc/Z6OyBTeHlQiBnGjxbL69gvGHWiogFJM9T64F7aO1+2+mHDBl7UyU+Qi
gE6Im3ol/YztffgL9999aXUlTN9qN4GedOivChx+jWXMfcAOM6+xafvdYrxE
D57/nBZgrBOPkp7EE77b3QfSfNLwUP9eLV2ZA2a//B81311HDjHUP7p0dkIa
+L/1sxnTN24hNHCbu3JOFuho8UCpMoya11HRJPyhX3bAzx42SRwmbP1Id9xr
55QosK+BQNJPFHfiNZQtc41iztIFY/9fCbGxw98Jhe/8aUGHQLx1ClvIzukO
QJKXC8/lvgH9AjnzSdp379qQg9hbT7NgwAPRmkeN17UyEYq7Rje7WV9g7GwB
0relCTahQEGe6qNUsMfERvLVXoowK+zQ5q12/Tzw88vJraej46JwODv7Wo3q
f/RY8pZsN8/ehYUt21Ktc0G/4DNXWFwPgza6E8ZZqRtmh8lPtHP0KoWbH6Lv
l6J7fkwFwkYn9kfCx1n4f5XRW3gv82c5TDB6LPFLoehVY3F0wQz/Vj8Z2BMN
GQt6Z9ykRQt78cMd+UHcEHm7xLjHPYgw1IrLlzwF/DdrIqtZtpo3UKWWwwrz
GJiXuXyd/BXv1lfoptTyXlQNiOf9gaURG8ERyLwIYXybJsifp3Kbk2Qc2hHa
FjG1Wg4wZ/TJ1XrvcmQWUqmjcpd3FvC9PYPqan3MVyEmJ4rLqgsjGLvQuw3u
zhl6ONRIr5x9HeixdKULj8Ym8sPHk0jEAR/A985kXGrfURyDKt9n7/MvAf32
qftis37zl1ExnduLD38A/EQ6QQxLuTgAffKFvMCwJxX2POmLjW+WH5s9MECD
UtKSRT7YYHSAcSmm9W2876PKY3pUTP/ZbyJDX+FSScuA/mDhZ8yQAHhU6Wvi
Hqo//ci9LFdLNn4wP2gGj+nX2IVCC85HpblUQMdJr25Iuqi6G9r2zVB5Owvm
ktSMZzzTbKORb8vx3tJtBRh7RG+YivlcB8IznqMZLQl4p1mZe6Yvr2Uhii1n
XDISAf48/G3xA/HgPLTB98vg6STQY2Fp0A3MDaeG0zQPQzuGgR4LDQfLdFTk
LfgH90IKR4oIxh7DMPFolpUWZaTfujAt+BATT6CXcf3eTMpwoi/r11VfCUzf
anKIjNi+9RM60hcunv+kHj6K/2dvaRC/ZLtkiS70RMUsLTvBp31hCVoOan9i
ZdRFI0Xme78U5j2H4W6eivtMKBkN3TGTCOCjUnzTXlJL+4qw9u2JHeUBvLTk
scQSLy/n53HeJqUOfA1MviebTJKTHdMDWUR+mw3CBTzqKU810aGFN4i/5gbP
3TzgN1heEm6L6kSGKglNiZL/o2NGk28qNJWBSPsUBJQrgn7x3vLZrGbTKejr
kTBsqAX2Ir2NVP514w8FfL9Ar72BCexbjH7perH8FR0cdQS3I2JAj6Wc+E4F
tyEjOqQz/5FXE/QFKgiwV1xYHsFKCR1T5yelMfeaamc9pw3OCrp3ofhrrPcG
LMg78v92HSozweMaF5Q4WvWFJ7UP/Obk+SOu43PYX9XQ5EeSrEK/ZTDveU/4
e8LvKStKQ426lhwC3sWqzhW+F5YlyJjJ01U+ToALre9NHMZ3pSAN9ZpvZiLB
9/0OB1PRk8UeKPbJpY/Nr8A91X6YrZ5hFIjYB6u61ZoD3sj91/zH0UadyE32
XJevq6CPk6KdUmlVnoo4nl0I28YFvGhOAR8lkq1+6KwZod90FeBnKgQxrG4N
k8Ll7q1XVXkAnnauhO9N7zkKGB3tSjOjBfN0Hu+T5Rh/0aENNkTzJviCGLtO
O5T/rV8XfvEbZ67orgSGb2CU6Ltg1z8On/7UPf9vz5f1NHb9lfv+6C/Nnj2q
b0FwzwkeUrVy5mlohjZqIjgRu1spi3kPeZXM4fFZdrR/lsnl7BHYN/rxRfPf
9dwWyCnW4QxzF9CJzR6EUsU9KhGFDWfd+bL/8DfKRbm0X/VA6ylcZTg3Ae4h
aqPLnNanjhROWj5PTwQ6IcxCu9+GH3QgSVnrlnatoL8W93H96aFsLJLd8Fhx
IBn0UwZp+GzlExog7r/rjKVL4HP8+Z1ZP3qZAP6ShDZyNwE9FjFxGXo+IUJ4
mTe2JlWbDWMXDngkM3XrGlpSEa0lhACdliOJN13vjfTgTDqhsntRQhj/eOb8
nrCIO4BvZMz6CsfvoAMh/3hlQr/XjdyPolE02KX7S2wMLHuCh/iFRBvdW3qM
Ov35snr3hjx8Oq/HUj+/xx7Ijl4vuf1r9wjsp/ihXltvFzYB3RRfXjfmBPtG
N4mfOOPYtCOVTG8Nxt6CvUhFa/crfM51Q3nfiRPuEgL9MYVYnpYnrAHQwAPt
z6LSgD/51OTKGqX1F+Rjy07367PAb7aDn77zUngiLj7TglRxYC6GqHGUM1jR
RXgxTpuWPsj886mdQwGLXdz5DGxHOKxL3An0E8Jl6ItoP+5AdtREBMq+oF4u
Q8jd6xWJUd6gvSjTLhDPCbMpvJk5dGHprY9/w5JvY77vur3bery53fC02DkX
mcEvqKTEv7yaZXu3pTYoA01+v7BApZcBJ53gIVa/J48vaxqj9hPxCtj4Cpg+
Y0Pf49y/T9jQlKnaNCEJULeOlEh7rjcsQjrdFJNy2GDvW2Vx3DAb7ggyZ16+
oHcV4Hv2L27f/kzSDikveXXjbYHzjCNZyenGGgfpX/bzvC0Lvu/StsXhTY0t
iC+Xk9GvGDDHEXnjCU9yqj9EzMaVWu0A5rINo2p7bY9rEJ5nTJLhX0CdUsri
zCzSsgWFi6pEvIw5AJ/vzcf8jN7TkEp0vOXUCvDnnWrXs/0/VpCiobbAdwJA
v6X4003GwZ1HMIedpO+u9TWMny9R2i1eyymHZdX69G6UF6F2J7zfI8I9wqrZ
KtRb3ouL07wSHjrhCRc7rtVyf7VAHyJOjC7mCpi9D4rmbzMraJhRl347BeYi
cI/c84gq7aBYh9Dv8blyVwHeSKPwdOvc3CwSa/Q96/0q2F8w+PbKfnlkLSTg
0uW6sQ/6WeFR8neujKRDxGTigyYuAMe+f33VrsqwEbHhvlCeJQv8HH6RXT1b
MgXaLnawoF8C/DETko8BZg2tiJDFTITMeVDvMCo8Zr1ovARho9duw9/AfOi7
q2JYAZeroEtb/mMtx0C/fTTv8yKyuwkpm/e1l9ssYN7TTLzya/6+JlyH+Fi/
5tlCTv28wx0cbkuQASt0notnaUlCjU5wpwXkkR6W0QAqZXeQP9XdBzfn/8NX
hdpm23W6bVH3gdn7Zg8U4D8n70l44Zv3TpIWvZTYGeIPA/20oURShUcLG1C2
Ea8pgTPAUaEP2jcOb6wja61ZxmnVAHfKkWmAJCkffmZ72R8eaPESk4eM8YqE
ao7nQCE6xet1YsDPouIqk1cpa5EQpjFywRHwuUg9dH80XJkL8bgOD/PvAF5l
s2mh+NRAF9IrTuIUKQT4mW22w6LhHROQnVeJT1zHDLivke8yBBwIEttF3Dou
BeLJ23dWBmv3CeGPHyyjmfaBfkW7ijz7ipkabMky+0qE4CYm3+PHKifi/RoD
6zqq/TLleIP2nMRhOTsPk01G3FpfVo7UUFwckeYrov9vp7hap+fN/BzFG2vc
tGmRh2dO3lPaSG0uPkSKytWLCI7agD6Ff4M3K5fjCuTGHGjBNsz4H/5qy5cz
nw+RdlvLTzV7hBh7Z0ZXm+WnFqQFL7ZAQAXUfUy4Enn1WwWQul/0x+F90M/9
Decv/64sR0r4BFLbb4L8nItnZs+p9RPELFJn/1YQ1JXERSR8XvPdSMXn+VWt
TeBntndbIy7m3ZCrR8KrpeR+zHv0Y10XWvqakJtThb9X9YAei5Xd38utVaTw
I7rPr90WwT5obVX1zftBKnBcuOItVmZWjB/u68/jsZ8JhjPeoKLG0X7o4Gmf
UbDi07r7Mnz6M6Xv397Aw3PLz/uG3dA4J99HkazymP1Tt8lwLcQVDqEnhtTi
bMTnwRzB03yTTbx8aEV75TDCE+xDX6G6Gza+iofez/tW+7YA8IEvbxuoag+M
Iu9j6NWlGcCetXbWAOLnRYUQ6y2j5DZ2MMehXv587LZoHnImyMaOha8QYw9w
J/rkWFQFkdY1xLE3AJyES/CGlYdWD7JBsiorNA50h1rFcy+uMFdBhkWRbMY3
wPxCwiP31Aj/esRd0smwmwLosaSl/rV2uUcGPygsG4xJ2cW8x+BDnkFR0gPY
6QZR91Ex0LF/4XrWU67XG7bor3/MrOCBvjrx20uFZK3P3cfwM+VSJ4ForFqu
F//m7IxsZrt2NXxQk7+NbI845OHSk+f7Oq+9mKamgzn0rt4ZTAf7O9RISH27
NY8RFXKJDzp/7mLszhUPn50TJUVDEKw71+fAvqRnGq/ppX3mEPb971kXjUFf
g6H6HfViSR7EKcLjM7MP4jDV+JKKUX4MMmN5ru4PWxzGvtjywi7LqhYSFhmn
G/MG34skmxVdE5EeZPjQwHjzNugXwDYEwR8crIV/f1DajbfXxuQhV7C+NQi9
L0Wk19aZX6iDeKV/2L7QgkMOF3VUWo9cW8a8Z8vuzNmVpPuwyZKRZlE5qLvJ
yQaoz0c/h38JPN/uW3ZE2078xjh6rK6u2Q7jFMfLGP8fWW8dVVX7/H/TjaCE
tHQqJSAge4MoINLdLSEi0iJKSAoCgnSHgEhIh8DehDSCtBKiIKkognTo7/5+
bs+57vU8f521xrO258zZXHvmPTOvmR5Gg//Ojb43OrXixheBHpxvoz+9owHf
//v+YByHp/7donCc0IA8FwT6hNsn72RkpNCjRipbdg/GFLD2a5EdKx8szqIn
ioI2b2hB3RMZN2FVotxCNJNYkvgugb0nLbbc3C6dhVCa8NvRJT6Qp8h+IZr5
ox0MpYan/smXAXoU5TD5XQmHDogzsfPAExfUp0zNxtdvWQ0jOYy0c7X/6Z/U
vs8V60ZQjnTJxnjhvAFcF9HSvJDQ8DREWoyDapcF1INqLh1TvfGggbWvf0i+
bAv0cPIaqt/PWK7BBWoxV+vcQF7zW4xN1uiUCxxGe9VJfs0Vy1s+KLCaSxIs
hvm1KSWKf1aj3n/noJW2xUPF/OPQsjXRGcNMA3jj7zkTnzGSLZYtBSfm9BE3
qoL+9g4FJkG2Gj60hShv5g4N2M9o2ddOlWnPjmq6Uga5eXJh7fg/87KoCg4Q
5V67xSpPMP91g45/TssgBYKv5PDUrIH8+sdzdZrer/nQ3t3ICllj0KdHJ/Ss
nJGyC1opfLZ+phz4+bsvv7eZ1DDydNdpZEMe+HPb26RNrK8OMT23NVzeDexo
7pdP8fdiocfDyjPa/YB3d/XiLkfswWn4drZw7OdlkL9XfxRWv8ynAB8Y5sHI
ReDn5oX5ZIMbtnApH03FT1VHbP3r+VC0BedkNCyx/+VG0acstPbvXP8JKxs5
h3AG6m62LqSkcRs+81dfDcFduDHIJwmTFA07vKe3weqoQllCHl2IJDq7vvXj
CZUW6GM//4hk+S4vupPKsL2YCvolTvzHVu0EcFFkm6mJreQX9vt+XmofUaRm
bvmAR/z85W9jbBzCaE1EUMVeAYlw5PT5sYB8v9e7+VJecA9k6UfwdGoTzB+5
p/YeRnu9Q2oD5LMTXgOuCH93qsnbq40ISkXEKm0L9lBICIltyAXnQQG7ttrV
Gm5Yu6WtMqReRwUb7gjxn58D/UXGxTg/w0JlYDPSV5weUuDcaHcMye8vMoIP
AgIKNFtssPu4yXzF1SYoPWCunpNTrfjRKIZT8TTySnWSdzXKjjj9uEaZBl/5
yx3C/T5BPKL9GSnNvL2qL3sXxuwt5Zwy55ILUkRFSPtkJVP0sXG7LztjiTCT
MLoRVctglg/6f5wWKYfbfhGi+8OkPi8JQVyt8462VC0jCenc1K6rZwLcp8wD
YSp741oouvJ2KIcEuJ8XyZOUqHr6IEaGRTnWDlCXqQoxfdLW1I+09Gpu6D0G
fZU0b8+2d5s3IEUxv6E6PXDf2pf3r2RU5kGvHjXK+XCC/ZjXm37/5P1OBi9r
tUWPMG5h7cuzjOqrXRfhX1m5piL24DnIJ0jILkWkCd9gVGusO2OG1VF98j4s
Ibm6MN5cbsPu/EMUw11RYhAQ3TwJhzGv+3/PDdUYo837ObroA0aPj2oLgNOi
ov2Lp4ZAE21WIPHKoTHD5vtxHdOOPT0XUe89w9IgW1BnFPEr7qHfIEPrRPRG
2ahAfwKeabEHX20eQjs8YHL1NNDtBdITBsPdGqBlk6yGOd/7WPtCOD3SszsA
mbzyly/SbcLaOSocKawu9SOq3YMcrGNAJwm80Ho8e6cW8c3OGWS/AvpUo7bv
8H3LSoIaq/wuTDICfsJZ3jvoyS4hHJAiZMNNsY21Nw57hKSxCMOlNYHq5IVA
98idF+LmDlCEe1P3c8LS9LH1r6pF8uutuJ+h1beJTzJl72L36oZ4iTunelfD
t3MkcBUp01DM/WxxWuJJPaUH2hKp4opDADgtjMbycwmFRmiOx3CJcbMNdj8j
50gm83igDIrzWgGHQgL0Ldg9t63abqVCv40S9VQMfAV5XEtACFdQHkKTT90W
qQr4J/eemuuzXG6E6Akl9NWVQH/1Tw6vtEdnhyBiu4PwsGHAlTXoILBwrupB
ei75fidiAX1QjmcuygfzVCDKk8/15vnAedItJS0z1q8nF/TU2do14TI2Drnb
TrFhyI0LM1zrs+Ip+gXqCFqI4aVHvPDageqP+Rg+rJ+XRptGQjok4Z6DOe0g
Ci2sXaBtKySQXxLNe/fIgeKsDbbOe1wii/PP+QxbUismaWncRjHns1rGy0nZ
yWi0476tbuGnLBhznivElUo9UrVFqWeE+0/fAJwWLk+ccVk+BTRrdPtTtBCY
Z3xboRM6fHgaJStlN00/AvVohwfS4hrBscjx4KoNWy+4b+W4WeTEuuug2lZ2
apZ+wA8RC+IZdiMchoIZYgvFVkB/L7wkBzWZdyGqXyZkKFpAHC4Y+vzx+4/5
iOl+R7ekHrifK28YE2nopiAXWuSGbq2Bvvr4cNRjJusASmtGXnxyB3m6Yrvd
TL0tO0xuZ2yf5Ac4wKHZErmTCB88oF8/pH9GBWuvtVG4zJcthVq1JFAOqIJ6
gYE9P42kfxysWXTEz51pgGLiDbsgkfkIwWLUaMrjXPnPahgTnzg3IO4hVC7o
HW3C7sVVwGmpcemN/sR0Dc2ejOy39QF+/jJfzintR4Ma4zsu5HuAPrHLY+4G
1WFpUNG10vATFjBnISPWF/LqdxmEJghxf+gEfuYg4mCPHh+GfqwUiwUVg3y8
Lf5NF1VXO8K1z0knSgb87DKvHhEHBSMsAZ3Ls0JgPjG0K8PgYnchIsbJM9HE
D/qd2EP9qe+f3oKI6bb9e0TA3sCLQtkPfKzPwt3exzdiKM9h/VkUfofaOpIe
FiRkxmEZA5z8Ny66+1+6RVEiMrMVUQjsIT0X9FDGjy8CRnEvhc1va6CY+Lm7
usHAzKgfFZ5ym/kn3oYx8XaqXKyVXaI3esuMkKf5uxeMic/jZfiVXDKuoyhT
Q8FgAzg38vM3O/PxadEtdVacDFLAwzERevTjXk4t9EFA0yXHCOjYxKGd8s33
mVoK3UzIn7l4Y+OQGAEKjxuWI1B+siiJmA44HwqG1qUMz7Yh+0Oa16r8Qb9x
96Aj+0hVMqRuGuOZwAk4olGDpJnczWXI4aH4R7djMKdz2kXjGX/gCsQVPAS9
sQN6SNWKnKolRA2PGdDRDa6BfYinavMq92T/QLr3+Mw/b4B9o8aE6j4GbJyo
zkbLxkSBMIhP2Gi7GYwewaHho/53hdRQTD7oo/Z5tmH4D8pIh9Mqm4grf+Fv
/jjqY2UaNBqEHprvexCq+cOYfDNvCl+lLV8DLSx6rkpVBp6DiqfKVWMv06BU
itMO6kWAh/OqwdVSOLIdQp2s6fHpl7Df92indQKP9zUSpcjoj38O6Jyv1DNs
FO6OQBRpy/k5P4EeEjtO8EnVpQnhiDnTPFwBuO5zKoJMOWJlkNwEobe3ENg7
IBjLTshcV4HQj2xn8UiBOFzlsePa1Pg0NPdr6zQxD6jnplDc/VC0TwjbMvTo
SpSDugyDOLW4D3MF8tV9p8U3EHDhZkdJ6+zUjhHtux+aTygpsHbnkaxI9ik/
OC7nNYMLnxqK0TfyRSu/sh5vwZhXt61/+e0U43fKOv5EodZdMHQtMQzG6CcD
u7OD+E90UAI/LiJWFgGQpwQxzNq/pkZZRm/KTK4BHk5/4ASdOHkX9G1K0J7e
CtQfjdoZ6x2chxH2p3iwXC6Yv1vAeaVl1zoMnZ7FH5I/Bnp1qI/Y9BemWoRJ
ZHAjShpwn25nHhF2z9dDerlcEYY8oA9ktjXe8eh6BfI9wW3b/AjoIbWxoUfj
td2Qs0X+3LAO+Lv4nZb4pRU9hureWN3K3QP1DnbJq38ehW0g57/6v1CZAnt1
0yUcIjcmqeHTvSzOOndBH1e9QpC2Op837CghcsZ+QA3F6HUDzOv4ezwE8pZu
91ejCPBbMfqeVJJXnc5QMrqPNj7XPB8PY/RAMsUqWklHfZQp2PScI985bP5o
+W7M7NN1EvQkRYXyywHg4fwOh5OE37dAC2S8pzaVAFfhh1SXvPy3T0gD88y5
131AD9nt4053OT0E7aQ+Jg6+DPw8v50/pJ5TinRW0l5yXAdzMexOR09rOFqh
wr5itH0c5ONuuYlZ+1SlyJjD2XNDl8B5pfkNueW8FySnqKNPzTxli41DaBdN
SaL5t6DO48hrTg1gX+3Czji36c9fSPtj4ZX4B6Bvocsm7VPTNQ74Zvf600WY
FvRjXE2h9hh2gyORs2SBmuooRn9uJmRaxLk5AfO9yt+aHx5DMXq11nBzqStx
IarKbZ4q1Z0NY/Rtlk6dG3dUjNCHBGIWgdAOlk8ediBr5n6wjTgoe7WU3F3D
+qEWt12dYLoR6bfI59fCAfUCwW2mRXLTb4i4IE517QjI009RrVzCGe6BkjZz
Mv3IQP1ryObijRDOXMQquFWH6xuIQ6yIn57oB72BmAk38Z8YgXP4rFAh5VBe
AaIvKCpd4w/8zNuq/azoWSvyMMGlpGYP/C5eI/TD7p+XIAbS8N0L2yCuTpyZ
0B6i2kIOXA64gxgAvx2XXPhDOTsfLO7Vbt9ZCebreaXKJ6OGnOGQZVbF+Fvq
KKaeoltwpbFl6TWs1p5JyHyrEcXUXwJbmaOpS+rR1oBFL+b6ShhTr7lm2mW+
tG+Cumy23te8zYyN271WUupJFjYgVVvYmEwG9Peyvp7pd/dfQK5VvpF+sfkf
foth1LFCxw4y2PMoeiwBcFqEA60qLX83QwlkHn34/UDn9FOZTNNJC0fokyus
W+8C/kziVPY6w3Q3VPG62pv1GfDzK98ncr2TqQjr/HAg2zWgV0MTRI3GVP2I
DanYi5e7IK+PkutdcCSbgkZcZgVEGQA3CdFKeuTY+BVRS7EwC8cDe8xLbB/6
v7AVhBtZBY+WlEDfPhdvjPS2kT28CN96K4Kvju1T9eKYle6IKoS1LouXMFoU
oph64j3GPjWx0mH0jMDFRyqTfTCm/ohs79u9FTJH78uP0uxkiWL9/EuzAIdN
6xRs881ZYWkQ+JNEkwsvv3UPgW3O1dI8An3X7zZ3UVt3HDQjKF/+/ltwnvCP
hi5r/xCUc5XdcovYCcbGIebhwsObi/5QwW27e/bFoA8n4Ceb/lXjPohSq0q5
jAb0OxVHf2zGvxODNAc7vo86C/qBq72bA3pODSNZr4gKVE6B+hdOZHIx4tgP
nQ0oF/2R+AHrZ+qALlWupE9IUzPFeWaxH1g7K4nahmSYECwdPDn/YxvUO3hc
RGNnv1nDJcr012uZ1LB8Wve4m/q1J4nw96hyIZzUZBRTH28biBx2SD9Cb8x7
hihk7MHv/9bTO85VKljftEBfNYtm3Hh2GZvva5V+tXovygxP2tDHtiFA93ji
WmRLpkyCcmcmcpEaAR5O5u2SUfolYlR+8UGvfD/gtMjybvv3pncgwTMUO8vf
gN/OhHrkKP9JhsJXGFQfpIO5jJVvrTXyxQOQxVqsIhEFyNO1g/S+S32zRsrw
XHjbgoBOolNM/LQjegRxqDJUmKQB9zMNc1HxREgjJPyet7WrDswp7D7M4qIu
60YsA/DIGN8CHbvgymm9eZJ/vmcPLWfYxh72OkH07TkPikxhYc6ZjOZ6Vax/
brQlRp66Hg7fYJ2VqRmKQjH9HvramU33hldhzOuf9vX/2eupEjRpJszRZvU2
6RhpwGmRytJMx13hhOUWh/haCAEP576cvkYWMT36nlWgGp8T5DXjZHTZOgPU
aInq8vV1qf/UZZRukG/9GEcYPYrxWJrA3zu5iZjjpYI8CNrRkymlBHP6C7Z5
MR8c30IdzDalllNgDt03b+hBvv5TqJeP140pAOQphft0prRTI0iglQKtZBT4
HcO/yXz79TYX+rkU6w8lgLm8toIFTh2Xaoj00D5fVhjoANucG6rudgJwW9sT
TnxF8Lw40lnyqhrQh3PxB+q4N1Swf++/b/Vyyjf7wka9lowjbI9QTP9SQpbW
JU/8DZhpwQQ3KegXCv3td/pirHNOh98Edf0YL9TxSRl7nZaHit/Ub/LAENvW
qIkR4OHQx9l/lAnnRLVgcQsfedAPnKTM/+jdBj16k8qbGeIEzxGnFZHPFXrz
SHF2T+03S5C/y7lLEucPFkLmj1QSrAxAX3RchLIkE8dbqNxPa5p8HMzHKTNS
Fr33TYZCzzn4XkgDXCwjvFGv4KQR5BXNAumoHOi3LCPHsU9SNpBb4DfRcmUS
x8YhbmyF1wsKh6CFjSfZL+sAD+rT+uozvgNe2FPXjOGpAqg/+qiHxilTa8PV
SUnNhGNK2Hw8i7wokevbbThIwrHS8QfgtCiGuKLuPTXwerfP+RLbdhTTv3c5
F98+iFcbTUiPlKAJuYq9jjtd8hYOFwcc3uQbpiqrC86HmXHjwLgLaMVSrFBr
DuDh+FXrbEVFsqHnbZo+jX4A57mwfZ8t+89VpLVJ7ebEDJiza3+yxBfPVwyt
y0baB84AvyXDaOVx/QC0OvL9fVcU0D9DKT0eTl9LhmStp2szzoP6Y5ovZx5T
5TBCHWJMwvge9OEUHK83znvEIPWN45SJTGAuxu96iabT93Go78b0XJ00iM+5
JdfTf3Nxw5nmLuHXlcBcDPHFBHO/h9dhhfMvFfQCr2LtX62LHktqWsFVdsZn
zucDTksyS2yhSVUErJyV0W4wkodi+lGHLNZGn63SwQl8adet50DeHTQdokv8
9SNyX/cW26Wv5li9WhsvbDmmSAoVpJkO4L8I5jikBv31tae50D5RXFPPbdC3
MDkXWZlp/xPpOtu4PrgA6rlp1A9STTKLoe5kKkfcKhNwDj8/OIhQ7oe+0hxt
c3wAOsl0dIbRiWMidCTlJJ+MA/qd5Hvw/Hrx3yH08nRaaeygr4+LJ0qsvSke
wfljl+RrBLjWhSQ6D2nFJ6Ed9dpM80zAETJUeiTIx8EB+3d+y8ETJMb6M0oy
oWbKSREuV/JR+EpzBeiraeN1xcfa8EFGy1HZBQfsHszd2javii5d+O7vLaOh
+ccopr/6/WJp9j+RO5xgQz9iGeuOnTdf9jR72kF8Ce2kUipNLAU8nBzpO99e
vVdAb00OrKgaAR7OVRwuR/bLAijTMq+5PDngh7yt+rznenYb2Qx+kVLycgz8
vdt+TUNMX0Bx1bgyvxPAfdtWlmA409sDsbQHsNk5AQ7t6ocKmnePHkDTsU3n
KkJA3jc8t8bfSf8WgVZj8yjXQV7pLMpecTQTiVSzb/NXOQI9SpfnknIZ/zg0
dCB7svgc7LXnC6HwfmLBAtud/rIzb0uK9ae1HDdTjthlONKKh/FAGeytI6Yg
vrx74QpsaZOIy6YCOC1oQRnXiqQy2qo++uFCHeC0oBa6D+qrLdANdkbIySwD
xswXXFc9liA/0UFvK5gYTE4AHg43TuyLLM/r6I6y+jlSTcDDSbeS7DKxFUFF
OR+OnyQDP3OKVUub0+wh7HzqGwym4Dk1IrJxw0+0EGrU6i4y/AbmbUef53kS
S3ZDUjPB2TEioB+yTHKcXs0lHLpMtPQaaQL5Tumpx1U6HH0IzPHMpJsZ6CQK
kp+JmNdtEBzeb6aQkzbWflX0PS/9zjuIs+atvOYq6DMxyca3ORqkhxlYI7OP
/uPn2dld8qcNF+ELy7PmzpGgH/gubPBmZ+ECbM95u03hyAD7XOOVLTtvaaqC
vn3qt1sRCfx/7d3pDVGqLlToaPqK26sxGDMvM2HGfGW/1h4lC85vD88GPJwn
HdsMtLd10GcJlK+bmQAPRwtPYouH8SL6irj4zy8BwGmppIrWomjbRzI1BsMF
KECekov3QS9pOhfaNmE+yeQAfdHZYkHnCl92QGYvI6uiv4D7E+dQ/Y/bjBTU
9JDcrWEBcMtFDLdNh+K6kNTu5qhNQVCX8am9YDNzHAXNmq+45WoBPiFvmrXW
oVkXdGSbMGBUAX5HLWlFnuj3p2FvUXpfp1xwbqS/5SLgxj0P9xgdX46kl8Da
eQ3Eyb+mUsMoi9uXhRjAabG7lN0p7iKDelu0KAhPK4F+hnyrrbdCwzDm9ff2
v9yhTdwE8RJxX1Sq4+ZK6gLg4aQ56t/z8jBGa9MsFsz5AQ8n6I7muF+rFIqT
ENFx1QZwWih04/+Q+O4j9p9eWPRkg3r07fsEUaeU0qHazFBSv9PAz5bnpmNT
7rdBnynWSLibwe8SF0ZMyz56F4mwC9i13AV+7j4HEerMtSPyzlOifXjgfn7G
HDsftpAL4d1acfNkBfO8FJvXqdaf1kJn41kussaA/vlr9WVhueTk8O5IVOlY
Aejjspzqc3rizAV/deVnTCEA+l5tsHO4A/UOUnCl3694CMxxtF0JJ6LFp0BT
qffyXCCwJ51Hwvma8p1l+GBUOvSV3ie0++8849Rx9F7dYhSKZmYxb2smwZj5
x7bvp+zMcWxQBedlGbktM+y5XeUhYCUUJIuSoaMXyj+AvJX21mBH2tMd5DXO
Q4fuKcAPuf9OSZ9ELR6Sk5XB5wx7grWrBm5J7zc0Q3M7vYsy8eB+3mWcusE/
G4L4qouq6luAfuCHkiou5n3NSEdZOI8UH6gjXNH+OuX/rQwSg1IKf9wB87wn
/PoboeseciHkdP1U9CrYeE+oajDh2yg+7Lo2/lBmD+hOh8grFlScCc66oRso
MAXm7u8puWfabVCgH8Th319DAadFrinoTZCOELxLJ/r2cgPIlwm+W11N+NgG
95ePfwoYr0Yx87nppb5vxqtz0ItZB8kn4oUwZp43ra8iijnMEQ0hry4lXbLG
1r8WFmrO6HDCaAlHqRtEB/Ju4y9UH1c+/EBqXegDcP7j5xjLsOL44yBIPeKa
z6+3YC5mVFaTrcuqHnrfZDZP+xL8XS/iKJ/5XB+L/ECv4D+GQb1AyfqDi0ZV
DVJWniWRswf6dh5Epr1NkqmDyuIom0Q1wHPBT1gpRlytCln7fC9/9A6oB80S
mOrojRxBwsxkdt2coL9XutnGXp3pNExWdmqRrRb0XX/ne3pN7zo1yjPScpvX
HfQthK4RE6v7ycAyRXVbl9wuYP3wwni0coezFDb7/vOtZkQ6ipk3ZyIrFXoY
XYfWRi0T8Zi9hjHz6feOU6/lXnNDLY/fXZbPAjycPYtw0YlXCmhmRYfsQwVQ
12DRC9vxyZ9EcovFWv2dQX3KIkva6FWoilzms2c8C6ygroqbkSSvEVEF4XlP
3OCJB34LCH5muS4ejzy5F1DffB/k0fMUo1Jeu0VIkmyX8bs3YJ63xH99UEKk
BWJp8I76UQrmFEJcqPPJfVFETJeU+kUAsLs66Mv1R29BdEebAVoloD9Bh2mn
kz6GEB7vFrh9IAh0VO5LRIm/1CnQ+tjVCZIhwGnJLHdku2+oADvKJX166QH8
POsNxUx+zYTvrVzSqouPQjH8hCHfcVRhbwx9IlqYwuYzAXf/5S3Q/DrwzS/0
QSu2nOJScm7BGD6DRZP7d8nVKyhpNrfitWagN7IcKDP6b89BcKyvwa9PK9jv
Rfxa39R4IwB5W3g53FUF7AuY02lJoNt4CaX69wtSrv1nj4NYkrjVWDyCJ5es
XQmB+JnhjGent380Qn/QL0LnA+YyWFPypWl/tENxVY7+boVA95DaJGherXmD
FNw2S5hmBX1i3mezb0r/WIaGSWsGz3IBfW/GqMOF+uQAYobmfifsgb79YmJy
ZNuRAB1+zyVhFAc4LSb+PEszLIrwx+rd51qyYO6ehuHk5XF5PKwrXykQxxeE
YnggyXseSsOkhK0E9792qLkQymP4IRfUcKlHjwNR23V6YUpPwMOpaakxrQlQ
RGU/6dGk4gFOi/fBfpUF1z4UJe7C3B8F6hTD6/5kIotPkD8ioh5aRGAPVyK9
6dpdinzIUTeBEd+pGOQp+V6dV/PiEIcjrzQBQRCP+T3O+vDO/Cn06me8k6Fc
FPY6Ani6Wi++dUIOHUWvJ3NBn6TGFTsdac1u5IXW7yd5rkDHLnJrIiLa+gAp
arV4i7WAOTs2eRMzp77vEN+hABWjEoj3GDrFRp5f20NyTu4G3ykBz03Zzz6k
1WGKcHKuqm3EAOBoNcZ4PzQxiIBTZjw+lAj4oBi+zcSykEpf1gmMeV0ye/Y/
u7q7Vg+veARKR4rLf/myD4zh5/j4e8l5sSuihsl/rgWxg36JBrVbN5m3CWBe
fNPKpijAaZlyf9OShiQgOBlzhgpMYJ+gj0b9fenUFMh25eygYzDg/7e/dG48
cxyNjIwS1/KWgvvcLuIiq7NZIaQpuY1f9Z+9w5YXRbhhw17IvW4klaUa3M8L
Ho+Dn/H1INrfBYbswwEnjV9jjthdtBN6dbdsIEIP7FWniqfcGT79GdLEPQgw
evsHa5diwhfUgmYRXYnS2fIwcP/L3veK8d67Am+UGmjcXgJ6WswXmZI3jEHw
HS0UH3IHPBz9VLpSIXJCeV3c3KZmF8JW4798pzwaSuLp1HhU5Suj0axCEIzh
QW1LnKq67aqAqkyMOdb9Bv0/339Zr8x9p4B9oIdvXEcBp8UQr2cGjU1Buqh/
b7Mzg/3F3x+7lxCMR0HJ+uoajBdBvJf3JlHNszYc4eB4UFZ1DPS0G71pDKK2
lRB3WujGsy3Q9zhwnYoZEuuHtJpdeUofgXP4PXK9y/9LN/LcQHD3cTm4n33w
x8OU3wfJbRS95t8buIF9XqgvyLk0Ug1DJWPPdXwLwLnd+HpeIfjVB2jbda2w
sQD0G/udOT8x06oAO6mUksjeBP1FRoOjcX7vfOCPR9FMFiW3UAx/jFcy7u37
gzF4uL6V59S9CfTS3/N5UFh2L3QiE114qCGOOx4FY/hmQfTm/MTfZNDimA31
lTDg55pvxP2lJdRw2qeSlng/oJ+cE3hopl+SjmgbTM542gM/S0yPv6ya8YEy
bRxt8tIAF32zJV/bjDkAsT0KDO69DPbjFKSS3bIkq4NsqteMcTbB/KP8A5e+
Cbq30C1+X1XUC+hy1Ezqm/KHXQiXecARlQqo59pwDHGE779G7kYMGruZgv2w
yhXrqbqSCOTyp5r/2QbYq4t///6Z/cQNqEDmhqu4MOCH9P6xflWsBMNhvyIF
PEmAHmX6ydvW9qYbzLfN/tK6HPBw7H/knR6Pq4NRtRnRz+av0ea/8QbDLGdq
H2cpmpsyEv56OR3G8PoYjvuTEn+fR++LXPAnlwTnc7xKNO10HyXMHdcW9DMZ
cFpE/VaZlQWzEdYnSMPZDHBuFBkvfKbIkpMr3ybUGz4njL2vEg5OLn7IdUNk
3/6wm70O9gOmz18uO9FrhNpkL3i+KgNzRm3VZT9OOt9Cfk6rHiMuYK7/C5O+
1W5NJ2JyHu0iNQT3IYmc7w+Gyk5EmmBBsYsF/C43TyUN/Gh/AV2Ti1bZbwGc
NHh3udB1ZAfCi89WRRWBn/OJ8XjeZ8vC62X7h++ywXOTvVDh5XSNI0wV2p51
bt8axfAhD9ZURXaac+AlynMZZJKFKIYn6eEvJHJjqw11yqXhQURrYAx/snJ3
sdNNDQdOFISH4dvg/C+O+/xDoXIX2g1S8IY/An0vI43t8rvobAQ9vLHc2Qnq
KcT3ijIW7t9Fyqegl2eIbmHtl4eePm/Y1keCB/QdehkAh3n6BpWm3+UmaFsB
Gt4qBH2qhD3MM29G3kIBhjv+Nk6AZ/hKk5X5QWcHkjMvWon4AQ4Jx37f19T8
XiTy2VNcshywB7b5vOcSE3c8pIy7iabSg/z0xWEQa3nBPvSMa1wSLZvEvn/y
4Lq0zrQUTP07Zvu3IuC07At7u3Zx2MAZAYtZFkzm2DrjewNqPq6NKLhd6SQr
VScJxfBR+xcl20dbltGr5Evu/NSf4a9/eap30U1DsW0p2KtFO815G9QFYpiH
XiHq1KhhIEFCaT7gtHzBTz0MHMpGSFPiX06lh4A4IWXsW3rdfWRIjVV5bRbw
S8nEuUgZbitBDGm6aFeECPb7eurrvXn/oQmazrBPCP/yGPv+P7WlWysBA1CK
2GywqjXY83L11GIdu0k7ciqv+DPZA1DH+XgvQ3jyqA9Rpv69ZuYE6jhShFsS
hFU+UP7h+VtfjUBfvbkvwdfomX3o8Xbkqhw3qK+9chjP+iByEXYwVHpPJAE4
LVfFM84e5hnDm0WlMtpqgIdTr5zXVCPvCz9IfsRotgx4OHoDn2kCqsdgzCvZ
/r/ndkiExYNCVSX4ZYxSohavNVb36PZz2IxtuoCGr897OVMYYnWnxo7Ay2sf
cpDFisWZnadgj3yCtZ3kpfwAhLwBij7oAfuDViw6TGYSzaANXJ+t1z/FsHa2
vmuqeNZNUPYqwdgrVrBPUzZ/mQRN7YecH3ykGBAC+mrOgllDvkQbst8tG99/
BPbf9e7cGWpP7UN0U2WEN/WA7jT+4jpL1a4ZdGtJeDxdyhP7fq4Br+Isrj2o
3pA/ucMAzOmwHfdEkEeIwKveQyMk5YAfMiGndEIXpgPLKn6rDVYAPBwHMysv
h057WINf0C+0APBwdH0Ed/+I9MAdZyMveOeNoxje9eoy6Y54uSLc0FynIH8M
OC0hNRRnHwheQblNv/1wtASclhdiOsf5DzKR8wb27JqW4PO3vi/cxlsOQD6/
im1Iu7eFPZ/5aYfVJhktoRvbq/PEty5i3/+x+Mung+FGaF/K743qKOCKJJYa
7cSm90JF3A850q6Cv/dLvJJIdjCKSFsKHM4ygHwHp9jro/9RD/JjVvfT52Zw
/zcZcz29Qcog90Ywkzlea6wZ+zsmyXEJcWxDuXVfaet2Aacli67S+K25ANzs
rfLgBSfwc4Z4yYu4lOtw4CMS9bAIwMPZe3T5dwG1LrxY62ZrNg14OF8XDizP
fHaD52h7vuc5Z6EYfjuFkwCXyIEBemNSwDSBKRLG8N5Lr6pM8+PqoM9tLi8+
gB1gDO+Fx5tODs1LQzrpgyB8rQjs5yTe+NQTfuUhcslq5OhphiXWXmsTT5L7
Vg8yyj8SziwG+3nP4QvEZl6vh75MZjg+9ALxtpPEeVyna11QLgGfvrUS0PHS
+l+NLye0ICFVMc0WXaBeEMocl3vVpwthWbOXUN38DwfjgY/jRzkdJFmBZBD3
LTjHJjSrH/o6/YQodC1EvVlBXuO0NH5R7hcX/Ex9IL7hFAvII5iZZVe/K8AO
K3H6pyIAD+fVZtTLQ5lLsO8ZIxn5agfsuX2GJiOg9ZoGOoZSqTKKeqGYfQS3
zwzyUz16jBalvXxw/C0PxuwvODPa29tkYYX2XO1/+7MRcFqGtxaRuPoMJOwo
EYosAvmy9Meydv5gH4S34ouJ2ijYI/k4tYbTn4ZT7rla+3MH6dPY+zz96rCN
tn4NdKQQyL1xCey1dLzz/VXpiw4oz+yO/rYt0ENCFVMDD7ubkHqG09wP5IDu
FxcoRvtZtQMxmpnIryMBfLlExYdEzyo1kFDW7iHmKFAvtkvL3jqzuQq1sIak
0+8AP7/CtVWtrmSDVX2zEwX3wBy6RQD32WRUCv6lU2trZwp01LSnRbGPXRag
cJ31M5I7gIeT0KfmuAMJwvQi0lCnB+gTfu5SaBJJVotqFR/rlXm2w5h9HCrs
FsI6J7fRFQ/OqTsngNPyU1gwK4crGfm9InCKih1wOZJ4YtUq3VwQttgfynsG
YL+5oMxD+9EiE6Q+hlD2lzPY991AOSjvVVEB1er87IqVAvnLmt67vC6LVmjS
KMW4BQ/kd5vPdslYK18j8WyyeyMaoK9blLc4avoagiwIyLha+AE/X2cmPLl3
wwK6LqF7rEAI4vMcw1glB915CLZ4MMPtCHR1Ic8bq2okZ2E92bMN+ZfBfD21
2HvV34kX4HufeazQBcDDafylvVJKxIHy9bkNjSiC/vazPwYWA6/qwm9KFO4M
Vsth61YqCQkRrhc20Aff/H4+iv4FG/7dL9O4kJ+gMeiLqp9vaVQXeARj9tHo
BSvO0Y2nIPXbNBUemoCjy1+tzJHfpYGou27f4lBQwNqHc1u/acw7IyKSd+jS
v4D5xFlqt5itN8WQsp+Aya0CMGfxzVn+Z3FqE1St8WNCjRLcz+bityc4LjQg
ZEG7dvXHoF7wzGanaJunDvlNq78Q3gb6KilY6L4QdgRBxng4KaZNoG9E65X6
rMDaONQufZs6qgX0Zxa4fvg88JEaHilk2NrSAP3A8V9VLvM84ISFjGj1f94F
9S8Js5MSKyMe1Lrrhjj+TcDD4WR0bj3DYwprb+iX1LcDTksZ11XPvdubMObV
k2r6f3a2z0zivUbh6If+i7/S56JgzH4l3af1p4zK4xHd9jP3ZcXB/fyn8dTh
UYM1JOe1775vCfaoEnh2p7d+90R8ikvOLw2C/SDtWVnOC2V50POQu4eSxuD5
dc5/0If+ah0kuA/vnxIB5zMkTWkg0VCHkFMzMq5ugTrj7ObnX8NzxUi+CTfj
8zXQV/PVX7V1yzEBemwQUG/6BujYLOvKFi7JHVDUN46BC2v/0Q/l9Sk08Ujg
HgnlyZYVwGnRi5FibB+jg889v/DB6xqYZ8wK89XqXuVEH59qGWpgAjycdc3Q
3pyrFvDuI9dQCakrWD9/bbNsZU84ggeLGrajsvZQwb/7v655ckzOkCehpkSD
6XcKkmHMvrDnsYKNuLJxCO+06OvUFqBjpP40Oeez5Q2Vju4FzJYDLvqulwLh
8dx9pNro8egYGzgnPe2IywWUkqFT2eTfoE7we+XynB786FsJiUnzjdXvgzrL
vYuPaNl/VCND9V/jxG0AV0Tb0vOFo9ITZPIxmcaoA6jvfGhdsZEKyoPEpBpu
DTwG+eP4TUH5kNvBcr++56gNBZNgnxchd7w64x/hwMsywgItnwFXwbeWXcVo
lBhmbaDdWQ4HPJzU8yKq7HLMaN0H3MnhaaBXLF6MrQqOtIB5OB0YqRelsX4O
+mXWFZU7DPtpxSoFj/WhmH12kRlGqnOphSi9h+nGimMhjNl/Z+9wKkivKRQZ
4qGjyGQE/aI3B15whSgEQw0xv0bD3wH+f1D2XTKlIX/kRyytwGg9mN/c3rzA
MlEfCrGURw+MGAIu1uHZm1ZvuYsh/Hd3njocAx1VeWQohcC8EqHzZ2XYIQF1
W8/u59dvPkuG6A9LF/nygA7gxdtQdYulFOK3yecxvwT6J2VWZy/c3mlGiq64
Pv4nfMHaoeKO+s/DO1AsZY51UQXgtGx8/iMosLILST2yOhTKAHWZ7agUQjPv
U+j51Fxcvf88Nw1JUx0ZhMxh5SqjOrecC1g/eywuGuwm1cNRBZnJXFWVKGY/
Y7qI6F3fnddox6VH92W9GuHgv33Camu39DorA5Esua728x1g3/f12zPStA2R
0PMhnMCsB2BfYcNnGtVgJBAJblppj2XOwNodOhxfFF7RlHMwEiQKuiiLva/I
xF+/cy3Jgzqm79D6zoHz9sGD70iHUwmy6yyxhvaB+mMZ1behre4yaBlKD5Zz
AXtFY7xEb8dMVENVHx66ye2AusC8iA/f+84epO+KtVzIAZjjmDzAN5tx/gZt
5Wh6EM2D+S+y+8Hx2+8/Q2TRlc/6yUE+zuMjImSp8hMxdZBTn3kB6mVmdOVE
v76YwDZXL+tfeESPze9s/HsqZDYL4L7F+PTShmwUs2804Fa/c8DdCZSqKcX7
4MMYnPp3P+kskhcS3euJTOJQKx4M+2Cvb0Wkcst26Clk3JjYwxUPzgf3Nu4+
c6Yg5Pa41jn2kSysPWRswJ7m8iNE3zHkR90vUJfhaJy7I0SeCo1PpKeSmYC9
osJubAEp1gVIhUrFSdUfkCeGxk66t3vXQ5Hhtnv+h4DHspEnV+TI1QjpTOe5
zlkCfW+cUlCDg3wICdsQXuQVBv2Zb5l6zo/tfYIkLa27NGdB/Y56YjAiKeAl
FK0bTDtCAupNSw4jbJV521C7LVVe8BLgJhWKpwraChrB43vUZ0hO42LzxxVZ
3u+9NcmwG/VHXG2OeBSzP/fVbqnSlDBBq199sqwLOb580999u1vvhxHuHVPE
zqhycvks2B8E2eml8zAlQPcnnLsTd0H+a+myczm+KwiRfXNT87sA2Cc1Hfrg
kpTIU4RcIGkapwjwl0Tp/cLiSp9Cot6kVYfdQJcIPbor1qSeiWRRvzib2Qzq
NYoys2JmDQgUsqc25kIP6uMCBDYrBzoItPZ87I29BuDWMo1zzEYiw4jmOfWo
zK/Az7HD5pLbt4ehpi+1D4deAU5L7unYKSHDN4jME/7RCBic2+rbP1Iqz5HA
SMCJFdMk4OEMs7ksLarow8e0mU5CKezYeK+g4fiM3j/xhFfu0VPfkDAUsw+a
1STPeb/oD4x5tewM/p99n1W97nmtDiTCW70g9/wG9vo+O/KtZdTJkHuBkVVM
IvAzrW5MhLFTEEKb9TwChxXocgqnlJq/lCQib0atz3+5AO5/y1WnSaY/wVB9
v+5b3knAAbYbHjFUeRCHUOA9+aV0Hewfb9R/KDPV0w4FPpA201MGfpYw4fFR
7myDrkwZqnusgrpMxa1hw8SbI0jzUpSazAi4z+Pi175Kcb+Gzkz5usRzg3yf
7mV5kh95H1LyuHzknDToR52sSrUieEEN70Yah8AzgIdjHTxLVnRbB376ti2v
o0cA6+cWI1/88pYgePFjug2OmD+K2W+OT8XDcTj+B+4xz1PsScVtvfx3HzrD
iuENvAIXCF6ckuFZu4m9fo0KKdPe81SoWLWooCwT6KUtZ1+2TbYGIEZiKrB0
M9A5Iwn2XYw5UhEvru2OvW3w/q0x0dDQSU+o19F+y8jmETiHJ2reiNX4Iocv
rK8/2Qb7AqwvkNE+33wDXX0TvfOyCujVcfZkK2Y0HdDprTeyF/XAHIdeR+TP
IL0RZC3YAdWQB/XHwP4dSu5MH7kO/8azzzMEsPMLzn+K9ntzOpGqB+zBLDXg
PBH8btmZIkQDp1TYD+nnAx6OFMMG/v3bGvC4D27twz3AAXhDv1oD+3rDs/b6
bsIfvNC+v36effAwgUy/HybPY11FPw6j0N+5URu2WQPuYW8og7zxz2UXZ+z1
NacbSBfz0yFTrgUjEkVQV/XZfn/1E1cA4vGZLO4XCbhv/dR2P/1OSEeo058x
yJKCc2OYhDZ81dwSej/MKNyUAvaoao1aXLBet4UOX5LHBjcYYN+fQfySxNau
C1K7dOiBt1SOtacn/Lw6Q/4G0v8IG3+LBv4fIuRVLewcRp610+wptID5I/31
Debj72VI/J7r084CUEcbMtJpLuR4jRhP6G8Sx4G85tFnKh3ogAZubky6IycF
eDhruQYxlneuw1FjNim3OkF/CM+NF+QF32/DsUFh8iVdgNNyn/Lo9RxrMVzP
HidM/Ksavf93DprtRL1umf4BJNWp+OM2rxP2+l+pazWndzMgSOrCN5x18Fzr
6jhN5vPZG+HtOjXQSA306u2wwK7EygzksM5z8cQtGGu/jUr2bz7hlBM6KOEh
IqTExiFUORcne0IeQe+eGSo1UYO5GFoT/Oc6uN1QwD7nfI8lqOei17KSmCnf
QI3qJuWMwkDfluxS61khGUYohl8/cl8CdZwRvDOvf1TXIemiQTY/PIGfDRqS
BPFOPUfcHnnjLHmA/uHPiOTvOFcauPuY5ZT/BohnXr6UjL2wfRU+x3q+JfcW
yGvGxYrweCVs4YIdzuhgYcBpCeQVCTxfEw2/MiEfevw5C63/O9eP4qnVPRUK
hN4Wbex5Dllhr6/b+z2RMykdEr7rzaS7A/LBQ/JTKVNPAhAnkr7Pl76qY+1F
vR87L9NlIhJ7ARfhBFB/0fbMshI+1EKeqiXpydeAfbWXs/WIXQsjoclt6pI1
N7BPMDCIdXrsRxeE452c/83dH8TPXNvxXfUdEPMjGVuIAsQtnBMyanR0Q8jF
jAGuJSGQ7w/JK4c0nmtEct+ebatUBnH4O2b25SHKh5C/ftylo8umWDtNWlaU
9q/TMONsjRV7JdBJFJ9KOJkRKsCmL12/0XADP89e67x6L8YIJhFeRe4U2mD1
vaPatYv2c+6w0nxbNxcu4LQsv5nz8XcIgNj5pm9rdCti/1/bXmsXEZI0aHeZ
RuV1viP2/90yZQvW4PFFyqwvUZI9B31iNU1Ffp1mGcjqy2kkKxvoe90y3aEj
z/SRtti2xTAjHOz1G+nwQ63VYiBn2sGojwvg9z2ozdhpIOiCtocfHpN9Ajp2
3I3R5MiBdgjPXW2R4g/gsUhEatjcej+AaEf2KdSpALtHiW81rWoDcurCz9ua
hIEg3mi0bY+myIYMcFhTjWbB391e5nvCmkYqOHQodmg2D/BwPn68NFCiJQPv
5kRzUbGDc+PSGmlQ8Q8N2KbZFj9pwxSr710oFvESYNOFuRzmyzmnAaelvraF
3HvnMfzrzXqXkaILavzX/vH/Xt7fh3W7mzM5lK9j99GU8LGVf7VNh/32qysI
CyLQlr9xI4nHNPMF70p4PZ4JdTpVgPb/5ZA0z0Y0OkW+hXk6lPau1XWhGejf
fuMpAaOXBcdwVe5u03TmAbrY+Px/9juW9+aeCyzApFdsC1t9JtBu8n85ulSe
LrBa9wkaYmhNruqMI68kG/Y/+zc5dwavmBV0XS39izW6CrN2fv83joo5/+xg
uB2lH3vgh9vTAQcZ//t55mxOP5HaKkE933l81VcvhfHX/rUvwSc7HSXpqDnT
+Mt+mjS486+erHB2UK4nKBbdprhLcH4kEnb/G7+ZN22dxz0dgkadIlk4w/sQ
9vrrH/6ms5YG5++j53pof/wJuwtjno+kvN49HJfc0ceKrRy6GTbwGiavVAkM
YyBwQguT8hwtqPWw/PYLNs47Dv98I/Qgc+a61VVsXcZ07cWH5zVGqP4jh5T5
i2LYvGkowEIz84E26hA4df7yHTBHLFIT4bMVqIzmM+N2nM0A+dqLfskJ+fcQ
2tVMkM5yQgnmJpYISpvwLqKstVqG3wuB/kYcS7rlP86LnqVVPh64DzicK3Xk
Sa+JGdHmpY2dwnDQR711w+pSrS4xyj5af3vrLpjj9kR/t4j8WUeIrBStCiSW
sfY3sh3RBN6dkP0fLWbzTjAX2Zm/2bA9vwCdP2wYNGIHHLajEeW35CdfoH3h
rhetp8Dc/SxvU83wnVkoXsT/XWEyiGdIbWY5P5L0QOckTioslA5AXOd/7xQ+
WS3C67gvyokL3r9W7ZMu9GUEUXh2rk2MFlx/x9mApNd3CvnY8djxeQCYgy7X
tQkNjplB2Ns6KF0+gj6WWWsBNY2xD0jUkErwHAT2DE5fpmycLBhFyHX3Mul4
AU9Y8OMPStyDTsTDtcqeCQVx9arPxS2GsizkUHRv4OdTMC/Wz3EobPWxAYoO
6OjMugL0bUG+LvqJ070QvlLxWOgg0MkzmsiWYmLfQR896KYES4B+a/3jke6D
P8OQMt8Ix+koELcw6du7nrx5By1TCBuoaIO5SM3ggsK5mj6Igu70hUPh/+zp
E7LpeMbVDq3XVbNM3gXXkfY/GtaML4cw3DuM/f76GavG9RREzYL968vud1j7
E6lMts+EjQgTa+EBHAfqJsIeGpvLhx0IhoOFsb+6YcUiX9+D+GxOkEsrgb5f
807BrmdjfchLAk/zq63ADz7xv0iu+PUhLddtWwLdge76Eqoa+i7Rg3yt9lM6
HgB6qTffl2GaqDeIXUyYi04B2HMqpexp7X+IIJBBNKu9PeiPdV8fEM0Nq0Uc
friL/eZ7BX4X4evaREEvkNCObaEJ7/9wjcb5y752xyOKphtst97FYu2/IxsH
bX1doALZ3ifiLoCTVsVw5/Epgzjo3NIjF9wIUPf/MHPrfghFEiTxUfZRSSHg
9kR2iUWICiRAZZmKjxVugH2I/JV4mZsWkRBmfg5j3/ygl96K5wppsdPzZw8C
+wXmz75fIr0Q4TzDD+/OATsaY/99quExcpbW34R9CVyfc/5VpvpIHLLI9ZO0
vhfEgU1CBVd0guKRcHoa3hYxkLe+96IdbCqNQXC0cJw6rcGcl2znonPZnWCk
0jySAF4A830KP6UfzRGbIQs1q26Sc+YgTww/HFWl84PO5j+/9b0QzDd1jc1X
WltHQ3PU+KJ3xQGnSzuwkGJbOhFK0i4luv8O5MVLNPXGygMpkOmpbGi8GPCs
CtEXBCPpqdBT/cjZLV7A1WS6VF981zAZWqW6a560moW1K7yu9if4HA9h+p4w
dr3XfmvflcIhTJ8Oxi4nXtZhpucCBSU/PFGnBHoIpdJMWWD/HSTQDZGtUwDX
jyaY1W93CUPufIo9cv0C8ne3V04iTidPEaue93JbMoDvtHoYZN84n4CYa1q3
8IeD7zV5/3V/hm8SkrHenNVNB/ZgOoZzfRZ/kYh8+ojMlj8H/rFJ//jJ2ekZ
0nkYduoGMdDtncKIHr8vjkEsx9XuXKQJx9qtzo9MJRqEIQaS+H/IBUBeTJv1
naMn4T4iHfhymFgV6HgcZJoS16/eRAwNcHBdBGyx9mX8JffIcgWoQb7zrUMz
iA+/+ez8k0vfhFr3HlYPvQR5UHt/QUat7m3oVeL5e1+F/jO/f/bktbKcM8RF
yn32WBTUF15R3Aky6LKFhIWNpYSLwbznymILa5OGJoTJAzB212UD+jeLioix
yCsftzYQh4+HPH18WcUa7g6aXfpOo4+dx8f/v39mN4FV/G2CuelUsbocNHHg
+VrLHtZdL59hNLDC8ig2X/NN7aq5wOZqc7GTok7YPoQ99XwbZjZP+Cq/Gt6z
Yg90/K89woijxiveD96/03rSzeSP5vy1z28l1R+ahsAuGWO63tciUGZMXsma
MXXaIBbmauavPfBPQLP/9kdlI2ZTk4npsHQsXPKoLg812v8b7/EdEV/aKYWF
aIhp+XKqUda5f+2dL9cMH+R1wmVpqvvz6v1o6eq/8R59Pu9vhqJNONnJ3hLP
cxuNtf+Xw7M3l9i0qzUPk4pa2/3GnUHr7+3/+zk78C8Uo1/R1Iud5plZqzCv
2bf/2fWc9es1WGfRWf+Pwank43Cn0dG/n3/g6qYiXiX6gUPbZ+17Bvxz/d/P
k2u3JNNb9gyVDf/9XcvRGU77G7+tOlY9ykp+gLY+WC37wa6Ajvz1wxdLvEG7
Tnu05K6whFCYGnYvT2CLxkN4QAu9pB3QnvzkClZ3+jGbQtJ9/wLKdpyoRdwB
+DlnLCVzzFiY4DPX+UO9Kjiw8VicwTCdyZfzcDcu0a29bimsPZ96PbZeRwRO
ffC9qOkZmIPO/xp0v4FeCO4YfqWfyA54tganzPi4V7jgx4260b6bwC7tupHB
WH4WHnK1EPyZB+wmTmyviwJxYJFSOxOdWLAPKCOYqy2mfBu5/nNj2Y4QcHGH
xYLTnw1QocK7aTsJdnJYe2d7ezvhy7Oon6NowkIymIs/uTYWlfKUBU3/tWut
1Af2lDlFa9R3LrKhzBfMf1wSAn22xes8Rul/2NAdxy8KVbOAIxF4MKEx6cqK
nu66RqVHz4u1e56ybjJMYEIl73VNqzMBf+6u6GoyHNGjT9IzpEQXwHwct1NW
xR4RDbp7J9ruPAsN1r78k9W+7MwplPBP5zQcRo61r9dzKt8sJ0JZBm5Dguxg
LslosS5t6gIOqqFdRuqRD+LGkOtlm1eidpBJMzGI/c5PrP1qX+Tr2stfkUWf
FmGoEMR7pxosfZUPZhDp8Ik6aZUJrP1m4Wrwh9s9SFf5h73gTsC7drlZ2Vwz
l4dsXfj8+CQJ1CluvL63G7yUC2lLnrvesA36Im7JCXCwL76Aoug8ea/vgXqE
hEJfzbR5NtS0iRdIuQr2WZelexkkLRlAUTKLxL+OgJ1tPJO5JzsVgSsYtvK6
QDwTpRrvfenic+QT+f5173tAb/FJepxrRpSPtEL8ecnxoB7NF+LmpEn6DEmF
M6cVdv6TL8uPVlcfR0A6e9OK22Wgzkh5jSCMQr4YMiRrJeInBjoPeXUES+eN
OiiG1oZ/sALock6P/1BT0iKQ6q0rPxf/w2M3bqTjL2Ruh8SZxk958wF/Zj2d
F4kn6oA0XS4+OdcK9iBfOHOv2EuyHSIK0aU8+xroqBLxe/PclgiU2TM7abcH
8pGDa7zMykN1EIaTgbGbcE5o7CoU///sgrzfkzOeBkMY3gPGXjsSu5qmk4P8
f6/Pq5E2kZVdibyKOL94kRjU3c5wpl6usm5AuiWrHyqSgrwAz7IwjuBMC/La
AO+s5iTgn3D7oRzSawhSchW57SkIdGM7L2qbnnAE4ZXk1n8pAfRMM/5hg1rB
ZuQpXXj3V0bAMdAhN+c5cWlAUO/BFY8rwP8XY4RIP81VIyHadJpVOkBHJWnA
WX7DXIbM8KW8248HOp75aLzeye985DIf6QsrBNQ3uxJZmWOuJyP66mPiRxlA
PzcluaJ22iwUySMKtWu7AHRLItFfSrCBNcJmZtkasgn0qMqua+1P4m0h69Oc
57prgM5TofSdmMXRBVKfzxtek74HdKFJPktWEnvIukV0wKvGH2sXe0k+pZ6v
CMW+v0Y1bAP0GdO7jHzCX4wRlcKx8qxu8P4z5x4xNz93RPoVbnYo4QPurqUb
ngV5qBNS4+rr/CEU9JdGNOFTrSeYIrQ/r2beegf6+m7IcZp/9NSF7gzCL8Wm
tLDfS9pBI1CY2AsiG/qke3MFxP+LWug70opgiHbBLjqcFcQhTbe2MxbJn0C0
XO9VOywisPZ3nLPhIdNx0HlU0Y/aG9SdCSIvVicsPoNURxTjvyqBulKhyxm2
QLUEaGoHN+oMI9ADx2xCl7xG46HWun3qlnegDmJIPeYedxADYXR9jP3n9B2k
iDYM2gl4rpTDCX73uPbSwFuIF4TRpzF2oVuP7XvLlRHCQHrWsqQ08Dnz4j4m
2voizVzeol6PwVyGQ83DaBlecZjvTSuTfIAc6Mv6vxdqMdhF+VHXHxkp0Ic/
9ZuBBRGHeRU+Sm2tAy5EkNF90qvj4rB7puy3RxdBH5FQjFOqk7sYrJqIg3qT
qQGdLWnt0J1PGNZVY7IgkdTGxgM0EhHaK5O8cPbVvq1+Gj2svbGP7MXtpbPw
Kqe0ZyydIdZukzZQoXprC3Gq+jgfSWMCuGG/yfIFOrhQ5spCpXNjgLfMMl01
tygsgZpeYSUiObbA2hU3F87k3JVHTypudL0/tMT2Y1NU9GYNHl1Dkwqi2gM/
WGDt3ud5PiCeKmj3G+Oh4EVj7HU+KvQvW5fAqJaLFQuv8g3w+etqFfAWtWHL
q3uUffVgj1sv3Nk9Jh0Mt1qkbCls2sDFf+2Db8bk7/nXw30mAhbP72Wg7h//
tVO1lE28TR2Bf3S2Zbq4daCm3v/Gh9Sx8wq8dlUoU9LV4pLgYThk9l/7ctyi
c+LdKbSSgjWVtmAelsz8Nz402Kn4KY5bic5zVMC7SDO82Prv9dEh1anLpilo
yq8sllCiF3Dy3/4B2lvdN8ePI9CY1VTFx3hp8J+/umW5e2lucI0/GheqL5L+
PRae/hsfVvjdpbuQ64UKR29U60aGwg//fq/lBocPOu9d0Yo5+uMD54dw6187
MQU5pQ+/E6qTwC//issLnvtrn1WIUzv90A5NPrK//vGLC7Yf1drBsUDqlxV6
5Eovrzh0E979ay+iyXjdaGWKKuCX8jZ+t8DymcvPB0TYdhqgT1LjCMOsDbB9
KXZvey3OLeig/qzFsxmCmlg98NBwmfAunQaKvKClN9+/hv29kp7UHFw1UUG5
WREzmnsgrvOQDL7U4KWIbt4+pLJ+B7hSIREt928lyaFcBNKrd/HBXKdSRCLF
s5eSqIUHawGTJOA/2IVoiZBuiqAsObNcUtmAH0hlx789NcqLVr95xXr1DNj3
tKj54u3A3XNoAT+zzHtOUBcbu6N093EJLYpqEF4JrAJ1ZP6qvqHbNaSo6+OG
IeYioHeZ3qwomag8QT5aXvxV4Qvmmut0idnLd38gCI4XoVYp0IWs4AFC65cz
SFQcKsRpCPrwb/AycP9M6UDsTokM9siCOGdaXEztsVAi0l/DH01gAeaPnuSt
Tn93fwKtvOu5p/EVnFeK86lvgyq9IefvsQ/il55j7YdG0jvSuiHIk8SMXmJH
oIfk7XuOKZCFI8MEa0LOzqDuufUullxUIQRq0FlpYvgF8mJL6NP54raXkPHi
zRe5xSCvT3d9GnD2VxOUW+5iuPUAxGPGp+uHfei6oMaeUZN3MmB+wT3VdND8
eAAaTouN7GoAOlVCcPPQjP8wxHKXPTtYFLxfzphotqFoBDKnarxymhT0Y2jQ
XUErdEagchOLc75lQK/ofar3mahvCKrcJR4SVQBx4AmLwhVzw15In7Qcv5oF
9I9F/jK2KiJqgxKLn3LdOf5/TF11VBXr26UFRUE6RGkQlBKRmqFRuhUQRLql
SykBAREECRWUDklJSWdo6VZaWukuKf2+371y3ss/rLXXrDlzZs7Mu2fv59kP
8CW5puOaKq/kQac5ZKd49YNQ4R9IHPJez1NY3hKsR/Adi8Ze4QrkNH8Ic10i
DJ49km5EKin5+jvSwDpoelt3xLGzFZEcNTB8LgbW01E6LzRZuRN5WO9fF0L5
CPAurGLT8xpdSF1EfRftQ2nM8WOHBI68r+tEiC0mCWJ/g++VSS8csqfSjqRc
ujHxXg3UEzoWWmgy9H9B3hknEG0nAl2FKcj1vmNNA6KVntSJFQLO20/xmy9y
v31Ggp2wmrvqwfb7XsV7H/LKEDpyuRIqbaDDtDW6CuCp5iGviW46jAWBer+p
+Zrv5xhTkJVRR+3WKnCcb7EIi37yRiFpDpc2QhxBn6Mij9TuhpEnYlhZZdjv
ao3B+2VHkrbxVJG8rrcxjtJSGDwuJi8Fj0UeIknMeNN0Vwtz3t7SSqksE92C
ONeFO6ES4K+laXLiFW9ASD+3nm/0iCEG15biUzLelEEiclmLcCcBL3qXtG35
clMW8vyWz3NPUwTzudl7j3+SCdpDjtnl0vOJoE5ppPqd/ZiZP3SmifoGmcIj
DL40MO07EfUCSh7ixFtIBHlfJ7xy01GJMZCkyoPm94XgPFBHF4zXL7+FYh+d
LZwiAj7jk4Rz6fMZ76HT+rJTXD+FQOLrsyQoXHLij6I84JO7V6VVrg4lQmS6
FFpyHwFepmu6cL46Aeo3LfSWngH4q19BxoXqcdBpXdUpPuSpfpDDEA4xbXMd
stqA40yb5+mxz3WHHGUWeLQQwHubvEuWpy9aImovbjkff/TG4JS57q3EpMFI
kp6TcIytKwZX5Zl1mOachWQKNpdMqkG9Gd4//+ehoE1SOYp0kMP8UtXhasLd
Loh2rtC16RPof/Rjw6Gz3RhHhCg6aFcJwdw0+bzEm+HKW0hKBbl7vxzAvwdp
HxeEHCNUYkmbLy+SY/D80KmrM2tYaLgZQnj+BPhQFhW2vvw1JwgRIbLOb4eP
wS9LuMTgTc8gdaNEdSKkoL+77d4C3uw5HNjYqUc7XA3UcZGw5RcnDjLAsLp6
hiAx0A3QG9cHzSn4YLpHVg+M4sGcoM+/xfC/5kIwaZbie41zYB5ZlSainC6h
ABtkRG5EtgMdQ8lr1tMzUBu+1JMZSxHMiFmXf+OTra1IP4Tb851eCA0SYnha
amq2fkqcNZxhdVOA5S2MnvKEL1LuY0+VXWHe7pSKGe+7mPqQuYn2NpVgf/g+
++WbdaM2aPFfXH1bWNFdPhx2bvlzcEHaF/3zl+eId71fHFNJgIn9xiTWDV6h
V/7yombcKJddqXz4WKrugHclE8X7q6cN89+ajj9shL13sc/P+tajRWr/4sjB
nlMO1ipcH4rKHaQuo8yrP//lnw5BqeTm2BI2pCHeIV9O0LhN73/wx7aH8+/f
tKEkI3y/3mluwVUPl/7Bx8I6fqrWYtWmRuKmy6tgSdQ7efyD+3iSfSzL6kN3
JA4/uTP2woZN//a1ff3Rwi2X8Ak1Y5t+QDJSDK/+rcvFPZnFf+uThiqtPJAt
fpUAz+//i3cW4DL1TUWj58PvWXq+CoYZ/p4HPtsRh8gHz1CRG1vuaQyusNvf
8zYxoiMI1XqhKRuh4Z/ijDFz08pytc21yRzR543D8qVWSvDGXzzvg9abKnMz
FFXDkmIUuYbJF3Lmsqhdm9FDsxLcv/hik2J4fmiV32UxLnWUtXfV9gED0A+l
9Tbr/J7KoKWRtA5VyewYfCZXkvkbuxCaraHEkF4N6pn7zzK8XQthRzf2hUl/
PwH1twIyFCNueGQoe9i5pMJDkC8RkImMUizOICtPnrpeiPqOuS+krP+oWV3b
g0QqTT41GoD7Iju47udeORZM1XaBVpEb6Gb6s4dm/Bew4As3K2RMPoOchFHq
y44i0/sQ2UOhHxlfwX3USdfgfvvjIiT4k0HR4TbwqQN+dWSZh1dDMY99zLkd
wPbsSuael4wmETy3IwuyBrD/b5fJEoIbVpEoevKPcrgkIK+Jo6AgFX8bcUc+
QzgUIG/2oNR4pNJuB+GcQC6TX8TH4J5sWXhY4duIcysTrpU8mM9Yk2r6PPFk
A6n1CuF4hgt8YROR1LWigSVk7OFjpv4CoPvd6orQX/s6g6jfNzsvyAvy9s2+
s3+loBpEyomUX9nwgFxQ4Rl4f4yoHrF0vKiZwAf0mWvH1gO0o8mQ69I98eOX
oI9PRHA2fnmrHrr+yPXKgi3wK9t/7LM8/tEKJYa4HlwsAj6pWevIamV+G7Tp
UZoc6Q78Vofw/dycvGaoRPRFCk0e8G0rS252m05+hiYyDydmvgH8+q9Mzmaq
D1B3WOFgxn/mu43fsecfpHmLVG2m/zAPBPuPubtLjPO7DKnNIwzfVQdzBEqN
vhHWdNQiB6UxDHQe4DgL+XTVZX40IDsGpUtb2oCf35mrSqfWakSWfi8kEqOg
/4jrqZPilfR6JIkrZ+rNEfBnUevJS11+nxEepSssS7ig3sb+CM86p78U+S6l
MnuvAfB5IflvTAhFJlKZo6PvcAf08XnmBvM9oPdFDMw7PxoHgdzFoZ80w7iZ
sRA2jvkn/0jQB+EhxhCZtZoOjeP06Oi5AD9UHIt2cDUgG4LNDbQpSkH/9SFj
T6fU/Wwoj4JBoZMW1NMal6U6hlJnQAmbfLK8lKBffrQPm4ycOgEqT/cqzkkF
fdnj/YS/xOEASGuszzccH/TRd8ERTBWtvgiO75CBuBbYnsD6yE165zXyE484
Cu8B0PeK6kw6hodSEPn61sHCZtCfNfTUevN6Rzpy00XmocxHUMdeVNt1b14o
A/kqrH48KALmzivKbFAmMqYhVEk2M4Yw6KdrFwyXfvPsPfLomXHbEiPwoz0r
2z9Fe0YjdYy6ry96AZ+XTG5+GuuCH5Jwl568yADw8DIk9mWQjTH0aIp06ImM
Mea6IGEdtIaKQVAMzg/suFrAYzl8YkXFU15Cz2WvzBGcBXxYVMu78779K0gx
1fh2bCLom7My2sXPsouC3jZzarwcBb5n/AK7kfSP5xBuI43v+ADweVe5M+tT
Gn0h35NUU+eNdxg8tl0f706aLqQ1H/dncQ3gSo9P9od/OiFyLzdb8zkBXlV7
iDx0CEFIv5775kUL/F+afxaIBxBf/7tqDyEwV51xh6Piy08LpOgQv6jeCPRl
u9taEAoKlECvbeLTGx4D/z1Gjr44WbQP+rpAdDH7P78TglTWGl+nHxAj40yi
agfQw/viLL8Ize1CNzaxogYgoEvfdiy4RjKMCz9eaH6YaA3yYeZXfdnaXpLC
kgJfDwcfgbwv25hL9SUltPC7Nc4b/Aogz43KnTLkFikLTHgz3NvBDcw3Hy+F
1L8yccPUpBUobQyYT4GdkfGyNk8A9q3wSO96BPKmxMufb5FvCcMJXW1h0Ydg
HSxavorFKycJu3xCHd5qgzksTX9oPQwrZeHovYdzpXfB3JZIThOsW4cKsHNK
FWe7AdADz1l6J5YTqMNiuDdIJwUVMDpYxKWktgtxWnCK7E+uin0NzDruUngj
4krVPfjRhLLpppgehr/16Fz0ikgygCPCHpC7RRpj/EQDD763dJrG8J2hzXw+
DStM3elHwfQyi2vmsPyLc/7Ew47owl88qWTl8UszG1jjvZOug78HJoc56LE4
besZJ1h5pTokMdsfzfmLK/BcbS0W9YCJKMgymFRDUaW/OJXR6IsB2adw0lcv
n820aFT/L/+h3fyhu+URAZtCOXU7N5JR/b/1rgXn2kupcFLgYo0FaPlMIbrz
lwdaG2g9NZWqhVO1CF24olrRS9f+8hnlROv4uHE4o656S6ZgFhVt2PsH5zEz
WBJn/ghrOXgkBLypg3/n/7s9dCfEg0i+D7WLE7EQi6qHA0L/1f3uujkIZO28
QZ0NPl3Rv3kDbvjrR5eX8N2YsbVHpYbk5uc276OnvGvjbWA5FxYZ2lvtYqMs
BOrQDuPst341yMEbOQfRglPqGL4tnPlM0vLdbfhTuTX5zTw9jG421OSS72gg
A+Oab2X+ZjHE6Gx1ZAVdVCZi8PhwfVNCBMC/lnxKeSLBByvifiMqFAV5y4p7
pBMqCC1sNXzmUtoO2H/lOyayjpwjRJj3DpGm6D0MfvU+vnm9MCPq5UDEGaml
jTnOw+lBVfyaq+g1nZrqW04aGH5icIRrRUvKh94aYOnltFHB4M/7qvlXxvnR
o3La9gybO8AndW8vSA8WQK3OmbWZL8tgcEHr9E+tYgJoSbJqmvUO8J05gnSq
GG7wozcJnp8NFRTB4IR+n0S5VHhRsSefhZT8b2BwIntPquf+3Oitd6iOYDbI
2TNTa2ARMuFAh+mdllkYwXvQ8Xxb3lllFjQb+3GpBgXIseESgNcriy6jSo+X
f03PgZyxOY2AROEYalQ3eb+CpQbwvZ5pbKrMhxdRGiX6rXAbwOuK6KYzktwJ
0W/us/OEy2COhpDwiAaDOhZaLXN7lTYG1O8dt/exb9/bQXT+XAlzIAf8bUmR
kM9XbB5Rziz5kLwP+Fu0TIB7mdsQEmQwNnf2Pz4dakHALGXTiDhHN7z/+RWs
79BN5uvErJnI5f5Ye70a4OeSfiZKHn6kA0lGtBhf2TXCPA8/6rnzh57xhi5J
za+eEEQC3uK1xuPUpInY9mJvd1SBde0OxTJhofsTJOpW0TDXl1CwXuhOnu8P
UUMY+Q4dU2O0MfijdAPPSaUY6AqNypFaJNDBJCPjzhng5UKs0dbEcblAnzwb
mSY+hl0BMXjYjGf1AL/va9i04XhCHaRa4+dUXQr4w34eed7iRhM0x9XXEloE
/NnpzF819IMtkPJvQXoybuDPDp0XaLld3gphHajvWrGD9QjnbcSO14cWiE/l
20hLMPBnQ0ubYBe9Jkg01XLimy5YpzhCcz/orqOQda1OSjYf8FsNXfsrzzeU
QKd5Raf4db+iuiabWChQd33mQyfA49b7X5SnpiDiJNa/IQ/Qf2oROM+gM16K
OEhv3cjwBp/ryTGHf7cfQZofneWDXMFxyn9LiUl+3IDE70+IUV0G36vJmfCm
2tMmpL8AD9/TAZyHy7UPah+daUa67hiTwFQgh8qcpCP5NXYTEvCqKGqZF/C6
s+tDgxfJG5AA3Bsrznsgp7R/Xk6GKB9FHpSSadcwgnkB5Lkdil3plYicY5nA
SMJ/eFqcQldjcAnCuHTiEScOrruyDSd0sTIHoQk1iIlWAvoqxV6RVK1kCoIS
WyuJBr7E4Ffr7bmbz0cj7G8yBD3oQB272tOPzqK6/kjtWyixJ9wZgy/kjHHH
GJoiIkFJhRqjwM/dcAmXnU2hhqKs6+lpTZiAvseUkNlUJAExdyvg8VJoAP72
8IW/uyEBonvpLtxVB37ncLYc6YPAV4hQ88ynO7yA97795/kaBO2/ueGYewTu
U27oRqnS7wwke7CP+YMywJlpr63elvyAyJt444ulgHlnrpzvE+TC/JHzksrc
zHVAry680ML5IrkS4vg4Fx1CDuootp/3rMr19EPmX5l5bpWCnIozGltHbeGz
kPGiFPudTPA+filytIz4zwbUAB3P2TaAOU3xnHRKVt6HEH4zbbHhJzD/6MlS
QFauLC7smqK0yxYMcg7FOHlMnDnOwle5Qr3ccMD6mGU9XOL+ixR2kwwNMIOB
vufBphPxdI4ClhmteUJ8F/AuAmVj2ax0Gvj9FeOc6z0gD2od55u4/hQ9XL6Q
UF7lAuY/Vqb0BzKKXobrL13WnmwA+cMXeuIdvx9chv+EzNJt/wQ8rfmoYN2j
ggGOI+USHpoE/SPaFqRjAbh0sLiJ4ZP5KODn5i41ZIWnkcMePYlm6fdALoFX
tpvnfA4e/DEN1VYhgzE4ndGPtaAfk0iRuyGvcymYk7ictbBAlEiK+kEu4V6/
AQ+8Rv3g27fbjCjNN95zNNkgF6UD59zSIBUn6oMX6aZgAnDLs1NRf0h50JBL
heLnW8H+sWni6+2seNEiS2NbhjpwnNBy7m4TFQc65Mnt8ysRnIezaaFV477Y
sLirGIexKZgbRZrmkCAVKwXnnKg8VPkN5sUr/xFtbpW6D8+KC+Km9N7G8Iol
wttBNVZOsO57HbPGMUWM/+hFnr/YTh0M/2TyOePIL40G/8XlmM54GDxOhpcz
k4WWawLQ9r888NLApWghGRTezCFlxXcsQqc+/Yt7793n7ojYgLnfc7JkTC2i
q1Zz//LbzytUF87PwjvfOK7fX2mHCZL/7eMIpFVSzAraQn9qO8BiCb9g9HPT
v7riJR6cn1dH0bc5u0GQ6iRs5/fv9sMq90uyVMrR8FqqEwMYgd3z/v1cv7Uf
usFiaWjShApbS3A2bPU336CY9cHcjmIMSsZOzrHwOB7G/atn7ji/Y3j7IgSt
CnN7+sYvAn7/l/eqcjuSuln6oUSHgv7crAGw49/zMKbCZD3D44528k4rIlQe
cN1f/OZVHUV2GUf0B93aiteUPTxzyvd25GMrTa3QQI3LK1F2ppj50Tl7DC9u
PzNBLeKlKkWp9DB6oJrBcjirqAGK2p040I2oYfo7qu9W5tB66KDfI/2/imTK
YK6jqD+ZUBWPOrph2t55+xq47nX65e8vkN1Bd+zDNn5YgXmFZbn7Gy6xUijK
rj38WRfMT2lcCk41IhVBbWmP4q9oAh9WV+nl4rgmPyoZLxg+auKK+b2lupUU
1eJzoM+64prmSTcwzxMblXJbSyoGVPpjlCzvEnj+NNUYpOswX0R/jZg+MZAG
c3ixqtvkZyRw0HaWK0RxZ8A8UHts+74vphsIdpiB11oFeE/EF2YLFO4fQBIu
hpqx3wV9Ch7rC0F/+FIgoRFnmfvZoE4s6vJ2uHJwPYQX60yYgQ36/u5c+mCi
UPUZ8ukYx4+cBnMYccbzU9uqUyHis7fYtipAruDl7sTHWjVZiBnk7xR1DtTp
UcdJeV6TqETEvKqw1M6CHNQVh/4r85+qEVgskzjvJajLkueUFDgcKkHu4Ew0
sX8A606e5IhePGUoorBEZM7ACfpYB80z4NfyxdBnZcJl7sN8oMupx3QQ0zVC
E9UeWk2WIM/hZdKu0k26TugyGWWj5xmQpxHUV5xdzd0Hrb8oYzJeBP0O2Nj6
Q49C+qFbhl8Pbx6DvC8hxy3SupU+KNb6vGLMKsDVbMRRC64eSJ4hwc+fBuAj
ic8HTkJboLDluUGZYaDLNZf88dwi+AzR6lTdOsYCxxNbNXzCWpEE+b/zNPN7
Bnz2BfcU7ttBOcjZxf0BFieg45HHyjd8MUUR+iD9WcUBkNOSc3DyQV/gC0Lx
Y4g/4z9zTPQ+O/gPr7YjTdGdT5dvgb6MkvOHA380u5AEdo7BYxqgB1q+C33v
INGFCEikX2DNAnWPVo8qNHHNOhDvUKl7bJygruCPymF48noLwjcGM4q7gLrK
HtHaJoXkRqRy8joNxxzISXPVEBMTXkCQ0M7IS/QBYH6KfrhlNbxfhjR/1J8d
sMvE4NF9UtUkYrlIfuGsiJYw0H8IDUpwyFTeIZfo1y4aXgU+7/k2KiqEPhDx
nbOwGOYE/iOWn3HzSxENSM1ag/fNIOh3VnZsJsKXcoea645bSWFQRxcrwWJ5
fd0NMjjzrUDlMphH38qYdGsizBxao9EgS7UG7wVi8jatW85qyPMjtTMpDgC/
/Y8/mA6pmX9qLpQH953kPw8uP0ThzLaqoQrgz2PjuKgvVwpCZfdNClLrAfdp
wfPmAb0KZBBisVV8C/IZepSvhxntNyMrytmbzZfBfUdjdbVgkqAb2Ttfy6Su
DnD6H+yDrP29SE1YU/rgAtjPBbp0Cqr3vYgErrlg3DnwuQre9C+T+TqRdV7H
NJxk8B6X0rI1aGfZgNAW1JNtd4A8pfCYV76BYqkIscuI1KY26MOqTCnbMpuv
hIo88LIeUIPfIVWpurJ9XhdE/lPfPnEK6OfrA6VX1ugGoZ7a1DNxEpMYnKyK
btRgZRSCOB698OOZx+CcAYXaBj5j0Nax76dZznXwnGyU45Z8NQg9pRzgr/cC
z1seRDdVw6oVkivjWL/es4fBlxrMCOU5shDD0XQmY5wDDD7sPSWMynxFNJU+
xjI7AtyqDmegKXca4U6mPeg3Bnrd3XItG/ryOUSIraYB+ybIeQ6IP9ajtxxH
sAKPBK93zmBw/ryXNwho+iCITaft5gA4z448Cld7rhxD184PzfurbGNwu49v
Dj76XYSzAhTtjDtwMOvUy1+Vhul0TDA7TTm92WfgQ50h24o0L7wOt/iLvMSm
Az5RWIP3hWvrt+DFq9FcDv+Zi8cl2OLyy0QaLovoXO13JMDgHyb2bG1VleBL
OHJNPS/Aecu2wB7W6dGC7wdqja/eYcXogR4L1QflmgbweQ9Jg3l7UUwdHe5q
v1s9qxl8zZhOmSxUCdPv3Ltrdyau1g5uQo2xbUj00VOesEmq3xLe7gpzL3+n
zI+3RL//xXVeucTLT/vCt9+rWW1ddMPoe4Elhy+n9kLgSDG+h7dwA1Gqv/g5
vGES/JUYOKSZME/h2yv05l/dbL8+7lGbexp8ZrtiMIMmDY38Wxf3wt9SctKn
DN4TuW4Wq/IJNW/7F68IFBWhmOqB23vFigWOetHU6X/9Vv31GLlnX47hWA/K
qUyZ32gjVsw/eL3ZQO6a3C4s9+3oScCbIvRM1uw/uCxNtQatxy7afp+R+jjx
CE4MLf0Hv8ZKeaX8ziK6woN9opj1A75QtPYvn5xYefP8Vy26K2eIHadSDp/5
m3ucuBZi0I6Xib7G+p4q4PIaZvrr53bQR2m5s0WjXrvnyeqyHsMv/vI6nwml
84RLT1HFXh3rnnwDuODv+TFlVZrhW3VGX/WZv/l5wIqZlzFokECa/9QMtQ2+
i6Rw30RP6+62ttJb0F0d9DM3NWVOoQhG7y3TqgvNvSmPxmLXRNAZgDlB49Xt
WszuN9DkuNDL/m7gfYd75uslpIYSHWsR2OrZBu9ZbobfJ476f0MWzJ+41utB
34HbsS0zexkFvKKkuEPGB+ZYrZePSVNXUcNhE1lTakRATwv2Wo27fUgBp6ul
F2izgvmbDQ0exXixF2A+5Ewd1gLos+CyaWnxJsaGh5toR49GAb7Bxb68XTwB
lcu9JWd6DPZDsQ27TgqvIb36EuctboI6wBlI+nqYIRZKKPNldswS1D8I8Dp1
/pAlQG+XDmWYG4I5MpeTqT5QmxOhHYfeAzvp4Hv9Yd06r0x6FhWGenA4RgFf
9b12GQpsJ0Sfocb24gnAF1Y/iHvkRUWAiiy0lWwfn8fg8GPBZ1GBOOjZr5Zf
ZW+B+/r3GkOTE9MJMlgkwqrw7g/mOTOqJTg6r7eL1DyWiBl3BX2+JL15PLrp
K0jpmDx+CryMwT1es6qzjk0h1yJYn39hmwTbm1J7vBDsQd58/VM40AB0JM+j
Vs/nSdnIPTfbC8kFgK+a20joxkDF0DF2tfr5BZDfNTd5U4o4B4Go4lOzLT8C
n9dGl+VKCoRAth54zMZFIKeOY0fI2jO+DJL29K2eREHdYzK3+UACZwrkBQ/X
2U8A/HlhWlvC5RiErTe48DgW+K3Gz6GCP3Yfke75H5nk/5kbvpg2HRlc+AnJ
1F56dPk+4HX8mWfkUx5XIES0QQK4BbUYnMDCK4qhswyJIXXtDu4C/EojbvGZ
kVwBkpf3gPWHO6gzfHr3Ybo/WTyi1zd4REAA+hZFWZ9v8aDBEHK3tSDjC8hR
5CHcUTl+nQUxfxlxfRMC9CvRCU9Zh7ViKJtV7ccLNqCDfRyfvymIUw6Fu7wd
ds8G/pfVKEsmFVsFRGNki9qfBf57o8QfaW/DT1B5/94SqTfop/hk3oRNxV8M
YRGGx9r+R5+cTzhqN9TPgrjS1JnOnAV5gFrlOxyivK8gr+gvpNWXAZ7/gDiq
t/8ZUqV7/P5PANjPwFW7C734aUiSAaGpnDbw1+Jaf0o1N9ZBW6KirkxXwe+B
Dud//1shb8vdVxI5gD9H2S3RaCHvoSTdzM9RM2B7mbAD1+61QmT686/CLGFw
HVcqzG2bw2qQsOaadwOrYHvn3mcidW+bEKWC63ZoMuDtm9LcNrd025E7FSQ9
yePgutNNvX19Ibkb6R9UHXIUBvynQaFL7/JxN+KMxzPXWgZ0sN+bVbYu2F2I
9VVF/J0ngD9fMaR316FqQ25K8gecqwZzJGc66aekCxoRUTiflvMiqHfteuCp
dMBVg4yTYR9R1kVgcMpgi51froVI3h2HEJ0h0P/LFl/2y8XsHWLWtfXd/Px9
DM4N7+U4KT1GSDu1JKgJgN5oFRH5TfzWRXGmHQYrld5jsVP8mZbLhUvJ5OI0
P6d7VKTxMDlLm1PtRDtBQZD6Q2d7gwUu8D4yx3RPnKsACh+vWY//agf4/0ix
5c7cF0g2rK2d8wzg+cS/a1x4b4xB4erq3uZ+oP42lNhTU9RoGZJ0LfR/9QNc
r9h7KsYm4b8grlfGeplLIMcskEFnd04KD87AG/4y0Qtyn46DG1NmVUngLk+d
sVYmwBuzuq1ndfGo4bXFZ9MVtmCOWOrPH9M61xnhd31kOAejIC9UmoErZ/sn
G4w/UF58ixzk4u49xI5yKL4Gr1mLdfpPXQF6Y3PlWRtJAfhufHixpC2YL7N+
KyreOkUI5tYcKdJGwDy4/o2h+El9MVhlRTWByQj4tkMCfLcvsUrCWN233tVh
AZ3tYjf925AcabgYUvh86RmYx/ee1I5vjlUO5t3b5rd9oozhb7rUdW/UnG/D
djraV6LiQU7vhSiO97ghCvB4no9mLQ7oj8jAne28dUcJFqG9Eo8Ugz6LzjYy
ir5UZfj+RTU07Ikphj8M1+DL3g1TgbstRgzG3llh6vckR+WOSS6qwkOWTgQl
RA4YH5NS9fcPh3uqsCiltxJ+CpiPafHNSe1Phyqc/RonZ5LQCx3+i9u4pjBP
C6jDlCTxjWdl/VHklM9MK8qZrGrCzcQCjwrmn6Ehf3EyyddWyGUD+Omdc3dW
P0aiOH9xv0VlYS9PR/h4MFswGv8dSvmXN/p3qorlh76B3bjKzYaSStGWH//i
38Q0sLwb3OFnAVEE//tf+3c/9ZtR7VYiHvDFPI2m//0/PZ4dlmG+3NA3qJuv
NMloUil8uh+9P0tU/p6OKOt+i8D/fy58+rmxb29fj7tsgLqKFovuf4yET4+T
e5doHmdVE30BHTNWzj+DT79XW99+h46AOvrKiejlDVl/zOcKlPa/4e9QRRs7
Jdb3Cf9/NfyLWxMIGDnfV0V1P3MGziWDPHztpV8sEJkqujq5Sk9w1gFT19fO
WrYh81wF/SBbnjjy3grTrzFRPsuXn6SMLviEtZY8McX0a+Q1s1HnyymhUy4z
+FalDzD6nk3SbLx6iAJ6OyKc5QyOLsZHrv7zIfiN622UmfnKMX68Jsb/PcsX
xW/PKIeq6Uk6GnkrY/AM6BHTbrY0moGjiTA+k8PwHHNvo4FH7JIocWygpzAW
6OfFs2cPU74nhrYVvh2mfAj0w0vDg75IkhAq+NRONKiGD4PjpK2YUsgKoDJH
KupD5hwYfIrqYcursmvoTf60fZxFUAdbo8dWwrjAhp7wDS+QUIC52KJ4nMfC
PIwo+4iDcPUkqMe73zyU2o5HjfY2rzbdtgV1dxTYtD5f7pGgI4nYRgwU4H1Q
u2O2e0QCDxWzVaaHu+fAukw8hA6H/EIex7IU5RwBfS/3xhElru4ysn7d5d3r
A+Cv0dx9eLv15hgyNZL+SPYJ8DHpN6uv3J//giw+M16vPAP64Cjf1HRIcRcg
nn6eCq6oHQbHp5dL1wgJQiQv15R0ZHFh8J+3idgbiQdr6CeYIxREsTDrQhdb
z+q55d4am/4Utl8L2BicXT0Kb0ThMSTZ7FP3aoMRsx+zF+7c54zeQSkc2R/u
/wC+mGzF1TO/HAohmt9SB8NzIMdbOCTwZRp3DRSi2x9xtwHoMy/uPDj8/3UT
6ud8JMeKA3I2Roodeb5ytUGazyLaGt8BXhrkoeT2h64LmvEfoHRyBL4hq39I
7+u+bkiZRMXpZTvwecVS580nz3dDwU5OJYwHwJd0aGkRpq9ph8ie3xgjSQI+
5la6eTvntWZIQPRegFc44F0vho3Gy49qoAcrWw/xy//Tt/tgbHc5/AO0eLXu
lq0i4GPZ1sNU7NsxSBIhtSDlDtj+qQP2JKd4GfKDgmaMUx7gLb6Oq7FIHULu
FYIHJf9n/q+c3toamgNFC/8RUHMBeqnnP/wqFrrlY6h2EwI6p98/+lUUgv09
dcCOAvDksjNzss1hecit6t5X9QwAD6Va32S/XowsrutuVPGA/fucbWQoVP+E
8OoR2OV6Aj522I2NQ1xUgZRbj+g14ADeFZvB00g/9QkxTZQgYU0B/KqquEim
/Hcx8n6fFIeCowzwIleOM9FvshAaS6PM2OegD0gUGuPdKw9GoqQ1GCXaQC4H
d4/jhadk8VCn2JWHybigj8nRKaT00KQASlisvk3n9J96v09R4cytZdBSW9Io
VTOYSyUrosQUHVUBZfi9N2YrAtddeXPAK230E/S2UEU11gBcR6Fj5/70ho/Q
xIEn1y8twJNRmksy+aXRUOAbeRbzN8BPF4nUk7zEmoJk0ZOaMYwDHYnDTjPn
+H0ZckMcS/9CN8BjcYQ0fqohyMcl2keCpUCfX8MNEHuQjyCyrD3zfkXgd/Js
NIsxQKoYOX/yu7tvAdQ9Cpm+9fqVnA3ldhSeNy8AvDQGISfG4e+BLgbwBPE3
A59iCp/7DP/oFERnPO/Rxwr0PR6DDcvnuStQ2c4Ep7zIMgaXHelK4tffhci8
I3YCXEAO6p3CgvnfrCeQ5IEP7moc8HMbkjiGxp/hwNrYnAWR/AQYnhNG0Tdp
xEAAF/feS/pyDHK9bJJ05Qe6CeG6AZoj3gTQT/GI0dKxkewszJebkqg2AnKw
w7sDe2QdieD872fuZiaBOSkLUca3i9UJ4BffO+JuGYC6O+9d4+gvD7Dg/P1g
dmlzUMd+MVnq3lnWNSiUOZTOSQjoIU3FT3ooJyYQRwYhqqAnIP/8ncvUp49k
2CjBTWZJze8g/1znwU7D9NsL6B2E/OzaIsBJf48s8/2iQF87uIVssoL9dJJB
chOV1GjuDb42WSJQP5/mYjZJU0aBWhw82VPiA99LWeYoKKr/NyL5+T3PZj3I
+42RqOyvqqGEv5AkLRHtgH7GnrqvgXzuN2AXBxlqMnegh/wm2bBOvSkP/1bs
XWq7D3Iw8FtDVt/u6sBtjKNV84UioB7sqXr946dmcLzNWzlVrpsY/kDA2Pft
yqoz/Gz5040vx6yYuWx3BfUaRJeewj+xzTdf5hmgp7oWrG1iGswWDQ89pOFH
sh6jpzrY9Y7x6l68TNh7z2H+lstr9FQ3K1n5tfLiVy28Gs08HKVSjp7qbD6B
rSOVdxZhkZLJ64pZP1Div7rchxLs2OzW3/D1ggdtdspbqOZw4T+4ZsZQ6RZN
G2wUOsTyzPkAdl0c/AeHJraynn45RoWcqYJzZH7DDX91wjCVJEmyqR50wDRI
S+CoFz7VFZMoiPF6fcpQ2sJQ43iVT/CpDoktSafe6p6GBpKcPCygSYNPdUve
toT6Kysx6JO3YQ+9v72CT3VO2Sz8N3l7IajzUKT3Ak4gfKqLKt9ufI8/44uq
VF1P073oBp/qqAI+lq+T2l1RZgVJ5vp4S/hUd9VnCGVLQu1QybvVCZyk+hg/
N3CDtjKHzQydHHLaDg1Wwvi55E7uF2K0DNDYJBbXdw6iGF7Xses9o9Sthb7E
/ijPpMEK+qY1vBuLVJXQ4bGCV4vwHuY5c2kE0vxpKo16Wu6lR7qB+9rox8dh
781bqHTjaJ+EMMjl42uY2yz8eB3NYjyZ778EcPeyrMcQPRNKrf1OWqXuHKiH
jLh0PdDvImp0630deweYA8j34nIyfOUY2Wt1TjFTAe+DXGPO9y5T9SHZk0xG
Yf1ARxo5UVd7bDUObbmnyM52zGCO37mxL4mufA4qn2F1ChfcwuAzociQctE0
ZH1BfMbOZB+DEzz8epQn8hVyuONeJusA8lXqk6d3jH5lQd5KqT+e4QA82oIw
T1W7Fbn4OPQZTi84b/OXv6S88xlEHhdfjzj3BPDGKfqrXaQaYwheHfevce51
DF7JSWbYPDKKkNvV37vLDebzhnNEPqa+NYhEL6VKEUJA38Oylv1OmN2FvHQi
NJ+YAn4Tjq9NBvdWJUKQ0sh+lxLoS6y4W/VJ/KlQ54PtICtd0MdxR0FKp9Oy
AToOsRl17wS6TQlhuZ+QVid07aqL8KP34DxLqz2w3s7phWD1J53JlCAf75vf
Tbfr5b1Qc/BuX/sm6L/wvbNcVMzXBZVhTYlrWgC/SWmcZDKsohkqhb59qWEG
+O1ry49MwishFi1NLbP/5BWzH2hnG/+MhCrK9qQcIsDnktnc9quz+Ij8FjDG
n7QH9Ut4v9X65QxrETh5U4kZBv0dNcbTwQ73zRDBvfYcXgegz2D9/Ru0e8pG
bwfw+5RqFsd2Hoiq5MhZwasgn621s+WmV4sbwjwqwOAuBfofe1fnRsRO1JEF
vrDYiF4dDN53t6hy7mIglPJnY8uBE+R3/TyyzG3heAclM68mBYsAnj9SZDAr
WZwDhbHdEPJhBXn1LQ9InEJXyyCLDUX1c0agrj67S+lTxWUU4jvJKqvqysPg
Jelr3Xc/NEKe9Aoxk52AP1e+zSW529ACqcDuYhPGIEflIY74totZBySOpfBT
Cg/UmzX3EGrqJXZBjzkEHr45APzqF8XzTd2ILkixYkNFqBL0ibCOCXmzk3ZA
JmpFZd1O4HfoSHT/SdpoM3Tl0cUGwWVQh5kw4CjlyFwLNaB/3lq3gBwYK9bn
moEsBRBsR7JI9QDw5AvfdVmv4qQglLvT0h7vAG8fMpjb1EI+I0Z1Mrrx/IDX
TaZsXlFvaUEmrm8ZfK4BeqYSUY3f8/M9yBbHEpYpNeB7Iuucx7/3+5B5Z+yr
FCsA9yZJi8916Ud0vzqv1l4E/G3qpIy5T7APof2a1M46CXRUtQtYZ20ZOhGS
G063CHHB8Tj5TrUY0DYi6pKFzvdswHk4d75U2O92MZKkhlX09Fc+Bve0tBBg
pgmFSJdCf75iB33Ti0NGJjTDJRCO+MalxA9gvkl25vDI9epqiPmcew/RS6DP
e5tc+MUiXQm1e83b054D9115tfHPXwVZkP3SpNo48TcMPuezKqCUmIpQMv2q
SaoYxOBCD/zK3Is+I4YnjurcM0DfW4m4c0T7rB6hO7SiHv8N+OfGhx9fhflT
kOEvdwRoPwC+qmhIZKo6MACtuymLVusAn8LCMmna0WQDSmTqinlRBuaZXvOz
xCmQwIHfCUWm6JKBfIZfgqvnNpguwrqhws1yCuB5O5y4Jb59kQHue/+pLX16
B4OLi1NPm+JxwHbqKVdVCEHfHO6hS8+WBj/s7/n+gP9DAOY449kbp2+QiMBv
x1XPHxtiY9apn5H3I7/HSsHfd69/07MBfPXay/G5QPI7ME3aDHe24VUMPiey
Y/+ZVx3W5HtOQMEJ9EOu+Pt5XG46sKPVjqJ7lgzG1yM/1vwqJmYAjz9gaa0f
UsPoe5o5y4oCQSZw+ejA9YuUehg/t2ROn+y3qRUstxdDmmVrivFzIc9uz1Fp
R/jdQWTX62l79LROTMaDg+8jjzts3OpXe43aAz2tK+shP38YZuEH37x4lUWb
NQA9rUPzeiuj/+RFCHzOtVJLyS8CPa1b23d7eHVMMQYuWCM7Onocj57Wua1+
QFJCxdLgfjpsrebgbPS0Lo65mDohVaUcLuOUZdOBEfS0ji54JgZr8eoofOkq
wVth1Un0tO5uqDOcZ7J3F3bfSNDBUd1Fu2aa/9WjlsIynbjGYW5xWgY+yyX4
Bs7WPzilyOFIa8QGGrX8/NKHqUV4/W8d4KqLAhOfDIqm+rl/wHcsgk/rBtfF
3jXJP05G3ZnbUtZrAuDTOkN6M5n5Wupg1GDiUaWegDR8WpeYz3rYhFg5oRss
KTRXxxXR0zpGVZ8PTvlS99H4ffJXHr23MdeRua7inUOsFHpy3zTL/De47kE/
8X+2+2Kjb0/CzpiYgnk0Fj3EHGtUHDCn4znflUQeDG+XtyThi7XihYXzSIax
60QxuOwub/n8RR44hfD5lboWoLNhGRfTRtJxwt12IRwvTED+Hllo4vKoAiOc
29+QeiYb4J1nQmg/vSSFe4kTIkx/g1w+rENl0dXqCSjlkzInfinYv781p9er
cDw0cZvj0T1SGIM/aCr+8yeLHMW39efu1AXHyfgntWKTkA7VvPKdseIFyBvk
8f6aWVvGgBZfitvxnQB5L4qxHq46a5dRfPyiQ5plcB4sdmZkBq5dRm9RPchE
2//j/3J6Haiu0qNLTRUKNo4sGPx8fjPp+CcalF/H0eh6D8iHqQsMXNKbp0D9
M3PIvBVAf0cMz/4Xz01StPGB1YaGNHjPaqrWZrDhOYsOULXEdJ49g8FJM3Kj
xIRwUdPdoYckAcDPrYKVzLVDD5G67dVOkSLw/InmUdCh2d5AeB3oin81LwId
o9NVRcxzFnGY9eQ4yPqOwT9kP72u29aPLAwIzn0qBXVNsMTZwLNplUhP9sqT
F+RAB6N4MuWtGeEPtYos2d5HwbwnBuKjYFeVD9DecP2jpNRCDC7jHbDM+ycD
EmVRWhNRAPVmLHP9c1KBUZB6tEBTMj9YX66v5Pe/2gpFTCQ++NHgAF/Vm7lO
eqJbAgnI8l5+Ta4B+PbQ/+4DEuiPm2isf7U2WJdxbm+Tn6dGDnBTb3WYMWHw
9zqSX6MNTaF2DZK5d9v6mP0Hu7xU0GD0hwrtSXFKYpwxuDqVxt7rkVdQ2Xe+
rdfnwXOb9UOwm3hAMjQWXqhdmwJyjOO6q1/m6uVAnxtYZbIiwZz0m/3jJ52b
JdDkwB3PbiLQ57j4M1RzIrAS2r8oxy78AehXqctf3qWOoFCFCO6iVTU4nz4V
WrG0HA2QHsSusOYOdDBemY2A7JuNEKW9/C9JLlAHOPJeYpPMsQladHHu84kA
PqZ33zqtbH4jZJDrGjz0DvhrK2JOMz8PG6Bz3j/DRQSBjhd4/bCN3KEWqiJ7
GL/RA9b9/tLF1600nyC7npcypawgpzqyEg+u7UyGnrlZPcqdATw5ddRCOywk
Gmkpy976VQPWcQ1Zl/OqYiUInQWhuk0dwLXeELJGPUaRJRPN7HU6gF/UV6N0
WW9EDvWlv+b5gM9V79yN87/dggQnXTp6IgR8fy7nC7z2Q60IuY9UyrYN+F5U
XiNp0+MtiKfYySteanAeEN4GHeXfTciYW67m1C6ow/SxI7rJlVSHeC3o9I4h
wOcVHhY0WSWpQNiM2tvxJoGP6V/IdyT3JwdJoW9JLssB1z3ZaPq6jWIMUmi+
p2UcCd4LLnvAvf0hapC56lcJkTjwe1bDEebK8XwCDYerJ4q2gnkiyweJlR19
mlAPab5sXTXIU7Ig3tzjIPRGZFtt2nfxQY4QnYSVNrm9DqJOpZkVvQlyaULy
VdAklkzoD+3Is97PIG+5cVHQJ9emESJvh3wpusH9u3G9+9Ur9yGIaZk4bOQC
eI9zoja0whKbhyJ4zaUTN8G8jOtUdswvtXegS5HSjJM0PzD407nHm05aWPCh
K1FYVyjI7W8R4w3/4EkIh++WmN5fAnPuIh7y5ZGaXIQjz3EucRmD/BPlznex
0lHU8MskrXb3epCXIug/vWdbeRlWp9sfx5oB/R17lW52cbIs8JcS/xYjakbg
/9a6Mp/YccDXxpL1ZEmAnpZLQpnh58sN20mGxFVlXMfgX765JZQr8sJq0b+e
CwfcAH0WljqUCXz88Lnhe+qrvCIY/IVZwGb2DQF4lkn2sf4OmKO610fpTx8u
AHdrKIl0LMpg8PN3B8pXv/PD7BSCc5qWdzA4L4VgQOx5Pjj7d/YQySMVDD58
a2lst/Aq7ENOeWbeSQODSx0lhVPfYYT1L5XsDGloY/zfa8/9bD3Lj6AdNpX6
78L3MLyijfhMV18VLUr8Ii28aBfk9X3yp6Qdh/hQB+4Edm1RAwwuuzrNzmMs
hm4Wf6c3jAB5fV4sTeKKhjJoYuD2rCQrwMv8mMoY3t1Gp4MW5y/kgf2/4SW8
TN8oh77uHrsvOAXyBj8Nc5WJYpHBuTQQk4cQWB+vLCW4zNrawzobZNSzm/cx
PubnJCWXnJ03MEd8SPwHwRvoaV9tmIPl5Dn5Prj6p2+WcFQ9+vRvH+7IeQMV
yq+9MKOc2r5QfCscqvIv3iN+eaGvYARl86ku4mT6ATc6/9vn6xY2rWYsVYve
tUPbuaNa4dO+4MHotQlCnBRU3WLWf/tMIXzaR7wMvZwu8YhA46PWiHAFk+HT
vmNputFbNHJPUSaTcObytGj4tE9ZhdTk+oioB8r6i8CTSTUUPu1r3pAlmDIi
dELPGNxI8s32x+h7GTN5W7/NbNB77YoZiL8HZk6xMUPV+msuc5SZ6mzJy2FH
+LTP+icvF+MVTWP07uHNpgINK/i0L7s7pBRXIM0AFa3uXDCMNMbM786nwten
Kb+HtgXbH4iI62F8XiadoW2f11roVV6RO3e2NDB6Ly+KJSxyVh21jfnRf5lf
AaMH2uNlK+8eKqBQYW6xqB7ggfb8EFNplSzqJN/voaYJfNuOWSxHdglJdMjZ
oi/vPuBptrG6JM9WhVGOkIHt9CNQd3ckbMfY/UEAtQtair/tAnjXwZRo9Dwj
N3qReM9b+zkhBv9q4B795wIL+p31eqV0MtDr1Ji+E8FltKii81fqeSvwnnjx
rJAfpS8pSk7Rx7UnBOZLdpzcPx4fxkXJcpekJgSBj0aAJW7Js7OLVFy9ge+j
ANapS2MLmeZ+PxBDWnFj7QGwHikMU7GtyvYhCBbTnDs+8L985x7nc3KVIMRa
4ksEj0Fd/bJq7zerBQtorc3UieEhmJekkX5ZNdQxBJKbuhrQRAN0Hmed0J7o
bBPkPa7tnKUQ6H/kafvKoYnYIYevRtrja0BOqf0/Pww/pC0g+wFRE8g7vWDQ
GEu37YEIdXGLD+IDv5U2qJviM3sIwlM+X8lABfYztdeH7ccVhUxhN0s0UwPf
LeXiTc3LmVGIO493zVY7yF/drsqJPmB+iTBvyUw+XAZ5ufYyKXmO94MQTwqF
u/SdYD6CUfMoz6SCMbJL8tAuUt4Ygxd921bXW/eForW8zzka/CeXzMMScTWP
hvjEHv1OfwRy5+7g1RaYFb6Hlkd6RqR5Qb4f/8XL4jJUadBEgIqZ4XXA0xal
/rTsQRmQZpfQmThJUO/X/Xmiu4Q1A6rbKLu19BbUPcoaGS5RYqdC4g4+Ks/r
AH9wM5vYYfN/Azm+uc1PYfGfebI+FGaBN/yhqqmR4kxewOtMt2tyZL8+RQKc
AhvcscDvhIQ6EsVuiUfsrVNFP6WC7bfDyW56UGUguq4LcUPYVRj8lVgijblM
NmJuM16XfAas7/SfvzV9e52NEJwdyB1GQZ6Mx2+KXbPddGR7b1/iojnIRfQh
MyRWTI9FSNhmdkJjwZwFkuOp7HwKX8gXu3WqJPgJ5rrcs+HmziPPhK4Wu5vn
S4DcSK/Qo3iXoVJId4WcIrMN5MlcwPO+gfPmM/Rrcf5u/gnQA7dVbidQptdD
SznmLI5HQMd7gpXjEXa7EfpwjjttuRnocqm8+V9yZhsgLoGkQi554Lfa56Hb
zCW1UJiwFkTxFPRxsFFH3kypL4NkM3u7cR6CfM7Qx2dsh03eQCdlGmWcLqD/
4oZRzDMoMAv5puq4UWAF9PMsnpX6zNnPCKVdReSVCYBb3cW6zFLYjLTuhUex
5AC8O3169XNWG4Jw4RXKuoH9F1DXTHb8aEWeJX9cC8oFx9mIfbnRdbse2U2Y
cb5gD3xeKdm1KJ3vycgbHB6S3DDQx7Ex/tQ+mqgeWvzuZkDDC/x3VRmOrVbK
Qch9bvxi9nXA3/yILZG1bzOQmEb5PsENwN8+0g7OZo0sQS8aOs5a54C+OUvK
Psa7fzag29aceW1EvzC4zvGdZfuobcg5eN8xRRHU3fFox97As9yBPM0PKGou
AF6X8HzvJ3q4BZXO4E65UoF6vAt/EIODglVoK5i8kek84Htv25IN3rhPQiuJ
xsOzjcAnSnsiy6fTUI0ExUa8zHAHvrDb64aqH28WEeXorj5/eZDLFxvIvmA+
v4+kNVhRHgyC7R2/CPTgXcBCc/2Gq4g+g/3/yfXC/1KOhfbuMNUycgMfakWt
bVv92h5CzLvnY2EI5kNVt1rs7S7MQA8Q6YcDkeB9/FXeG5MkPDI4BevVyssj
Isw6Jb2jpqgWyg7ndMROcvuC/H9p1tp9K3YhmEG4+apLDVgH+7e+0tY8lYGj
VYPeG6WD+nlChzt6X66qwz7LKjSW1KCOnQd/TWd/Wg+2ieW3TBwjwazjgU95
Or+am8HPz+bfXBS9hqn3W7zS/baazBFmp/LcMjBXQtf/4vT32k0+oF5wY4vJ
4q84Y/Q0Ry6daCsw+sEzWG5sV7adwRU9zZ0bVz/geTIVDReSs3VYRwejpzl1
Y7WaVu980uCRSjz9slcJ6Gmunbv+XpdEwifY8HmX4Z/hYvQ0B2/+9cuF0qw+
OKf396Y7Yy96mptHLkZtq1GLJSHuJOEnq4JVi/7N2XPXpdj55IUlsTow0VM1
9hMeOvi3X4PNd3KG8vwBakH082VHPa7EXf5/t09s6FHIxFpFb+Mr1x2mLsNs
f3P/9lq7yqIPG9Hde5Nlc7718GlOoAFJcnyvVD76RIwkQHUlEz7NFZzjeDrZ
oZKAymcEezYYvIJPcwiPoxPDM+TD0ROm7KdM0r7waW5hIx17JFuIPyqUr+bp
O2oDn+YcXlmIb1FTdkUD98teFfrchU9zEdnu1wc3xlmjF0hojtXfwpg5azgz
04/JpR+icmfumox+JcTwN+dSVVbup9poqcezpUZfMM/3lTitgJO4Avrj5ntf
mQ7wHmQUzFwzkQuhldKqJt3EoP6BIm+B6TwlHyp9yc3521tQBztt/HhsrY8B
hTga3CvPgvtIoh/qnjmHg362RH/aqoH74oEPr2Tf5AxEhaXgQU0K5jtnUNmY
7FecQA7rIaIEdiD/5ICNOc19BQs+UBSJaTkEeSkVUmlXxDyPoVu/jMQNSUA/
RcyGTXGV/Ra0bvRFilke5PLpeoWtE7OOQ+W/IhQuEABc+su9yzEJHYi+cgi3
VAUZBnf3jnMofzqPpJVF94p/AjreE4nfb3LVNxHm1Re/1RKJgR6oP3xwUzcX
ga+JJexIuWO+l8DZ//1HoGHpo0s/KD2Aj1Ad2t3c6I/EtI8ydk8C/LjSfjaO
9QXSuq/PXhjiBd735ftrYs4lIGXFS/dCFME667qVtPP55zuk7qMorUwm8AdN
htz55giTkQvVCfpiJCB/zMSZtTaLKAXhtMX/Q04M+ijzS6u7tJD3CJfQwP1P
n8D201GKsxKdbxGrUhb/UXGwf7t2k4rc8hjEyTaIn/cNmDfE91mEViTuBfJe
ErJLewbmE+GLPKxi9vBHXnpQrsTogPzhm8/8u8Ru2CMu2zKO/nEPMXjFle6I
F9OyiAOF3fymoQgGT8Ip9/kwJwNF39MZfrishvld/R4gYZHAhqFNIr1jpn5D
DB7t/pgt5t4txGPBWqKuA+TSDB1PG4zyySMKLbfctZW1MPjrrHoeAUpVyM/t
Z3fhLSnM56KatlRHlp5Qt47lTZtnYM7pyF0O7B2uKCh5+kqNihA4DzLNudsx
7CmQspKjvmwe4LEm488D2kzyIGmSMn0iftA37fd18ur8+zLoqY31R8k/gA9f
I+rgDvr+GXrf8zD4rAjIlwtRfXKuIrMBWtN8vy2aBvD5/bwi269fIObxAaov
6H/ma9tXKI7cbYecLc4EnCUEepHm5ZmNj5Od0Bbxrc6GYjDH5Hu3w9cV7y4I
q4tHIrAN5JwUSrRjxzJ1Qo4UzLRlhaD+P5f03QDPSiuUNrIQw84P5mGpFd/V
O7zfCBGGLZDKMgL/sfQOzaSJVwXExaFN3fWfvmDihVsrsrmxkGMWK9tnA8Db
e/DklAdichG7IC6LOwZATwsu+8YydlCLrKjHq5pzgNzgpy6v88UetyJWoTMi
r73B75BKrYOS7qQbmQi8N3RyBZw3e37l5hHFPmTo+vK8wRXw3mTamenlWNaH
+E/R5fX2gD4dpXerg97+vchxc4nsykfgt254XpWR2uxADEgdnhA0gDpDKJzh
pIeyGXFu/mU0cwnU62a3EqC6W9VItUCNlHEw2D/1ys/YDTQHufphfvEoH7x/
fZouPXkuFYgIsjyJMlkHz5l5ExGCz+eCoRTyzX49S5Cn1Ih+KFRXCIQ4sitc
/WyAPtn9msZsI98N2XomYNc0C3IjDembrPNcXiAZlwaHBtdAH9N8v2PQOHcs
NPZEhu7hffA7qW+rmpZ+2wBVXvhsgSsG+LzQC2mJO3lj0HUXE9fdB8Bnj/iS
H1ywvwalmdGdZHwG/Fzrrr7USeEJxOfsMv3mKah7zHhGNxFQSgS/JTKYInAC
dQV3o5zmXPMpYHnJCc1PTiCfU2uPRa/F/grsljeqJKwG8hm+zBqrmQ2ww5O5
Q+6O9MCHrcmSXFlc44U/cOq+rk4E/Yw3nhW2lGfehNXbm+VUb4F8mDivluGW
1+LwNbyFS3l4oA6Qcd2S94eTNNwU3/lcpx/kvdhc2j4+0LsN9zETOBx5gLke
appnvQwoVeDAh7Y8uNuyGHy/I2ef+rsGfGReomjNo4rRzT6bpfFcadCBswKR
k7tGOhidrVPwJw7fA31Y3Xtv78aaIYa/yV7+TW+4aQQn36v97Nhjhpm/xolv
IovrYwqrR8yoUs7aYfxH1j+0PlpXreCEB01WFiyu6OnchwuW+th93x7BW9Zc
iLedN1p7yg8b9QXFUlzhb1QkqfXPg9DTuRIfGtcd7pT6wIJ/Ksh5116ip3Mo
kon+LKLHIXDlYNqLZzjx6Oncim+uRgZX9d/AL7Ou4oYSfEBP51xE5r6gFcIu
gts3W+k2kRr0dC5G51GB4xuHEfjam1+qFzOmUaG/czQoTyoPLZiG4KecCjUJ
vGlw7+y//JDr+DHDIVsrOvSRIO+sdxc8Hfuv7mfzSo/V2accfb58xSDH4x18
OtfDEvHJHhYOQE/Eh491N43R0zkg2HnrZ45m1dFzfPvhZeUyGB7FUe8b9yAX
hj8vcsrzyitidDAF5e+tOy634Y2NSy+d50B/RIPOvSPnI1m4Y2PiS+CwIYan
6bR8EylzkoDlzxjvdB6CPgtCbQtyCX5BeB5HfWPkCOT1EeN6yeXXscBszkT6
K/33MfhiX2fveftNqOblxEENGcjr46HFo/9xTI0S0NDm36W8iznOxOC7Oapt
7OjrQgPSEHItDJ49X6faYMqDxopTyAvzg7zBVj9LKqkIfpSb82mVF5EShv+c
kZDa/5EngLK86bV/KyiPwcN15st16wTQCJfi6Px1oAf2yRpNJ/7hRztiz4lW
+YL5HWnMUsezKXxohtCzuGJJ4PP+m88QiAwoZe3LqYDc0Tuj/zsuP+hOs8KW
qQ7INQ3nf086w2mKcBFOKfWHg+1JLtytY416ikQQ/trR7gPbPzGN/e7AHIkM
rvva1iHguZey2WtF8zgWefRAfbfzBPh9X6LJCFLqY5H+hD+0eREgf/Wc3P/0
q1jEkXKZRMMUrGuKjHqP8rejkFTijUYfIuAnTurKU2TJv0CsSBPKPH6AOvZS
JvNqkguByMOYWmJqaaBrBZ1FuvXwXJGNcW1yRgYwj8lKhPKRs7cmcilov79k
DvCiacLFfq0wfag/GPcHbf0DzPMzwLQPuhZkBcmOCs6+83TC4Kon/jsC7FYQ
Y0jSb318wD+PlKFYUgtd6IGrwtLtwf/MZ39l+w5el0Ge7zK4DUYA3sgg63+1
vtEM8X/OqXn9Ldh+LhktP4qxQ8iSuPLa2QDvxZu/cJYg2ARxbBdx6/lqgcEF
r9LnDKg/hPA4lW04V4CfO1d8xdzKJAjCe13lesQP6uh4zK4ovL3zGop0/D+m
rjseq/d/k1kiLWVWdjZFwjlmdshMSJQtK2RnlGTvyJ7JKJtwH3tHNqFByBYh
s37f3+fDc3/+vV7HcZ7znOfc7/u6rvf1ztyjyw+HfNdxc7GF8xnIMktxAm8m
fB645O/eWqDPR+6YRWxLJ8A5dHwuGqpm/cWInhn5E5ESmGOT80vxi21MBaJ9
6l0C7Rbk/cIzPDa/SFQjFkFb+vR8kN8TOvthjlQZIJvvwEO7PADPk9FqOVMP
EGv5u3NsJZCfwXcsiqyYrUbO3ifnK4yAPPPngSDH5LsVSMloyhtCTqjP3vdq
5+W0K0QKPKpYeh9Bnc715GlrvyupCPK0qcuK5z9zh2+XtK1feQKKsN3MGjOo
t7oai2Fnd3OArP+F059LIK42hlQxfigDEip6HN4yEI+38G67wgrA55F3il/6
IO99T39V7O31enDH7SOLTA7UZ62MytlLCBtAjt2NwqoCyIc/GxbipTpbD2Sr
qJ5do4L6bK6F/Bb5UQBmEqTB2GWozxr/9qrxUSsDaBHV+kI6zLFpkc1qTbmR
A2aeGOJzUkCfmMDjRIEn28+BNVdS+/tsOO/GJZHxLRtZJPLslkPr+C6sAxd/
xqrIkKYjv4wCdecSYD2m4i7u7sGegYw0jn4PcIJ1TltFl6VxcBzij0dVLP0O
+iiEbnwREvHWBD+PYr4yJ2FukuhXZstc2WSwM8QRGPQV+iHL2HPqxWZfgyyC
j6kF69BX2Z2RuivwIxU8imaLpFuGc+guT1KS731NQ6IjvnUGxUI9l7HzsmSV
dSvSxVU89KsV3k+Ugohz/vcYMm/FzSKlCX16u0VizIwi84gKnvjcvcLvOPy0
4e3kscANhAwrIOk0hbzfwmWaRQYuPLS+4GtIfSLMV+E0ratjKiFGfyVsh7Wc
h30Hm2iRYMV5CtTAsn223BryZvROYGad4DRKGDgax0oDeQMLBpfAjB0q1LUj
3678M8z/N6WY1duPpkEHtp3OKFBdwuGpGbGdLTb0qLy220QNGeQxOqSls+WI
L6D8R2df9wzAPovblHMk+TMM6JuZxVlmXn4cnrmPWlBG0aEkd33mRZthDsZ8
o7Hss7fnULcb7ydzwoVxuHxv1LRo1wmUJ+7J32oTWNex29aqcfetI5HV6coJ
BLCfdznQg/SDKx7mfWGzLSIM5vJp3V87lVl6DquqKiLlSYP5ew6Ktc/dZ5mw
B8fEdyJWIM5KZ5fofI4Tc57TkA28BHHiJ2kctWq8GOUr9xHLCKg7cyhVHXH+
zoUl8MfFt7bAvEGpkXx7IToabCVcdUryHbyfG/pnyW+7cqMF0U2SdA2QP7Re
JLxC0KmK/hRatv8QJImrBziFSxodmkzQiKTv7VFPlXB6Yr0239XwWHcU8ya/
wXdRAu05wCV/Tr3vyI9EUyyI0vvMLLHDObZs5Q+MJI8UolKWv17+WErADufe
nnfs1lenH0cFR34uxJINYI0Hc3I9L9a9HDn5C33pQavBaT+K6QX+y9flh5ua
v2EZQv9mpeLPrK6jrrmT/+AjyuLd57JXsewCjg9Ej9bRgIO5vXJaPZKeaU2Y
qFDf8oRyB3o453dxnZyediMPM458tk2SUowyHMwFfl7Y97Qm+hW2kHFHNbMs
DT2cI2ypP7rjpR2KXXzJMv3ZMwo9nDu87mE6laDv979FbzqnXPo5ejin+PGT
QMWfYW6Y09HhzdhznmjKAf6QK3GtmvoRRixOd00pxwE9nIPc5aPBQqBijf2a
C+Xf5DVHD+cmJ3xRkpLXNcGCwx96vVE3xPXzvqpii/cRvYeF/7RMLCLXRA/n
NQcVpFeYlN7GjOmza0apFXD1IXvH59KgOm3AGNIrLHYJrqd7//+HT/yAv065
v+AgrEP2ifZ2ecnNgAf1Za0gb5jfZT/dfw8TNwd6GLlFhz3cj98577pYFGEJ
su0G3Kvt4FweugUrEaaFB6AF74rt5yBzyAPws2w3N0oAYRLCBvFSOJfqds9J
b0KlB0iZ9nLjrZPGuPehxJ+PfHGZroicXdwqtx3c74+qnWcXIvJHih/3hEch
Pji8xkxC1YEsDImLKFfGVuB8ybB+OpvimUik7yQI+nsV5sEmnfe3DwiNRk6t
l0yeZoS8Ckm/XfmD2Ghk67zVxRoSqG/K4Q2vU5tEIYQWFDONbjBvtjuQ/8wK
Go5oMfNhhJ+hTtpeZvzYfdYPmc5z/nmmCeqqhMPG/g16FgiRZPoHsAF5AEmX
RaNYZiuQPUs5eakb5jBvZHoFv+vxB1c335Cb/0cX9hBe9s1djgB0QJOrIgUe
P3hOwYpBPhbsWvp3a6f8p6/22uNFK9U4cD/TWkxADerCVDmUea3fXgINaZpf
H0/Cz+VCpKSQfjca3Fvv0hSIh/fHW+Xb/nP/YEDcbHjz+CjMZ6vgmx1jO+sG
riio4icbwP5fuqp3vXR0ekjdq+flQ936uO99LSYw1snCF0E9ng8VLcP5CKnq
P9ruxoQgx8ynDeZ9IV+E7xh28WhQBPLseHx7pTnM2Whb4bblLg9HwoV3Wu7K
p+NwqUdL8Wt7AYgN3/ORB5lQfwea5Cl8BI7I3fS86w9WoS4cZVTIhJbbAKpF
5V7VAaiT/vHwbTcmewHODPob3SCGeOLfYuNErijwlb7Xzt8Snn/NJiKG50gM
kGz4smDcB/Xor+JmpafVw0G7CsOd6sxoHK5JNprn6WEN2M+639k2t8PhXsxy
4dbtEchjtaMrtEPwuRVqz1f88OQ1krrbQI3FpkPeps7460xYKWLO9qX253/m
XwTU90Yt/gVIa7bjVxIqWM8oND4OefGqEblY8uPt2T+wP/png6rd9PVWhC6g
geGG7n/02dqWW4+d2xHjXfOUZ0SwfyFF2v7G8ap2pHPFYSsoFfY7VPvwvvCN
bEXG5G6eGzgBeaGnxLRqeYsNiM4vitPSijCnWkBk1nQlswIxCbVe2bOE/n/F
s0mEvjmxSCePDMm1F1DP3Z1LVI5G80EBo0otFz/UW/EQBfNSunqQKxMod/kX
xIsdZgYvdbUDfjq9zy8eQN2WSov82c7IR+AWRqlA8J+8Pqtx9cw3xL1AtMh8
Z94anmftZTW7e9BH8HOC3mVuFF6nyFRrZvTJNqClKj0UOArvw4Npq491nytA
YJZZzAoC+S55LbPBjwVJCB8GRMOjYR9W25lUx52tJuSePWuwVxXcF1Qded1t
k9WHEBJU9ROfH8HhRi7d1x8OjyCW6lmDVtyw3ovdzy/sDxhDNr3OWn/8Mw/3
Wdlj2zoun5C3/YGXr7hA/x7ddbGY0Lle5I6+j/GXC7DPN8d644OMSCkyZm9s
/OQXzNkTS5qp3yRtBSevlsVma8C68SielXatxTiIOxOr0RINdeRAt0Zqi53v
IIec1b2FGJ4/UDYj2GBiEsSpBOtKMC3i8GiJm90Cj5sAs26CIUMj3I+oO2Ul
YvuLyK3WtX1Czhnc/fRzJIuNuUWC3i1zpclzhPOhImcYZLKJqFFqoYv5ns7Q
h5ax4sNTOsCKDrk/IU33gDpUOdPomh7BFdSmU9bmXSHM5XtUSF8Q9glBldS1
0z3uUOBwD0KPpUZPWbTD/E/qdhLM7a/hxLID3NTQVoXFZwnWUKeW7kuStyvV
QaOKRbGty/w4PjDoBjomMnEPXXIaSfOxkMb1d+yZ65dHHjFHJcVf3nCn0sAO
9UEHUtuY10L2KDOpE1NmjBE2d4CX7XYOGHG5ooRDDxPFvW2x9gP8gYjFogmF
HzpIuKn5mMsDczzAw/rMj6n6hKLmDQrrH3pfYPYH9RvnpBDBrdxXaAqpwJDn
mXisaedf/DetdKbYWi5ae4ZaT0s5DyOY+xenW1Ug/9NTjzr8zp8nbG3Antz+
F/9CMtHlEPIDFRoSeq6LzWLMTUv/4OIK43pa5kfEudPGTwp1bGNulT7/4Kxn
kgd+Zq2ij45m1lw/jideypr/D26Qv0ScnbmHUd9PoRxP3EYXKjP+waUcHHQ9
X3zAXng3HOMpa0ZfYf/We8ONF9JEnAox6VdE/V0UmWj77AFvFlzjGm70CptS
GhxozXyOggPe0vtPObDdDMDCr9QHVElYo7cP7g8Hu9AAZ68rFmG7ZmglL48O
HeBHHN6HCo96oLMPk8Y36NWxzgPcLScmnwEvGF3T6lzQ+GqPsR/gm6sKp3kn
k9BNYR0uzeJgrOzAT0gV17+8vlaMjoTi3wqlz8Fcv/2L2zxXXS793IOyDBNx
02t2YIjQv5+r3yqsoS0OX/w9zdWzWwN/MSGpR//gAkUy4ZZkBLXaRnfrRngI
xT96iP+DH2M4f/HvSD/28UGxRrjtIBqdu/fvc8XtKy3oWIl9YT791nTjPepX
ePD90iif6TTLwjoDKOfOxWehoQd9OrWrdY5fM2Mxj7w44rJjMeiNg/vGw3Dv
ViOnD3Zlo6Ceuc0FDT/4vHM+xteT9p2xnRMdwer41jh/48dSd5OASlvMKUtc
tOyhIS73O+jXR+MYCVPM/cmKnP+mGm7fMfRNkn3e2BCjuy8wFMQoieNR36a8
nOrMUsFaWPwHtfmhniuJp6JP80UG23q6kiNBCnMyg1eCq61iRbFWyZ+KbIEw
f6BcuH/c35UfUxsy+XItDeoFI2Qjph59zFhCpR/J2jycI/lm2qD8cxAhdk7Q
jp7gAny/IXb3b69O/ACq+RbpF0hgrsLOBHgX+LAdqdd4G8yfBfOcs034P4l8
mkBcxUUT97qWcfgJn/lIv/EJxKk1WdEhGeb+7fFMn1KiAMgfQi788CI49234
LbWkhnwdaLGq4nNngX7IABGBqv20fsDxXJZPlgT2m7A6U53VmPsEvALran0s
YL/bL8EZw/vfRsHIx/kMiiGo43fvi6FGt4fB9tKxnGYz6Ks8Zk76bPJ9D+AR
9lE9sQHzbfj/rLGULtSBoYuCdkqJ0Nc0/+rOJaZAi5qjjaM8QSouuJwZAWtW
mbB2gBhF1fbZ/YW+OFHLqXC54x2I6Yns5+YN/+lfkDrhHCnagzSbvZOaGIR9
vr9O/FQQ/dyN8IrQP/S8DfsZR/YMTdb52pBk2xV9U3GIp1Cf+VLajCF39AYW
LQxhf3HYpnnving2suTC7qQnBPFSL/HkqPfpwD6ubSfYEfYdK7R0XaLvbwSX
3pkdN7wG16nWay5LxHT/qwcaCA0si+D1K3wfvH68ph2g02JIlT7kzZi2GM/y
HWsHdRGNzSeaIX+41a0iU+TZAjK7F4W0z8G+bBrerpVA4Rrw1Jl/9DsN7Ctp
KjxzzWyxGEysp3crp8CcZ0Pf2ltMC5mg2+iKoh8jrEupYt/dq7UNBm5yQ/G3
4iFfnWl1/7FJjhOi78/TszoF+V5kQ+N6Hnk0QqbLb3YtE+qq+j5yUYZaEYiY
vSBJehfsR14UeWHyZOwpUh80zRbBBufQtcSeMMMv0kXiKd3jdBMhHl6Mf/1P
lDvQMZ6PB3cgX1ep2pKtvRAIenlXFN344PnXdWn3Ey9FgNQjIxoxo3COW2ni
06NuJyOAlSthIMUNuN8RE7lOwPgsCLh+vKFJqgT7L5Sfyzj/+uAFQu4+y4nY
gz6KxMhIlkl60RqDJGGdt0/lcM/thyxRfxs5b4Tkvead2yv/ybtO+KItQROD
fLJvrIkHcP/STPln/SJtHKJ9pHUMC4W6g5rW0NgjkzjkwmUPPc1cqF/QB4GK
cwkxCJ/bLK0sB8zfxnYUZ5qawpGEeAbRj8EQn3o3NbYRZoRUNjwRnRuB9SSX
lslFlbuPwGv+W3vp7nDf1ETljRCoPgcsTmfFsDSojzzbjUZeZIeDnrUpEF4O
efU/Py5TnLgYDX7ycCSlMEG/qHr9KVcRgWigHlZOoVMAdWrWUb73cTURICOU
oxJfBPL23SxnjydSBwMTUwpvjSq470sSa67navADSnMWGk2FkJcYwqOU2u5x
BuMgzS+4Dc6V42UtnhTLUES26JXLMkphfxk69ek6y9wD5PwPbcUjmTAXK4Gs
8q+otSVixDCuxdwD+QShJqllK1ZzhGFfuWyGCvpwPmSv/H7UbYhgR5TKwjih
DnKRbdTqZosUMtP4xdnTFPpnTLrwJkN37qAC6neeGCzdxOm5hH8fxr4pM0L9
zGnWZaN0cP25Wi4vTmKMZuiopaLQCUFj3Jy1ZZ4bp8WabFAzhi4m/hUr3Pzc
Lp+4xvefHVFk763N98dOuLrOtkN/4ju3J+oSPzHyuNYbe3aADyuUZor7PkMj
GwwvuX4JxEYO6jpiwcWWzYsR6PXNwYWEklhs+GAdl3RadpurSEb1LXS+nFnN
xJwPdNue0yE5dEWF6C5jog9XbDlWeuDfq8Kvagnub0f57u/K+aX2YJ0y/9Yn
MvhvQXDSb9SXDWGni9rFBFMK/sFXXij89Qz+hU2cn3vziHsF1Vsa+Qf/pi1M
kfuoHkM9hOJ9j5WiDa/+Pf9MAevVI4tp2JU3gt4XfQJQk4P6cywuJiSA5gWW
dddN1mBLCzU6+LwSXjujqnuPMGHGx9lLBVK4fMKjjSSNGeuyWPvyg5aMX5Av
1d+rupxodRELDsVU7/zH1xq0+fvJ+tWL6AWBvNc0f7lwdQU4usow7c+J5rBU
DJsswLljVqV6Y717nCjdzuhGkg3sh5Xlbd8b27uAMp+pFfPzgn21Hb0M9XZV
lGieH/mLSz+gfuodQv8bX3cK2Zx5Gkn6Dp5H1KrATHn3CJZ4WuBSGivsq53B
fxNgMnoKWx6y5/nkB/tqO5UUPpWy0mOMSiHO3DRwDtrZ269TFcMZsI2/a/bt
prxwX9PmrUl3nAGzlXm6nSoG53SEPDAo51yjxUTjfvF/mIL9s+k6eyGdI+cx
9gb9gLwwmJMs/9ago4H1LBYTqTZDvwz7OMo9Ws9rCJzElAOZf26MwDqtPRlr
5G86hn0fY7sbvQT3ZfakI/oUHwgwLmV8TqnHMH8vTOJWuF/sLihlf8wm3gLr
oiMYLR/6cRWwKN+7fNIE5iHbPyn2edU5BdrsRiTCOmFeiptn4tOFlAHAGbfx
ycUC7uuNCiM5TOgBaJXKO7nCBv3qixmqWwkOd2pQW5KgjEc2uPd/s0iII15j
NqLmyhRqRwj7B+9cWOspaMlG1p106/jbYb8AdoKYXtg4FmFvidP9IA31RJfk
lK6LkongCXft3vhDuI7LDmVoTLClA7NTV8R9WWA/6Z2thhZBjUTA8TQjYPgz
5LvovJpmxjldgPWE8vNwBPa9Kt8JeRTF+App6TK72FsE58NqpDI912apRKwS
d4laJiAvkdWeg9UPYMhF892wkkswJ42WaJUgSKceMSQJ29f0hvzPu/fFTvSR
9Uj0p+TF86MwH4NctUg2/3Qd4vWTQVP6NvT/NNAa5d39VIRMGqeFjJhB/qTA
TXWUbCAFCX8uK0hzCeKzvUvDzYHuIBbFCvfKoX9+/vTu+qWRbKCWsb39XBby
SHT1Xgz3zUtAXX6U9lgbzOUQGvNNDuF9D/oy0h6RCMLr1Hvzoij4ew1I4fe+
kPUG1qvfjs+RMlcDcPfCaOhLV8iDfdlom7oeUQMUnqwJb1XAPJPhKr2JM2/+
d34RFYZmQ3g/jzgNKrJElAH8hBjxm8+hzhjn2cFBPlcIvtyqiTq78gaHm6lH
UROY54AYqjtztschv2f841yXmW8KcL5Z7iocB3naWE3lm9RXIsBSgH0u4UAg
rFuMzIzS4t3A1dGBN0Vj0FdWsE6k0XOBpyb79uS340liuOe54BPy5hSxBULy
ODth0tUW9/yQVSDB2633kKh79wWvpcM659vb0Ir4x2s1tcNZ60dmIH7NsHc3
LOEuIFn52uov6QHrgXffdZX6TIHw5/x6dl9nHM4Quiz7W+s+iGEJVSq0g/5D
Mcct+627JsjfSoqd3QroI83r++01XuCGxP3UveC8BtfxipBfff4fnyEPOl8z
+UnA+W4Z3XhPktxDEHmrMeEzFZCvvl0Z3coUEYEYEstZGHdD/6R9po5hSHQk
4rwhXptPCX8vOQrZmfmJ4UiJ3FGa3xlxOPwO06QOqVQgojJacXQqHdaZiBD3
At6iNzJPWaoyugn5fx5bJxr1DRNEvW0pmjEGHr85c1rufboZMG67Z81LCnWE
42d/HI9q4Ud9xRVZW+RhXyrIez5wnVUAfVx5+fsPQqhLDqi5f5NyEkDv2x8v
vrAK+1KdNj+7dozwo3dWBBq+WMG+1NHEKmvwjhel+q5recUO9qUWxzhIeSVc
Rl/ThqzI2t7C+aMUp351ceVcRAkXNtreyMK+1AdyrWa3HfDQqsscoU84YV+q
A395hWQoFZZ/fXUhbAr2jcpKpBDnxnNjzHEnvx/j1MfVS9vhFb3bU8KYe9uH
KsJA2H+KR1IWSC0oibXPfXoUJw1xZvIkEssGaWyJ9IjiJvMdHL5LdNKSs1gM
03ncqR0qDfOTGSxtv3U7SKGi3iPqLxCYyxe119x+nM8RNVEMabkvcxOdOay7
WIItcy2TUO31dYej3+ywkIN6KeMTsYJL2gCa2gLu7vG2Ypsf//Wnpfq/1mWl
/IYFMQe/G6qZQWe///oHf6ydS1DNV4IZ43maKq3VoXwHuXZqz838wMwrbNw1
c6mPMQ/NO+BbqmmbTpIOBGJ/TXtk8gYTUfKD/1vvkl4sLOmN6Tf2C8TGRaAv
Duo6A7tq1bhHdphDap498e4T9N0hD/O2KHUuxQITH/rqkJbljOOvpj+vPhRJ
fICpnSeVILxhh5s3kYBdM1yduof9vJQcd8XPDNdnOi5w32JpXQ/b1pjjmMYz
wuXL7UVEkexc0MD6X611qFnCftJ2/j87slqqmJtWJdOUnTxOXw7j5Fyt1lDA
/L5t3B/9DOucv99A+K6gDNaVKTb6Mgn6xL7wz6VypYpjF7nYJ6Mi4fzWqH20
A0gKY9F+rifLn8I+Gmy0K938kgBGViwY0UcG65ClKy+r0+5wYJJSckyCorCf
1J7hKImaLyMWJsdUeCkb8ie3ohOsJlbOY8oX7gmxeMMcuVMb/uMtf09gcecl
8Z//Zx76yy6K1s83CLA1MCZHwgV9QRcn3i3+NNgAd166zrX0Q/+Ph4yzUQ/V
NEjU9UgL94f7fdnVNTZ3rV5wDv9jg2g8rAeE+S+d2KQrBXx5aX5P/eF+LaBH
dkytwxVgqd+/RjyGOpHXprFa8U075Con/4qYL9yn1/lUijkzugPLgo4fCYUQ
ryxy4x6ifgEC1x+yLSRB3dM7zPKeTZRoTYuQ8PX+Dg3cesFdI9ZtMZeKFCre
Jr6pDvez/Iwsg1XsZcjT5gStKy1QF9vZEfhst1ePBHYdTWSuhv6rpSi7df3d
bmS8NsJsVx7WOf2m5y50X+tF7FKjk7ZOQB5Dk4NPuMSzFznHmUXenQb9XfQT
PU8YZHqQty5BYm1DcE56ta/ZcOC5TiQn+HM1wUPoM29jY7Wj8SpDXNK63dM1
4fv/6QVTF+74p4gsNXn2sAt8/4vcGy1N4HoHnpI7eIzKQHxXyFw8Fq8OjAYn
6OybRePw0dCqC+/8WsDsyLvTH33gvlKUePo9qOoA+YIDVErWcH5ElQeZXcXk
B+C9o/zXbkwIhz+/77V5d/MDCH9GcuZiH1yXXZT5FDQNOsEm9SdF9nGY67KM
SRIEoG1gCk/21Ldy6EsMeuxVXu3aBLx8I+8uCsB9+hGxWLVCpA7w8ccIGPZD
3GzXMf4yRyX4lO7YJJ0G9++9fSSlrHmFoP6NZeWpPej/v3TJPb9oLxOkNUYr
PSqFPJLx7hPfNtGXYLUmXU2PFtYJIh+W74/LPwNR2/tXRlKh7unbqWnadt4K
iHaHZVSsw3mpdvHqWPNzXvCLn+noeasbuPuzgu+89v4nP/LDoEF3LFoPhyuu
z06QWFwB7Gd6lIaooU9SJ32XJzFHFpQaRZCmftCAdYJSfYap8MmagLgSRs/T
jLjnvDyESOSXpTHCcd3DpC9bF3c9zjm5XNNd/gjho5ZXtUuQlyjWCejrZ4hA
Nh0liPa+uMLvJfTM5b7yWMQ72fbYjW5P+HmrftSH0iYgFd9OK/gCyHtYDahe
uNibhNjXMbfr00D/xpmkjOd49InIGfWQ57fNIa7DL4cKV79Eas69qRuqhffZ
4dux8F+kEYjz+rD0VyaIszZTdFZS+iHNDSePOX9zwuHmpO3frs0rIztkFC8/
BcHj8+9dIz+W4QXW7jD43mSBcysoOla6/7RMIp4VvUXf62Bfp5tFJ3JHchDp
zPERNdyAfZd0wlfSNcAHIFI1lfXJBvrEhJOCXu7rL4G37YqKu9sQd5P2/nX1
9Raoes9HNcMN8Uff/FaDxv4AaquM3ruvIW+vnB32y+PzHngpMKPAdIkUh6//
vF8yszwLenItR9+mwbmQKrGOnBKvd5BSfpNwKznIhw+zCoXt755HW4qKvBYe
Q73v4vwpn6efONG77ix2yQgtDh+rLaGRpBVBPzion3WdgeuReWTQ9GkzWdRq
+Ku4zm3ovzrP7P7qo4w62pKupGVCfgm3Pj4+46ExvKmP8vUr8/dZToLDegY/
+UkLa7EpGqp66c8P4Ws4HinyM0tV0qg9ind/b5DypDp26CN687JyRDrDAyXT
fS3v2WSCtRzgJUw+lMdmnqPjOquGSuIu2M3DdZxISyPlVgxKjefhVL4SiD09
8DsRcH6M4hDMQmnsfqTkVadgxw54odN6g+lz+u/RjjBzvsHwMqyq6l9cnEPU
kPLxIPrKnUf+03Y/JpT5r97U87LIr9aaSJxC9xnBZTKiWqUXDP/gngS+cfLW
RLUintWO/UeJxFUS/8WXYlM+MzgPYi7Ff66L/+5HWw/O02ZgSs2r9x6Lwif1
eRpchn44+L8WkSkXfwpkYQ7zbfFnSlJQioPrJCk9GSihGoNVP5OfyvweiD47
+FydWnTTJ1M8MNumoafnSk3Qw/sTRss+7jFoj20lMlEO/7mF82WJWbWl2eSZ
YhT5C3brx67h9KnK+Dc7Qgv6GF7WqY7fKuPI4ffFwrRBPimijsUyf9WdvnwJ
V38O681mX9GRxcoprlbwG8F+zHrbo7OmxCKYZ3yKIssMzK8uroi+LQo4MbHn
unIT3LSwnyVwO8qs6zxWBs541KtQ4PDC4baAOOEdcLXK9djAFziPT82iv6Pc
dg4Zza+ZB1tQD8rOsIpm3dlDYuIeGq7Kw7pIh7Hmhdv8H8Ta/s/Z1veQt7n5
rmwoNnULSU/7Y+NyHfZpFnZW2nyiXULu7nXMtRDAfkw1+ZFYUeMupOTa3olG
B3i8VTJP6LeZYSB9ZfNS6DbU2bU3ONm5vsyDu8ayiHIZ1OUnVeuCe6nXgGzV
n5+sS3Beg9dLTiPm4+vgHOtDbH8T9pmel2k3ZMn+BWzrj69oM8N5svHV4PVX
+1UQ4Y85jCXB/F6Ss+uerbyL4OJTT0rXkzAfmMm3G2m8PwVOWt+MZH8C83i/
/lo7ScLyCcgHmM19GhjF4ZYG6V96brWA0tCnuwOlkGeQuqVJSfvJuEZlAVhY
/vbGrS8eUda5Jb8xhLVWLTI7EuZ9GR3lf/1msxVBBokrb5+AulLSW+JMOYoO
pNip2quVAupTTwwlzggG1iFZW2fvnPkEda63pyeP9okVIjpH+hx9YyBO6Xeb
lHrYCcS7MKbRFMLzUImfVY2/WATEW4+4tRFAnQuZDU0jX6wBPV/m2JuooG8c
vRSp20LbAPIoAopuXYJ+9biW6sBVjkbAq71+pzsc6lzilp/42o80gJYLCNGt
L7Dubcj3ZxFiw4CHoJy1fjvUAfMLkq6m/C4DN+6NWN8sgv7wGJHm2x8b34CJ
431CjpvQH0613cF71jkcnD/1qMnJE9YnmT8jzLXFAhG7gKSRj/qw3lMRXCco
4k9D7j+/Qm+pB3Ul5vinK5Fr2YhiW/x5PmOYl2tUPHcbb/U1khl3zOLuMein
qhPhfvQ2PxN5NSGav68B/eHrEkjPWlYiMqp4QsVNFPqsviWYRPl/D0DsNTUa
h0cgnjxL2P+W3h4wtMsoHLkH8S0ht0aFvijwOef71+0eeP7vQwlmHo4p4ALB
5dBEecg77Uo8YV65lgFeSfcYqWlC/3nprZ/NoUKZoIK8S9zxHZwXL+92Wdci
Mx2MU9qFrDVCPS7Dz3ZH8HYyqE9KspzMh/sFimSyBaQpGjy6T1Jw+Qash+kK
gjt7tZ+C9VVuusFy2CdrqsNB7H1FpMa0wex1lqQK7vnXNPNbLvvljfj1d5qc
FoV9po1997i+c0cgEhQ3qr/nQr+cI9N6w+/1cOQF4Zb17Uuwzqd8FXle5Ggw
4qa0+fVPFNTRdsoeTe3b+SLrz540RxdCPevqb68raJQFkt32uUn0LNTFZt+M
gqRkU1BSle3WpAePl+1Vpec/6Qsorc7kYmRQd5NoXSVQWb0DLn4ONwo7Afmu
+DH2X3tuRYhMa6NZGwXMS7FROvmMxr8H6QnCVNYvwf3j372H1iuZU8h7o2oD
2Zcw/yQ54Lm4JvsGQnPqyuOWv9BH14Gfw34KIUBjoq4IvQ+EfGyYKCXFPjUl
+q1DlLkwH/oVJx5qvhE+So0+GFGmYKz6hsOHbzoFZCUyot6PhF6tVUG/xHHR
QPHSAA7UPs13yH6cBLe+cG1G7y/ICaCrrZTnWj/CuVrNyrmsHY+EURqnhx+v
uMH1600vyWTsijgamu1x73UIzGFz66D48vW2DFovPOY/2gB1GVEppIPbXwE9
8eWKgeUq5LV+S1DS4fuoony+W+7rr+Rx6+m5WbPF8+IaaFlKXxoWeAvHL93w
CjktpKKDklzp5g1Ou43zU+mKJkxbnNNHQ46yui9dMsLVUd17brM5v++hBgSx
DPYlZtj6Ab5m9HL4wrsHaO40pcrgfTvcvION8CBy91wL9G4RWeXFj87Y4AHO
If25wtfODiVKMmL8Ru2NHfIw/Vqh8vGXnVHOEI5rt7WeY3cOcLV7Gr842bxR
7WFVXvRtBOZ/wOe8LDry+UhkIPpAhSK4eT4RO37A/2jRJApbP3+FuhnSeK4w
5mG1B3yRow61mddAMbopInQm6nMdVp1+cJ3HokxLNL6ibFJe9VIPZ7BWlfV/
8NKe2IcP3/ZjynX8N66eaEabyf/V72Zr0p+b6CVg63Zjlp+LDVDKwzmtoTyV
+qH2WA1v6Kte5ju4+yCpxzev/oUfm5CXnH42C5+HJN/L3T99pVHE79WANyvs
N1RN7Jw4/k0WrSA5suLCDvsZ3RcJfhRek0b1OpCCjwP6uP7H14yiZdejRNF9
6Yiu+AewX1J2I/tPaAofSvqGypuNSx93Hi57Gd8tG1q0qOQCy9BveP464GPz
QmADNFOszMzK6+BwK/bpp+IkF7COW0qcK+aauOuMC1Phvsx2GdPV0FqXD7wF
cyToj/bsF/Fihhn5hoXJN3G46cIDncJyfmzDHu/YSrI8Ds9UCpEusxPAyEpO
/Imkk4E5GNppKLgigBV/5lEWZYM8mN7Rt4wOQvzY7Ry8n8+eQp1xLSn1Dq8J
LzYzTq082wx1vbySJ8pkWZxYZY+DXzwdzFub21ZYnghhw7xUgfY1H5gnQ3b/
tkmMGxMmVX9/rNz4Ig5vcdpTDCG/gF3hTHZ3vncOh/drnT3bNXcOK/ohpnAX
gXWg8flW9asFJ7HY47Yj2Vuw7iprNLRI/U2K/YmP/l6LQR9m094LGfMKPOzM
1B3SYHZYX50/6r/Jvb4OHHupeuy/TePwXuvxy3znZ0GgWNuk2bFPOPycVwHf
cvQIwHsRmwPMoO7DM8xa21zWBE7RZucM+sH18ed0qCcS9Rr4L1xf+PUB+kMm
2XVVbWgEavLJ8ExiZLXgfr9ygDyaxgvJ3FusnHD4z1yAv/djXHTOASaWQP76
KsiTFF9cZy8ycwGWfBff7Y7BuQB4rAt3EHM1ICH4jZh20QiHj+r/sEtVjUSc
S7mNxvagXnPE4ofdI/o3SCRt6MSzSXid/MjLrOWH5Yik2vwnzwWYS5AfTl7F
d7MOcX8R/yHmOqxD6CqcApfzmpBcz8Wuq7wwTz68yMzTLqsVoX+ZLnxmGfbv
mzZkvx9KbUMuH1FXfb0A1x37st44uuJW5O4VXmZUG647qtU2LHk+TUin/Ala
hB/efwt2FwXMsRYRd7duHzwL9Ts381mHXusSpK44f3m/CeJe2hueRuYvEaJW
2rHGXohH84/7KtxLBn9L89Z+eEG9z9L98/FOzhIgkj5DisXB/5vN7HEpXhqA
6DydjdBX8DpTCdk0791oAOZXufDNZaAfO03voea6cRMwe7j0Nu811PuGdF7e
rjnSDOY0PqY1G0Dds/jm8qASeROYtxT/mRMH6zGOLXSLgrcBXPDscqaShvef
X5itv3wLA6ksJ7s+u8C6keDjwzDTvUqwc+6B4QdmWF81jD484/KlGBwTeP/R
JhfWVwODr+KO6eaCS5VfHnKSQb2Jz+lo0U5LKuChcnsWngfr2PIO9Q+sQ5Hg
7qz5EM1fqH+1mZms6Rj5gLV+vqdPh2De4HAPNU/VSxPQQ3rGf1Yf8mOc27ks
xETkNVaYYMdqEOTBwpRiNMRLJBC1R0mGPDuwH7kutG7qmQ4e0nK95WlvJOTr
bEyJqrXMfZD9lM1+JTnYF/nMv45T5FUsoLmUO5NKB3+nqwLR700Us8Hr/iaB
NxXwfmo2ijGZZ2WDus3dYedF+Pz3Vixq6u5ZiW3o9PRYyhjWHOLKkgXvyhkB
ki95+9pVZpibZ2rz5LPW4hRiMLtHsbsJ/ZkhtivvE36uIoq5zgmcpnDu1QC6
TvQ2YxfJ6auVbR2CfnWDoIeD1CsEqHAYOpjnC30j702KKY0njqHGv3yVZHdg
vXSC22y45cpZ1MA98cODs+dwuJ1e94fO6fMobV17wYkiOO/ptxHjczcCOvSV
nO3wiU0mHD7+yC0un58BZU3ovRGrCecINGo09haUMaCyaXRfG5/y4vDHNoVS
t1BqdKenXiPsK6yv8t6bnXCOP4W2alpe+5QkgsPfDmo8FmA+gjJp6dGlyKE4
nMTOr8xrdR44Oxf2mdTBesw0NnJh/tdJDFs/b2X8G/Y/8rcP334pxI7973Xw
JpQO9jN6f26g6bXnxqJkIv1atOF5HpO2ElHacWPJ+dZSD9ygvjlp009KWcGI
hYaH14fegv2em5zfdswRGpR7RmRSlQDmNa3lMGZ3vzBEd9KkHGruyOF8wsMD
27WMZY9QQb6eXVlBWdw8zfiF6N4vEwHonVyDSrFmdezBAW7cfuatUW8aKpso
ia9W9BzzOvAdfeoPkyowrke/DZ+mcGgtwfYT/sW3yYu6X3r/QjU+1PPYEqxg
Ilc+/YPTZ037iiX8xrxyF79avtpFB4P/9UFNSpK5yA21Y/p9mwZX8npQGel/
6y4FzX4D+vJC7BS1/Txtbjlqf+CzUv5AlsDekoz95g8KsyPJQh8c8Fr6jpoz
ZlwRmBB++dEr3bFo70F9aDlQf49N2RNzdz3mpdjnjT49+Fwzwk6b/UuO2JnT
gwzHo53QtgP82Rlpc/E5G+wPP4OIDoU1Lpcsj+30u58KZlj15ESslqIxTgfc
9vLKVKkxwurN/NI7snVwc8Ha4rZSnsVrYqkTnMzMXlK4+qp1+4ua93FVbLqv
qtevQRD6lDTLuzVPyWFPk6+mDgE4x5ODiBaPrl8Cy/Z/SHnvBdTv1B+z6X9b
uYZRlKYV/haBufpc856v5T6xYBcFpf/6PIN8V30Az48Id1pscmOA+c5PODdq
23qb2fs8JRY9NqjWfWINhyu9NNDzP4KPAdUYH7NK2C9TVX2ci5Z/GVB6NSsw
xcD3xtEdk3QRnjSkLnOS8ZY1nMc3uRKU/KasFrFjyJLPzIL9Su2Ko1/KhCsR
N/lcFfMl6JfeUC5N1E+MQrJIb3mcEYD+8O5tkf2pjDygznJNNp8dHs9Y8kFc
ZbYSSPMNs1JtfMTh28ZRnTrv3gOW+HuqO3pwvTsXQXeFPqQQHF+VP7EYBueP
+5Gd7ThBJVezz6658nTRAfeen/v2OL3vYSnixnMjREAJ5ojyqx+lfO3VhPhZ
U6aTuWCQV7HSixql70KEVgmrZ0vgvEi1pcvdJv59yKRDgG8kG/Q/Z2hxbAYU
9CLDQL7Z8zucR8mk77V7Qq4boaRRXhXfgXyRLhfWfFS7BflOo2m4WQL105QJ
vkLg9h55q0JP694E++K3WkQiOnYLQMqkXkX6VeiXFr57eWf8fB24xioIkn3h
9fsVhVQbNLeA+I63AzNRMJeg/PxJZnexTvBUKu7JTgvMZY1gEPnde7MLrEZu
HqMvhOsLGSU19exaB0CEybWuVkDfV3f5fLiAUSt4fMXnzMVlmC9x1pP+/AZp
I5Dt7X5JqA/njG9aXp3D2muAu/sSaDDPxeHv5N7tF/0tATx2DF4v70Hd8/iR
oF835OPB/Z5ebTl3qNPtvL4nH7TuDfIHSxr5S6Bes/OGLNS3QgtR7TPgvrcI
+20/RmrfqKJ0Qk6kXBlq9YN9tUPrlLlzdo8Q0WQNEpss6J+xPNMV+HnSEKk8
S/D0nhKc61rp/bQlEb8EmIOvldEYrN+IX7zWtNWLRlrEh9nBKJxbMSk0m+XL
VABCZX9nKn6Hz/MNaTfNr0M1wB6R+CoxCH16NreG07t824CM/ef5BEnYr8dT
XfxYyfUj8Cme/parCfFdW3znI6d6ga4nZpBfBs/TvKn86P7xHvDGQdtMjRj+
Ts/kMap9mmsH0XKOm+daoX/Mvrvq4rFmAIhTeFeUf0Hfl2Jp2jVOVVexcMkb
2fX2Zrg65PGXq7dVpuoQg4q3FwRewudzqjz6u7DyMLLE26q/oDGBw/eVW5rs
j44h+Janv6b/msXhC0NcYUTSowg6lP/+nBnMbYjOo9i3ohxAyrQd55ouQD2L
RNC4yt60Hjnyp95Nlgn2642/13XcqBkCd/poAxazYN9Kbt4g0bzYBEhvbp7+
0QPrnKEmtE+RZwK4NYPRXzHwvbrFuXuLL7kFzHP9Pt34FvYhOj+/6d/1bBYx
HGtRdRAbx92fuL4j5TZhVOi2OMXeN1NC+J5/3dtzoZsZpfayvS0nD9dxRRlX
cM6eH/36xPevjCzcb+YHyuW/8BVFzSuN2QyX4fFh11u5mbpl0Ktuc62881DX
iH8cEnBuTwtVtoy5sDXIjeOF/KNLp7/KGqLLmr5bjlySOF6Im8ivYJrLFNUV
+5tD/EcN12cXmJqeIp5hi35eL/9rftMQl6811xsVu7DkjLY0SJ2yW7DCDvub
KKI13L0YfFA9GnORv9UuWMQB/kOnd5vmYyBqOXmk/py8P9ZzwPNgQS497S9j
UdHFtQce+9GYwsE6nhI/N0djkIWyb2611AZmYckHPI+30hNeHotKdJ90m/T9
9Hts+KBv64b9bsFETz86B3QN8B8MYs0F/+plvpe50kIICcQV7T1N11kIa5vP
SfyDW6uVOgtH49f6Kafcrun5i/K6/9tHRlCUIGcy2oOxjP7V0tLpQH0P+s7Y
1civ5vwsxrYzDb/EcOSgTgd9ale3vitmf03CMrqDDRiHgtHSg742ptZ9ilqC
YOyYi4DSILkDetgHN/shOihRxBYrmiKTr8X/hhzOpUr76GN6/JwRdrluze8J
uyDuezGsiSLvVFDHSo0kRNmShXC8H/ExvR98iBTWaK2+9b2FD1cf3lqpWRnM
5MFuEyk7azFAHvJkG53lLVtC9NVV0xcrQ/C5etCyGDaFnkGbjeK/VslcwuEC
jvUmTYVnUXwynpGCi7A+qaTn2J2+cQrNNfbwfG3MgcOFfYcmltdJUXpSpRXB
Z5w4vK4uiJFAKhOsM64o2N+H/upH6nrnwyQ2wNfF2Ui2bcjPJOpb+8vfOIIx
Cy6++sPEjMM9mxZSjnCQYNo3fDjYLsHrvH/y+8aE8VGMze+4U5ABHdS/6F8k
7/4P100mMNrtgnWUEx+Vi3kqCaYqLMUSPAx1t83ewLz+TEJMpjz/WSoZGQ63
mRvwuP4bD+Ms6opa6CPA4Ty0x+63MO6AccI7tzR6d3G/u7O7q16quWvAxlRT
rCMY8jw9R0u6zjHNAqdzyQ+El2HfrpRqjRN/zSjItqsiJl4bweFvbfM7n2s0
A/abX0js+SAvsZL9nv13p2KNM8HAM9lhqKPZPu+6bXenAjG61H3Jfwuuy8KE
k1LNdLUIqZjL8vlCWD+8iAzDP5ZSjVzaap+PS4e5Rupx13lWNSKRto2H3fVx
UM9aHlf/+q06GeDlOH723IX1DN2cyVWF1ULwlDY8VdoZ1i06Y4PpZaTlIPwJ
/5lvCvD9P3n5uo2BWzngY80JHJWBPrF0XWbqjLnXYHz126+eL5C3Hwo4drPP
NAio3X302uxGEA6n2smbYkuLQR61ZMg/iIT6ywzyylfMOhfJP7HQvdYC98sv
/I1/e+4UI09Dh+zrnaBO9MRdWE9Dthyp1PS4/qkV8kLSjcEbb4pKkHvcx85k
rEJ9QenajsOR6QIkgeQNqfF9WGd6bTFOtN5NQ87oEmTcwoe6J55TbPqCvSfy
xJt+tH8ZHr/e47F37GsU2C5N2KgghLhi/I5M7sthhNClM87+IdQHFys2i/ZD
yhDxzFNxnv9ZT+f1Gtwn2aNAb7LgEyYuWH9yYBe+pdSXgk96QWH3/4Nn8fmG
gQv14CiVRtmUIDxPWqcNH5doKyge9WAmboR1Y8SKxsOdu50gFH9EeP8u/L5e
Dtmc+Yh8BKOu1He3HkA//1vyy82rJ7uBL6lpUNQSrPei8aM9RAg7QWUJsfPr
09DP9s7bdKo1rAVkFLmu78XDPM+EoQeqPxrqwHXCJuUNe9hHpsx9c8olrwzU
bbf7N1ZC/w9da5OREtFr4FhAzaaaC3M2KBnn3HzDI0Ci6dKAislN3H1edH5M
zd9lBeaNGehaENg/5XBCSFZI85QY0hTxWzBnt/oQ/xzFfS3u6iPk1vLyLP+e
Hu78f0IEuktpADJSbBq5RwN50R7lMpmE6j4kkJes62szzNmw3fsQXfTzO0Lx
4zVVGBu8n4tG+jJir9eQktffaMqOQD067pQ88b3ev4i+UyqNCwXUrTZM+J6+
/HUKrX4/53H6KJyXJ3CfwjKWmRa9+4GXDA2EufRjhF+JjIoZUXRx4jPzf+YR
9zXmfHnwlR19l0/hF8ROg8OrM+1ro/7wooT6LK6dlpCHyfYVNlUOFEYL8/3n
flXB+UEBm/yVPxQQtLXGnPUjvygOnzMn5h44LYkmLIRg500gH6I2bkDD6iON
ElJN3rX1hn5sF+1UubGBG6j0JS4Gfwo4TydFV+ay6KIcus/7l+xItyaunrER
+fpyq1IBrV7Bux+SBf3PzsvtP6/RK6HPgqMfXF+4hx3mBTl8TVA+QqyMPlz8
9vesjglO/1IHziwuFspokeNqLX+3JS5f1GNwWt78pjIq2jbdoddjhy0f4ETj
jeu2LUoo1fk6A282J2zqAH/l7KsbeVkJ3SNbcuofccPlyZv+aeTQ5VJCH9hO
d21p+2Clh3wCVx3VyY2b6LAOxQ87tueY6wGeP8c3pp2ohd5YF3jK7xmOrRzU
S/Z6i5w3blqh+/QMZJd4ErBTB/rURWC+LEMej4a9kCyOcSrGJA/6/a1SruJL
kcdjfo4ClnFOxeghfpdSKkb1phW2lyuC97/zoIfnUcneZWdO1MK0TNhPC3qG
o4f/F8O/9mxi/SZ2wdvjuhvbc/TwOp/693naciph9QxnWs7r+KCHn8vsKu8p
k04lrFzCW02ZzQk9vD8vwLljT1SUMXHpl5QOPXbo4f30m6GXirBQxliFCoYC
uy3Rw/s/hVp84CVQxphYQ4TXdUxwvutcWSr5UholjMWaL3R84R4uDyqVoLOM
eUUO27017VjUqYnjYYpjYqqJ+m9gzspPw2UpoR4nwfVGQuOJNEZyJUrfzQPq
VgU3nCXmT0tigYJRJZ/MYf/aC0MW6m1ZBLsnxkyTwi+Kw7lnxvUtXwhj4+Ob
ZGEVUJ9q1dkTfUF1FXv1gYmQGR/2083bsFO/JOTD7n5qNw+yhP1lSYrqTy5/
Ysd2wFs6TIAGhx/Lp5hiKGXEhKuNTJRpYN0y0HLZapuDFrtFs9FEFQJ1KFrk
y5+o36ewMZ0Ga8p96PNh27l8gvrGUYxBXFfPvB3OjVXB3/bS+fAXnIgg3+g5
+Q2H5/Zn3HLJXAPKk2LWlSfg/tH6bzF75Mp3IPtuMU5dEOBwGbFgua2aPvCA
IqZzuR72L8vir2JxVABUcz2apmGGfcdpO1wW8zqpQJBo7SpREezTsZjmGXgl
9AgMvJanK9qEvtZGjkTaCNX+6qrbTGGKR8/j6p9YCdIu/A9WyIS7s9lnsVu4
9+FT+pZu2sAIJFrKgziy8CYOl7+qvidB9BqRpyXaf6xogDt/gJZX+Z3GOmTe
U6F2zQzmKPILVVh0BrQgI7U/jIS8oU7BbpTOon+tE3FkrSiyoIPzpotGPOzE
NrqQEEc+q5BByI/dGk2z+XK3G1lJE8s2Y4L8v+QnbWWH2Vbkqi6Ls2wT7Lc6
udYockWjHgk3OfZD7zTUazQ/o7cXgkuQV1E/pcfIYH1SqaxbQM0TgGAySTG0
5BCn9blujBzPBY5M6xHN5fA8R+yVpo7/rQLhin2xLzph/TMqZ+zO3lCAHFmq
VjTehnWjBNuwziy7BlDce3uycBzWewSS6RbaJzLAj8ebe3eJIK/1gbT4psJS
IegOaJs0cYTHa2cxhE+dLAFYpoLmyzVYn6jkNs5V2P2vPpxOoKFugvWPWB/9
7pBhOfhJznZDJBWum1NbWo2ik8XgGuOgI4krnAeke/Uz0umbCxQRDX/vNui3
DxQQKax+EQMc36JHpaJgH/dijs8DUpsg5FsYk8cOEgSfw3M++6NkOYjMMLIg
PAp1qwrpF2O33hcjZb4zt94wQL1m0iuotD6oHLHpMCZplIK/C/JzD0c1hMoR
9qHFWR01eP+Ffqd6tjEUIUcpAGmjM6wDb05x3fN1S0aOTk7SiO9DHgYbld4I
MIsEMio5D9Rewr5CvWLx8fMWRWBb8dSs7FGoD6pbv8PKS6rB8US65uRsqA9e
DqYWi2aqBS26F1bCi+D+omPCQFz4bgXoucf699E29Of8WO1oynzsIVYqOML0
8aIRjudZLjjmm6LRjBR6/2gQ4YfPibTer9c5LLNIf1p3n/z8DA4v8i3dLspf
Q4JjgoWbgiD/fHqlmJqLcQf5ElYkLvoRzk8cQqT/Pt3FQ3+HFD6I7oQ5nI6+
E1PzbwlR0nvbntHHYA5n8/Qbl0rDo+hTWas5vx44P1EimXh4xv4oKoCkybHo
0OHwd33EYY5CJChiIuKddQHmRn5hF2LJkj6CyjFVuFReYsbhpy8y/mUV30D2
wty8VHZgPudFBsy1eC8diSdd/PrsPtSnmqZZXY7t/wbn38vt/T0GdRy6Yr6Z
rX1SjL1+dpszAOKpE7XpotKnsIb+e3l/jGF/lsuAvTJb4VlMxSLmdcVFNhx+
KulDsD96Bkt0982Pk4HXr1gvLjJqS4iVNjJYSA1Df/g9IwYpDorjKN9pQksp
ZehP4DI4f3Uokwft/0DrPskA/dvhnJ3iTIgU6otnGubZwofDo1PaSSoV1NGI
hN5k/mQh3HpKmt1jOkxlhPrhTyp2sQnidKi8RKtZTRFbFH9pkKRX7Rs45D3c
qR0+K016oAohOquuKTBHqOaFnA0eYTBqcPJqUDm5Ay5HqMHVWD3raxKqlPBm
SGQoGDvkW3Q+OVwo+FmM3vfmnXjOkYMd8jM8n+zGTEZ70JbiCi09nQ7skM+h
PotXKxKNL+6s9G28oucvxn3A/9y1c50NJCSo7aRdJPjNQih+yBexvU1fm+jp
x6qJaKbwHgyih/ySUn0iEa1FJaaeKVlZM/0ePeSjVEUFcqkNsjDHS+PCDYFZ
6CF/tRRYwIkXF4vZhz/QLN2PRg/5Lp22u9S9DD7YH4s2RvFqF/SQN/O+alZo
tuyMJZFlRzMtWOFyhIru3z7FlW6Lzd/LDhBUgTlC2wk1u/ncplhq/EBZzp4a
bp7OXaNofAY5Q4zkOInoJjfMETJhtKqT2NXCbFGtxo1Jbly9hNHZfZ8MUcFY
tQTI5uMgX5Qp2eGW0y2Dlfpa+ptSQr50RAD9M/9UFHt8wz7x/grMC2LprbFi
tefHltjCZDTk4XNYHjo7SNrNjDFfI47+pQyP7xlmuqoTToXlkJCBdTNCHJ6y
b+v7MJcQO9/E35shA3ld9at54wXPZoEQDQGHKjKOw9dt5rIqM1uQyvcTEr5v
Ia+SeV3RRoBnAiFwdT21Fb0C18GIZAVMagJBN2eybHphf30k04Aglj+EvN7x
pi/IhLlDAesvZsWYqxB9F8L54DGIl2uzxzZo1QOmTsecJCbYT5daNn+mbLMf
iMSIMXFegjztcXUDPif6UTCoUuzhYg77L2ro/V5RbYyC+/HJa6dWYR4RauA+
xmw2DFK0Q2+YqsM8onphK8rAmh6g+lZ5/PIc1MsCFy51cs/VAbpFWQPrWLju
/FpKUer2Ja0ZeMAh7mfli6ujsiVtAqJqAHJ9dpzbagP6kNsl74n5bbcjE7zO
bMNNkP95tsIzxcrTgwyQc9y8RAbnVlRPBypd7+1G3ln0aEc/gL7rOV9T7KZ4
G6LR8OKntwbEI+tP/5aowZBuIlaFrCa4/z3e897HfjoTEWxWav1BCvErCZ1M
05zpgHHwutLZs/D/qr1olyiTqwJXX9w0shiGOeGGrTOSzY33gFKpepmXAvQ1
/Rk39ti45Aha7wG5qULoX3pwmVd1qcAJzOmHDeEFQl8u+8TPuVf1moDvN+Cm
WTfG4WwMhJ5ia95I6WPmi4qlMP8zxfqZ5huWeGRViRkJCIJzcEaNGZ5EXM1B
HDPMvayEYE6p+td3WOx2CVI1ws9cpwHzsaeoTg9Xb9cgxRbeKTzlcI7nRAV7
eRJlI0JC9+xZqAz023B8vqCrc60VKYw/KVU0DutPczMScbIfHchSixGaFQTr
lvP4lmGK5l0I57Ji5Y439KtIVd/G3gR1IV/0iRpKNGA9IFH+06VNshN5u9j4
Tv0U1IMU8Kep7G1bkOLTrELF/tB/5StdbFj9og6h0D8dvWSG4XBGwU2raeIi
JEkg7qHhFVj3fr/S9ddXKBbIDzwUyDeCdSmNA3uwBn0VwPw/jE8Qw/o2V9CC
jraxBXjF//Uxc4P1zMJfDmLy093gD/Fb/0BCyMspSP5hSK3oBTzuR9LJf0Bc
gEsc76dDH6CPtGRZvw7rLkEdloatx72A2ueO8lkpePxIdVX4+0tdwNyx4Pqx
Ing9jHIP30t6NgH/juLrWm7w8+p+534tbFsKNG5YntpQgHkInCGodmeBvViJ
fbj00jM1XH21w6CttxlSiHAkmOlyhsF+2OkgQS/JhUpEtoniy9cN2KfQ8+rF
49SoPMTTNpnLlGMAhzPXSikV348C4jELLNv8Qzj8eo6rFYdQJSh9QdFLswyP
v9y/LbmfXwuoPt5Z0EyHv69x0/s/BXnSwE+9c4LuVpDfc3j5CI+tqxdJdm/+
s5YH788FqaU1E55l5ItWbb19KMwh0euh+qZ4BB/9VCzrtdYwD+vbsYQ8xfOU
6HXPqNJOKsifv3lwxYzkMS06nESprDv3C4e7sQVYcoywoP4N3pd5HeH7fOXO
yl64Fx+aer/AdJ0Izie6dUY6Q2/5Gqp5gtK3R+cv7vp15Nbuu/dLoPVDDxMS
XsK6sYY4bezhaTm0QYKGg6EE1l3ji2vLQSdUUc4kTodmIIjDeY+2iwi+1EQZ
P+kziXlL4XiqaglSx5TTeqic2i+WEkIVHE+V4tCTe7vaCKW+Lf4lKksHN++G
coyn46SiGSoRnifkowDzkR6qEbVMzdqglhXA3u+ENS4fyUKPiKV6yRGNEws1
vB/thB36W3b0txyIlDzRPmfDO9593tihH+ZeM4rIRD9Djw88zG/4G4gNHfA8
W1hlhgpXBCoU41h2qzsWO/TVKDDrxwm1JKOqPdV5NiRZ2KEPp9ZrypG2vBB9
UksbTJlbjh36dk5dvuIjN9T+f11ddzhX7/+2CxnZq8zKKCtSOIdkZERWZIWM
srMySrZI9sqmSHZkhHOMhIiQPUIRkSQrRf2+19U57+dz/fx5X+/rOON5ntf9
WvcLvs3+RlOipB/F63w05jxCFDN24JaeyH679N/oKFYXxPHxKnFy4AaamKUj
40G6BkNYHdHXDu+TxdatqFKIC3qrsxrG645UszJaDQfy0BSumIKrzyNgvE7J
9c8Po765++j2ixbPitd6MF7X1Kw1OHaqxgNFn5TyL0qrEvSR3sb6bVdEXkOP
y5aetDBRI+TdPM2bFEUnVFBrmex2SSdQl5VGv5PnBHGgLefDKZhIAW/ZZhZ/
K1fHB8s3BL4K1AX5r3OFNT9k3E7BoV8OHNDyA/XM9vLJM8/cT8GZZfZHfa+A
+ufpqu3HOrKC8NW7xxYmuUDcKSVX3TqihweWnfWmrAoD+FqJ4SXHhcOwrK/n
Q68doKd0Q63koKzNMuTHcHJ4shlcP2wjUsjjIMn/1odleZEK0FP6Wvrz17ts
BjT/AMmx0Wygp0T/5+HmHyV2dGT34lndCaBLYHdFZZRC6ghabjeUNSYG4l1L
Xn0DB8uOokf3OiOoI4DOUqOXmv9TvqNoFnOl8VszkAdM0OqJr6PlQm8sDJ2W
3wBxMHWf7CThHTa0nNhavaoS6Czpy7LW5csxoyIeGkuaB0Gddn8B248flw6j
j13GZnumAV/tlFIdaVqkQtkUDA5pk4D+vs/nRIWaZknREGfP9vggoLMUQ5Nj
WVjxG4GK2mpn+wEP/JGj7U4xt46M7JKaTjoAnSVpC8vX2lPzyFuOzpPvd8D5
1vDpxZ2+8iEkpt9MetMRxM0Yxn2c4gUQJC7+y/IZAWBP2+7Wsz7OEJK/171F
I5DpTeBj8Tsuse1PCiGDr2uce6sgjpEuHmj1zaMQGiBhePmtCtTb5L5lbalU
TYb6FFRD6rlBXob21HdHbfJ7iHuxTxWTeh0Bfz852cO+wYosb7LT7kQYEO6H
6HhX3/VkBYT+wWtS/T86BNyHyuuaCTGPfH6FXUt1KiPBTpF8vFx+Pc4WMpV6
IhZ72wLwLsgse+dYEEQioSxrOwX6xEfphhXb8xMgm5Os+R7fgV7T/W+qVx3J
iyH7nJn0pEugvylBIte0UrUaCj5QwP7AD+SJzFOZuiem6qGX1x/wi5wGecND
F1oFJ083Q9cF58voT4L6orOVMx6oVBskQfZzZaEf2NO1mUc/Wm+2Q4zPS0bl
1kAforO0dwtPzitoa9f3dl0byJe9WI23n+1tgx7HbYS4WIC4VvNTUl6v1yik
Z20b1b8NeDLRxwvZ4VEvIGvJ184U8qCfseB42eRsRTLCYXfwskML6Cu0s/qS
9eBTFcKj90WG5T/zaw7Z2Xx5vIMiuYztxwNJAJ6R9aXiE2s7Yq0qPe2tD67/
cVc4l0K/E1H9aqTzkgLkedW1Amc3SjsRz/BSYp5xEGdTr+G8wPyyHZHSVnxA
7A3qwZzUvErrL7cgw1vLzOeUwHr7XiBrmu9fiyQfzzu79AusTwmd3cCLbM+Q
S8Nr7IFzQG9TaJthbe/6ZaiHudpZfgXMPX+mxsmy6OgDHVAOUySbAXVW9cYe
ayemWCEXSucF4UYQN/5ye/9FCUcAcgOesmi8Beqvpk+36/RQXJGvsrywcvq0
KGF9trUaxc8nPIV+7M7sZfSC+6k/nnxtKnkM2qS1vk3qCt7b4s3aL+ZsS1D9
8/QxYbJxAp5qM1n06PsmxKN1fYt6EcyVXu8sss1vIIKhxyZH9o6AuFa3m2N1
4+5BmN2r4w1RE5gbG40QS3EtssK36/ScqBWBX7yvJGz1iokbVo5sWxwzB/XS
2i40gW4e/LDFm1a6TFseAr6VxrY5n3YCJj4ZdPCzK4hHrUW9YDPNF4F9eNiL
RTlECTjRS0WiQ1ISMN9AJufQPWDXsgY3Z6JFJGF+D6Ih2ROgPjl7JLLb2lsS
rnbqip7hAHP9UI66J711EnD8OUEVpwyQvysofKxOVyoG542TqrXkAz0ljmAT
bvsT3DCV0nMmaXugm3SHTML8HrQFcbXrajirAd0kp/VmX21HTlTZ5LXZwk+g
m+SrMMi4lSWOIps/r78VMSPg5Y3iGRoJcmgbd6WipQ3QR3KZjhdpm1FFPxnr
cusKguskpkdKMYZcQOVySW0Dj4M8Y+KJRxctP0jAfeZfBhOWmAl2IdGKZcAi
5hY8Ol+SPSRgQtALWuNhh26YZsCouZ5/bZU5iveLifyeOO9W/h5Wfnd4TZzu
NYr3l+0Ong0t159Bj0k5KKs6f4Y7sH607rKhmYChKpRs9dqFxOkWGO9fM139
/lY7Ih19ajxYucVXAuP9brcXZXRq4qPQKS/o4chyJoz3x+kpVArFnQhEGdn2
n+2VxcN4P52zDkoK3XJDH346V/yKPZCgjzT9O5rDvPgmatQ7GOf3zhvG+/hO
bPI8syyzQU1mvKytbYA+El1oaxb3T0uUp0Dx2US1PYz3CWYEzGeZc5ihP0W9
XF7zAn0kWaWVF8GK+uiwvMo+cxjQR7oXdFArLEIHzZAsfhqXCvSR7BbjDGgj
1NE6Tk7ZpVXAWzZ0X1hfN1FGzQMEWFNQwENuzx67hn5UQOklRtX/JAF9JO7H
p8Y8lSVR/Ydn2Fvfg+94pI5p63O4MOrzgkfNaBDoLp4JuvZLJIMPXZv9Kyy0
uE04T6iiKxO6qdlRKt/g+M1RkBeL1gtmGjhIj9IP90YkBwD9uuL7ZQPcZ7cQ
5mdlyX7UoH7muT9PMFf1POLwt/BnVw6IkxsPG6wfiOtH+ox0Gwt4Qd2OW5AX
0YL7c8SwLlmYhBbMM71rECfzW84EesfJ87mP5g7h/xoSHUkzmgqGcuutW6MP
gTkpRNhfCOl53kwaoMNW/HXf8PUrN+QsQx01z9B/9NlIEcUtoSCEP7/Bb3sK
4Fw0Hzi+o5HIck4KM2c90G37wOpLzPE+DhmgeqJO6wD6dJLP3mysso5DHm7r
f7TtBLpAP27NFR0SiEYmF82lg2hA/07xSlnLpYVA5KS3w5VuZVB/e4/pJx1p
n6Y84sJ45TWHAuE8t3k9PhijHgqNC8tqQDVAR7ec3qBmujgJIuadZL6kAPI7
N2lWLPWisiGHWccHJM8Bf5jf2rBtEXoCOYykmFU2Av2lTlMLEbnIx1BzRHbW
PUXQd39e2GuTYjcHWj2m99FbHeSb2qU52PPOJUGl+3cOUbQC3lVX0uvyONcd
KtWc0lPSAnXUFQG+h0vhTKTIuTpAXxLgiuHFVFHPniCsYYwPTiuC60AXyYNE
Pz1Fbv5y2bixB3jLuXPZj8kOPEWMQh3WLjsDnuNdtMxqdzYPURKSbG/WAjpU
F2L8zh+8GwdVxC0nlbqCec37Q2Y3+ZFnEKXldQV54v/kbSudbSkP1EJH52h7
14pBH/3KXaaxehEUSnUxPvH4HYj/JBXnf2KlbIP6WQx64CkQt9FcG61KEG2D
uKSias2oQN4qdudbBzraBJGQoxs7Z0AfHLfK6m5iYyXEzMUUenoL1CdvBxfo
Ji94QeYto6qVDYBXOyS8W4giq0TUc+iKn6WA+udUa4bC16EtiNTJ45XWywBf
zRWrIeXuRBxqFcVMQgFeOkmbKXOwG6lcv1gXRA2uf3nlXj/5Vifi7i8u3kQH
8mtnfXp9N36hyEgy66/aBNA3JxwyFHvfIUS+WK0NUmbXI6zbDvLU8rO6HdDb
gt4ux2qQJxX5NVl02HYecroSya8atEjAtZO5kk/IfIWQoatHVGgAr1Dtuj7/
3GMdIv2el0X3BMwfQTY5Go4Wb0D7d98vXRcCc4F/9lN6PyPfhG7M0/S3bIC6
oJVBis6KnmXo+mPr55vNQL+IqoTHJP33KPS2Qje0/xeoFzImtf+Y796LfJor
4zvrB/SIfmgdIcqgXEXy89fb80nBvA86pQk7rcKfiBJtmXqMHPj9fqoazafd
PcTi3XvTmYtAp8hO1bOp2PULErYra3prF9R1q1vDxlTnfkGei6m1Bz+COI/V
ioPiQi8bvKH9hOioDtApGrFiiWlBRGCdkuVro+JApwg6+mPwqpEq3HRHaUXL
BugRhTf4hKnL6sG3mFN+EPGD+lJfvZtHZZbN4MCJEL0Dy9MIbr/a6VRKkkrs
4M8eprFtB4AekaPiVcOR4VvwRfU9Kep9XYIeEVVwfmt49h142JTz/M8XQI/o
TJvNYtrHCPgHcaJksSTQI0Izszg3tZPh8b3onZr5KBTX7TmdtZuyL1kAp5f4
vBqqykFxnZ8XUZ8pjpm+hDmoSkTuRNeguC7QA/GC1KPew3CfzxCquPMe7cB0
hMh8l9s0ncgVUnbcVfopyZtx3SE94tyGRifyZoM05hIRanIFY0ynqL+2+Rjt
7WH0uHTc29Hd97AMdh1Uc1J81uwlavst7/BQXA3ciP3fBRruDCrpAnT3i7rY
VmMOjOsmtarsZ6XpJqOjhvQn+NeiYFxn6ZKgsF/okzuonek1T7t2oEc0/8LN
2nTiFroTJPfnCb0eQY/Ih8HonEKVHVq+HvXs1zkZAt8I1/3KIL1lhj6KLYy5
7/SRoEd04o1b34CSHlq/cXmxhALoEd2nbeqr45BFs8J8dDqWQL10zRjxSP+E
CJp2UkydRx7oDp1MyyXW32FDN6NSyU29gO6QiZ281uTTX8gxbzERCzXQp9Bq
TZcXvLAELdgNHK3MA3mf7UjjEHjyDzTyPO0a2VMQr0itsO0zyP8JCa9atKeK
AL2gxvpkZ/kzq1DQLJ0utAvwjj0u2rtrvdAsIv0nzgXg7FPV13gqRxHGR1lR
lzdAvVBoX0zfVN4yspM5Sl5dD/SFPve+q30S9hKCT8qlb54HdTipQlK1c4KJ
yP/H3SbmdM1N7JCuHZPjFRFgru76ypHR91dTERbSRvun6wA/Y+B0eF/qETK9
5tdsFg/mKaRezonc5ctGaBvSTeTogM78cbOuNEbXHITfkfwv4yEwjwA2aFTx
UctGvLxtFQ95A9zprOF2mVEG0pT7qG+EDuDRjywfKDilIJxFr+CPg+D/WjhQ
CKtrxiN+2n8oH//n/jVnhhpW+sIRddYziCiJJwE/Efa3q+anD8KWONnh9tSB
gPeleK9GW1kjEpOwN33NVQKeWcMyzvGMV/5pWUqgEA0D4fyX2SUt0khXhQIK
HNCSIX3COrGk/ORl5HMaQvtL9ecOg/jJ0t/1lI1zksjxS7OM5GWg7pRn4eJa
vbgjVEvbv3WGzpDwf+MaA9kWzoZBcXQbPIHubgRc8WdlGd2FVMhYLfDAwe/g
PehFv2d0pSqArnuXv1dVAHqMFrb1aZsVlVAsB1MmcQbgCQful+o8vNACRVSm
DeYwg7l4OQuTX/r12iH4CBMyUwz89Fub/lUaV7ug0oRPzj9pQP7Lrufxpr1N
D0SUofolOQnMKxwMKeQ2kO2FiEK+2mXeAfx23JsYse7ohurrBluqGYAuX85q
BXVJfAfkHfPlWXF/BHhvCgczuoxaoKH7L+I2HoC+sHerGYGqXeWQge18QL4b
0NUJN9qQlCkNReYCDBRHv4A6XvcH+n7NN2uQ7r1nhgU29wl4zayj15OsV8h3
d7MT+e8NCfjwJZMmRdUeRCtVssNaCDyXBXNYgLh6P0KqXC/qJwT4My2j0oid
zwASm6gpxToO8n3Rps9/tJwfQKZOKzw0mgb5PsOwpMKxX33IcbILpa1bYM7d
kVM2OV0ib5BHQhG0XpVA10hUQTJo/lcrItCQdnS5CtTDPxJ9O7hwogZpshYQ
cGoHuk/w+Zxj1V9yEQ1mwQ86hkBne4zkwONnf4zlZxdaB5ToOQnruX39ck0t
RySk+46pRDMDzA1nzKdviVR3Q+yaAkL4AwHf3utdsjra5QvZ+Z+VvBQM9DkL
lUvC97leQHLvbxlWhQH95zEhbaccowHoqkjQt9s5oH8TvWHJQsqyAJXXuViI
RgKe+ZHqOO26Cin8JxxOFh0F+cdu83xBHSJ6+AVxqxbZBODVypWvzj5dZ4OP
vJzsvnX3IwGHrbhfMAbxwQe1+Unym0G9gUBmEj+lkTD8wKXQmkoV8BYdWNLc
W+EszBJnO30uHNiRioUYkeYcBThzcsj4XhzQ/xFmnAgQPK0MXyYJ+/ywEPSn
3xzpWVQ3UodzzjqvlI+COMyWqhY3pbYOLEAU8zTLA+j/JCTSvGzk0IcftG2y
MTkC/Z+GR+YfzQSN4CR7g9ue7kD/R9Hh8zn5H6ZwyyrtdTMioP8TQl1VQrlg
CT96UxHFGWZPyDdZ7L2TU8iygW/vpSnnKgP9n4ofN+JSc27CjBu7PvkF3iiu
q2z9lUWUxsMNPqVJTD+4d4+g/0NCSSwoJ+cNq97S6TwuGYGaYrjaMrvRlGIg
nMdIc2AiLR7F9Zw/3rkkSTwUBfeKyu6EDmeiuP5zbupA+MvP6TDbFF/aG74S
FNeLvpHLeAwRr4bd74qIafxoQXF96QvUC7cE6Wfh7nnp1sGmz+gypkfdxhp5
yitvCNXzFt7+K9YJ4/rVH5g6V/McstDlj7sWDLNuMK53/R6lU2cX90QZGDMC
mpUvobg+NovYWajdXQlNfKNpvwWBfqhXxYrOvVXyMOu3nvl7F/QI8Y3tIJdQ
qTPn4a/aoV05F4CezzE+O3b6+bPw/OmY58GR/9H5eW5U45ZzCr5CmWbPJgJ0
gawuyBmcCmKBTZnLKDY+AZ2foR16hoOHidECyTRha2Gg8xP7tiWvrVMItQye
oip01CXcz5A38Ys7O2LoGbY1Ul9HoOcT9d4q9Wa7BPol1/ChhTOoi+Y+crIp
96Yk+uyZdMypzQsE3OSZywqjgCSqFCt1w5QcxG22c6L56Xgk0OlpmZ5iHZD/
aifece/Yi0cORfRMGX4EemVuH64MzQmGIHc3Uyp4goH+2Kypz+zEg3NIdkB5
dsBhgBsyTvyxir6PfLaVZl7eB7rQmW5snExFSUhei8cPdRTkEVqWWnlYrBIR
sn0+VkFtEB8gf/hBbLQ8Gbkh/+UEGgP6TRKDDxRu0yYgTwzuS8aqADuiFdXn
qPc3GnlAd2mFxgjUjXyulB5zkQ1HRL8/2SITBHmNaHoP9uyvfkj/aZbQYhqg
/y9L2SkvYWOLVJxgSqojBzo5Zn+fybRxKkJxrB9+3MkCfSvRAtxnTphchyKP
JjlduALm++g428jc0reHosjtVdBIwNN45FaDynUsoHJSw2/Z2sCetmiOIEbH
yBDv0GRjGS7Au+ZjPjbmuFkiXDFtaOsdMN+Hqy1DPY/dCSmb0NlvyAZ86dtq
yfXX2zcQInulV6HZrsAfP9T+ZGgGkpd0nt07ny5CsBc/+5JnnqX5QV8P7ep1
z4H3YGLV3dMgHA8FPQrs6iQBfV7kXin5lXU5UKZxoWVYJNDZNtaG64yGK6Gn
j5z508ufEfAbn5tDHFproLnR5zs7Z0D//qmDSSev1L2EGmxuTgtKgbjNae70
Xt7QJgjW1me3jwX1TsVxL8K29RGo4SHZre4c0A91cJjdynunHlKLXu6vFQP+
++/UU9eL4GpI4+Ysb1oayLPwdpw3aD75FJoreZ2t5gHyC5LTxUZJykFQ3GCM
7s1FUKc0Wn/QnjInF4E1leGuRJDf4RYp8en7/hy5GHnmb5INwPOKfjje6nyJ
HJP7+W7sErhOYcdOfyRVC3LdjnWd3QXEIYPFvG0+p7Qiqm7PY9tfgft3laCp
LVJvRS5yfb/10grUY0cfn2KSHUcRRSXdWTZ2kBerkj6b181dj3yFy1a/1oP3
ORjpektQugIRq/WaElcE+aB5R+qWb8LpCMf0iq5NGdh3aeFpf/PP+UCynygm
/14Guj07rpEVssaZ0LfHWoxdy2AOiBhvzhs/rnyI3ZKC7DkP4DnRlY6hvFKZ
UOauKJ2tMeAJV02y6j74+EL06Ym94W6gromFXMpASyUFuR1rZsAlB+rwXzTz
0HN1FyLyAlzyEh2gPgpNFBEYay9Ezkm8CSn/A3hUgdtV6gQnL/kDoe0Kjb4c
hHUepcR+l5QbgX5vNQ+THAdx3TrOSe6Xb+ahb2deKyisAD0NSWGiqhcD65Dw
Jsc8tQnQ4entDIp+n/gbCrwStafYBuotMwLzFXzfksLv1rdR61tAh0dh3r9L
oZsKznQsHmRZADo8NnRenBAfM5ysKhj0bg3Ut5y0apgZHGOD/ap0f0RFAh2e
N+LEJh6bnPCZ3rsGlydA/xfH5+NmCtRH4QtE/PY8cqDOWZzvztB+ylE4/Zr0
66vWQIen/EDR3w2hI7AOidSPY+ygX4wpMaLtghU7HOKsPeTXDPgPFTp4qmyM
AX7uLnRNJBDo8xTzlrhBzKTwx4/VDLp8QJ8ns6JN9o7iPLJjHi4+XA74EmW2
gJJyIz1q3nBrVXoJ6PPIzugzppHwoNVN1SbVAaAfzTTlr3Igzwn05l1PeU8e
gKsNv7ev+SOCbkrRPnd0AdcverimtRgmggaymAkeWAF5NF+xU3eppXlQtr3u
5KQ/Jwl4kjDcDzvywJXb8+1umqDewLPp8iOHTVXYFV2/IrEJ8hrPHqok6Ry3
hEMizP0L1FUI9bp1jTWKCnse8NJnyi3JMiWCno/GiJBJIkckfOiGEL/YriGK
zwUrfPTMf28lD3Zk6BWkC7qP4nPEdIr29Es9WuHHTgVXI6leoPjcMf8Vv+9B
0RuwWmJihMupNfQKNqest7BuMyprB11usWjmSfwNC2Nzzfx0YlSC379BAzdM
X0fl9sP4HLSoJ5kp/M8rUff5ecPt5FoYn5v2Zj4+vaQuG7W621lxbv0JjM9Z
c6OfJr7MG48uyh5f7apOgfG5bPPT6VZEEnfRJiMf0rKmQBif7zZla+AmOuaJ
vmJZqoZ9vGB8HlxMYJhC8WsX9JjGU+onq44EPZ8nW3zRwaL26JBEIclxKaDn
c1B0CXEusEKnlNsv3H5oRIgjWTVakyavmaAyXygDi75dIvCuHoEBQxc+HUQO
4byMUoH+UwHd8WkxGntExHfKLLQH+Kc85raS4v/DP/KZhJ2V9Cfg+d8494tV
7RHq5RPXuHOA/rzBxt9Iyr+2iNRqVintpCMB//5TNMGGXAtZajAOvuYK+pse
mFd8Z+CwhCwf8j8L6jIBfrrAkLHGtDcEv3BkfzDjTsCfhFBW+DqEQj/PRjxQ
6wB2/3t4Cark9RBqCSs6yR0D4gAyLC7aTGcSIKUVLaWZGRAHcKRgP6sokgS1
Gwid5b8L/P1v+5ZPHrkkQesWAVoariDvE1B+TDuiIBHayq6+NvAF9GsTURBN
3ngVBwVwpz6LtQd+n6VWvKjHoXDo85W6a1yeIA/1QGBc1uflLahg5Nel9gpQ
N7vrG/Ka1tIKGblYQH88L4uA30eqDmy6hSJJ1Am/b9CCvFiwUui0REccoule
tFLdBn6//UO0I+FuMqJRo7ukvQmuf9t52Psrexri7f2H03Ya+O/uNRKUnyTS
kN7YVtK708BfbpWr91RSSkaUGqNSrj4GfWTkPC5NZCdjkWkHgw3EB7zPRwlB
5LwqgYjN5UorwWLAuyYoXpR/59WQv5Ff2mH2SZpgX97TCGo7vA6ATgh1Z/7d
B+twS9qnx8vjAZSuzxjXeAvEMSjoH0nMH4mHaJ02vYTMAd9WqxAf0aF9AGV9
sI2WmQS6OiwyNtz9Qv6Q8RJq+8MY9C/Xm+rKnF4wQap9XXaZE0C9jXYHkU9B
VihS9HTXPoQT4KpB5RG12vEIFU+ZvdwcyEN5Un2J2SZLQnJNcuuda0F84Emb
pfZwThwSW/jj+p464Hs+QR9lOdK9ELeR6snTLGB/0QqL5TV4REMJR6wlc/LA
ut1+7uHAv/IEij0sYvhMGehJSvqOjZ3ZqYJU9O5cHasH/XonFFrck2WbIDHJ
+V3vTpDnYm5pSxdpa4Oi71BWe1aCei15hWm+qcAOaLnD/1aRM8j78CW173oQ
v4Fo+qldpexAvf1iQcJXhrI3ELNIQhk7DejzsvAjix1f74S6vBpl8oJBvTE7
27z8kbZX0Dx1sgpdJ8iXWZXfVSjUa4A+hbMgndtAX+jA9d3wsP486Duv56Mg
VpAvC2aLKZBYfIJIBB7rdyMH+axvi0USgUUowkvByxM9BPD8FPGDErpdyEOh
Q+4aFiAvdujR5/yc731IuVaGlaIrwJmmSPsU9vqRWaJynevN4DpbafcPBMv1
I9tvBNKdDoP7SV7PyfSj6kZo6RZliPrB8yZSub8h7UYQ0XvXKi3+gHyii+wP
t4itYHnBwdDPl78JE+rigicPbX1eaYFkj2/e7UoHdVlF2Z0vVixGoRuLYrMV
/9EXam7QtBmenIBEbd9Y83wH+kKvWeu/9n4ch0Y+RFZm2oK4/Xrw09TiZ++h
t89nd1xYQR6K54TWGptJC8QnUXXWjBHEhTIv9YYLHUKQSrponUMtQF/IbOap
eWf2KMKiF//3oA/AXxLdsesYn0OYbva2PYoFvO6FE0sA0f9w409004tj3wh4
bpFE812HNwiXftiWdz6o34ZjfAw3ZhYhrl1V9rubHwjvLUrSibM7igz22v35
3Jwf9KdIkppUNkSxwKjmTRvOTaBH5A3deeUyKACvblguflgF+kKPZoqb4v0k
4OqVA90lxSBPIRDXEvg9RQ6OV4tmmnhDA/z9QEUveFoZLoqb/aZYCeoortwj
SyzJ14YfcvaVI1qg3in865ynw6ErcIef3XpMA9ApEjBZ+WZvcQ0OqT7E6i8M
dIoeW8nN+8N2cMkFtQlBYl0Un0PReaH77fd6V5hhsKurwRzoFC26840773vD
ajzmorr7QKdI62RTvZZQEFz/MT/xUq8Pis9tH+8+vZH+IQo+Ossh2WUUjr7D
4lEmFL3pzk9SYGUP3pFJ6mQUn//O4m6ytmhfAEdmGKl/SCtA8XnxbTJBvrKe
9XC6mLirz9ZLNBjrC6NrSPXaHXsPB9zsdghwHUbTsHn0frUpsk7UpArl2yUq
46JkzQ3Y/PpOszylzjTiZlK6Y7y/hv7Ccti8e+q8I0vodD865X8nkcqgG4aw
vrZanjjRAxtVqC/N75cfjhTBvlgfXPlV6r77s1noveNi905WR8O1WN+cylxL
Bz9xNPr7xZfTth9uEXSK+O3myvgm7qCnisQ8hY7qwXhfnslP+Jb9hyg0n9qV
/dOVcBh/P9GtM4J01FfQ+5eEpwqHQR9ZDZ+V3/tolv+9r1EdXRKQd/aYu8xM
+3QUcvZrce31Auuzrmnpu/FmP0RbSSd9bwn0+zR1aa/p329AnoeYPGhpAH40
70OGxv6KNiRmiGxG3QnUUYQvsqn7p8dBjKHuOap/Ad/4KyburkMRC/V/vUsl
Ng/iDFSp8c/G00OgT6Rpv+71AX372k3GCnftZEQ/WOkD8xCwR9ZGlSOfWS2R
b6P9iMCWCQHvCOqvkz1uiV73M/dN0FAhrFuziJNjU7wnYP25utgbvKB++0rE
WxcuC3Y0wG8kUroN8P/qh3+gGn1fhP4ta2uHGajXVRwm9/ISqYDm1IQ5ciSA
H2r2JUaJ4lADtLjSXK1QBOzCe80jql+mHKGTqe9X0mvAPCYpl82bvIqKCH2V
Km/+a9AX7zvs0JG0nQBB1/XTj3EA3hLSfFuoR9YbPZaKyjyXiIDx+G3TlQdl
EoJG6KeMqT8RHsYEP4V1YDPr2Jk30KkYHnLOGlBXU0ridLwl8BVkGai/embF
Evi/0s7M6Z98oKHc5pVLcw4EXPaVjfaqUDZ0zWlLLv414Dn33eN7az9GoAm0
3/ZdJX1gPG9u+/yK4ghjJ6RbdCC2LRr0l1ELJU8QFUZD46H+MmfEYgn4lf5T
95hqhiCJ4tMFNY5gven1nLpsZHQYXqIfM3UdB+fV7iBbw6LMETjimgf7dXHg
z853exeWv+FBJXwlf0+EAf8ROk0fuTauAnPqnHAedwTxz4J4VNE2KQy9aLFE
LkL0AMb7L9TZNetrGEzRY8LkPGcotAl+x/KtrSafe+KojyS9pDcneJ8WASRU
7G8HkO07Wfz0pSCeU6jz50GeywCkef667lltgLPlFc1S+SdBSrTzNTxXQd0v
VeD29dq9t4iZpOMw7ymw3jLpn7JmNhYhob9dJRq0wJyIgbtC7Eea+iHPhL9u
H5ZA39BZg9MzpLkvkTn564cLJoC9k1J+brpVTAbP+ryNF1MBfZHrzVHMK9Ha
MIPtwSiSMvCeST7k1m3P3UFv540tILng/LnsOta4T3MInRqkrLmuCeppiTqZ
+MLWdqAn5w/rzx0E/Req9H++mN54Dk3dzhAd+Q3iYH+YDD6Gt1QhCVZbhZvH
QD1z6I7meyeWWkjp3JSEaR3o3399x9ms0iAX+l4wLeDVAuKWR8YzmYaUKeGA
HasTWmOrBPxUQcung0xScGVRNrxFDuIAsTkv2ZxOaKI3B7Iiecb9YFwfRoxv
MqOxVh0NZGnN8S80IXx3YxKiVJOGGoiGi/kTeRvIa395/P6V7aW3kBCZ1eKu
LrjP+ueXybUaJyCtZs+Xyz+APmG29JCG6uMDsAz/u+bcEVDPo3Fk6lx1XxSq
3pIUSXsxHMZ1+bS5taIyl/shjiHeqUgE7AslL56W8zUvoTafc7vcZqDuPXyv
2pL3Qi4U0s6SI9EL9tcNIVKn8/ArSGHh9s9n98H5XDxy7M1Tp0xoyGtmmmMd
xC1zPliQjrZ2ISTuh2lbJMD1a/2u9YpoJyD3PA5yNO5FAf9l47bZUk07lDMC
5SndBXm9i6XvmpPLD8NrHDIx09+B3fHauVISaC0Gx7VN2Hd2gv1L5sdPcYRL
CO7ZnuolfaBLwBu1Ws4+PHsBraVL1GYcBnNaUyfdx4qFvNH6h153rhpGwPg8
i/XCknOXNY3QC5IZrL/ywHkoYsRk8N31LBq/rCZ3zB/01597IDgYAZOiuYdj
xkWugLjrW3/de8bZ+dDRPZn8t3XAn7o4GJdtB99HOhoFJPLHwfssWaO7B8tH
IcQDTUUNtuD9X65x35ehfgVd/ilHKRUD/I5HKfyGqgLjEPP2NX2T4QnC72vE
9AeP0v2AxPyKOlnWqIBewaDNuZEvfxDSQLYp25dgn8rP951oIpeFz2RppxMv
gufyTwliN/0cgdaq5jVUK4Dz2fK1hiSpjSoqZbpffM0IzP9CAvavcYzsQZqb
31IruUGfjluj+r5ZvBiURPs95relCuE+kQxiehXueuiozWPKglegruAvLCYa
UfIWIirMNB4K1wJ+QX/P1QuH/SFxkyL3Ey+Av0k0IWzLcm0LSr83zCxJDd7P
0BGhKlI+SdhW3uBS1gEQL9VdMyiubb0AC7A7NDMcA/t0jynzhkgqD9p/1Glh
Xg3M0bD6K67m6lkEJSRl38+gAfPKFf5cJIkiRaAfr09/znD8j25bLAksnzsE
Wbey19o5gH1Xpv754tczh+EBKuZs3R7w/j1yf8f6hISh+XV7DPr/461j2P5V
8wlyW6KPh1Yb0vmHjcDzCrgXkXA19ENHVTSof/yn39Ov/IVipPkAMplchNqR
Ax3mDAtBBoavcUi4C9Rr6At0b6yPFpzKcgmFKSvYZW8fjkR/Y//3i0vJYIsD
A6p1mwniMGUgfEedKfkyv/FhpEvh+3u2c8B/bGzmSfku1YRk/WpdlXgC+mc/
eVof/Pb4GXLZ3eVB1icQ/+9yKXmn3ykAO/ufkmX20yfkwTtWiWJnhZVR3gSx
zj5LU8I+7be8oVEwK4XWZSZp1GSBOsAKN97zxId3kRuHyO+IzgP7WFAOcVfW
eCFLlO2TVmvgeZ1TWakvmb9FLv9y5WGkcyTgPGQu3QZtDYi35G+9N+9AvOWC
mk1wTPo5ZGDuZWJQwTnC7zVMJ6BxbSKUKu3AIwYKUD820cW0CWcrwQjM7DIk
AeoSnRLe/+GgDYcTO9Ji+qO8UAfsuaITPSk9nJTQZTnymz1EoO/DPHDn4Rdx
Ivi9vpq33X/8Ml3ZkNs7FOsIj3jlxKQ68O/oyx7MsIlPIJk7oc6XeYBurf+g
9PDhlTbEuLP+wxo7yGdVRrEPBxQoI/1mlZGawcrAr7QPkNThTYBctx5+Hm8F
cyKEwteMAxbzkUdsilurpaBO/gRDykU76V3I/8OoRt9noEuj/MKj59VvKbik
h/zgGAR0WiKQU0Ib/YawRe6TX2d2DAnfd1Xo+dgwnxe87qSm9uhvGOqI4e7+
KVKJ5Gqwe7dezAlWE4I/stl6ZP+TJD/KbtfL0murT9inAQxFLpR24ugTlZHg
aW3Aww3vuvHNKjCiR/lhteUEcC7lthnNM3l1IL0P997WyYDntWQPcBdQOQ0p
6jRxrMKngf9CwnJb5FAXxE6fkLv1GcSFNH/ffpWq4YCkKKgtL4qD+meDozf7
Si3bkcwajYIJVlDHYmgzsSD+Mw/xc99sdxwC557gcpVXjmQDUrdCUq7nBfqv
Dw56Z3r/7EcucW2W8neD+Mx50yM8IhyR8OL8cviObihh/3ZZfrk4H3MQ1Rtt
FWFXBPWEJM+pNW/yTiF6PpmrCWJg3h/uj3G+bxgJXgW64g93Wf8YU9ch9c2j
/Gm/wHzecj/mycBEdXj7TvaIe4kx4TvSyzZJ+4drwVQ8zJRjwn6EeVKe9/23
ay+dQc+LWm0cswH6M1UBvB2u2odQd26jjht7QDeDciDA0PBHHlKqsTLYU+hF
wFvcKR+bGNQhGvu6vjo3QT53ibPRRHu+Etq/FOao4AZ0EvadOD1fOlUg6guH
++mJQb235HWtLx1XFxBZar6s9GSgzxN9/NhiqvUcNJvZMTJgBeJOr2MbdA6L
+MFNFNcFR0K1CM/1ls4x4bONPrrtx1Pjco6fsA755hN097to0Kknx98Vi4O8
Xox5R/QqRSdEbm/GpXwY6LlFUWZdpJYfQDR/By+EjA8TcO8TshtdNTkQ68nS
MBdzEIcn0/TsCj//FlKwc4l0egp0UKeqMwNc+fwgEjuLuW0yUE/lf+tN6mrG
ACLH/XSr+RpYV7PvHBqCpiIhou9fuTzHQP3D6uK5O8xJwrCryqZlnxKYZ/Sh
4pGSQIkxbHnPykQkUZ3w3UeIXwe164bCZfKCY3Pskegetg7PKvEF0LGaoNFX
5kbcyNUIcSE+iuOZv0iPw0ZVwRdSnIAffaPYQ+1ONidq+cp4pnNaioDLUX1b
kzJkQBUP95ipOQB7pB7m+vjx3jAi9vOp6kdzYI8sQvQ/dT6ORo7bFRkNNIP+
FNq91JuM9h1I7MjnGfQ//QVQXR9X0t8wmE7AXJGE34tw/lyhP2leIZWDlOcF
Gb0OBHkW/8Bt7W5OP0Q5Rpf5oCiwI4oaUraqFK2IgSLUGwV5Et4ny+5ty7vb
b5Aixzfehk4g3+36xyNea8sQ3voaudz1DpyHCiskGSwPvGCK+uXah7ThBHtR
K3zmZPfBZMQ0IIHMZhPUPR46w3D+XYAA0v6Sr43mkADh+sQyb0tHzR2R76G2
Ob5kfgT89oCo8t/UWmTrU1mACCOoQ7htnvEryqsKCX0tKBE8B/pQwuzbaThI
QiHKj7NJpSwg/27msYtePM8F//Gp6JvckSKs8799BRSsksfQc+Tf1F5mAj96
vUaO9ZOlKfyn0fC1hrAygXfllnRrUPrRQTyGJn/6pekJ/5cv5ZJXz70kKOOY
ZRa5JIhjlNZMHdKDAhH/8QOzeb9A3odUuZTTaSkW6dhLqooVAP2kTeuROiGG
SYibtso7PwrQN/qu5XYPlXsLZL675KgyCfaRX0p7TkQrCuXKfj25owviMGpL
U0/cBvsRad9n2o//o+cvFOWzl7PQhZANjY+3KoE+jpFquyFiMlp4QvORCpcW
yBen3TtEouunD1e9cIbT6gUI/CfZZH2a7HAkDNNJyFK5gfP8AMbPLDG+huM4
f3qF8Sn8OjQYL8F5Cv5/72B2GrfbOK6N2RXczuA4G2YP/n+8ThM7f1ux85jw
e+ycuo2dWzjOg+1DY2xf4vhLbF8ZYvsMx/H1XYetdxy/iK0Pemy9EK6P8UWc
P+LrCsV42DjGy/DfF2O8BOcpON6O2bkozO7hOJH2P7uygtkZHIex85ccO49x
XAk7F4KxcwLHFRv+7c9o6X/7Fcfx9Y2vdxyPx/iiI8Yf8XMA5084n8KfVwWz
cyTO/+wefh0yzB7UY/YBx8nD/p0LNNg5geP4vsL3GWH/YvzsK8bX8HMSwuyK
H2Zn8N83Y/vw54V/+xLHxzD/xAfzVwjrCvM3ljD/A8dx3v8O8wNwHOfNOI/G
cZwv4vwRtztzGE+SwXgTvo/WMR5TiPEa/H2ewfjBBYwv4NevXPtnLwX7MfuJ
4bhdocHsDOG7K/yzB7h9wHH8/PXFzmMc98DOqWbs3MLxt5jfZYz5YTiO+z9F
mD+E4+OY/2CB+RM4jvPmXYxH4+cGJcbb6DAeh/OcDxgfisP4EX4dF4wf4HwB
x6cxO8eM2T0cf4DZlWDMzuC4GXb+vsXOYxyfwfy375g/h+O4/3MF84dwPA/j
/bgfgOM4b+vAeBz+XDiPwXkN/t25MDtXg9k9/DrZmD0IwOwDjodiftde6T8/
DMdZMH/jMuZ/4HgpxpNw3oTzpTOYXVHF7AxhvWH+SRDmr+A47s9nYv494T4x
Pxz3y3FcEvN7cT8Yx3H/EPcXcbxd+5//04X5Qzjehvknopi/guO4v9GJ+R84
jvN+3A8grH+MN/dgPBpfhzhfxPkjvn9xfobzNfz8WcP4ky3Gp/DvuIvxkksY
T8H/7+/3/+z0ScxuE+4fi1N8xuIWOH4biwtwYXECwr62+Oc/G0f+86dxnAPz
D3F/kXB9zO/C/TAcx/0f3B/Ccdx/wP0JHMd5M86jcZwV44tXMf6I2wsVnIe9
+8fL8N+PYbzkHcZTcFwZi3cEYvEPHHfD4gLCWJwAx1Mxv1fx1z8/GMcfYP6b
IubP4Tgp5v/oYf4QjttivN8G8wNwHOeLGxh/xL8vzp9wPoWvn3gsTnEMi1vg
18nF/HBDzC/HcWHM7/LB/DAc18L8DSXM/8BxnJ8lYXwNtyOhmD9/DfPv8d9f
xvwTH8xfwfH/A1VZyfc=
    "]],
  Axes->True,
  AxesLabel->{None, None, None},
  AxesStyle->Directive[
    GrayLevel[0], 
    AbsoluteThickness[0.2]],
  BaseStyle->Automatic,
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  ImageSize->600,
  LabelStyle->{FontFamily -> "Times"},
  Lighting->{{"Ambient", 
     RGBColor[0.312, 0.188, 0.4]}, {"Directional", 
     RGBColor[0.8, 0, 0], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     RGBColor[0, 0.8, 0], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     RGBColor[0, 0, 0.8], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{0, 330.69396353576764`}, {
    0, 330.69396353576764`}, {-0.00006847519775590727, 0.}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{-1.8046804855268939`, -2.71403060816547, 0.9094867800575114},
  ViewVertical->{0., 0., 
   1.}]], "Output",ExpressionUUID->"ae045992-609b-47ff-9228-9a65addff327"]
}, Open  ]],

Cell[TextData[{
 "See the implementation notes in the code for ",
 StyleBox["makeDipoleList", "Code"],
 " for further definitions of what each term entails."
}], "Text",ExpressionUUID->"40ca58dc-75dc-4e59-8274-7ad0575b41b6"],

Cell[TextData[{
 "Setting ",
 StyleBox["Verbose\[Rule]3", "Code"],
 " makes ",
 StyleBox["makeDipoleList", "Code"],
 " return as pure functions the prefactor and action of the SFA integrand, as \
functions of the recombination time ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "e0477fc2-cb28-46d1-8d73-454ce02abf33"],
 " and the ionization time ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"t", "'"}], "=", "tt"}], TraditionalForm]],ExpressionUUID->
  "ce8aa446-b3a2-468d-90cf-d60f7ea5b343"],
 ", which can then be used for e.g. quantum orbit calculations.\n\nNote that \
the precise name of this setting is subject to change in future versions."
}], "Item",ExpressionUUID->"8f4fe318-d60c-4b01-8c4a-536cb1c8becc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"prefactor", ",", "S"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"prefactor", ",", "S"}], "}"}], "=", 
     RowBox[{"makeDipoleList", "[", 
      RowBox[{
       RowBox[{"VectorPotential", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"t", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             FractionBox["F", "\[Omega]"], 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
           "}"}]}], "]"}]}], ",", 
       RowBox[{"FieldParameters", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"F", "\[Rule]", "0.05"}], ",", 
          RowBox[{"\[Omega]", "\[Rule]", "0.057"}]}], "}"}]}], ",", 
       RowBox[{"Verbose", "\[Rule]", "3"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"prefactor", "[", 
       RowBox[{"t", ",", "tt"}], "]"}], 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"S", "[", 
         RowBox[{"t", ",", "tt"}], "]"}]}], "]"}]}], "]"}]}]}], 
  "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"98b871aa-9d07-4bd4-a838-088af12aff4a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"0.`", "\[VeryThinSpace]", "+", 
          RowBox[{"10.212922378276676`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"0.`", "\[VeryThinSpace]", "-", 
             RowBox[{"0.1923668821175746`", " ", "\[ImaginaryI]"}]}], ")"}], 
           " ", "t"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"0.`", "\[VeryThinSpace]", "+", 
             RowBox[{"0.1923668821175746`", " ", "\[ImaginaryI]"}]}], ")"}], 
           " ", "tt"}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{"t", "-", "tt"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1.`", "\[VeryThinSpace]", "+", 
             FractionBox[
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"15.389350569405968`", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"0.057`", " ", "t"}], "]"}]}], "-", 
                 RowBox[{"15.389350569405968`", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], ")"}], "2"], 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                   RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", 
                 "-", 
                 RowBox[{"1.`", " ", "tt"}]}], ")"}], "2"]]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"15.389350569405968`", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"0.057`", " ", "t"}], "]"}]}], "-", 
               RowBox[{"15.389350569405968`", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], ")"}], "2"]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"0.`", "\[VeryThinSpace]", "-", 
              RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", "-", 
            RowBox[{"1.`", " ", "tt"}]}]], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"0.`", "\[VeryThinSpace]", "+", 
             RowBox[{"1.6874287905050402`", " ", "\[ImaginaryI]"}]}], ")"}], 
           " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"0.114`", " ", "t"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"0.`", "\[VeryThinSpace]", "+", 
             RowBox[{"1.6874287905050402`", " ", "\[ImaginaryI]"}]}], ")"}], 
           " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"0.114`", " ", "tt"}], "]"}]}]}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"0.1`", "\[VeryThinSpace]", "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{"t", "-", "tt"}], ")"}]}]}]], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"0.057`", " ", "tt"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"15.389350569405968`", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"0.057`", " ", "t"}], "]"}]}], "-", 
            RowBox[{"15.389350569405968`", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"0.`", "\[VeryThinSpace]", "-", 
              RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", "-", 
            RowBox[{"1.`", " ", "tt"}]}]], "+", 
          RowBox[{"0.8771929824561403`", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"0.057`", " ", "t"}], "]"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"15.389350569405968`", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"0.057`", " ", "t"}], "]"}]}], "-", 
            RowBox[{"15.389350569405968`", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"0.`", "\[VeryThinSpace]", "-", 
              RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", "-", 
            RowBox[{"1.`", " ", "tt"}]}]], "+", 
          RowBox[{"0.8771929824561403`", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1.`", "\[VeryThinSpace]", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"15.389350569405968`", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"0.057`", " ", "t"}], "]"}]}], "-", 
                RowBox[{"15.389350569405968`", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                  RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", 
                "-", 
                RowBox[{"1.`", " ", "tt"}]}]], "+", 
              RowBox[{"0.8771929824561403`", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"0.057`", " ", "t"}], "]"}]}]}], ")"}], "2"]}], ")"}],
          "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1.`", "\[VeryThinSpace]", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"15.389350569405968`", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"0.057`", " ", "t"}], "]"}]}], "-", 
                RowBox[{"15.389350569405968`", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"0.`", "\[VeryThinSpace]", "-", 
                  RowBox[{"0.1`", " ", "\[ImaginaryI]"}]}], ")"}], "+", "t", 
                "-", 
                RowBox[{"1.`", " ", "tt"}]}]], "+", 
              RowBox[{"0.8771929824561403`", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"0.057`", " ", "tt"}], "]"}]}]}], ")"}], "2"]}], 
          ")"}], "3"]}], ")"}]}], ")"}]}], ",", "0", ",", "0"}], 
  "}"}]], "Output",ExpressionUUID->"7e0dd821-78c9-4e1d-91bc-d32a053a8486"]
}, Open  ]],

Cell["\<\
If the action is required in symbolic form with respect to some parameter, \
the option CheckNumericFields can be used to turn off the usual check for \
numeric-valued field functions.\
\>", "Text",ExpressionUUID->"391b0da2-5044-4707-bfe4-257839443ae3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  "CheckNumericFields"}]], \
"Input",ExpressionUUID->"5f57723d-8427-49bc-87e8-5f53bc4c9980"],

Cell[BoxData[
 StyleBox["\<\"CheckNumericFields is an option for makeDipoleList which \
specifies whether to check for numeric values of A[t] and GA[t] for numeric \
t.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->
  "Info83672149793-5368915",ExpressionUUID->"ccaf4e5b-b37c-42e1-8375-\
0434fc66ec0d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"prefactor", ",", "S"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"prefactor", ",", "S"}], "}"}], "=", 
     RowBox[{"makeDipoleList", "[", 
      RowBox[{
       RowBox[{"VectorPotential", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"t", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             FractionBox["F", "\[Omega]"], 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Omega]", " ", "t"}], "]"}]}], ",", "0", ",", "0"}], 
           "}"}]}], "]"}]}], ",", 
       RowBox[{"Verbose", "\[Rule]", "3"}], ",", 
       RowBox[{"CheckNumericFields", "\[Rule]", "False"}], ",", 
       RowBox[{"CarrierFrequency", "\[Rule]", "\[Omega]"}], ",", 
       RowBox[{"IonizationPotential", "\[Rule]", "Ip"}], ",", 
       RowBox[{"\[Epsilon]Correction", "\[Rule]", "\[Epsilon]"}]}], "]"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"prefactor", "[", 
      RowBox[{"t", ",", "tt"}], "]"}], 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"S", "[", 
        RowBox[{"t", ",", "tt"}], "]"}]}], "]"}]}]}]}], "\[IndentingNewLine]",
   "]"}]], "Input",ExpressionUUID->"c3ad28c2-d226-4a70-9ffa-c5c1eb4d2b5c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2048", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"F", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
                   SuperscriptBox["\[Omega]", "2"]]}], "+", 
                 FractionBox[
                  RowBox[{"F", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"tt", " ", "\[Omega]"}], "]"}]}], 
                  SuperscriptBox["\[Omega]", "2"]]}], ")"}], "2"], 
              RowBox[{"t", "-", "tt", "-", 
               RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]]}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"t", "-", "tt"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "Ip"}], "+", 
               FractionBox[
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox[
                    RowBox[{"F", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
                    SuperscriptBox["\[Omega]", "2"]]}], "+", 
                   FractionBox[
                    RowBox[{"F", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"tt", " ", "\[Omega]"}], "]"}]}], 
                    SuperscriptBox["\[Omega]", "2"]]}], ")"}], "2"], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"t", "-", "tt", "-", 
                   RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}], ")"}], 
                 "2"]]}], ")"}]}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{
                 SuperscriptBox["F", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["t", "2"], "-", 
                   FractionBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "t", " ", "\[Omega]"}], "]"}], 
                    RowBox[{"4", " ", "\[Omega]"}]]}], ")"}]}], 
                SuperscriptBox["\[Omega]", "2"]], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["F", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["tt", "2"], "-", 
                   FractionBox[
                    RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", "tt", " ", "\[Omega]"}], "]"}], 
                    RowBox[{"4", " ", "\[Omega]"}]]}], ")"}]}], 
                SuperscriptBox["\[Omega]", "2"]]}], ")"}]}]}], ")"}]}]], " ", 
        "F", " ", 
        SqrtBox[
         SuperscriptBox["Ip", 
          RowBox[{"5", "/", "2"}]]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{"t", "-", "tt"}], ")"}]}], "+", "\[Epsilon]"}]], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        RowBox[{"Conjugate", "[", 
         SqrtBox[
          SuperscriptBox["Ip", 
           RowBox[{"5", "/", "2"}]]], "]"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"tt", " ", "\[Omega]"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"F", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
               SuperscriptBox["\[Omega]", "2"]]}], "+", 
             FractionBox[
              RowBox[{"F", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"tt", " ", "\[Omega]"}], "]"}]}], 
              SuperscriptBox["\[Omega]", "2"]]}], 
            RowBox[{"t", "-", "tt", "-", 
             RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]]}], "+", 
          FractionBox[
           RowBox[{"F", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "\[Omega]"]}], ")"}], 
        " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"F", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
               SuperscriptBox["\[Omega]", "2"]]}], "+", 
             FractionBox[
              RowBox[{"F", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"tt", " ", "\[Omega]"}], "]"}]}], 
              SuperscriptBox["\[Omega]", "2"]]}], 
            RowBox[{"t", "-", "tt", "-", 
             RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]]}], "+", 
          FractionBox[
           RowBox[{"F", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"tt", " ", "\[Omega]"}], "]"}]}], "\[Omega]"]}], ")"}]}],
        ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox["\[Pi]"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "Ip"}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"F", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
                   SuperscriptBox["\[Omega]", "2"]]}], "+", 
                 FractionBox[
                  RowBox[{"F", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"tt", " ", "\[Omega]"}], "]"}]}], 
                  SuperscriptBox["\[Omega]", "2"]]}], 
                RowBox[{"t", "-", "tt", "-", 
                 RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]]}], "+", 
              FractionBox[
               RowBox[{"F", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "\[Omega]"]}], 
             ")"}], "2"]}], ")"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "Ip"}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"F", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"t", " ", "\[Omega]"}], "]"}]}], 
                   SuperscriptBox["\[Omega]", "2"]]}], "+", 
                 FractionBox[
                  RowBox[{"F", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"tt", " ", "\[Omega]"}], "]"}]}], 
                  SuperscriptBox["\[Omega]", "2"]]}], 
                RowBox[{"t", "-", "tt", "-", 
                 RowBox[{"\[ImaginaryI]", " ", "\[Epsilon]"}]}]]}], "+", 
              FractionBox[
               RowBox[{"F", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"tt", " ", "\[Omega]"}], "]"}]}], "\[Omega]"]}], 
             ")"}], "2"]}], ")"}], "3"]}], ")"}]}], ")"}]}], ",", "0", ",", 
   "0"}], "}"}]], \
"Output",ExpressionUUID->"cd3bb4a8-4402-49cb-9488-6c5e2864619b"]
}, Open  ]],

Cell[TextData[{
 "It is also important to note, particularly if these functions are used for \
quantum orbits calculations, that the action does ",
 StyleBox["not",
  FontSlant->"Italic"],
 " include the Fourier-transform factor of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"\[ImaginaryI]", " ", "\[CapitalOmega]", " ", "t"}]], 
   TraditionalForm]],ExpressionUUID->"d63a7ba8-8f22-4626-954b-38eb5f7c04c4"],
 ", which affects both the phase and the amplitude of the harmonic dipole \
when evaluated at a complex saddle-point time ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", 
    SubscriptBox["t", "s"]}], TraditionalForm]],ExpressionUUID->
  "7cb2cdfd-f4a4-41f7-9fee-196fd91aea21"],
 "."
}], "Text",ExpressionUUID->"5eeb5f10-4703-4225-a0ee-8c0337eb79e7"]
}, Closed]],

Cell[CellGroupData[{

Cell["Bicircular fields", \
"Subsection",ExpressionUUID->"4d04d328-e49d-47d9-b1a6-b64b0d49073e"],

Cell[TextData[{
 "As a slightly less trivial example, consider a bicircular field: two \
counter-rotating, circularly polarized fields of different frequencies. The \
\[OpenCurlyQuote]standard\[CloseCurlyQuote] case - as first demonstrated \
experimentally - has one field as the second harmonic of the fundamental, \
with both at equal intensities. The resultant harmonics appear at all integer \
orders except those divisible by three, with the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"3", "n"}], "+", "1"}], TraditionalForm]],ExpressionUUID->
  "6d08749f-85d6-45f5-8d87-7b0d62314ce8"],
 " harmonics polarized as the fundamental, and the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"3", "n"}], "-", "1"}], TraditionalForm]],ExpressionUUID->
  "08bb1bec-974d-40a4-947e-c9afe6ff2bae"],
 " harmonics polarized as the second-harmonic driver."
}], "Text",ExpressionUUID->"34b78285-8ed5-4bc0-a0bc-ba031b5fab57"],

Cell[BoxData["Quit"], \
"Input",ExpressionUUID->"383eeaa4-0ce5-4644-b0cf-2dd3c0acc2af"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"bicircularA", "[", "t_", "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     FractionBox["F1", "\[Omega]1"], 
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"t", " ", "\[Omega]1"}], "]"}], " ", 
        RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", " ", 
         RowBox[{"Cos", "[", "\[Alpha]", "]"}]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"t", " ", "\[Omega]1"}], "]"}]}]}], "}"}]}], "+", 
    RowBox[{
     FractionBox["F2", "\[Omega]2"], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "\[Beta]", "]"}], 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Omega]2", " ", "t"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", "\[Beta]", "]"}], 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Omega]2", " ", "t"}], "]"}]}]}], "}"}]}]}], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bicircularParameters", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F1", "\[Rule]", "0.075"}], ",", 
     RowBox[{"F2", "\[Rule]", "0.075"}], ",", 
     RowBox[{"\[Alpha]", "\[Rule]", 
      RowBox[{"45", "\[Degree]"}]}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", 
      RowBox[{"45", "\[Degree]"}]}], ",", 
     RowBox[{"\[Omega]1", "\[Rule]", 
      RowBox[{"45.6", "/", "800"}]}], ",", 
     RowBox[{"\[Omega]2", "\[Rule]", 
      RowBox[{"45.6", "/", "400"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{
   RowBox[{"bicircularTest", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", "bicircularA"}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", "bicircularParameters"}], ",", 
      RowBox[{"TotalCycles", "\[Rule]", "4"}]}], "]"}]}], ";"}], 
  "]"}]}], "Input",ExpressionUUID->"c63aebb7-b0cd-4c77-b6c6-a952eed5eeba"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10.727685`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"6cbaabc2-2588-4d44-a4f2-7931225c412d"]
}, Open  ]],

Cell[TextData[{
 "The function ",
 StyleBox["biColorSpectrum", "Code"],
 " takes the spectrum and plots it, separating the two circular polarizations \
into different colours."
}], "Text",ExpressionUUID->"f9a8b2f1-1c50-4632-af28-4a82d923b1dc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"biColorSpectrum", "[", 
  RowBox[{"Most", "[", "bicircularTest", "]"}], 
  "]"}]], "Input",ExpressionUUID->"cfbf1fd7-87b6-4e19-9a28-126b812874b8"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[0.009166666666666668], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw1lQtYjGkbxwchZYuadESldJLO53nf99/UlIoc12FLOjjkUPkcVmyIvjZF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       "]]}}, {}}, {{}, {{}, {}, 
     {RGBColor[0, 0, 1], PointSize[0.009166666666666668], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw1lQs4VfkaxjE4GZ1pXLfNzhYiRG7bfa317huV0Jh2KtWJ0JMRnZJE5Og4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       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->800,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"e5ac8f29-f53f-4193-9d1b-2ecc28ee5d84"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bicircular fields with a sine-squared envelope", \
"Subsection",ExpressionUUID->"62b4619e-c553-441b-8b00-cb277773af79"],

Cell[TextData[{
 "To benchmark the original calculations, we compared them with the output of \
full MCTDH calculations. Here we used a ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["sin", "2"], TraditionalForm]],ExpressionUUID->
  "dd1c7426-3365-43ad-ab95-61030bb6c0bd"],
 " envelope as the TDSE numerics require a finite pulse; the calculations \
take correspondingly longer but they are still very manageable (two/three \
minutes per calculation for a fifteen-cycle pulse, resolving up to ~70 \
harmonics). One distinctive feature is that the harmonics near the cutoff are \
broader, because less cycles contribute to those energies."
}], "Text",ExpressionUUID->"b4b2dfe3-a0a4-4e05-8a8c-e0276c3c9640"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"bicircularEnvelopeA", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"cosPowerFlatTop", "[", 
      RowBox[{"\[Omega]1", ",", "TotalCycles", ",", "2"}], "]"}], "[", "t", 
     "]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["F1", "\[Omega]1"], 
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"t", " ", "\[Omega]1"}], "]"}], " ", 
          RowBox[{"Sin", "[", "\[Alpha]", "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", " ", 
           RowBox[{"Cos", "[", "\[Alpha]", "]"}]}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"t", " ", "\[Omega]1"}], "]"}]}]}], "}"}]}], "+", 
      RowBox[{
       FractionBox["F2", "\[Omega]2"], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "\[Beta]", "]"}], 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Omega]2", " ", "t"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Beta]", "]"}], 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Omega]2", " ", "t"}], "]"}]}]}], "}"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bicircularParameters", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F1", "\[Rule]", "0.075"}], ",", 
     RowBox[{"F2", "\[Rule]", "0.075"}], ",", 
     RowBox[{"\[Alpha]", "\[Rule]", 
      RowBox[{"45", "\[Degree]"}]}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", 
      RowBox[{"45", "\[Degree]"}]}], ",", 
     RowBox[{"\[Omega]1", "\[Rule]", 
      RowBox[{"45.6", "/", "800"}]}], ",", 
     RowBox[{"\[Omega]2", "\[Rule]", 
      RowBox[{"45.6", "/", "400"}]}]}], "}"}]}], 
  ";"}]}], "Input",ExpressionUUID->"000389fa-46a1-44c7-a861-a7320f7579cd"],

Cell[TextData[{
 "If (as in this case) the field depends on a number-of-cycles parameter, \
care must be taken that it matches the ",
 StyleBox["num", "Code"],
 " option of the main call."
}], "Text",ExpressionUUID->"3443689a-d7f3-460f-94d0-d540e084a9d4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"bicircularEnvelopeDipole", "=", 
    RowBox[{"makeDipoleList", "[", 
     RowBox[{
      RowBox[{"VectorPotential", "\[Rule]", "bicircularEnvelopeA"}], ",", 
      RowBox[{"FieldParameters", "\[Rule]", 
       RowBox[{"Join", "[", 
        RowBox[{"bicircularParameters", ",", 
         RowBox[{"{", 
          RowBox[{"TotalCycles", "\[Rule]", "15"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"PointsPerCycle", "\[Rule]", "150"}], ",", 
      RowBox[{"TotalCycles", "\[Rule]", "15"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"4acb9aaf-ffad-4209-b002-71ce8c84d833"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"173.565397`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"d8013e0c-50ff-49d2-b742-9ea568183852"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["\[IndentingNewLine]"], \
"Input",ExpressionUUID->"d4ddbf7d-b380-47e6-bcc7-c32d0c62e962"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"141.301829`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"5afe9533-1c5a-43aa-ba28-50b148db6edc"]
}, Open  ]],

Cell["Plotting the spectrum, and a zoom at the plateau:", \
"Text",ExpressionUUID->"9ac403f3-76c6-4798-8e79-b4e826c930ef"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"biColorSpectrum", "[", 
  RowBox[{"bicircularEnvelopeDipole", ",", 
   RowBox[{"PointsPerCycle", "\[Rule]", "150"}], ",", 
   RowBox[{"TotalCycles", "\[Rule]", "15"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"biColorSpectrum", "[", 
  RowBox[{"bicircularEnvelopeDipole", ",", 
   RowBox[{"PointsPerCycle", "\[Rule]", "150"}], ",", 
   RowBox[{"TotalCycles", "\[Rule]", "15"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "40"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "13"}], ",", 
        RowBox[{"-", "1"}]}], "}"}]}], "}"}]}]}], 
  "]"}]}], "Input",ExpressionUUID->"03b35f19-d8b7-40ed-862f-339e1c83c3c0"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[0.004583333333333334], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw9mnlcTN0fx0MRhaRF+77vTfs2n2pqWqaamZJd2UISIrtkDdnXQolItrKH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       "]]}}, {}}, {{}, {{}, {}, 
     {RGBColor[0, 0, 1], PointSize[0.004583333333333334], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJxFmXdcjf/7x4usRGnvvfc+7fPqdDrtOucQ2TuzbJlJyB7ZWQ0SQgjZSlFU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       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"9d39828d-2a7c-4489-94a9-00e6f0396a05"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[0.004583333333333334], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQPq/403LuJXOyAIBhvtPXw6e+IOq0D5B+3TmVgX
7jqgfGDWTBA4aR/IwD3hioEyVP6i/ZcG0VyP+0oHQsHgqn3Frzyem84w9Tft
p3Ezd+4PUD1w7y4Y2MfeOhVVNE8Vqv+hfekMdt/fksoHjMHgsf0+6y0LNXbD
zHtqH1347ZLpfNkD5WDw3P5vu8PcM7LSUPNf2jc0qsyO2SJ2YM9uEHhtbyF5
sX7HJwGofW/t7687vnKdM88BiG8/2Ls9rHmaOYELav9H+wkJUZJTYngOKIHB
J/vrpR+W7H4sAHXPZ/uXrpf7GWtED7iAwRf7Ytt/CjOWSULd99VexVjQ7cwa
mQNpYPDNnn2BypP3rxWh7v1uX3g3knfZeaUDnR0g8MNeV1NaLPgvLHx+2tcF
xMkY5KgcWL0KBH7Z/0ra90FIQBnqn9/2PzkqDokwKR84ewYE/thbx0nl/fmu
DPXfX/vT4Xdj4m6pHnj/DgT+2cdsr3z4LkkN6l8Gh6hdG548tdeE2s/gUPFV
4NMKXlh8MzoYidZNc/JSg7qH0SFv5kWutHtq0PBgclD4t7Kj3k0V6j4mB4cb
BfPYo1Sh4cPscIDtqHrXRVWoe5kdwj48O/Xmkio0vFgcbDm7yj8bqkHdz+KQ
euHb50dP1KDhx+pwf/oC69dL1aD+YXXIOjmttLBSDRqebA5Xw6pfxXqqH0g7
r3s9ayebA8RbWgcAOzJDaQ==
       "]], LineBox[CompressedData["
1:eJw9mXVY1NnbxjFQVES6h+mhcwaGCZh7lIWfLiqiKAYSIquA3a5gS7mKDYhJ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       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQbXMl5PSfc44ODGCgdSAUBK46Otz/5DLVs1DzwL27
IODowNknu2TtHY0DaSDwzNHhi8m2n9/OaBx4/w4EHB1MlrZkPDfUPFAOAt8d
Hco0z6wJ+aB5AGKuk0PyN/91Ug80D3R2AAGHk0N7+lzHa+qaBwTBwMnBS3Hh
3JV7NQ7MmgkEkk4OmiFfnhZO1jigBAZODhE75B73VmscWL0KCLScHPJMAqet
8dI4YAwGTg6PjR+8qvutfmDPbiCwdnL4u3rZj62L1A+4gIGTg4zE76V7vNQP
nD0DBD5ODqLHrvMmfVGD+DfUyWG78r8wx4VqEP/GAtV7xF+eHqoG8W+akwPT
0yWnN4mqQfyb5+TwsDvhSdMTVYh/y50cDgiw3F93WBXi3wYnB65j3q6/N6tC
/Nvh5LBYh3V101ZViH8nOjl8s7GQP3VcFeLfmU4Oh9ZzsZ99qQrx7yInhx/L
fjmLSqlB/LvKyeGW5aRFz8PUIP7dDDTv3tVdnfPUIP7d7eTwxF7p0pT3ahD/
HnFykJYXKjDwhPr3jJPD8ieJJfdWqUPj18lhm3DrzynCGtD4dXK4/2R6glkD
LH6dHJqlWZiyXsHi18mhYd5UiVmesPgFyh/3i183HRa/zg5sWQsLu69pHji2
ef5yTzZneHoCAC3jGOQ=
       "]], 
      LineBox[{{39.499787424132414`, -13.}, {
       39.53333333333333, -12.914049832592715`}, {
       39.6, -12.752124051072586`}, {
       39.666666666666664`, -12.602756467686282`}, {
       39.733333333333334`, -12.469948727675517`}, {
       39.8, -12.358488249393861`}, {39.86666666666667, -12.27271306194124}, {
       39.93333333333333, -12.215663968430237`}, {
       40., -12.189096420875494`}, {40.06666666666667, -12.19362891486153}, {
       40.13333333333333, -12.229014977266358`}, {40.2, -12.29425262084057}, {
       40.266666666666666`, -12.387789844535378`}, {
       40.333333333333336`, -12.507633270554962`}, {
       40.4, -12.651605851524497`}, {
       40.46666666666667, -12.817436768773097`}, {
       40.53232236061077, -13.}}]}}, {}}, {{}, {{}, {}, 
     {RGBColor[0, 0, 1], PointSize[0.004583333333333334], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw9mXlczNsbxytbUkr7PntN+zoz1TTNZ0IhO5E1bsSNku1mSZI9+3XJEipL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       "]], 
      LineBox[{{36.6981769501653, -13.}, {
       36.733333333333334`, -12.850063406996428`}, {
       36.8, -12.818491258836495`}, {36.860611035172596`, -13.}}], 
      LineBox[CompressedData["
1:eJw90UsohFEUwPEvZjGShJTHSDNT9/vuIElNGeK4dzZKRLETxmMjNErfhlh5
l7fCwiNNMjtS8prrEWIUSYrIzIKaxUweGdkw15Vfnc7mbP4dva21vCFMkqSU
0PDdEXjwHQ0SkH6ZWAw3SqC5K9brP8RsZpojsPFlyatcxczALRJY1w8NODcw
c65wBHyWkverKcyyuTUCbykW92Y+ZttbHAF14c71dakwK3dI4OobJdbVKuzc
zRGoMY6b5l5kVsFdE3AU7PhdfTJ7uOcIpGnjyzUZMmvkngjkmMMzyryIBfwc
gdqAT7WvIKZyQQKG4EhSXA9iootCd/J+QWk7Yv19IVoK69WRw2cqEr0xFD6W
C1OdQ0j0JlI4UW7S1VUkeg0UHDZLMPoZiV4TBY1L17Qty6I3O3T/iBPsdln0
5lLQH2s89Xuy6LVSeLXdRhzE//UWU5iP0sx+Niuit4LCaNHEs3SqiN4qChdL
me1+BYveRgqddp17txeL3hYKxqA268ODmXlMNxnVRv//9wOELM/F
       "]], 
      LineBox[{{40.699591547574016`, -13.}, {
       40.733333333333334`, -12.921745372082759`}, {
       40.8, -12.793436076898741`}, {
       40.86666666666667, -12.695516349860648`}, {
       40.93333333333333, -12.630283113913517`}, {41., -12.598599889411101`},
        {41.06666666666667, -12.600331179119788`}, {
       41.13333333333333, -12.634440142326554`}, {
       41.2, -12.699126682603564`}, {
       41.266666666666666`, -12.791817311002239`}, {
       41.333333333333336`, -12.909380515568943`}, {
       41.376816832060896`, -13.}}]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, -1.06},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->500,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 40}, {-13, -1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"5c61b971-269b-4b5a-a84b-7bf52127139e"]
}, Open  ]],

Cell["\<\
The comparable MCTDH spectrum, for identical conditions, looks like this:\
\>", "Text",ExpressionUUID->"f9154675-f1b2-45b2-bbd6-79debe97a6cc"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwUWHc8lt8bfod32HvvPbOThOeWlFQqJEqaRkhSoUKEkmSWChkplB0RpeeQ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      "]]}}, {{}, {}, 
    {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
     LineBox[CompressedData["
1:eJwUV3c81e8X5+IOrr333iUjo8LnCCWhUEai+kaKyiiSkl1GdiVFSUIloiEj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      "]]}}},
  AspectRatio->0.6180339887498948,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0.07, 40}, {-10.531896791434443`, 1.2761637702878668`}},
  PlotRangeClipping->True,
  PlotRangePadding->{None, 0.5},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"663d6e2b-e219-48b0-8bdb-39a6b01bdea0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Original RB-SFA: \[OpenCurlyQuote]rotating\[CloseCurlyQuote] bicircular \
fields", "Subsection",ExpressionUUID->"4a1c598c-23c1-4e1c-8596-357ecc4953b9"],

Cell[CellGroupData[{

Cell["Calculation", \
"Subsubsection",ExpressionUUID->"5e6db32d-2af5-4674-87ba-b1ffdeebe28c"],

Cell[TextData[{
 "Here the fundamental laser driver has been set at an elliptical \
polarization (as in the original experiment, A. Fleischer et al., ",
 StyleBox[ButtonBox["Nature Photon.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1038/nphoton.2014.108"], None},
  ButtonNote->"http://dx.doi.org/10.1038/nphoton.2014.108"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1038/nphoton.2014.108"], None},
  ButtonNote->"http://dx.doi.org/10.1038/nphoton.2014.108"],
 StyleBox[ButtonBox["8",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1038/nphoton.2014.108"], None},
  ButtonNote->"http://dx.doi.org/10.1038/nphoton.2014.108"],
  FontWeight->"Bold"],
 ButtonBox[", 543 (2014)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1038/nphoton.2014.108"], None},
  ButtonNote->"http://dx.doi.org/10.1038/nphoton.2014.108"],
 "), which helps investigate the spin-angular-momentum conservation \
properties of HHG. In the model proposed in the original paper (",
 StyleBox[ButtonBox["Phys. Rev. A",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
 StyleBox[ButtonBox["90",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
  FontWeight->"Bold"],
 ButtonBox[", 043829 (2014)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1103/PhysRevA.90.043829"], None},
  ButtonNote->"http://dx.doi.org/10.1103/PhysRevA.90.043829"],
 "), the photon model is validated by splitting the elliptical field itself \
into two circular components, which can then be tuned independently:"
}], "Text",ExpressionUUID->"866c7d83-dd06-4227-8335-f9ac94f7b6fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rotatingBicircularA", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"envelope", "[", "t", "]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["F2", "\[Omega]2"], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "\[Beta]", "]"}], 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"\[Omega]2", " ", "t"}], "-", "\[Phi]1"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Beta]", "]"}], 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"\[Omega]2", " ", "t"}], "-", "\[Phi]1"}], "]"}]}]}], 
        "}"}]}], "+", 
      RowBox[{
       FractionBox["F1", 
        SqrtBox["2"]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "\[Omega]1"], 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Alpha]", "-", 
            FractionBox["\[Pi]", "4"]}], "]"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"\[Omega]1", " ", "t"}], "+", "\[Phi]1"}], "]"}], ",", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"\[Omega]1", " ", "t"}], "+", "\[Phi]1"}], "]"}]}]}], 
           "}"}]}], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "\[Delta]"}], ")"}], "\[Omega]1", " "}]], 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Alpha]", "-", 
            FractionBox["\[Pi]", "4"]}], "]"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "\[Delta]"}], ")"}], "\[Omega]1", " ", 
               "t"}], "-", "\[Phi]1", "+", "\[Phi]2"}], "]"}], ",", 
            RowBox[{"+", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "\[Delta]"}], ")"}], "\[Omega]1", " ", 
                "t"}], " ", "-", "\[Phi]1", "+", "\[Phi]2"}], "]"}]}]}], 
           "}"}]}]}], ")"}]}]}], ")"}]}]}], 
  ";"}]], "Input",ExpressionUUID->"92d62b84-d77c-4814-8b93-0ea96f82fc4d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DistributeDefinitions", "[", "\"\<RBSFA`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"directory", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Temp Data\>\""}], 
     "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"filename", "[", "\[Delta]_", "]"}], ":=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{"directory", ",", 
      RowBox[{"\"\<data 25.09 detuning scan at \[Delta]=\>\"", "<>", 
       RowBox[{"ToString", "[", "\[Delta]", "]"}], "<>", "\"\<.txt\>\""}]}], 
     "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", 
  RowBox[{"\[Delta]Range", "=", 
   RowBox[{"Range", "[", 
    RowBox[{"0", ",", "0.25", ",", "0.001"}], "]"}]}], 
  "]"}]}], "Input",ExpressionUUID->"9f592334-fabb-4643-9bf0-87b580be8542"],

Cell[BoxData["251"], \
"Output",ExpressionUUID->"338c3c07-a970-4d16-9f00-024ecec77ea2"]
}, Open  ]],

Cell[TextData[{
 "To test the validity of the photon model, we ran a scan over the detuning ",
 Cell[BoxData[
  FormBox["\[Delta]", TraditionalForm]],ExpressionUUID->
  "4d43b6b6-5db9-4e0f-98ea-8189dd7c8f8e"],
 ", using the calculation below."
}], "Text",ExpressionUUID->"16855b3d-0089-4545-84cc-abc475606324"],

Cell[BoxData[{
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Total = \>\"", ",", 
   RowBox[{"Length", "[", "\[Delta]Range", "]"}], ",", 
   "\"\< points at ~230s/point will be done at approximately \>\"", ",", 
   RowBox[{"DateString", "[", 
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "]"}], "+", 
     RowBox[{
      RowBox[{"Length", "[", "\[Delta]Range", "]"}], "*", 
      RowBox[{"230.", "/", "7"}]}]}], "]"}], ",", "\"\<.\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ParallelTable", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"makeDipoleList", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"VectorPotential", "\[Rule]", "rotatingBicircularA"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"FieldParameters", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\[Alpha]", "\[Rule]", 
              RowBox[{"35", " ", "\[Degree]"}]}], ",", 
             RowBox[{"\[Beta]", "\[Rule]", 
              RowBox[{"45", " ", "\[Degree]"}]}], ",", 
             RowBox[{"F1", "\[Rule]", "0.075"}], ",", 
             RowBox[{"F2", "\[Rule]", "0.075"}], ",", 
             RowBox[{"\[Omega]1", "\[Rule]", "0.057"}], ",", 
             RowBox[{"\[Omega]2", "\[Rule]", 
              RowBox[{"1.95", "\[Times]", "0.057"}]}], ",", 
             RowBox[{"\[Phi]1", "\[Rule]", "0"}], ",", 
             RowBox[{"\[Phi]2", "\[Rule]", "0"}], ",", 
             RowBox[{"envelope", "\[Rule]", 
              RowBox[{"flatTopEnvelope", "[", 
               RowBox[{"\[Omega]1", ",", "26", ",", "3"}], "]"}]}]}], "}"}]}],
           ",", "\[IndentingNewLine]", 
          RowBox[{"CarrierFrequency", "\[Rule]", "0.057"}], ",", 
          RowBox[{"TotalCycles", "\[Rule]", "26"}], ",", 
          RowBox[{"PointsPerCycle", "\[Rule]", "115"}], ",", 
          RowBox[{"nGate", "\[Rule]", "1.8"}], ",", 
          RowBox[{"PointNumberCorrection", "\[Rule]", "1"}], ",", 
          RowBox[{"Preintegrals", "\[Rule]", "\"\<Numeric\>\""}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"ReportingFunction", "\[Rule]", 
           RowBox[{"Function", "[", 
            RowBox[{"Write", "[", 
             RowBox[{
              RowBox[{"filename", "[", "\[Delta]", "]"}], ",", "#"}], "]"}], 
            "]"}]}]}], "\[IndentingNewLine]", "]"}], ";"}], "]"}], "]"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"DateString", "[", "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
    ",", 
    RowBox[{"{", 
     RowBox[{"\[Delta]", ",", "\[Delta]Range"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"NotebookSave", "[", 
  "]"}]}], "Input",ExpressionUUID->"db180b1d-ad80-4634-a07e-d213a846018e"],

Cell[CellGroupData[{

Cell[TextData[{
 "Total time 2h 32min. (Desktop machine with 8-thread, 4-core Intel i7-3770 \
CPU at 3.40GHz, 16GB RAB, running 7 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " kernels in parallel.)\nExpand this cell to see the calculation log."
}], "Text",
 CellFrame->{{0, 0}, {0.5, 0}},
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellTags->
  "Collapse-to-print",ExpressionUUID->"9a5c2c5b-0bc4-4a98-ab72-9759bbce1b64"],

Cell[BoxData["\<\"Fri 25 Sep 2015 23:54:59\"\>"], "Output",
 CellGroupingRules->{
  GroupTogetherGrouping, 
   10000.},ExpressionUUID->"3510aee6-7c00-4172-b844-07cbb1a45edc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total = \"\>", "\[InvisibleSpace]", "251", 
   "\[InvisibleSpace]", "\<\" points at ~230s/point will be done at \
approximately \"\>", "\[InvisibleSpace]", "\<\"Sat 26 Sep 2015 02:12:26\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Total = ", 251, " points at ~230s/point will be done at approximately ", 
   "Sat 26 Sep 2015 02:12:26", "."],
  Editable->False]], "Print",
 CellGroupingRules->{
  GroupTogetherGrouping, 
   10000.},ExpressionUUID->"8e4214a3-8ed5-409b-a6d9-cd82e65901d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"243.448912`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0bec864f-2310-4a74-bc27-6afd16f3c25b"],

Cell[BoxData["\<\"Fri 25 Sep 2015 23:59:03\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4c5a2ab1-dafe-484d-bec9-a73cc362968f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.907445`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8fd9355d-2b8b-4bfc-a94a-e04070e60396"],

Cell[BoxData["\<\"Fri 25 Sep 2015 23:59:14\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b0be45e1-42d2-4897-ba95-12abcb730d77"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.794374`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e70ee364-48c8-40f9-ae0d-085b2aa7ef21"],

Cell[BoxData["\<\"Fri 25 Sep 2015 23:59:16\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e27ce532-6555-4eb5-be54-92791e678cb9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.342352`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2f37873d-42bb-460a-83f5-1d36a83a1656"],

Cell[BoxData["\<\"Fri 25 Sep 2015 23:59:17\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f0583262-b25e-44be-bd22-2c737c0ebd80"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.439146`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"32ab106f-7263-42cf-a0e9-b6fcf50584ab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.496122`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7c23116e-9b0e-4116-853a-b88cc1588e8e"],

Cell[BoxData["\<\"Fri 25 Sep 2015 23:59:17\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3f9a0ca0-da74-41e1-a6eb-5c0076bad1c5"],

Cell[BoxData["\<\"Fri 25 Sep 2015 23:59:17\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b8e5dfd7-b114-4ed4-b4ee-650fae70d5cc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"258.157016`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"131ed1a3-54bc-41a5-88ea-1aa4e43dad00"],

Cell[BoxData["\<\"Fri 25 Sep 2015 23:59:18\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"94feae93-a147-4f60-8c9f-39b784e3ef0c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.620582`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ba37f50b-4dae-4dea-bda2-dc34bc72fceb"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:03:20\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5760bd04-ac6c-405c-a797-02df9c30e2b2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.176427`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8aab61d0-df10-4df7-abbc-163c896e3814"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:03:32\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"94a32055-2370-4a1a-8c3d-32d969dfe058"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.456594`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3dec8344-3439-4f8c-a27a-ec4cf38b7d81"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:03:33\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"fb60494e-6921-4862-8ef8-befba9e970ff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.85765`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3324e38c-0773-4fd1-bd79-83e04d1b99c9"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:03:35\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"11112772-9dc8-4155-979a-f4bc4d638989"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.248664`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a49972a6-23c2-4728-8069-db782ab2db60"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:03:35\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"161eba3d-1f81-415c-8055-b0742ff07464"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"258.549114`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a24bc118-2bac-4796-8c0b-53f27861abfa"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:03:35\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d1680ff5-7dd1-43d1-9049-360b92adfadb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"262.009637`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f61ed368-580c-49fb-8a94-84872eb96559"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:03:39\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"415faa06-21ca-47c8-9260-1a0ecfa06300"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.520138`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9cfa6947-f5b4-4fcd-b673-6eb2d9c8a292"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:07:37\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f8c39dd9-6136-4eee-a538-a9652f666146"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.312835`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9c2070ca-8995-40b1-a0db-49056afaa679"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:07:47\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"340be84b-6175-4a79-be00-d70343a9aad2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.303413`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"cfd2e9a4-e6af-4f01-b5be-4458b37bf66d"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:07:50\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2814dfe5-b939-439b-abc7-afae57befe21"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.504372`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5d7b9e26-8774-48c7-8e61-e271e9f89062"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:07:51\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f9369131-0dbe-42cb-8971-786ed06f0170"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.6762`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"149966a5-b98c-445e-91a4-1b72dfb2960c"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:07:51\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7f1f6162-bc68-4f55-8742-3111902b1742"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.885706`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"baa60cf2-a3c8-440e-b838-325f5746ee52"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:07:53\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"131a97b9-dd2a-404c-ba7e-e406e4ed6771"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"258.437622`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"36ee8db7-d5e0-4b84-a210-f984716042e2"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:07:57\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"bb308c39-10ff-47be-9603-be19113f8f13"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"259.004569`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"939ea807-e4b6-4adf-998a-395f08c6db3d"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:11:56\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d5bd7b89-e955-4e52-b8a7-3340c863aae9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.526246`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"424f525f-1ccb-45f4-97af-352edabdfa8f"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:12:02\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e83013f7-e6c8-4453-99ec-9dc6f6bb621f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.989434`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8986ed71-0d7a-4bb8-ab75-cf8bc26ebfe3"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:12:07\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"aa57eb5a-e2ac-459e-b6e3-4a93265a4d7c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.397658`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b1060534-07ad-44c3-81c9-5aeb55276d36"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:12:07\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8d882394-751b-4a6c-9f64-af267a2f03e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"258.372834`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3e5684da-bc2d-4835-af84-89237cbabd15"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:12:10\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1f68af85-f3a3-4467-9d13-db5bfda8f0d8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"259.410236`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ebbed109-9efd-4e13-ab46-73783a5afc42"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:12:13\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"66c97fdf-624c-4afb-8fce-16ab883bcacc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.385829`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0d3fb7ad-1791-4fb3-b96a-43a558a1e940"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:12:15\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"37633fc5-3f98-4c17-87c7-e72a6a3a61d3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.567062`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b6d1ee81-48b6-4850-bf18-b7022b68ae96"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:16:10\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"451d730e-4354-45a1-8237-bc75a7afabc7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.773009`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a7436f6a-66d7-4a07-8bd6-c1414f3b94ea"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:16:19\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"bcfb23b1-a065-46bc-b332-c845c8472db4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.932478`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"dbc9bef5-22f2-47a0-924d-a55d39f0fcee"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:16:24\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"37ff61b3-62cc-4bd1-99e4-3ebb794b3a16"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"258.163606`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b3a45183-b7f1-499a-b501-0aaf58ee5ef3"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:16:26\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e4b581bd-356b-49e4-a6f3-761a4e8c41c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.856922`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"55e09742-2c44-49bc-8b32-dbaa25ef9150"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:16:26\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"892f2099-56d0-427d-93c7-325649e513ac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.819242`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"04ee5189-320a-435d-a3d1-cf676368e17e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:16:32\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b372047c-c9e8-442b-a756-874f3b633498"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"260.328878`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0c691b26-4fdf-406d-8e4a-a86c28ca1815"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:16:33\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5497007a-bd9c-4185-9105-fba7a3a93479"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.694937`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"80183acb-b837-4b2f-bcac-59884053b831"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:20:27\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"821b2cd8-c7ad-4f1a-b422-ea7f664978c5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.694126`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"149cb6b1-f4bc-4947-b240-9e99c7193d57"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:20:34\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"78d0dcc2-0f04-46ab-abed-e43adc5e6fc9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.261593`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2eeb0768-f0f8-4a29-8728-5cdba2c9a610"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:20:42\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1177b4b1-5666-4998-930d-ec6b8fa175c8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.647727`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"67e46121-9428-42f3-95a1-6329a4483283"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:20:42\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"afe38561-0997-40fd-8a0a-32f9f1efd5a1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"258.688424`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3e60a331-1d85-4ced-ac98-fbe91764b7e4"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:20:44\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9d5c6285-53ff-4ecf-b226-367733d97106"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.148369`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f9a1f100-e97b-4df1-ad23-0318663e6ebc"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:20:50\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"333c108a-dbbb-430d-b6c3-c2944f907ca5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"260.137872`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"bdc96819-913e-4491-821f-43f4a009cd39"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:20:52\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ed9f13c0-acf2-4a4b-990b-96add4df813e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.577399`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c7563df3-35e8-4174-8d87-883d40ea5b68"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:24:49\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"cfc7d039-6726-4639-8ace-d26b23cf3542"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"262.370377`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"93f04846-8f08-4068-9137-491f5ae561c6"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:24:50\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f71cb96f-d56b-4781-a5d6-d221f67c8076"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.262716`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e9c34565-d3e5-447c-9afc-fe4815795559"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:24:57\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3e48ea25-7132-407b-b916-64b551e8f238"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.928757`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b9053711-879b-4a85-b61a-07186ed0ba7b"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:24:59\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8da448e8-bdf3-44c8-ba40-ae61066a6937"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"260.328953`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"452b479e-1f33-478c-bbfd-142ae319e0eb"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:25:05\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0458ce9b-6a3c-47d5-a287-5e2d96072fd0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.806958`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a8f73e13-5b43-4e04-bba4-554c4aec4d20"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:25:07\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"aa13092c-e281-4fa8-a9a5-caf3016690d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.474374`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5537ced2-e9c2-44cf-9e3a-2963f06563e8"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:25:08\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"11d640b3-a0a3-4c68-b496-6ae86ca28a11"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.524414`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c7cee7be-05a8-41e3-9d8c-8921b0311479"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:29:04\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"39790d82-855c-4f2b-b096-66d3e8391187"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.079931`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0855faac-2a51-4183-be7c-342897aaee04"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:29:07\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6a388ab4-250c-4606-9c3e-8907325069e3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.669247`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"05f0d6ca-f2f4-4a89-a5fa-69ec5235563d"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:29:15\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5453a520-2c73-4eb1-819e-385489af1f3e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"258.810467`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"52f79cc1-9b6c-4957-87fc-5df9e7f6687e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:29:16\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4731ae21-832f-4202-b27e-a8ecf959da03"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.721105`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"958c1fd2-e540-435f-b5cf-b94e500d31b9"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:29:18\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ba441f03-c1c8-4567-ab36-35c7b4140bbf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.744484`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9956c0a7-b9b1-4120-b13e-23678e01e230"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:29:21\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e496213f-a41c-4b2d-84de-868b39c21ced"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.036654`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e7d270a0-f3de-4bdd-a34b-e5aa9646f9bc"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:29:22\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b3549551-a95e-407b-b268-c122de928124"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.339281`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"db4e256a-86bb-4c4e-8fe5-2ba66bfd17bc"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:33:18\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7b723a6f-ccfb-4a58-a9cd-8845bb6126a1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.705924`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5cdb9069-fa13-43ca-a31c-b48036e9c2a9"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:33:22\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6561af65-9102-4725-87cb-c9e0f4aeac0b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"249.275424`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"bf5d5366-c1c7-4940-a991-b3ec779926bf"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:33:26\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4289210f-d017-48dd-b6a3-f3d26bd98478"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.394245`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"24109beb-c7b3-4104-8bd8-b4539a86db77"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:33:28\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"912b0ee3-c42f-4fe2-b72e-6acea07bff1d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.763734`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"37e90baa-6ffa-4064-8cb6-d74d479050b5"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:33:32\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b573aa85-424e-47be-9130-7956739eb59e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.285869`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2663de32-02b5-4c0b-812b-6c32368546c2"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:33:34\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7fa57c05-9771-4478-a382-ce7fafddde4d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.998896`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"23448782-68fd-4dab-9154-5d53c2de8e81"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:33:35\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"daffe2f7-5ef4-4ea4-914a-040fefb183b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.872064`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f20ecf62-5cad-43cf-b18d-e504b0271521"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:37:30\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"eac7b51c-7b1b-431e-95af-0105d07f028f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.841317`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4320238f-aef7-42a5-8e05-e0b5025de5bd"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:37:34\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1683c51b-30ba-46e9-af64-8967d41ce104"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.07051`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"020c9973-da66-42a9-9a08-a8e39d18b9d9"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:37:36\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"481ed3ec-7953-4098-9acf-8b3800013c93"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.216104`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"05231e59-84ee-4756-b877-4be813297954"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:37:40\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"264ed10f-1979-4bea-8bf5-566457866fbe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.313424`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a2f79bb8-8465-47c1-a521-85d66d323a3b"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:37:44\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1feba1f8-48df-41b2-89d5-3e35be422cfa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.187552`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9e212464-0f60-40c9-9d4b-67afcee91298"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:37:45\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b38aa7d8-c401-462a-8d8b-ffd8c7ae1094"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.910858`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3909c03a-d88f-49d4-807c-a34a511ac358"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:37:49\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e8ee59bd-3874-4695-8b47-f7c2f5e1de51"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.658139`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"58c8948f-58c2-4b9e-b7ed-3e87e4393dd8"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:41:43\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f0e768c0-611f-4148-8fa7-631f04421a03"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"249.29132`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"dbda3466-c53b-4a06-b249-d1370787d6a6"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:41:45\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6468b735-2f32-46c7-acac-649676ab75dc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.750036`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2d630243-f81b-4f5f-9637-667645655e95"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:41:46\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a14b90c8-b148-42ac-b53f-31af2a5544e2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.848327`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"227e1ea4-af23-4c33-ba48-83ce59865275"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:41:54\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"08dfc7f7-5f77-4a50-8e71-b84791dade4d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.809672`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"07d05398-c97e-4444-a7aa-0c92a2327ef3"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:41:55\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"13e7bc10-bace-4928-ad02-88efdf9f51da"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.740743`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"270e7c24-342d-491e-98ea-06d4f144c5ee"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:41:58\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4afd0ebd-d3d4-4bf7-9d88-72ccdc29830c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.087383`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"80c2f883-e4b7-4c0b-a829-d734093fd50b"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:42:02\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a93219e6-94f4-4f12-bf74-ef55619ad867"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.428689`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4bb9199e-f93f-434d-af06-169d5a020b8d"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:45:54\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"aef827be-5ffb-4d4f-9eb9-be025c09d560"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.527468`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"254dda16-96d2-4fc0-839f-f2dc73db8782"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:45:56\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3abc4810-ab83-45d4-8948-06b0da57bc09"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.764517`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"cfe1bb33-708f-4708-accc-9fa2802d7ea8"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:45:59\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5d3f0a7a-e605-45c0-86ec-30e15cb5c028"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.482346`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"30d57c7f-602d-4a8f-802d-10c5a1747da3"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:46:07\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"42523f83-d019-4acd-b079-d52f319b0a83"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.130429`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"36ebf272-c36a-4a57-820f-e5a69bd4bf52"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:46:08\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"18a395a3-731c-44d9-9590-d6fd0d20c885"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.40936`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ef438757-5902-46a0-be04-601aa5138c3a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:46:09\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8caa20b9-0687-439e-90c9-308ac83ee734"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.257937`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5af1ae5f-8112-4fad-9a89-0c36c6bf2b63"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:46:14\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1c346a58-1c5c-450a-865e-8ea8008aadcf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"249.625987`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"70fb850d-96fd-4c21-a54b-2ee073c20b87"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:50:05\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6a075605-c19a-4c62-984f-8157d3307790"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.681178`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a2ff6dfd-e1fc-4446-97ce-d1330fbc709a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:50:07\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7795ea53-3ebd-43a6-8966-6583069f55f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.079441`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7822936a-0b09-487f-9ca8-dbef087be2f9"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:50:11\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6b978c68-a983-44e7-bd95-442c0cf6ab30"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.279725`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"cf75b504-096e-4c0b-a3cc-c34e1fb63e0a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:50:18\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9ec99f17-3855-450f-a7a5-169036596870"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.295498`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"30ba46c1-6359-4c04-ba5c-bfc356efeefd"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:50:19\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"da7855b0-eeaf-468a-b0a3-b4ee89314c6d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.678413`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"32d32909-d89d-4cbc-aca3-8c402586b997"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:50:20\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"68f4686e-956e-45cb-b012-180ca325fbbb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.41357`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"dec05be2-0064-491e-a011-d94d2848702f"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:50:27\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3b802e21-3536-4e2e-bf8e-26729429d035"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"248.014341`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f9a6dfe2-3bef-4a29-b697-c1fd5aa8d70a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:54:13\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8f5a13f1-ec22-4182-9b9e-076af91c380f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.171364`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"517b4ff7-11b3-4e22-9605-16857974cd5e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:54:18\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"37e64740-144a-4959-afd6-3e595dda6f57"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.742788`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"81571112-689a-407e-b0a7-27bc7f3c593a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:54:24\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d448076a-cb63-4e81-98f0-79ac86bc3bc7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"248.420464`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d3a90c37-f36c-4bba-9b1b-cdd6bd4e0c3c"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:54:29\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a64e08b1-ca7a-4e77-911c-60b5f8fa6b85"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.651405`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"982780a3-c476-493d-856f-4919b6fb1044"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:54:32\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4b3295e9-5ce7-4309-a1a7-27cbd094e30a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.747107`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"fed70c36-8024-459d-87b9-5d384d189dca"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:54:33\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"978a2214-63dd-45fe-a86e-389456fc32f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.036022`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"47b6b312-bb2b-43a6-a60c-a77a59218ebc"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:54:43\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d833464c-e6b1-46bc-980a-33bd4723b366"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"248.918139`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0835d0ee-0d56-47d3-a8ce-8605a37076f0"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:58:22\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4bd51145-8831-4ed5-8979-1efacf2fb0d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.22964`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"699fcbc5-ad53-4fcc-b72d-34d7b2f4a44c"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:58:28\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2b984031-0081-4b84-9171-f4efe42d024b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.975975`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"03866a24-25f4-4157-8fb0-fe3db3d1d909"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:58:38\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"11f3b5d6-e6fc-4016-9171-78a77bd07c1e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.674235`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"87f50808-3fc3-4dda-a017-6d7438bba13f"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:58:41\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"184088c4-ae51-4819-87c1-57171b4173e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.011086`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"78eff1bd-b56b-4e90-a72c-ab19df696492"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:58:44\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c491134e-2e9b-4745-8e3f-1ec5640b5b7a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.236936`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4010505d-e5cc-4bba-bcf6-b1cc28c8ef28"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:58:45\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4f61349f-81c1-4d3f-9242-02fda7b86d6b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.192517`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"76d53fe9-6607-485a-885c-fd56288a3b4a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 00:58:57\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0b06e733-b4c7-42e9-978c-ac67487ce61d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"248.800983`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a0d98645-c8f1-4373-bf05-c026874546eb"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:02:31\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"77599755-da58-4a8e-b13d-440dc7b6e514"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"249.892205`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"fdca401e-e747-46c8-83f7-6f109233fcf7"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:02:38\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2c6ec767-3333-4077-81be-678c171c6310"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.765551`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"54f8db63-f0ac-4635-8fb3-bb6dcc6aae24"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:02:51\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"63e5383e-b651-4593-b3ab-2b85dce12d16"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.716358`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"31823c84-bb44-4bf2-895d-1ee8f058e4eb"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:02:52\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8b65165e-5458-411a-8093-57794138a27d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.986151`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"76f22206-bc4b-450d-8d8a-c662f9d65ba3"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:02:57\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"46c8c2fa-1f58-4a23-b890-0b09d33b1e96"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.294456`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d6524fd4-c1cb-4b05-ba5d-44fdfa952a19"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:02:58\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"209e87a5-7776-4d0e-8e21-5f78a66a80e3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.338874`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c6a66dc8-9b3d-4cba-978d-a003d18942f3"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:03:12\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8d4fe5b0-e20c-4c37-87d8-104829dc185d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"249.249488`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"abc7aced-b37c-4cd7-bd0f-3597a47bea20"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:06:40\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6ce98f16-90be-4f6b-a68e-a61cb65c97d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.65053`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c097cc85-64d6-4598-8ff5-bb3524d336cb"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:06:53\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9413583e-f47c-44ba-89a6-59759fe17b59"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.018626`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a6a6c928-4adf-48da-bfab-78bb724936f2"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:07:03\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"451b225b-3a1b-4812-9a56-a52c974c757f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.431514`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"65d37782-a233-4085-8548-82cbb9071e1a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:07:04\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e49390b7-e9e5-4a30-9790-7d0bd1d208b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.608836`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d066a90c-2243-4298-8a14-8d9ae00c12ba"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:07:10\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"117ec84b-3a04-4a80-a02a-7e5bfbb8f745"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.379334`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e42a839d-bc72-469c-b05b-02c30e984298"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:07:14\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"fa938592-7fd9-4b32-971f-73f820939434"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.539732`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d401f745-b42f-472b-b9b6-07ad06295c5b"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:07:24\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"846e5ccb-9854-4150-96b7-57ccbed9c453"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.084146`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"88b36524-29fb-43a9-813a-656cfab79ff1"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:10:50\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"36b3ea4e-194a-4d94-b52c-99f9dd2d244a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.435567`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5f3d0015-2828-4a91-b03a-c4a2cedf6e77"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:11:06\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0bec7e49-2a23-44c6-9088-ccf81ef80531"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.095287`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"442b6fe7-22d9-4e54-8046-08119b1bb363"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:11:15\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"bc18ba2f-2c3a-45f0-b792-2c87e0604145"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.333439`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1c3caf69-9e26-404a-9167-7041885719ab"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:11:16\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"47b223ed-5297-4544-ba9a-8042e7972862"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.521586`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4d83d878-9d86-405d-a9d9-e6cc72c2a8e1"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:11:20\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ba4484e2-140e-4144-9f87-1b1e4fd265d5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.203941`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4bbe4d12-399d-473d-be18-beff84ce9e2c"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:11:27\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"bc01def3-fcc7-4aa3-a1f5-f3f8dfb3081c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.570933`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1c8e1239-3fdb-42b8-ba36-bf3c533c3791"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:11:37\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b63194cb-e282-4d11-bf48-b006c04f5722"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"249.371184`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4f7ec813-4514-4207-a5ea-69aa15464c2d"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:15:00\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"bfc3e199-daec-4bce-a40a-c12656d092d1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.510073`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"950ddfea-6e01-4309-80db-021ec289d883"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:15:20\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9f6fc1b8-678e-4a6a-8be4-4c1f2b0ad592"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.335639`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d61d5b1c-4173-4cd0-8879-455aa1b1a9c1"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:15:29\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e88cc813-aaf4-4421-94ce-238068605cc6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.651681`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6f2561a7-5c7e-4a2c-b2e6-f38a323f4e8a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:15:30\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f142d274-01b6-4b7f-806a-1b1a06a48a4c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.302282`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1e0e8620-84d1-475c-975d-a0f40179564c"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:15:37\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"666dd771-af0c-4032-bc5d-5112739507fe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.930026`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5175d8a8-82b6-4a2c-abe8-08ed966cbedc"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:15:40\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"74a3ba6a-b95a-44dd-817e-89ba28e3bd5f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.633715`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"39aaa0f8-af3f-4bf8-a542-946f84b8c681"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:15:51\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f0708791-5490-48b4-87c9-7997c1c6ec46"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.118737`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"768436b6-d6fd-4423-bb6e-bffdfee59a7e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:19:11\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c6363933-de8b-4acf-86d2-5d1ad058884f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.183295`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"78c89e16-9460-4393-92e5-d900a146b8e1"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:19:32\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0c7e098a-21d1-4421-aa77-9b55b3cd61e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.577172`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"26e795b3-c337-41cd-bcc0-c160cc2c4198"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:19:41\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"12beecb1-b12c-480f-bd46-cbce1377bad8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.152332`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"871c3981-1a24-4927-929c-3c922ec6ef50"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:19:43\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8d394e47-beb2-4cca-a22f-cd85959204a3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.266767`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b4b1cc9d-769b-4b4b-9445-abc324b41a1c"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:19:49\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ebc216ab-9989-4b37-a984-f28101da7cb9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.02487`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ce13f785-609b-455f-8c0a-1feeb8c3c154"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:19:54\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3249dc79-949a-4563-9130-693e50f333b1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.914114`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b5f61ede-5f3c-4097-96cc-afd1c91ef8ff"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:20:03\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"80383d7f-8475-42b3-8cf7-9ba59015644d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.455444`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6d78c293-835f-436e-81e4-66171fb8a5a3"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:23:23\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"cfa8cd06-e7e3-4826-96cc-69d88a7c13be"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.66453`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d2a19a54-be69-4bfd-8afd-c4c72f4f4dd6"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:23:45\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7aaf94a7-6a7d-4f12-af3d-9ae2db9a1508"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.912521`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7646e381-7e0d-4790-bbd0-f433af248e7a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:23:54\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b13a5aa8-da0e-41b3-9572-f30b4f73f86e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.737071`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"28dcb788-dfb3-405b-9e93-6ea81c3ebcdb"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:23:55\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"dbbbb0df-e854-45f1-81e3-5d736f53253f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.654702`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f1d6cc9c-2586-490a-b080-e6c6e418e7b5"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:24:02\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"fff47998-dfe9-41f3-b410-d8d920f4d861"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.642582`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6df35cea-390d-4f59-832f-d02a8b76c861"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:24:09\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"50e803eb-70c8-47fc-b9c2-824cfa5103da"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.561458`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6e2b7563-2baa-4734-842c-3165ee05105e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:24:17\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"98680cc4-0d92-46d8-a117-a128f27fdb9f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.303804`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"070b4c06-7f09-474a-b457-feb02582ff9d"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:27:35\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"01cb38ab-c86e-4003-8795-1a09b13b5179"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.381348`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"aba96ba2-1079-4dc0-8693-8c43d26ecae0"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:27:57\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8e102b47-6342-45f2-808f-a6514ea880ff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.911619`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"259714d5-0699-4e3e-ab40-3174511d9983"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:28:06\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"fe32ceb4-0ab1-45ee-96f4-e8423ea49319"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.388937`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a736c6e3-6867-4e08-abb1-205690445c15"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:28:08\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c54e4fba-d693-4bd5-a6b1-28b07e8be06a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.540439`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c74790e1-86ed-4408-b954-7e904803dc3e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:28:16\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9c09ae64-3111-48d2-b9a9-4e0f6111f6f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.446531`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7a5a9884-c322-4cba-99a8-b8716b803b48"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:28:21\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"14db0406-14de-45e0-b4b1-6f23cbcd2d63"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.940815`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"46beae28-ee8f-4ff4-9dd0-fd1c83c06a34"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:28:28\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a7e22325-e190-486c-8770-6b9abea9d4d8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.042058`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"266264bd-e4d4-4136-bf2b-95f753a291da"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:31:46\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4377b7ab-b688-44ff-adc5-ca0708258b41"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.257612`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"db8a6177-5b3b-431e-b8a2-87b0b71d7cb6"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:32:11\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"44e7252b-0dae-4080-bc27-cfb8e488c84a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.693019`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a3db8424-15b1-4c5f-80b3-b4a835ea19dd"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:32:20\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"380bccb7-7742-47f7-8adf-c4ba0b5fcab6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.796133`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a06773b8-ddbe-4427-aaab-0419fdf6a656"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:32:23\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"dba7f183-63d6-4eee-a1e5-3bf0509a97dd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.291635`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"75ae754c-9d59-4156-8960-253063a99532"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:32:28\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9530423d-9f39-4e75-9eca-c38f7871d425"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.497629`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"605ffa7e-761a-4ef4-b0b8-23b080ae9081"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:32:33\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"25bf89f2-228c-470c-9329-fe49884bbe1a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.874367`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"746e32fa-b0fd-4104-b493-890fdeb7ea4e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:32:42\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f9164daa-2344-4c94-92a3-d7873729ce87"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.816531`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"31dda24c-a694-4031-8256-baddd446309e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:35:57\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"72b63996-9bd9-4e51-bee8-101e1c39c83b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.01709`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b0c9f241-0302-4e1d-b780-3d482bafb18d"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:36:25\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d97a8630-90e5-4e40-b08a-dfff97ecda79"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.890073`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7ccdcf7c-428c-4a5f-95a7-4222127e892b"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:36:31\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2a2e4f67-6da4-4e7a-b904-94633f64d779"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.440507`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2fda6804-f304-4725-83a9-a138b85232df"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:36:38\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b255ceb6-a875-4a7c-8490-3da4826520ab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.566027`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"83f56c6b-f2ab-451d-b447-41d8ee9a2aee"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:36:40\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b857737b-4161-46c0-8113-47cfbe7867c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.020455`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5c560d4d-3a6e-4adf-826e-9c08c02cf0e5"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:36:47\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"90a0b577-9a8f-4ea9-9284-0542fdf23eac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.732616`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9c01c9b9-4cc1-4864-a51a-c790117b62d6"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:36:56\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2f4d21b1-352f-4006-a856-62375887b450"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"248.917219`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9e9dc167-98bd-4842-96ac-3b16404a013d"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:40:06\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1ad1806a-51fb-4e2d-8c38-f30782bd88a9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.298007`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"35a942d1-851c-484c-aacf-37e2edb736b8"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:40:37\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"de6bbd2f-f75c-41bd-8b51-730c9ea11143"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.613887`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"98ac1a06-2409-4812-b447-72d316065e69"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:40:44\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3ea762c2-7f8b-489b-b1b5-509a5d86974c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.666471`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e157a2e1-4862-470d-9615-7224c11e4390"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:40:50\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7627b8fc-a55b-4f8e-977d-30d7e8c4193d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.123358`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"cf0d6d46-ced3-48de-a03d-89c5e0aca11e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:40:55\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"cacf7d4a-9dbb-4c5f-a05b-79cf79f4348b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.492661`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"69635d9d-dd46-44f0-b9dc-c947ae7044f2"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:40:59\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7067a24f-7498-4035-b8a3-2090cb0d7478"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.390183`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2a73ef8d-b154-4a4d-8fba-449d77f01394"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:41:11\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"970f617a-17b3-468f-b175-71c05a299d89"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"248.750869`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ba680bc7-3e8a-41dd-b0e4-3421cf8e8f96"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:44:14\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d7d45f30-d14f-4412-b40b-d4724f68376e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.426556`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1598ee9a-b70f-4797-a1ff-1a5d9752f563"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:44:50\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b15bf51f-2c2b-4520-baca-ec044a5f3ed0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.3594`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c5b23caa-aa40-4a74-8ea4-a61e33723846"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:44:55\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"876fdcbf-0eb6-4180-9a83-770f85604a07"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.602877`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1bcfe162-710c-44fd-bdfb-f25ae5f09897"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:45:06\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7b156f1d-7630-4b46-939f-381d3cc16153"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.842904`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4f486918-3291-43c2-beed-cc36b206d9d1"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:45:08\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"391d50d4-2e9d-409e-bfe0-ef3cbdf9086d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.434333`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5834bc57-c25e-468e-8f5b-0919ec4626a6"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:45:14\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"240b9a5b-4c90-4e7c-9cde-772144030d74"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.935705`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"43a8537e-d5e9-4ad3-972c-790ab98e9e07"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:45:25\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0c1891b9-cd5d-4e9f-8641-2a2f08c0f1ac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"249.488888`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"fd03b175-816b-4cdf-be99-fe6580a55fa6"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:48:24\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3116eb29-b318-4ebf-9135-33fa2e6f2533"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.6092`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"26306e93-4584-4210-908d-6b4243285d32"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:49:05\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4698e491-b41b-4702-af34-55353531d758"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.490376`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a882563e-63f6-4048-976e-357b30cceb8e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:49:07\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d042d038-2f29-4384-8db5-a38a2f98fde2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.408527`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a6ab29a3-bdaf-4a92-a18d-b21132068d3b"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:49:18\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ee0ac29e-2f2a-4dd8-ba26-1f0317bdd03a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.696006`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4c990736-81a1-4998-844a-666df8461680"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:49:23\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"13253cd3-60b8-4634-ab07-c3a6d5a6bc07"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.176803`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0b3d34a6-6f14-41b8-88a3-8677ab510f8c"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:49:27\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"dc9df5e6-7ada-4d58-92ac-2374750a529e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.789313`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"84a9f888-84d7-47e6-9c9b-baf7b25e5455"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:49:41\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"abecdbd0-08a4-4b11-b55d-45ee6090eec4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"248.620495`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9cb9b605-5fa9-457b-95fd-ad5d2de27898"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:52:33\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0ebf37ce-0466-409c-9d69-c5d2fe9b70e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.659536`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"397ecf09-d095-43e9-9f18-75a287d4ec01"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:53:20\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5813efc6-1c01-4b9d-92f6-5d7afc8bbb92"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.740046`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ac0705b4-d1ff-48e2-acf0-2606c89f3ade"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:53:21\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b6f9753d-73d1-461e-a391-b79d547f0284"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.780459`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1d571762-584f-411c-812a-c6cf14c1d0b2"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:53:32\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"fd5e77af-bf49-454c-b233-c708c6b0c6ae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.811378`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4020fa46-8341-45c3-a439-86fe575521bd"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:53:35\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9bc4ef36-b021-410a-a8dc-9002dcd90721"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.04167`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"54288a74-3913-42b4-8e6c-b369db633b70"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:53:41\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8520519c-dc7c-40d0-844b-ee411208927e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.370851`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f6898914-d816-4734-952f-25a3869c0d73"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:53:54\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b93e2ca6-ccd5-42c2-bf6b-9933f5ef4954"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"249.14311`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ca4d5f6f-970f-4348-a994-a4b60b92da86"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:56:42\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c2eb26f7-bede-4bcc-a9c0-c8abfb61f643"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.543809`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"19f4f5ec-83ca-45ac-a0ea-5bc47efe95a1"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:57:35\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3637e324-4cfb-4394-8b06-669ebc171aa4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.728117`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"18372805-353e-4f9f-a734-4a81a4e4ead7"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:57:36\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"687c9386-1677-4253-9e35-a2afb52cb60b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.228663`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1f01eb8f-2a17-4697-b175-947d144a4e13"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:57:46\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6c52fce3-b553-490d-8eeb-fdddd9817075"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"257.017031`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"cdc7cc5f-3c5b-43b8-9c52-6ae2715c90ef"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:57:52\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a8312a7a-a6d2-4c4f-a0d3-6ee0d50257f8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.003876`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b3f398ae-52f3-4989-886e-d7e72e9b7a99"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:57:53\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"76be16f4-8d91-4082-9dff-301f236c16fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.533386`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"056a0895-d768-46fa-8ca8-b65ebddead51"],

Cell[BoxData["\<\"Sat 26 Sep 2015 01:58:09\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"79bb97e8-4f88-4f02-867a-a11c310cc2b0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.019084`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e5afa2a1-d0fe-4f9e-8ec0-eea5866f4314"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:00:54\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"58803356-bffd-4dd5-a68b-af0de092027a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.880824`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"157d7ad8-b99a-4b08-aa4c-d8383dd23a2b"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:01:47\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7a73738f-664f-43c5-9b3d-7138eaa8396a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.105121`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"87b7dbd7-5604-4d5c-bb78-2a1823ac4bd4"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:01:48\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"cb211080-1e83-4164-8652-114a4983a015"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.961419`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"75885c1c-d88b-4253-a46f-199761ecef76"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:01:58\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"15ba528e-174b-4711-8f6f-7dd6622a6f83"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.434954`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"56a2850e-a3b9-4841-90a1-d674ab7cc907"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:02:04\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f3356538-2be9-444d-b4d2-10c33b38ffdf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.185605`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"fc5be600-889b-405d-9c2c-d8e132ad1430"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:02:06\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2a1ba761-9218-4488-9aa0-bafebac1097f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.601893`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9b4f3801-f37a-4894-ac40-273e175fae91"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:02:23\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6db9ed70-a109-433e-86ec-62e26450499b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.084011`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"028f5e8b-8fa8-4b22-a926-10ed5dfc321f"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:05:05\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5da9c56a-fcd7-47bb-a8a4-f8f4a688d652"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.269689`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0854bda5-0a96-4b74-8dba-6022e05677e1"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:05:58\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"645efaae-1ae8-45fb-b3e6-c9262b13547d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.044907`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"67054ffd-fe18-4855-b41f-d68e5ffd5ef6"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:06:00\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"60257e56-f921-4195-9d12-12377432033d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.220616`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a6764b15-a447-43d2-a867-12b91d33f15a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:06:12\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1d643d36-0589-421a-9c0d-051bdd29c984"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.595705`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"6ed46ed4-20ba-48a1-b11c-7d1071e64102"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:06:20\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"01e9ddd1-02c5-44ad-8f29-1ce14631436e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.951213`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"35efa807-e65f-4881-b675-78fc90e1e3c9"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:06:20\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"52a2f6af-7068-4162-91a3-d6bfe30b0593"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.577431`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"08aac812-6c2f-419f-bd66-37fce0cd2a98"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:06:39\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b2f03027-20c3-4f8f-878f-e46a34efd439"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"247.56846`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ae39dc59-46e4-4217-aff9-7291f1bd7aa0"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:09:12\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1c3093b8-a99b-4d22-a4bd-1d6563409554"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.733683`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1df36dca-2eeb-4141-a666-bc2cd588fcb7"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:10:10\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a00b639a-9640-4a92-aab3-82d0f2eabcb5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.616053`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ea024aa6-ec12-4c09-8c3e-a2406184de55"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:10:12\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"4b252bd3-5088-4276-9d3c-e9c6060ee8e3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.626898`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"53ca93ed-43d9-4092-9790-6520080648be"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:10:27\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2de6bd1b-3547-43df-a571-2fc4ee827611"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.522796`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1ef04be3-5336-4c12-bb6b-23d3652b2936"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:10:32\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"1c719ab0-8f87-4277-ad8b-047482006227"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.796011`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9624cd11-dec8-4132-ac82-d87d3a69d1e8"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:10:33\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"377a536c-641b-4a9a-b02f-8f2083c88ecc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.219431`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b8574a5d-f6dc-440e-95d4-1dc2577aa5bf"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:10:54\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"bcf61f07-e902-4b1a-8edf-75c60cc84410"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.550777`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f6739467-e732-42dc-a715-2f93bb8c9619"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:13:24\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d0c19fa7-840d-424b-a1cb-2b34d80611ce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.663551`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f6327c8d-e725-4104-99d4-9c06068d5e97"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:14:22\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ee78769c-fef3-416c-84a6-3a1ca1cc7098"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.936186`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8428323b-775e-4e93-9e3b-c8ac90486372"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:14:26\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5c18c051-5822-48ca-bd0f-986b5966b2c7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.517745`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d3e6c27d-9518-4f52-9651-ea1e77856aec"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:14:39\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3caad0fb-7338-4391-898c-93e79e1f9679"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.396745`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"798f20c9-2bab-4d1b-8bf6-6bedf4a51b13"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:14:46\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"bd22ba15-8b3b-4df6-9638-176dcece9700"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.64801`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9eecfc62-a86a-446b-b6ef-50e6b2021022"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:14:48\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"f3f40fd4-16d5-49b6-930d-db6d91487319"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.288592`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"8b8aedb7-d128-4a81-829c-a9536e5c6ff5"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:15:08\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"22024025-3d75-438f-bdc0-0b2687d936b4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.790448`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7c6c9a87-f95e-42ba-8ab4-9a3883499802"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:17:37\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"24aca60b-b071-4285-8cf6-0dc140d9b594"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"252.897188`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3fafaa86-8ba3-473d-9b52-dfc74a5b8ee5"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:18:35\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"26e9fa66-349b-4877-a0f0-fc853f0ec3eb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.918886`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7ad92b80-bdcc-42b4-b36d-af5a90d4727c"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:18:43\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"403576c2-20c4-476c-8cd4-b61b01b4409e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.880464`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"ac50a036-48f3-41e1-9102-78f572195ef8"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:18:53\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"bb4cdea5-3d23-419e-bce3-661a745b2272"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"251.461121`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e8cef033-4b04-492b-b83a-1c29e611c2e9"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:18:57\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"7a71bc6d-e4de-454c-a70f-a9d50314c7ff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.058344`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d59721ca-d951-453c-8d50-e3b2bd7be763"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:19:03\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3b9e22da-e6c3-4c6c-a133-3668b592c1c4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.170901`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"73585003-741c-42c7-b028-f5009a4a15f2"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:19:22\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"a8ec8fcd-9e4d-4590-acd2-c9f22f589b92"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"250.37803`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3639e8c0-1d30-4fb2-82b2-327b3743a488"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:21:47\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"56232648-7a87-4c67-b9c5-f7e07d3d75d1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.34619`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5df1995b-e4cd-4f84-8b9a-97c5836c0dcc"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:22:50\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"340d5e23-dc31-44d6-a586-4b71ea06aba5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.272481`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"729d0ece-c1cd-4c10-ad73-3da53df88a56"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:22:58\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"08147c7d-a777-4afe-b02c-e33c454b88ba"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"254.574211`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"befbcc09-241a-4b25-b164-8c71e923a5cc"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:23:08\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3ce56fa2-997a-498d-b7c0-3c4f631ebeff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"253.244652`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"2eb4b7ed-4373-45a5-a61c-2690b35542e3"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:23:10\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"09211e52-789a-47ea-a31f-632fdda61529"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"256.74748`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d4033e71-a582-4385-80f6-5e0c0a2cce25"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:23:19\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"557df8d2-0bd5-46df-8a2e-f2a17f57fb41"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"255.070243`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"baf6dffa-2da2-4d4c-8fe7-e1979ceae72f"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:23:37\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0920d089-8106-432c-b939-6c2abb8d9018"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"241.296461`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"b0ad0ade-987b-4ecf-9627-d51a0f1c914a"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:25:48\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"e9aa510d-2de1-4cdf-b2e9-9ece90247197"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"237.180836`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"fad3762d-55e0-404e-8e3f-c076303ae109"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:26:47\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"d254fbe4-230b-4a6f-9dc6-c171f24e9ba6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"235.88365`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"9b6e59c8-179b-4326-a47f-b1615e361f07"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:26:54\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"c4c024b5-87f0-4970-8cd7-2f63865c1805"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"230.583645`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"58c603db-572a-451f-8104-ffd828e6227e"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:26:58\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"5cf6edea-164e-40ef-960a-9cf0d54e2a64"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"228.564646`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"540633c2-e61a-4a57-8229-9ce196746dda"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:26:59\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"93d855b1-205b-47b4-887a-00adbac36769"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"226.843732`", ",", "Null"}], "}"}]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"0aaf7c37-7b94-4a3b-992d-4239145c3ead"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:27:06\"\>"], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 ShowCellLabel->True,ExpressionUUID->"3227686c-15c2-4893-87d9-c8363da46cf9"],

Cell[BoxData["\<\"Sat 26 Sep 2015 02:27:06\"\>"], "Output",
 CellGroupingRules->{
  GroupTogetherGrouping, 
   10000.},ExpressionUUID->"4dfccccf-c4c5-4d30-9ee4-7f3004800fa0"]
}, Closed]],

Cell["The results can be pulled in from the files using this:", \
"Text",ExpressionUUID->"d891dc63-f695-4d4d-aa27-98f0ccc51f67"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"detunedDipole", "[", "\[Delta]", "]"}], "=", 
    RowBox[{"ReadList", "[", 
     RowBox[{"filename", "[", "\[Delta]", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Delta]", ",", "\[Delta]Range"}], "}"}]}], 
  "]"}]], "Input",ExpressionUUID->"4c226823-e50f-4780-912b-d04a92186a10"],

Cell["Or saved into a single location using this:", \
"Text",ExpressionUUID->"b744ed70-2d30-4db5-bee0-2b83f2d22058"],

Cell[BoxData[
 RowBox[{"Save", "[", 
  RowBox[{
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", 
      "\"\<Detuning scan collected data.txt\>\""}], "}"}], "]"}], ",", 
   "detunedDipole"}], 
  "]"}]], "Input",ExpressionUUID->"9a37a53b-fd86-482a-9e6e-3774ad1c6b9b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], ",", 
       "\"\<Detuning scan collected data.mx\>\""}], "}"}], "]"}], ",", 
    "detunedDipole"}], "]"}], 
  ";"}]], "Input",ExpressionUUID->"c5b9d626-b53f-4411-8f99-805dbefbf595"],

Cell["and pulled in from the single location using this:", \
"Text",ExpressionUUID->"273b34ad-408e-4e9c-96a1-f3869f4a311b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", 
   RowBox[{"(", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], ",", 
       "\"\<Detuning scan collected data.txt\>\""}], "}"}], "]"}], ")"}]}], 
  ";"}]], "Input",ExpressionUUID->"a13eaa9a-669d-49ce-b8f8-fe72b1a186da"],

Cell["A sample spectrum looks like this:", \
"Text",ExpressionUUID->"c7065e6b-aa3e-4903-8136-b9485a8ddfe9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"biColorSpectrum", "[", 
  RowBox[{
   RowBox[{"detunedDipole", "[", 
    RowBox[{"0.001", 
     RowBox[{"RandomInteger", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1000"}], "}"}], "]"}]}], "]"}], ",", 
   RowBox[{"CarrierFrequency", "\[Rule]", 
    RowBox[{"45.6", "/", "800"}]}], ",", 
   RowBox[{"TotalCycles", "\[Rule]", "3"}], ",", 
   RowBox[{"PointsPerCycle", "\[Rule]", "115"}]}], 
  "]"}]], "Input",ExpressionUUID->"72e0f3c7-cb0e-497a-822a-29b8ecb4dde5"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[0.004583333333333334], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw0WndcjV8Y19JQtPe4u31727v73Lr31r1RScjKpqySRBRRRiSFkLIlZP8Q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       "]]}}, {}}, {{}, {{}, {}, 
     {RGBColor[0, 0, 1], PointSize[0.004583333333333334], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw0Wnc81G8cp5Co7M25bR2+9nYf5ziO8ivtvUhLSCpUGpraU0NFiVLSoKUe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       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->800,
  Method->{},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.02]}},
  Ticks->{
   Automatic, 
    Automatic}]], \
"Output",ExpressionUUID->"2df9edf2-e2db-49cf-9235-686d4fe78536"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots from the original paper", \
"Subsubsection",ExpressionUUID->"d8dbef79-d5d0-412b-887c-ad8a227c5ebe"],

Cell["\<\
The plots from the original paper were produced using the code below. For \
simplicity we pre-define an interpolation function.\
\>", "Text",ExpressionUUID->"1845bcd3-4c17-4c87-a706-45aa09e1dd04"],

Cell[BoxData[
 RowBox[{"conditions", ":=", 
  RowBox[{"Sequence", "[", 
   RowBox[{
    RowBox[{"CarrierFrequency", "\[Rule]", 
     RowBox[{"45.6", "/", "800"}]}], ",", 
    RowBox[{"TotalCycles", "\[Rule]", "26"}], ",", 
    RowBox[{"PointsPerCycle", "\[Rule]", "115"}]}], 
   "]"}]}]], "Input",ExpressionUUID->"d8210f02-e853-4f99-a97d-0a92834c531b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Remove", "[", "detuningInterpolation", "]"}], "\n", 
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"length", "=", 
     RowBox[{"Length", "[", 
      RowBox[{"getSpectrum", "[", 
       RowBox[{
        RowBox[{"detunedDipole", "[", "0.", "]"}], ",", 
        RowBox[{"Polarization", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"1", ",", "\[ImaginaryI]"}], "}"}]}]}], "]"}], "]"}]}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"detuningInterpolation", "[", "\[Epsilon]", "]"}], "=", 
        RowBox[{"Interpolation", "[", "\[IndentingNewLine]", 
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"harmonicOrderAxis", "[", 
                    RowBox[{
                    RowBox[{"TargetLength", "\[Rule]", "length"}], ",", 
                    "conditions"}], "]"}], ",", "\[IndentingNewLine]", 
                   RowBox[{"Table", "[", 
                    RowBox[{"\[Delta]", ",", 
                    RowBox[{"{", "length", "}"}]}], "]"}]}], 
                  "\[IndentingNewLine]", "}"}], "\[Transpose]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Log", "[", 
                 RowBox[{"10", ",", 
                  RowBox[{"getSpectrum", "[", 
                   RowBox[{
                    RowBox[{"detunedDipole", "[", "\[Delta]", "]"}], ",", 
                    RowBox[{"Polarization", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"\[Epsilon]", " ", "\[ImaginaryI]"}]}], "}"}]}]}],
                    "]"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], 
              "\[Transpose]"}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"\[Delta]", ",", "\[Delta]Range"}], "}"}]}], "]"}], ",",
            "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], "]"}], ";"}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
  "]"}]}], "Input",ExpressionUUID->"e8345a27-9a77-44c1-b02f-80a83b799449"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.998286`", ",", "Null"}], 
  "}"}]], "Output",ExpressionUUID->"15fd4d0b-604e-45ae-ac20-eccec13bddf3"]
}, Open  ]],

Cell["Some plotting admin:", \
"Text",ExpressionUUID->"c8331cc7-a94d-465c-9b6d-945b2c04896a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CMRmap", "=", 
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Blend", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            RowBox[{
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[0., 0., 0.], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              FrameStyle->RGBColor[0., 0., 0.],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None], "\[InvisibleSpace]"}],
            "RGBColor[{0., 0., 0.}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[0., 0., 0.]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[{0., 0., 0.}],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            RowBox[{
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[0.15, 0.15, 0.5], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              FrameStyle->RGBColor[0.1, 0.1, 0.33333333333333337`],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None], "\[InvisibleSpace]"}],
            "RGBColor[{0.15, 0.15, 0.5}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[0.15, 0.15, 0.5]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[{0.15, 0.15, 0.5}],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            RowBox[{
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[0.3, 0.15, 0.75], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              FrameStyle->RGBColor[0.2, 0.1, 0.5],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None], "\[InvisibleSpace]"}],
            "RGBColor[{0.3, 0.15, 0.75}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[0.3, 0.15, 0.75]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[{0.3, 0.15, 0.75}],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            RowBox[{
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[0.6, 0.2, 0.5], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.4, 0.13333333333333336`, 0.33333333333333337`],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None], "\[InvisibleSpace]"}],
            "RGBColor[{0.6, 0.2, 0.5}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[0.6, 0.2, 0.5]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[{0.6, 0.2, 0.5}],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            RowBox[{
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[1., 0.25, 0.15], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.6666666666666667, 0.16666666666666669`, 0.1],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None], "\[InvisibleSpace]"}],
            "RGBColor[{1., 0.25, 0.15}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[1., 0.25, 0.15]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[{1., 0.25, 0.15}],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            RowBox[{
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[0.9, 0.5, 0.], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.6000000000000001, 0.33333333333333337`, 0.],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None], "\[InvisibleSpace]"}],
            "RGBColor[{0.9, 0.5, 0.}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[0.9, 0.5, 0.]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[{0.9, 0.5, 0.}],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            RowBox[{
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[0.9, 0.75, 0.1], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.6000000000000001, 0.5, 0.06666666666666668],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None], "\[InvisibleSpace]"}],
            "RGBColor[{0.9, 0.75, 0.1}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[0.9, 0.75, 0.1]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[{0.9, 0.75, 0.1}],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            RowBox[{
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[0.9, 0.9, 0.5], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.6000000000000001, 0.6000000000000001, 0.33333333333333337`],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None], "\[InvisibleSpace]"}],
            "RGBColor[{0.9, 0.9, 0.5}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[0.9, 0.9, 0.5]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[{0.9, 0.9, 0.5}],
          Editable->False,
          Selectable->False], ",", 
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            RowBox[{
             GraphicsBox[{
               {GrayLevel[0], RectangleBox[{0, 0}]}, 
               {GrayLevel[0], RectangleBox[{1, -1}]}, 
               {RGBColor[1., 1., 1.], RectangleBox[{0, -1}, {2, 1}]}},
              AspectRatio->1,
              Frame->True,
              
              FrameStyle->RGBColor[
               0.6666666666666667, 0.6666666666666667, 0.6666666666666667],
              FrameTicks->None,
              
              ImageSize->
               Dynamic[{
                Automatic, 
                 1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}],
              PlotRangePadding->None], "\[InvisibleSpace]"}],
            "RGBColor[{1., 1., 1.}]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = 
               RGBColor[1., 1., 1.]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[{1., 1., 1.}],
          Editable->False,
          Selectable->False]}], "}"}], ",", "x"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CMRwithMin", "[", 
   RowBox[{"minIn_", ",", 
    RowBox[{"minOut_:", 
     RowBox[{"1.", "/", "9"}]}]}], "]"}], ":=", 
  RowBox[{"Function", "[", 
   RowBox[{"x", ",", 
    RowBox[{"CMRmap", "[", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "<", "minIn"}], ",", 
       RowBox[{
        FractionBox["minOut", "minIn"], "x"}], ",", 
       RowBox[{"minOut", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "minOut"}], ")"}], 
         FractionBox[
          RowBox[{"x", "-", "minIn"}], 
          RowBox[{"1", "-", "minIn"}]]}]}]}], "]"}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"min", "=", 
   RowBox[{"6.", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "9"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"max", "=", 
   RowBox[{"5.", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "7"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"colorfunction", "=", 
   RowBox[{"CMRwithMin", "[", 
    RowBox[{"min", "/", "max"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HOTicks", "[", "\[Epsilon]_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"\[Epsilon]", "\[Equal]", "1"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{"#", ",", "Black"}], "]"}], ",", "\"\<\>\""}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.02", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Gray"}], "}"}]}], 
       "}"}], "&"}], "/@", 
     RowBox[{"Range", "[", 
      RowBox[{"12", ",", "18", ",", "1"}], "]"}]}], ")"}], "~", "Join", "~", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", "\"\<\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"0.01", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.004", "]"}], ",", "Gray"}], "}"}]}], 
       "}"}], "&"}], "/@", 
     RowBox[{"Range", "[", 
      RowBox[{
       RowBox[{"11", "+", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{"18", "+", 
        FractionBox["1", "4"]}], ",", 
       RowBox[{"1", "/", "4"}]}], "]"}]}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"downTicks", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"Style", "[", 
         RowBox[{"0", ",", "Black"}], "]"}], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.25", ",", 
        RowBox[{"Style", "[", 
         RowBox[{"0.25", ",", "Black"}], "]"}], ",", "0"}], "}"}]}], "}"}], 
    "~", "Join", "~", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", 
         RowBox[{"Style", "[", 
          RowBox[{"#", ",", "Black"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.015", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Gray"}], "}"}]}], 
        "}"}], "&"}], "/@", 
      RowBox[{"Range", "[", 
       RowBox[{"0.05", ",", "0.20", ",", "0.05"}], "]"}]}], ")"}], "~", 
    "Join", "~", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", "\"\<\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"0.01", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.004", "]"}], ",", "Gray"}], "}"}]}], 
        "}"}], "&"}], "/@", 
      RowBox[{"Range", "[", 
       RowBox[{"0.01", ",", "0.24", ",", "0.01"}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"upTicks", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", "\"\<\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"0.015", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Gray"}], "}"}]}], 
        "}"}], "&"}], "/@", 
      RowBox[{"Range", "[", 
       RowBox[{"0.05", ",", "0.20", ",", "0.05"}], "]"}]}], ")"}], "~", 
    "Join", "~", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", "\"\<\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"0.01", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thickness", "[", "0.004", "]"}], ",", "Gray"}], "}"}]}], 
        "}"}], "&"}], "/@", 
      RowBox[{"Range", "[", 
       RowBox[{"0.01", ",", "0.24", ",", "0.01"}], "]"}]}], ")"}]}]}], 
  ";"}]}], "Input",ExpressionUUID->"95cef9e3-2e0a-4029-beb4-c85d58bf4836"],

Cell["\<\

The plot itself:\
\>", "Text",ExpressionUUID->"850f1ab3-0554-48b4-920e-7d7fc71b5836"],

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{"Table", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"splittingsScan", "[", "\[Epsilon]", "]"}], "=", 
     RowBox[{"RegionPlot", "[", "\[IndentingNewLine]", 
      RowBox[{"True", "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"\[Delta]", ",", "0", ",", "0.25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"HO", ",", "11.25", ",", "18.5"}], "}"}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1.2"}], "\[IndentingNewLine]", ",", 
       RowBox[{"PlotRangePadding", "\[Rule]", "None"}], "\[IndentingNewLine]",
        ",", 
       RowBox[{"ImagePadding", "\[Rule]", 
        RowBox[{"1", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"35", "+", 
              RowBox[{"15", "\[Epsilon]"}]}], ",", "20"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"70", ",", "6"}], "}"}]}], "}"}]}]}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "550"}], "}"}]}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"PlotPoints", "\[Rule]", "600"}], "\[IndentingNewLine]", ",", 
       RowBox[{"FrameStyle", "\[Rule]", "Automatic"}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<\!\(\*FractionBox[\(\[Omega]'\), \(\[Omega]\)]\)-1\>\"", ",", 
            "Black", ",", "12"}], "]"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"\[Epsilon]", "\[Equal]", "1"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Harmonic Order\>\"", ",", "Black", ",", "16"}], 
             "]"}], ",", "\"\<\>\""}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"HOTicks", "[", "1", "]"}], ",", 
            RowBox[{"HOTicks", "[", 
             RowBox[{"-", "1"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"downTicks", ",", "upTicks"}], "}"}]}], "}"}]}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\[Delta]", ",", "HO"}], "}"}], ",", 
          RowBox[{"colorfunction", "[", 
           FractionBox[
            RowBox[{"10", "^", 
             RowBox[{
              RowBox[{"detuningInterpolation", "[", "\[Epsilon]", "]"}], "[", 
              RowBox[{"HO", ",", "\[Delta]"}], "]"}]}], "max"], "]"}]}], 
         "]"}]}], "\[IndentingNewLine]", ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{"StringJoin", "[", 
           RowBox[{
            RowBox[{"\[Epsilon]", "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "\[Rule]", "\"\<Right\>\""}], ",", 
               RowBox[{
                RowBox[{"-", "1"}], "\[Rule]", "\"\<Left\>\""}]}], "}"}]}], 
            ",", "\"\<-circular harmonics\>\""}], "]"}], ",", "Black", ",", 
          "16"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"01f39f23-a7a1-4d2d-962e-113253a56b56"],

Cell["(Removed to keep file size low.)", \
"Text",ExpressionUUID->"17775216-f6fd-4712-a56b-9182e5f87a02"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1536, 781},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{None, None, 
   Cell[
    TextData[{
     "RB", "-", "SFA", ":", " ", "Rotating", " ", "Bicircular", " ", "HHG", 
      " ", "in", " ", "the", " ", "Strong", " ", "Field", " ", 
      "Approximation", "|", "   ", 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {None, None, 
   Cell[
    TextData[{
     "RB", "-", "SFA", ":", " ", "Rotating", " ", "Bicircular", " ", "HHG", 
      " ", "in", " ", "the", " ", "Strong", " ", "Field", " ", 
      "Approximation", "|", "   ", 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.75, 842.25},
"PostScriptOutputFile"->"~/Desktop/print.pdf",
"PrintingMargins"->{{19.84251968503, 19.84251968503}, {72., 72.}}},
PrivateNotebookOptions->{"FileOutlineCache"->False},
ShowSelection->True,
TrackCellChangeTimes->False,
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 10, 2017)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Code"], FontWeight -> "Plain", FontSlant -> "Plain", 
    FontTracking -> "Plain", 
    FontVariations -> {
     "Outline" -> False, "Shadow" -> False, "StrikeThrough" -> False, 
      "Underline" -> False}]}, Visible -> False, FrontEndVersion -> 
  "11.2 for Microsoft Windows (64-bit) (September 10, 2017)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]

